# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/anon_output_with_report.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/anon_output_with_report.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+zetasql/proto/anon_output_with_report.proto\x12\x07zetasql\"\xc3\x01\n\x14\x41nonOutputWithReport\x12)\n\x05value\x18\x01 \x01(\x0b\x32\x18.zetasql.AnonOutputValueH\x00\x12+\n\x06values\x18\x02 \x01(\x0b\x32\x19.zetasql.AnonOutputValuesH\x00\x12\x35\n\x0f\x62ounding_report\x18\x03 \x01(\x0b\x32\x17.zetasql.BoundingReportH\x01\x88\x01\x01\x42\x08\n\x06resultB\x12\n\x10_bounding_report\"\xea\x01\n\x0e\x42oundingReport\x12\x32\n\x0blower_bound\x18\x01 \x01(\x0b\x32\x18.zetasql.AnonOutputValueH\x00\x88\x01\x01\x12\x32\n\x0bupper_bound\x18\x02 \x01(\x0b\x32\x18.zetasql.AnonOutputValueH\x01\x88\x01\x01\x12\x17\n\nnum_inputs\x18\x03 \x01(\x01H\x02\x88\x01\x01\x12\x18\n\x0bnum_outside\x18\x04 \x01(\x01H\x03\x88\x01\x01\x42\x0e\n\x0c_lower_boundB\x0e\n\x0c_upper_boundB\r\n\x0b_num_inputsB\x0e\n\x0c_num_outside\"\xa1\x01\n\x17NoiseConfidenceInterval\x12\x18\n\x0blower_bound\x18\x01 \x01(\x01H\x00\x88\x01\x01\x12\x18\n\x0bupper_bound\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12\x1d\n\x10\x63onfidence_level\x18\x03 \x01(\x01H\x02\x88\x01\x01\x42\x0e\n\x0c_lower_boundB\x0e\n\x0c_upper_boundB\x13\n\x11_confidence_level\"<\n\x10\x41nonOutputValues\x12(\n\x06values\x18\x01 \x03(\x0b\x32\x18.zetasql.AnonOutputValue\"\xc6\x01\n\x0f\x41nonOutputValue\x12\x13\n\tint_value\x18\x01 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x02 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x03 \x01(\tH\x00\x12H\n\x19noise_confidence_interval\x18\x04 \x01(\x0b\x32 .zetasql.NoiseConfidenceIntervalH\x01\x88\x01\x01\x42\x07\n\x05valueB\x1c\n\x1a_noise_confidence_intervalB1\n\x12\x63om.google.zetasqlB\x1bZetaSQLAnonOutputWithReportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.anon_output_with_report_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033ZetaSQLAnonOutputWithReport'
  _globals['_ANONOUTPUTWITHREPORT']._serialized_start=57
  _globals['_ANONOUTPUTWITHREPORT']._serialized_end=252
  _globals['_BOUNDINGREPORT']._serialized_start=255
  _globals['_BOUNDINGREPORT']._serialized_end=489
  _globals['_NOISECONFIDENCEINTERVAL']._serialized_start=492
  _globals['_NOISECONFIDENCEINTERVAL']._serialized_end=653
  _globals['_ANONOUTPUTVALUES']._serialized_start=655
  _globals['_ANONOUTPUTVALUES']._serialized_end=715
  _globals['_ANONOUTPUTVALUE']._serialized_start=718
  _globals['_ANONOUTPUTVALUE']._serialized_end=916
# @@protoc_insertion_point(module_scope)
