# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/compliance/known_error.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/compliance/known_error.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/compliance/known_error.proto\x12\x07zetasql\"t\n\x0fKnownErrorEntry\x12\x42\n\x04mode\x18\x03 \x01(\x0e\x32\x17.zetasql.KnownErrorMode:\x1b\x41LLOW_ERROR_OR_WRONG_ANSWER\x12\x0e\n\x06reason\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x03(\t\"W\n\x0eKnownErrorFile\x12\x15\n\rcontact_email\x18\x01 \x03(\t\x12.\n\x0cknown_errors\x18\x02 \x03(\x0b\x32\x18.zetasql.KnownErrorEntry*}\n\x0eKnownErrorMode\x12\x08\n\x04NONE\x10\x00\x12\x17\n\x13\x41LLOW_UNIMPLEMENTED\x10\n\x12\x0f\n\x0b\x41LLOW_ERROR\x10\x14\x12\x1f\n\x1b\x41LLOW_ERROR_OR_WRONG_ANSWER\x10\x1e\x12\x16\n\x12\x43RASHES_DO_NOT_RUN\x10\x64')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.compliance.known_error_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_KNOWNERRORMODE']._serialized_start=256
  _globals['_KNOWNERRORMODE']._serialized_end=381
  _globals['_KNOWNERRORENTRY']._serialized_start=49
  _globals['_KNOWNERRORENTRY']._serialized_end=165
  _globals['_KNOWNERRORFILE']._serialized_start=167
  _globals['_KNOWNERRORFILE']._serialized_end=254
# @@protoc_insertion_point(module_scope)
