# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/array_find_mode.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/array_find_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.zetasql/public/functions/array_find_mode.proto\x12\x11zetasql.functions\x1a\x19zetasql/public/type.proto\"v\n\x0e\x41rrayFindEnums\"d\n\rArrayFindMode\x12%\n\x17\x41RRAY_FIND_MODE_INVALID\x10\x00\x1a\x08\xb2\xf2\xb0\x92\x0e\x02\x08\x01\x12\t\n\x05\x46IRST\x10\x01\x12\x08\n\x04LAST\x10\x02\x1a\x17\xb2\xd0\xaf\xfa\r\x11\n\x0f\x41RRAY_FIND_MODEB4\n\x1c\x63om.google.zetasql.functionsB\x14ZetaSQLArrayFindMode')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.array_find_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\024ZetaSQLArrayFindMode'
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE']._loaded_options = None
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE']._serialized_options = b'\262\320\257\372\r\021\n\017ARRAY_FIND_MODE'
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE'].values_by_name["ARRAY_FIND_MODE_INVALID"]._loaded_options = None
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE'].values_by_name["ARRAY_FIND_MODE_INVALID"]._serialized_options = b'\262\362\260\222\016\002\010\001'
  _globals['_ARRAYFINDENUMS']._serialized_start=96
  _globals['_ARRAYFINDENUMS']._serialized_end=214
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE']._serialized_start=114
  _globals['_ARRAYFINDENUMS_ARRAYFINDMODE']._serialized_end=214
# @@protoc_insertion_point(module_scope)
