# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/simple_property_graph.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/simple_property_graph.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)zetasql/proto/simple_property_graph.proto\x12\x07zetasql\x1a\x19zetasql/public/type.proto\"\xb7\x02\n\x18SimplePropertyGraphProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tname_path\x18\x02 \x03(\t\x12:\n\x0bnode_tables\x18\x03 \x03(\x0b\x32%.zetasql.SimpleGraphElementTableProto\x12:\n\x0b\x65\x64ge_tables\x18\x04 \x03(\x0b\x32%.zetasql.SimpleGraphElementTableProto\x12\x35\n\x06labels\x18\x05 \x03(\x0b\x32%.zetasql.SimpleGraphElementLabelProto\x12K\n\x15property_declarations\x18\x06 \x03(\x0b\x32,.zetasql.SimpleGraphPropertyDeclarationProto\"\xef\x04\n\x1cSimpleGraphElementTableProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12\x38\n\x04kind\x18\x03 \x01(\x0e\x32*.zetasql.SimpleGraphElementTableProto.Kind\x12\x18\n\x10input_table_name\x18\x04 \x01(\t\x12\x17\n\x0bkey_columns\x18\x05 \x03(\x05\x42\x02\x10\x01\x12\x13\n\x0blabel_names\x18\x06 \x03(\t\x12I\n\x14property_definitions\x18\x07 \x03(\x0b\x32+.zetasql.SimpleGraphPropertyDefinitionProto\x12\x46\n\x11source_node_table\x18\x08 \x01(\x0b\x32+.zetasql.SimpleGraphNodeTableReferenceProto\x12\x44\n\x0f\x64\x65st_node_table\x18\t \x01(\x0b\x32+.zetasql.SimpleGraphNodeTableReferenceProto\x12M\n\x12\x64ynamic_properties\x18\n \x01(\x0b\x32\x31.zetasql.SimpleGraphElementDynamicPropertiesProto\x12\x43\n\rdynamic_label\x18\x0b \x01(\x0b\x32,.zetasql.SimpleGraphElementDynamicLabelProto\"0\n\x04Kind\x12\x14\n\x10KIND_UNSPECIFIED\x10\x00\x12\x08\n\x04NODE\x10\x01\x12\x08\n\x04\x45\x44GE\x10\x02\"r\n\x1cSimpleGraphElementLabelProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12\"\n\x1aproperty_declaration_names\x18\x03 \x03(\t\"}\n\"SimpleGraphNodeTableReferenceProto\x12\x17\n\x0fnode_table_name\x18\x01 \x01(\t\x12\x1e\n\x12\x65\x64ge_table_columns\x18\x02 \x03(\x05\x42\x02\x10\x01\x12\x1e\n\x12node_table_columns\x18\x03 \x03(\x05\x42\x02\x10\x01\"w\n#SimpleGraphPropertyDeclarationProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x18property_graph_name_path\x18\x02 \x03(\t\x12 \n\x04type\x18\x03 \x01(\x0b\x32\x12.zetasql.TypeProto\"e\n\"SimpleGraphPropertyDefinitionProto\x12!\n\x19property_declaration_name\x18\x01 \x01(\t\x12\x1c\n\x14value_expression_sql\x18\x02 \x01(\t\"I\n(SimpleGraphElementDynamicPropertiesProto\x12\x1d\n\x15properties_expression\x18\x01 \x01(\t\"?\n#SimpleGraphElementDynamicLabelProto\x12\x18\n\x10label_expression\x18\x01 \x01(\tB/\n\x12\x63om.google.zetasqlB\x19SimplePropertyGraphProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.simple_property_graph_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\031SimplePropertyGraphProtos'
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO'].fields_by_name['key_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO'].fields_by_name['key_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['edge_table_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['edge_table_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['node_table_columns']._loaded_options = None
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO'].fields_by_name['node_table_columns']._serialized_options = b'\020\001'
  _globals['_SIMPLEPROPERTYGRAPHPROTO']._serialized_start=82
  _globals['_SIMPLEPROPERTYGRAPHPROTO']._serialized_end=393
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO']._serialized_start=396
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO']._serialized_end=1019
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO_KIND']._serialized_start=971
  _globals['_SIMPLEGRAPHELEMENTTABLEPROTO_KIND']._serialized_end=1019
  _globals['_SIMPLEGRAPHELEMENTLABELPROTO']._serialized_start=1021
  _globals['_SIMPLEGRAPHELEMENTLABELPROTO']._serialized_end=1135
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO']._serialized_start=1137
  _globals['_SIMPLEGRAPHNODETABLEREFERENCEPROTO']._serialized_end=1262
  _globals['_SIMPLEGRAPHPROPERTYDECLARATIONPROTO']._serialized_start=1264
  _globals['_SIMPLEGRAPHPROPERTYDECLARATIONPROTO']._serialized_end=1383
  _globals['_SIMPLEGRAPHPROPERTYDEFINITIONPROTO']._serialized_start=1385
  _globals['_SIMPLEGRAPHPROPERTYDEFINITIONPROTO']._serialized_end=1486
  _globals['_SIMPLEGRAPHELEMENTDYNAMICPROPERTIESPROTO']._serialized_start=1488
  _globals['_SIMPLEGRAPHELEMENTDYNAMICPROPERTIESPROTO']._serialized_end=1561
  _globals['_SIMPLEGRAPHELEMENTDYNAMICLABELPROTO']._serialized_start=1563
  _globals['_SIMPLEGRAPHELEMENTDYNAMICLABELPROTO']._serialized_end=1626
# @@protoc_insertion_point(module_scope)
