from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ResolvedNodeKind(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    RESOLVED_LITERAL: _ClassVar[ResolvedNodeKind]
    RESOLVED_PARAMETER: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXPRESSION_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_CATALOG_COLUMN_REF: _ClassVar[ResolvedNodeKind]
    RESOLVED_COLUMN_REF: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUPING_SET_MULTI_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_CONSTANT: _ClassVar[ResolvedNodeKind]
    RESOLVED_SYSTEM_VARIABLE: _ClassVar[ResolvedNodeKind]
    RESOLVED_INLINE_LAMBDA: _ClassVar[ResolvedNodeKind]
    RESOLVED_SEQUENCE: _ClassVar[ResolvedNodeKind]
    RESOLVED_FILTER_FIELD_ARG: _ClassVar[ResolvedNodeKind]
    RESOLVED_FILTER_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_FUNCTION_CALL: _ClassVar[ResolvedNodeKind]
    RESOLVED_AGGREGATE_FUNCTION_CALL: _ClassVar[ResolvedNodeKind]
    RESOLVED_ANALYTIC_FUNCTION_CALL: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXTENDED_CAST_ELEMENT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXTENDED_CAST: _ClassVar[ResolvedNodeKind]
    RESOLVED_CAST: _ClassVar[ResolvedNodeKind]
    RESOLVED_MAKE_STRUCT: _ClassVar[ResolvedNodeKind]
    RESOLVED_MAKE_PROTO: _ClassVar[ResolvedNodeKind]
    RESOLVED_MAKE_PROTO_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_GET_STRUCT_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_GET_PROTO_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_GET_JSON_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_GET_ROW_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_FLATTEN: _ClassVar[ResolvedNodeKind]
    RESOLVED_FLATTENED_ARG: _ClassVar[ResolvedNodeKind]
    RESOLVED_REPLACE_FIELD_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_REPLACE_FIELD: _ClassVar[ResolvedNodeKind]
    RESOLVED_GET_PROTO_ONEOF: _ClassVar[ResolvedNodeKind]
    RESOLVED_SUBQUERY_EXPR: _ClassVar[ResolvedNodeKind]
    RESOLVED_WITH_EXPR: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXECUTE_AS_ROLE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_MODEL: _ClassVar[ResolvedNodeKind]
    RESOLVED_CONNECTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_DESCRIPTOR: _ClassVar[ResolvedNodeKind]
    RESOLVED_SINGLE_ROW_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_UNSET_ARGUMENT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_TABLE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_JOIN_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ARRAY_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_COLUMN_HOLDER: _ClassVar[ResolvedNodeKind]
    RESOLVED_FILTER_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUPING_CALL: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUPING_SET_LIST: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUPING_SET_PRODUCT: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUPING_SET: _ClassVar[ResolvedNodeKind]
    RESOLVED_ROLLUP: _ClassVar[ResolvedNodeKind]
    RESOLVED_CUBE: _ClassVar[ResolvedNodeKind]
    RESOLVED_AGGREGATE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ANONYMIZED_AGGREGATE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_DIFFERENTIAL_PRIVACY_AGGREGATE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_AGGREGATION_THRESHOLD_AGGREGATE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_OPERATION_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_OPERATION_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ORDER_BY_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_LIMIT_OFFSET_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_WITH_REF_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ANALYTIC_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_SAMPLE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_COMPUTED_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_DEFERRED_COMPUTED_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ORDER_BY_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_COLUMN_ANNOTATIONS: _ClassVar[ResolvedNodeKind]
    RESOLVED_GENERATED_COLUMN_INFO: _ClassVar[ResolvedNodeKind]
    RESOLVED_COLUMN_DEFAULT_VALUE: _ClassVar[ResolvedNodeKind]
    RESOLVED_COLUMN_DEFINITION: _ClassVar[ResolvedNodeKind]
    RESOLVED_PRIMARY_KEY: _ClassVar[ResolvedNodeKind]
    RESOLVED_FOREIGN_KEY: _ClassVar[ResolvedNodeKind]
    RESOLVED_CHECK_CONSTRAINT: _ClassVar[ResolvedNodeKind]
    RESOLVED_OUTPUT_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_OUTPUT_SCHEMA: _ClassVar[ResolvedNodeKind]
    RESOLVED_PROJECT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_TVFSCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GROUP_ROWS_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_FUNCTION_ARGUMENT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXPLAIN_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_STATEMENT_WITH_PIPE_OPERATORS_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_QUERY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_GENERALIZED_QUERY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_MULTI_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_WITH_ENTRY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_DATABASE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_INDEX_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_UNNEST_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_INDEX_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_SCHEMA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_EXTERNAL_SCHEMA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_TABLE_AS_SELECT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_MODEL_ALIASED_QUERY: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_MODEL_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_WITH_PARTITION_COLUMNS: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_SNAPSHOT_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_EXTERNAL_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXPORT_MODEL_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXPORT_DATA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXPORT_METADATA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DEFINE_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DESCRIBE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_SHOW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_BEGIN_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_TRANSACTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_COMMIT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ROLLBACK_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_START_BATCH_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_RUN_BATCH_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ABORT_BATCH_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_MATERIALIZED_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_SNAPSHOT_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_RECURSIVE_REF_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_RECURSION_DEPTH_MODIFIER: _ClassVar[ResolvedNodeKind]
    RESOLVED_RECURSIVE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_WITH_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_WITH_ENTRY: _ClassVar[ResolvedNodeKind]
    RESOLVED_OPTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_WINDOW_PARTITIONING: _ClassVar[ResolvedNodeKind]
    RESOLVED_WINDOW_ORDERING: _ClassVar[ResolvedNodeKind]
    RESOLVED_WINDOW_FRAME: _ClassVar[ResolvedNodeKind]
    RESOLVED_ANALYTIC_FUNCTION_GROUP: _ClassVar[ResolvedNodeKind]
    RESOLVED_WINDOW_FRAME_EXPR: _ClassVar[ResolvedNodeKind]
    RESOLVED_DMLVALUE: _ClassVar[ResolvedNodeKind]
    RESOLVED_DMLDEFAULT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ASSERT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ASSERT_ROWS_MODIFIED: _ClassVar[ResolvedNodeKind]
    RESOLVED_ON_CONFLICT_CLAUSE: _ClassVar[ResolvedNodeKind]
    RESOLVED_INSERT_ROW: _ClassVar[ResolvedNodeKind]
    RESOLVED_INSERT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DELETE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_UPDATE_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_UPDATE_ITEM_ELEMENT: _ClassVar[ResolvedNodeKind]
    RESOLVED_UPDATE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_MERGE_WHEN: _ClassVar[ResolvedNodeKind]
    RESOLVED_MERGE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_TRUNCATE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_OBJECT_UNIT: _ClassVar[ResolvedNodeKind]
    RESOLVED_PRIVILEGE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRANT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_REVOKE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_DATABASE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_INDEX_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_MATERIALIZED_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_APPROX_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_SCHEMA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_EXTERNAL_SCHEMA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_MODEL_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_TABLE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_OPTIONS_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_SUB_ENTITY_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ADD_SUB_ENTITY_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_SUB_ENTITY_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ADD_COLUMN_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ADD_COLUMN_IDENTIFIER_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_REBUILD_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ADD_CONSTRAINT_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_CONSTRAINT_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_PRIMARY_KEY_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_OPTIONS_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_DROP_NOT_NULL_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_DROP_GENERATED_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_SET_GENERATED_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_SET_DATA_TYPE_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_SET_DEFAULT_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_COLUMN_DROP_DEFAULT_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_COLUMN_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_RENAME_COLUMN_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_AS_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_SET_COLLATE_CLAUSE: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_TABLE_SET_OPTIONS_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_RENAME_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_PRIVILEGE_RESTRICTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_ROW_ACCESS_POLICY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_PRIVILEGE_RESTRICTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_ROW_ACCESS_POLICY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_INDEX_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRANT_TO_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_RESTRICT_TO_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ADD_TO_RESTRICTEE_LIST_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_REMOVE_FROM_RESTRICTEE_LIST_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_FILTER_USING_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_REVOKE_FROM_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_RENAME_TO_ACTION: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_PRIVILEGE_RESTRICTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_ROW_ACCESS_POLICY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_ALL_ROW_ACCESS_POLICIES_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_CONSTANT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_FUNCTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ARGUMENT_DEF: _ClassVar[ResolvedNodeKind]
    RESOLVED_ARGUMENT_REF: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_TABLE_FUNCTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_RELATION_ARGUMENT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ARGUMENT_LIST: _ClassVar[ResolvedNodeKind]
    RESOLVED_FUNCTION_SIGNATURE_HOLDER: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_FUNCTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_DROP_TABLE_FUNCTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CALL_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_IMPORT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_MODULE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_AGGREGATE_HAVING_MODIFIER: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_MATERIALIZED_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_APPROX_VIEW_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_PROCEDURE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXECUTE_IMMEDIATE_ARGUMENT: _ClassVar[ResolvedNodeKind]
    RESOLVED_EXECUTE_IMMEDIATE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ASSIGNMENT_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_ENTITY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_ENTITY_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIVOT_COLUMN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIVOT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_RETURNING_CLAUSE: _ClassVar[ResolvedNodeKind]
    RESOLVED_UNPIVOT_ARG: _ClassVar[ResolvedNodeKind]
    RESOLVED_UNPIVOT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_MEASURE_GROUP: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_VARIABLE_DEFINITION: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_PATTERN_EMPTY: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_PATTERN_ANCHOR: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_PATTERN_VARIABLE_REF: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_PATTERN_OPERATION: _ClassVar[ResolvedNodeKind]
    RESOLVED_MATCH_RECOGNIZE_PATTERN_QUANTIFICATION: _ClassVar[ResolvedNodeKind]
    RESOLVED_CLONE_DATA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_TABLE_AND_COLUMN_INFO: _ClassVar[ResolvedNodeKind]
    RESOLVED_ANALYZE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_AUX_LOAD_DATA_PARTITION_FILTER: _ClassVar[ResolvedNodeKind]
    RESOLVED_AUX_LOAD_DATA_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_PROPERTY_GRAPH_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_ELEMENT_TABLE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_NODE_TABLE_REFERENCE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_ELEMENT_LABEL: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PROPERTY_DECLARATION: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PROPERTY_DEFINITION: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_DYNAMIC_LABEL_SPECIFICATION: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_DYNAMIC_PROPERTIES_SPECIFICATION: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_REF_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_LINEAR_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_TABLE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_CALL_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PATH_PATTERN_QUANTIFIER: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PATH_SEARCH_PREFIX: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_NODE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_EDGE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_GET_ELEMENT_PROPERTY: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_LABEL_NARY_EXPR: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_LABEL: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_WILD_CARD_LABEL: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_ELEMENT_IDENTIFIER: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_ELEMENT_PROPERTY: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_MAKE_ELEMENT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ARRAY_AGGREGATE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_MAKE_ARRAY_VARIABLE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PATH_MODE: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PATH_COST: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_PATH_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_GRAPH_IS_LABELED_PREDICATE: _ClassVar[ResolvedNodeKind]
    RESOLVED_UNDROP_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_IDENTITY_COLUMN_INFO: _ClassVar[ResolvedNodeKind]
    RESOLVED_DESCRIBE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_STATIC_DESCRIBE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_ASSERT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_LOG_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_IF_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_IF_CASE: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_FORK_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_TEE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_EXPORT_DATA_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_CREATE_TABLE_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_PIPE_INSERT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_SUBPIPELINE: _ClassVar[ResolvedNodeKind]
    RESOLVED_SUBPIPELINE_INPUT_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_SUBPIPELINE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_GENERALIZED_QUERY_SUBPIPELINE: _ClassVar[ResolvedNodeKind]
    RESOLVED_BARRIER_SCAN: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_CONNECTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_CONNECTION_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_LOCK_MODE: _ClassVar[ResolvedNodeKind]
    RESOLVED_UPDATE_FIELD_ITEM: _ClassVar[ResolvedNodeKind]
    RESOLVED_UPDATE_CONSTRUCTOR: _ClassVar[ResolvedNodeKind]
    RESOLVED_CREATE_SEQUENCE_STMT: _ClassVar[ResolvedNodeKind]
    RESOLVED_ALTER_SEQUENCE_STMT: _ClassVar[ResolvedNodeKind]
    __ResolvedNodeKind__switch_must_have_default__: _ClassVar[ResolvedNodeKind]
RESOLVED_LITERAL: ResolvedNodeKind
RESOLVED_PARAMETER: ResolvedNodeKind
RESOLVED_EXPRESSION_COLUMN: ResolvedNodeKind
RESOLVED_CATALOG_COLUMN_REF: ResolvedNodeKind
RESOLVED_COLUMN_REF: ResolvedNodeKind
RESOLVED_GROUPING_SET_MULTI_COLUMN: ResolvedNodeKind
RESOLVED_CONSTANT: ResolvedNodeKind
RESOLVED_SYSTEM_VARIABLE: ResolvedNodeKind
RESOLVED_INLINE_LAMBDA: ResolvedNodeKind
RESOLVED_SEQUENCE: ResolvedNodeKind
RESOLVED_FILTER_FIELD_ARG: ResolvedNodeKind
RESOLVED_FILTER_FIELD: ResolvedNodeKind
RESOLVED_FUNCTION_CALL: ResolvedNodeKind
RESOLVED_AGGREGATE_FUNCTION_CALL: ResolvedNodeKind
RESOLVED_ANALYTIC_FUNCTION_CALL: ResolvedNodeKind
RESOLVED_EXTENDED_CAST_ELEMENT: ResolvedNodeKind
RESOLVED_EXTENDED_CAST: ResolvedNodeKind
RESOLVED_CAST: ResolvedNodeKind
RESOLVED_MAKE_STRUCT: ResolvedNodeKind
RESOLVED_MAKE_PROTO: ResolvedNodeKind
RESOLVED_MAKE_PROTO_FIELD: ResolvedNodeKind
RESOLVED_GET_STRUCT_FIELD: ResolvedNodeKind
RESOLVED_GET_PROTO_FIELD: ResolvedNodeKind
RESOLVED_GET_JSON_FIELD: ResolvedNodeKind
RESOLVED_GET_ROW_FIELD: ResolvedNodeKind
RESOLVED_FLATTEN: ResolvedNodeKind
RESOLVED_FLATTENED_ARG: ResolvedNodeKind
RESOLVED_REPLACE_FIELD_ITEM: ResolvedNodeKind
RESOLVED_REPLACE_FIELD: ResolvedNodeKind
RESOLVED_GET_PROTO_ONEOF: ResolvedNodeKind
RESOLVED_SUBQUERY_EXPR: ResolvedNodeKind
RESOLVED_WITH_EXPR: ResolvedNodeKind
RESOLVED_EXECUTE_AS_ROLE_SCAN: ResolvedNodeKind
RESOLVED_MODEL: ResolvedNodeKind
RESOLVED_CONNECTION: ResolvedNodeKind
RESOLVED_DESCRIPTOR: ResolvedNodeKind
RESOLVED_SINGLE_ROW_SCAN: ResolvedNodeKind
RESOLVED_UNSET_ARGUMENT_SCAN: ResolvedNodeKind
RESOLVED_TABLE_SCAN: ResolvedNodeKind
RESOLVED_JOIN_SCAN: ResolvedNodeKind
RESOLVED_ARRAY_SCAN: ResolvedNodeKind
RESOLVED_COLUMN_HOLDER: ResolvedNodeKind
RESOLVED_FILTER_SCAN: ResolvedNodeKind
RESOLVED_GROUPING_CALL: ResolvedNodeKind
RESOLVED_GROUPING_SET_LIST: ResolvedNodeKind
RESOLVED_GROUPING_SET_PRODUCT: ResolvedNodeKind
RESOLVED_GROUPING_SET: ResolvedNodeKind
RESOLVED_ROLLUP: ResolvedNodeKind
RESOLVED_CUBE: ResolvedNodeKind
RESOLVED_AGGREGATE_SCAN: ResolvedNodeKind
RESOLVED_ANONYMIZED_AGGREGATE_SCAN: ResolvedNodeKind
RESOLVED_DIFFERENTIAL_PRIVACY_AGGREGATE_SCAN: ResolvedNodeKind
RESOLVED_AGGREGATION_THRESHOLD_AGGREGATE_SCAN: ResolvedNodeKind
RESOLVED_SET_OPERATION_ITEM: ResolvedNodeKind
RESOLVED_SET_OPERATION_SCAN: ResolvedNodeKind
RESOLVED_ORDER_BY_SCAN: ResolvedNodeKind
RESOLVED_LIMIT_OFFSET_SCAN: ResolvedNodeKind
RESOLVED_WITH_REF_SCAN: ResolvedNodeKind
RESOLVED_ANALYTIC_SCAN: ResolvedNodeKind
RESOLVED_SAMPLE_SCAN: ResolvedNodeKind
RESOLVED_COMPUTED_COLUMN: ResolvedNodeKind
RESOLVED_DEFERRED_COMPUTED_COLUMN: ResolvedNodeKind
RESOLVED_ORDER_BY_ITEM: ResolvedNodeKind
RESOLVED_COLUMN_ANNOTATIONS: ResolvedNodeKind
RESOLVED_GENERATED_COLUMN_INFO: ResolvedNodeKind
RESOLVED_COLUMN_DEFAULT_VALUE: ResolvedNodeKind
RESOLVED_COLUMN_DEFINITION: ResolvedNodeKind
RESOLVED_PRIMARY_KEY: ResolvedNodeKind
RESOLVED_FOREIGN_KEY: ResolvedNodeKind
RESOLVED_CHECK_CONSTRAINT: ResolvedNodeKind
RESOLVED_OUTPUT_COLUMN: ResolvedNodeKind
RESOLVED_OUTPUT_SCHEMA: ResolvedNodeKind
RESOLVED_PROJECT_SCAN: ResolvedNodeKind
RESOLVED_TVFSCAN: ResolvedNodeKind
RESOLVED_GROUP_ROWS_SCAN: ResolvedNodeKind
RESOLVED_FUNCTION_ARGUMENT: ResolvedNodeKind
RESOLVED_EXPLAIN_STMT: ResolvedNodeKind
RESOLVED_STATEMENT_WITH_PIPE_OPERATORS_STMT: ResolvedNodeKind
RESOLVED_QUERY_STMT: ResolvedNodeKind
RESOLVED_GENERALIZED_QUERY_STMT: ResolvedNodeKind
RESOLVED_MULTI_STMT: ResolvedNodeKind
RESOLVED_CREATE_WITH_ENTRY_STMT: ResolvedNodeKind
RESOLVED_CREATE_DATABASE_STMT: ResolvedNodeKind
RESOLVED_INDEX_ITEM: ResolvedNodeKind
RESOLVED_UNNEST_ITEM: ResolvedNodeKind
RESOLVED_CREATE_INDEX_STMT: ResolvedNodeKind
RESOLVED_CREATE_SCHEMA_STMT: ResolvedNodeKind
RESOLVED_CREATE_EXTERNAL_SCHEMA_STMT: ResolvedNodeKind
RESOLVED_CREATE_TABLE_STMT: ResolvedNodeKind
RESOLVED_CREATE_TABLE_AS_SELECT_STMT: ResolvedNodeKind
RESOLVED_CREATE_MODEL_ALIASED_QUERY: ResolvedNodeKind
RESOLVED_CREATE_MODEL_STMT: ResolvedNodeKind
RESOLVED_CREATE_VIEW_STMT: ResolvedNodeKind
RESOLVED_WITH_PARTITION_COLUMNS: ResolvedNodeKind
RESOLVED_CREATE_SNAPSHOT_TABLE_STMT: ResolvedNodeKind
RESOLVED_CREATE_EXTERNAL_TABLE_STMT: ResolvedNodeKind
RESOLVED_EXPORT_MODEL_STMT: ResolvedNodeKind
RESOLVED_EXPORT_DATA_STMT: ResolvedNodeKind
RESOLVED_EXPORT_METADATA_STMT: ResolvedNodeKind
RESOLVED_DEFINE_TABLE_STMT: ResolvedNodeKind
RESOLVED_DESCRIBE_STMT: ResolvedNodeKind
RESOLVED_SHOW_STMT: ResolvedNodeKind
RESOLVED_BEGIN_STMT: ResolvedNodeKind
RESOLVED_SET_TRANSACTION_STMT: ResolvedNodeKind
RESOLVED_COMMIT_STMT: ResolvedNodeKind
RESOLVED_ROLLBACK_STMT: ResolvedNodeKind
RESOLVED_START_BATCH_STMT: ResolvedNodeKind
RESOLVED_RUN_BATCH_STMT: ResolvedNodeKind
RESOLVED_ABORT_BATCH_STMT: ResolvedNodeKind
RESOLVED_DROP_STMT: ResolvedNodeKind
RESOLVED_DROP_MATERIALIZED_VIEW_STMT: ResolvedNodeKind
RESOLVED_DROP_SNAPSHOT_TABLE_STMT: ResolvedNodeKind
RESOLVED_RECURSIVE_REF_SCAN: ResolvedNodeKind
RESOLVED_RECURSION_DEPTH_MODIFIER: ResolvedNodeKind
RESOLVED_RECURSIVE_SCAN: ResolvedNodeKind
RESOLVED_WITH_SCAN: ResolvedNodeKind
RESOLVED_WITH_ENTRY: ResolvedNodeKind
RESOLVED_OPTION: ResolvedNodeKind
RESOLVED_WINDOW_PARTITIONING: ResolvedNodeKind
RESOLVED_WINDOW_ORDERING: ResolvedNodeKind
RESOLVED_WINDOW_FRAME: ResolvedNodeKind
RESOLVED_ANALYTIC_FUNCTION_GROUP: ResolvedNodeKind
RESOLVED_WINDOW_FRAME_EXPR: ResolvedNodeKind
RESOLVED_DMLVALUE: ResolvedNodeKind
RESOLVED_DMLDEFAULT: ResolvedNodeKind
RESOLVED_ASSERT_STMT: ResolvedNodeKind
RESOLVED_ASSERT_ROWS_MODIFIED: ResolvedNodeKind
RESOLVED_ON_CONFLICT_CLAUSE: ResolvedNodeKind
RESOLVED_INSERT_ROW: ResolvedNodeKind
RESOLVED_INSERT_STMT: ResolvedNodeKind
RESOLVED_DELETE_STMT: ResolvedNodeKind
RESOLVED_UPDATE_ITEM: ResolvedNodeKind
RESOLVED_UPDATE_ITEM_ELEMENT: ResolvedNodeKind
RESOLVED_UPDATE_STMT: ResolvedNodeKind
RESOLVED_MERGE_WHEN: ResolvedNodeKind
RESOLVED_MERGE_STMT: ResolvedNodeKind
RESOLVED_TRUNCATE_STMT: ResolvedNodeKind
RESOLVED_OBJECT_UNIT: ResolvedNodeKind
RESOLVED_PRIVILEGE: ResolvedNodeKind
RESOLVED_GRANT_STMT: ResolvedNodeKind
RESOLVED_REVOKE_STMT: ResolvedNodeKind
RESOLVED_ALTER_DATABASE_STMT: ResolvedNodeKind
RESOLVED_ALTER_INDEX_STMT: ResolvedNodeKind
RESOLVED_ALTER_MATERIALIZED_VIEW_STMT: ResolvedNodeKind
RESOLVED_ALTER_APPROX_VIEW_STMT: ResolvedNodeKind
RESOLVED_ALTER_SCHEMA_STMT: ResolvedNodeKind
RESOLVED_ALTER_EXTERNAL_SCHEMA_STMT: ResolvedNodeKind
RESOLVED_ALTER_MODEL_STMT: ResolvedNodeKind
RESOLVED_ALTER_TABLE_STMT: ResolvedNodeKind
RESOLVED_ALTER_VIEW_STMT: ResolvedNodeKind
RESOLVED_SET_OPTIONS_ACTION: ResolvedNodeKind
RESOLVED_ALTER_SUB_ENTITY_ACTION: ResolvedNodeKind
RESOLVED_ADD_SUB_ENTITY_ACTION: ResolvedNodeKind
RESOLVED_DROP_SUB_ENTITY_ACTION: ResolvedNodeKind
RESOLVED_ADD_COLUMN_ACTION: ResolvedNodeKind
RESOLVED_ADD_COLUMN_IDENTIFIER_ACTION: ResolvedNodeKind
RESOLVED_REBUILD_ACTION: ResolvedNodeKind
RESOLVED_ADD_CONSTRAINT_ACTION: ResolvedNodeKind
RESOLVED_DROP_CONSTRAINT_ACTION: ResolvedNodeKind
RESOLVED_DROP_PRIMARY_KEY_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_OPTIONS_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_DROP_NOT_NULL_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_DROP_GENERATED_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_SET_GENERATED_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_SET_DATA_TYPE_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_SET_DEFAULT_ACTION: ResolvedNodeKind
RESOLVED_ALTER_COLUMN_DROP_DEFAULT_ACTION: ResolvedNodeKind
RESOLVED_DROP_COLUMN_ACTION: ResolvedNodeKind
RESOLVED_RENAME_COLUMN_ACTION: ResolvedNodeKind
RESOLVED_SET_AS_ACTION: ResolvedNodeKind
RESOLVED_SET_COLLATE_CLAUSE: ResolvedNodeKind
RESOLVED_ALTER_TABLE_SET_OPTIONS_STMT: ResolvedNodeKind
RESOLVED_RENAME_STMT: ResolvedNodeKind
RESOLVED_CREATE_PRIVILEGE_RESTRICTION_STMT: ResolvedNodeKind
RESOLVED_CREATE_ROW_ACCESS_POLICY_STMT: ResolvedNodeKind
RESOLVED_DROP_PRIVILEGE_RESTRICTION_STMT: ResolvedNodeKind
RESOLVED_DROP_ROW_ACCESS_POLICY_STMT: ResolvedNodeKind
RESOLVED_DROP_INDEX_STMT: ResolvedNodeKind
RESOLVED_GRANT_TO_ACTION: ResolvedNodeKind
RESOLVED_RESTRICT_TO_ACTION: ResolvedNodeKind
RESOLVED_ADD_TO_RESTRICTEE_LIST_ACTION: ResolvedNodeKind
RESOLVED_REMOVE_FROM_RESTRICTEE_LIST_ACTION: ResolvedNodeKind
RESOLVED_FILTER_USING_ACTION: ResolvedNodeKind
RESOLVED_REVOKE_FROM_ACTION: ResolvedNodeKind
RESOLVED_RENAME_TO_ACTION: ResolvedNodeKind
RESOLVED_ALTER_PRIVILEGE_RESTRICTION_STMT: ResolvedNodeKind
RESOLVED_ALTER_ROW_ACCESS_POLICY_STMT: ResolvedNodeKind
RESOLVED_ALTER_ALL_ROW_ACCESS_POLICIES_STMT: ResolvedNodeKind
RESOLVED_CREATE_CONSTANT_STMT: ResolvedNodeKind
RESOLVED_CREATE_FUNCTION_STMT: ResolvedNodeKind
RESOLVED_ARGUMENT_DEF: ResolvedNodeKind
RESOLVED_ARGUMENT_REF: ResolvedNodeKind
RESOLVED_CREATE_TABLE_FUNCTION_STMT: ResolvedNodeKind
RESOLVED_RELATION_ARGUMENT_SCAN: ResolvedNodeKind
RESOLVED_ARGUMENT_LIST: ResolvedNodeKind
RESOLVED_FUNCTION_SIGNATURE_HOLDER: ResolvedNodeKind
RESOLVED_DROP_FUNCTION_STMT: ResolvedNodeKind
RESOLVED_DROP_TABLE_FUNCTION_STMT: ResolvedNodeKind
RESOLVED_CALL_STMT: ResolvedNodeKind
RESOLVED_IMPORT_STMT: ResolvedNodeKind
RESOLVED_MODULE_STMT: ResolvedNodeKind
RESOLVED_AGGREGATE_HAVING_MODIFIER: ResolvedNodeKind
RESOLVED_CREATE_MATERIALIZED_VIEW_STMT: ResolvedNodeKind
RESOLVED_CREATE_APPROX_VIEW_STMT: ResolvedNodeKind
RESOLVED_CREATE_PROCEDURE_STMT: ResolvedNodeKind
RESOLVED_EXECUTE_IMMEDIATE_ARGUMENT: ResolvedNodeKind
RESOLVED_EXECUTE_IMMEDIATE_STMT: ResolvedNodeKind
RESOLVED_ASSIGNMENT_STMT: ResolvedNodeKind
RESOLVED_CREATE_ENTITY_STMT: ResolvedNodeKind
RESOLVED_ALTER_ENTITY_STMT: ResolvedNodeKind
RESOLVED_PIVOT_COLUMN: ResolvedNodeKind
RESOLVED_PIVOT_SCAN: ResolvedNodeKind
RESOLVED_RETURNING_CLAUSE: ResolvedNodeKind
RESOLVED_UNPIVOT_ARG: ResolvedNodeKind
RESOLVED_UNPIVOT_SCAN: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_SCAN: ResolvedNodeKind
RESOLVED_MEASURE_GROUP: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_VARIABLE_DEFINITION: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_PATTERN_EMPTY: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_PATTERN_ANCHOR: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_PATTERN_VARIABLE_REF: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_PATTERN_OPERATION: ResolvedNodeKind
RESOLVED_MATCH_RECOGNIZE_PATTERN_QUANTIFICATION: ResolvedNodeKind
RESOLVED_CLONE_DATA_STMT: ResolvedNodeKind
RESOLVED_TABLE_AND_COLUMN_INFO: ResolvedNodeKind
RESOLVED_ANALYZE_STMT: ResolvedNodeKind
RESOLVED_AUX_LOAD_DATA_PARTITION_FILTER: ResolvedNodeKind
RESOLVED_AUX_LOAD_DATA_STMT: ResolvedNodeKind
RESOLVED_CREATE_PROPERTY_GRAPH_STMT: ResolvedNodeKind
RESOLVED_GRAPH_ELEMENT_TABLE: ResolvedNodeKind
RESOLVED_GRAPH_NODE_TABLE_REFERENCE: ResolvedNodeKind
RESOLVED_GRAPH_ELEMENT_LABEL: ResolvedNodeKind
RESOLVED_GRAPH_PROPERTY_DECLARATION: ResolvedNodeKind
RESOLVED_GRAPH_PROPERTY_DEFINITION: ResolvedNodeKind
RESOLVED_GRAPH_DYNAMIC_LABEL_SPECIFICATION: ResolvedNodeKind
RESOLVED_GRAPH_DYNAMIC_PROPERTIES_SPECIFICATION: ResolvedNodeKind
RESOLVED_GRAPH_REF_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_LINEAR_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_TABLE_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_CALL_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_PATH_PATTERN_QUANTIFIER: ResolvedNodeKind
RESOLVED_GRAPH_PATH_SEARCH_PREFIX: ResolvedNodeKind
RESOLVED_GRAPH_NODE_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_EDGE_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_GET_ELEMENT_PROPERTY: ResolvedNodeKind
RESOLVED_GRAPH_LABEL_NARY_EXPR: ResolvedNodeKind
RESOLVED_GRAPH_LABEL: ResolvedNodeKind
RESOLVED_GRAPH_WILD_CARD_LABEL: ResolvedNodeKind
RESOLVED_GRAPH_ELEMENT_IDENTIFIER: ResolvedNodeKind
RESOLVED_GRAPH_ELEMENT_PROPERTY: ResolvedNodeKind
RESOLVED_GRAPH_MAKE_ELEMENT: ResolvedNodeKind
RESOLVED_ARRAY_AGGREGATE: ResolvedNodeKind
RESOLVED_GRAPH_MAKE_ARRAY_VARIABLE: ResolvedNodeKind
RESOLVED_GRAPH_PATH_MODE: ResolvedNodeKind
RESOLVED_GRAPH_PATH_COST: ResolvedNodeKind
RESOLVED_GRAPH_PATH_SCAN: ResolvedNodeKind
RESOLVED_GRAPH_IS_LABELED_PREDICATE: ResolvedNodeKind
RESOLVED_UNDROP_STMT: ResolvedNodeKind
RESOLVED_IDENTITY_COLUMN_INFO: ResolvedNodeKind
RESOLVED_DESCRIBE_SCAN: ResolvedNodeKind
RESOLVED_STATIC_DESCRIBE_SCAN: ResolvedNodeKind
RESOLVED_ASSERT_SCAN: ResolvedNodeKind
RESOLVED_LOG_SCAN: ResolvedNodeKind
RESOLVED_PIPE_IF_SCAN: ResolvedNodeKind
RESOLVED_PIPE_IF_CASE: ResolvedNodeKind
RESOLVED_PIPE_FORK_SCAN: ResolvedNodeKind
RESOLVED_PIPE_TEE_SCAN: ResolvedNodeKind
RESOLVED_PIPE_EXPORT_DATA_SCAN: ResolvedNodeKind
RESOLVED_PIPE_CREATE_TABLE_SCAN: ResolvedNodeKind
RESOLVED_PIPE_INSERT_SCAN: ResolvedNodeKind
RESOLVED_SUBPIPELINE: ResolvedNodeKind
RESOLVED_SUBPIPELINE_INPUT_SCAN: ResolvedNodeKind
RESOLVED_SUBPIPELINE_STMT: ResolvedNodeKind
RESOLVED_GENERALIZED_QUERY_SUBPIPELINE: ResolvedNodeKind
RESOLVED_BARRIER_SCAN: ResolvedNodeKind
RESOLVED_CREATE_CONNECTION_STMT: ResolvedNodeKind
RESOLVED_ALTER_CONNECTION_STMT: ResolvedNodeKind
RESOLVED_LOCK_MODE: ResolvedNodeKind
RESOLVED_UPDATE_FIELD_ITEM: ResolvedNodeKind
RESOLVED_UPDATE_CONSTRUCTOR: ResolvedNodeKind
RESOLVED_CREATE_SEQUENCE_STMT: ResolvedNodeKind
RESOLVED_ALTER_SEQUENCE_STMT: ResolvedNodeKind
__ResolvedNodeKind__switch_must_have_default__: ResolvedNodeKind
