"""Protocol buffer definitions for ZetaSQL.

This directory contains the source .proto files from the ZetaSQL project.

For compiled Python modules, see zetasql.wasi._pb2.

To regenerate Python files from these .proto files:
    ./scripts/build_protos.sh
"""
