# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/datetime.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/datetime.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'zetasql/public/functions/datetime.proto\x12\x11zetasql.functions*\xaf\x03\n\x11\x44\x61teTimestampPart\x12\x39\n,__DateTimePart__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x08\n\x04YEAR\x10\x01\x12\t\n\x05MONTH\x10\x02\x12\x07\n\x03\x44\x41Y\x10\x03\x12\r\n\tDAYOFWEEK\x10\x04\x12\r\n\tDAYOFYEAR\x10\x05\x12\x0b\n\x07QUARTER\x10\x06\x12\x08\n\x04HOUR\x10\x07\x12\n\n\x06MINUTE\x10\x08\x12\n\n\x06SECOND\x10\t\x12\x0f\n\x0bMILLISECOND\x10\n\x12\x0f\n\x0bMICROSECOND\x10\x0b\x12\x0e\n\nNANOSECOND\x10\x0c\x12\x0e\n\nPICOSECOND\x10\x19\x12\x08\n\x04\x44\x41TE\x10\r\x12\x08\n\x04WEEK\x10\x0e\x12\x0c\n\x08\x44\x41TETIME\x10\x0f\x12\x08\n\x04TIME\x10\x10\x12\x0b\n\x07ISOYEAR\x10\x11\x12\x0b\n\x07ISOWEEK\x10\x12\x12\x0f\n\x0bWEEK_MONDAY\x10\x13\x12\x10\n\x0cWEEK_TUESDAY\x10\x14\x12\x12\n\x0eWEEK_WEDNESDAY\x10\x15\x12\x11\n\rWEEK_THURSDAY\x10\x16\x12\x0f\n\x0bWEEK_FRIDAY\x10\x17\x12\x11\n\rWEEK_SATURDAY\x10\x18\x42/\n\x1c\x63om.google.zetasql.functionsB\x0fZetaSQLDateTime')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.datetime_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\017ZetaSQLDateTime'
  _globals['_DATETIMESTAMPPART']._serialized_start=63
  _globals['_DATETIMESTAMPPART']._serialized_end=494
# @@protoc_insertion_point(module_scope)
