# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/type.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/type.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19zetasql/public/type.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\xc7\x04\n\tTypeProto\x12$\n\ttype_kind\x18\x01 \x01(\x0e\x32\x11.zetasql.TypeKind\x12+\n\narray_type\x18\x02 \x01(\x0b\x32\x17.zetasql.ArrayTypeProto\x12-\n\x0bstruct_type\x18\x03 \x01(\x0b\x32\x18.zetasql.StructTypeProto\x12+\n\nproto_type\x18\x04 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12)\n\tenum_type\x18\x05 \x01(\x0b\x32\x16.zetasql.EnumTypeProto\x12+\n\nrange_type\x18\x08 \x01(\x0b\x32\x17.zetasql.RangeTypeProto\x12:\n\x12graph_element_type\x18\t \x01(\x0b\x32\x1e.zetasql.GraphElementTypeProto\x12\x34\n\x0fgraph_path_type\x18\x0b \x01(\x0b\x32\x1b.zetasql.GraphPathTypeProto\x12\'\n\x08map_type\x18\n \x01(\x0b\x32\x15.zetasql.MapTypeProto\x12/\n\x0cmeasure_type\x18\x0c \x01(\x0b\x32\x19.zetasql.MeasureTypeProto\x12?\n\x13\x66ile_descriptor_set\x18\x06 \x03(\x0b\x32\".google.protobuf.FileDescriptorSet\x12\x1a\n\x12\x65xtended_type_name\x18\x07 \x01(\t*\n\x08\xa0\x8d\x06\x10\x80\x80\x80\x80\x02\":\n\x0e\x41rrayTypeProto\x12(\n\x0c\x65lement_type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto\"N\n\x10StructFieldProto\x12\x12\n\nfield_name\x18\x01 \x01(\t\x12&\n\nfield_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\";\n\x0fStructTypeProto\x12(\n\x05\x66ield\x18\x01 \x03(\x0b\x32\x19.zetasql.StructFieldProto\"\\\n\x0cMapTypeProto\x12$\n\x08key_type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto\x12&\n\nvalue_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\"~\n\x0eProtoTypeProto\x12\x12\n\nproto_name\x18\x01 \x01(\t\x12\x17\n\x0fproto_file_name\x18\x02 \x01(\t\x12$\n\x19\x66ile_descriptor_set_index\x18\x03 \x01(\x05:\x01\x30\x12\x19\n\x11\x63\x61talog_name_path\x18\x04 \x03(\t\"\x8e\x01\n\rEnumTypeProto\x12\x11\n\tenum_name\x18\x01 \x01(\t\x12\x16\n\x0e\x65num_file_name\x18\x02 \x01(\t\x12$\n\x19\x66ile_descriptor_set_index\x18\x03 \x01(\x05:\x01\x30\x12\x19\n\x11\x63\x61talog_name_path\x18\x04 \x03(\t\x12\x11\n\tis_opaque\x18\x05 \x01(\x08\":\n\x0eRangeTypeProto\x12(\n\x0c\x65lement_type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto\"5\n\x15OpaqueEnumTypeOptions\x12\x1c\n\x14sql_opaque_enum_name\x18\x01 \x01(\t\"4\n\x16OpaqueEnumValueOptions\x12\x1a\n\x12invalid_enum_value\x18\x01 \x01(\x08\"\xd7\x02\n\x15GraphElementTypeProto\x12\x38\n\x04kind\x18\x01 \x01(\x0e\x32*.zetasql.GraphElementTypeProto.ElementKind\x12G\n\rproperty_type\x18\x02 \x03(\x0b\x32\x30.zetasql.GraphElementTypeProto.PropertyTypeProto\x12\x17\n\x0fgraph_reference\x18\x04 \x03(\t\x12\x12\n\nis_dynamic\x18\x05 \x01(\x08\x1aI\n\x11PropertyTypeProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\nvalue_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\"=\n\x0b\x45lementKind\x12\x10\n\x0cKIND_INVALID\x10\x00\x12\r\n\tKIND_NODE\x10\x01\x12\r\n\tKIND_EDGE\x10\x02J\x04\x08\x03\x10\x04\"z\n\x12GraphPathTypeProto\x12\x31\n\tnode_type\x18\x01 \x01(\x0b\x32\x1e.zetasql.GraphElementTypeProto\x12\x31\n\tedge_type\x18\x02 \x01(\x0b\x32\x1e.zetasql.GraphElementTypeProto\";\n\x10MeasureTypeProto\x12\'\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto*\xe9\x04\n\x08TypeKind\x12\x35\n(__TypeKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x0e\n\nTYPE_INT32\x10\x01\x12\x0e\n\nTYPE_INT64\x10\x02\x12\x0f\n\x0bTYPE_UINT32\x10\x03\x12\x0f\n\x0bTYPE_UINT64\x10\x04\x12\r\n\tTYPE_BOOL\x10\x05\x12\x0e\n\nTYPE_FLOAT\x10\x06\x12\x0f\n\x0bTYPE_DOUBLE\x10\x07\x12\x0f\n\x0bTYPE_STRING\x10\x08\x12\x0e\n\nTYPE_BYTES\x10\t\x12\r\n\tTYPE_DATE\x10\n\x12\x12\n\x0eTYPE_TIMESTAMP\x10\x13\x12\r\n\tTYPE_ENUM\x10\x0f\x12\x0e\n\nTYPE_ARRAY\x10\x10\x12\x0f\n\x0bTYPE_STRUCT\x10\x11\x12\x0e\n\nTYPE_PROTO\x10\x12\x12\r\n\tTYPE_TIME\x10\x14\x12\x11\n\rTYPE_DATETIME\x10\x15\x12\x12\n\x0eTYPE_GEOGRAPHY\x10\x16\x12\x10\n\x0cTYPE_NUMERIC\x10\x17\x12\x13\n\x0fTYPE_BIGNUMERIC\x10\x18\x12\x11\n\rTYPE_EXTENDED\x10\x19\x12\r\n\tTYPE_JSON\x10\x1a\x12\x11\n\rTYPE_INTERVAL\x10\x1b\x12\x12\n\x0eTYPE_TOKENLIST\x10\x1c\x12\x0e\n\nTYPE_RANGE\x10\x1d\x12\x16\n\x12TYPE_GRAPH_ELEMENT\x10\x1e\x12\x13\n\x0fTYPE_GRAPH_PATH\x10!\x12\x0c\n\x08TYPE_MAP\x10\x1f\x12\r\n\tTYPE_UUID\x10 \x12\x10\n\x0cTYPE_MEASURE\x10\"\x12\x0c\n\x08TYPE_ROW\x10$:b\n\x18opaque_enum_type_options\x12\x1c.google.protobuf.EnumOptions\x18\x86\xfa\xa5\xdf\x01 \x01(\x0b\x32\x1e.zetasql.OpaqueEnumTypeOptions:i\n\x19opaque_enum_value_options\x12!.google.protobuf.EnumValueOptions\x18\xa6\x8e\xa6\xe2\x01 \x01(\x0b\x32\x1f.zetasql.OpaqueEnumValueOptionsB$\n\x12\x63om.google.zetasqlB\x0bZetaSQLType\xf8\x01\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.type_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\013ZetaSQLType\370\001\001'
  _globals['_TYPEKIND']._serialized_start=1927
  _globals['_TYPEKIND']._serialized_end=2544
  _globals['_TYPEPROTO']._serialized_start=73
  _globals['_TYPEPROTO']._serialized_end=656
  _globals['_ARRAYTYPEPROTO']._serialized_start=658
  _globals['_ARRAYTYPEPROTO']._serialized_end=716
  _globals['_STRUCTFIELDPROTO']._serialized_start=718
  _globals['_STRUCTFIELDPROTO']._serialized_end=796
  _globals['_STRUCTTYPEPROTO']._serialized_start=798
  _globals['_STRUCTTYPEPROTO']._serialized_end=857
  _globals['_MAPTYPEPROTO']._serialized_start=859
  _globals['_MAPTYPEPROTO']._serialized_end=951
  _globals['_PROTOTYPEPROTO']._serialized_start=953
  _globals['_PROTOTYPEPROTO']._serialized_end=1079
  _globals['_ENUMTYPEPROTO']._serialized_start=1082
  _globals['_ENUMTYPEPROTO']._serialized_end=1224
  _globals['_RANGETYPEPROTO']._serialized_start=1226
  _globals['_RANGETYPEPROTO']._serialized_end=1284
  _globals['_OPAQUEENUMTYPEOPTIONS']._serialized_start=1286
  _globals['_OPAQUEENUMTYPEOPTIONS']._serialized_end=1339
  _globals['_OPAQUEENUMVALUEOPTIONS']._serialized_start=1341
  _globals['_OPAQUEENUMVALUEOPTIONS']._serialized_end=1393
  _globals['_GRAPHELEMENTTYPEPROTO']._serialized_start=1396
  _globals['_GRAPHELEMENTTYPEPROTO']._serialized_end=1739
  _globals['_GRAPHELEMENTTYPEPROTO_PROPERTYTYPEPROTO']._serialized_start=1597
  _globals['_GRAPHELEMENTTYPEPROTO_PROPERTYTYPEPROTO']._serialized_end=1670
  _globals['_GRAPHELEMENTTYPEPROTO_ELEMENTKIND']._serialized_start=1672
  _globals['_GRAPHELEMENTTYPEPROTO_ELEMENTKIND']._serialized_end=1733
  _globals['_GRAPHPATHTYPEPROTO']._serialized_start=1741
  _globals['_GRAPHPATHTYPEPROTO']._serialized_end=1863
  _globals['_MEASURETYPEPROTO']._serialized_start=1865
  _globals['_MEASURETYPEPROTO']._serialized_end=1924
# @@protoc_insertion_point(module_scope)
