# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/compliance/compliance_label.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/compliance/compliance_label.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.compliance import known_error_pb2 as zetasql_dot_compliance_dot_known__error__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)zetasql/compliance/compliance_label.proto\x12\x07zetasql\x1a$zetasql/compliance/known_error.proto\"N\n\x15\x43omplianceTestsLabels\x12\x35\n\ntest_cases\x18\x01 \x03(\x0b\x32!.zetasql.ComplianceTestCaseLabels\"\xff\x02\n\x18\x43omplianceTestCaseLabels\x12\x11\n\ttest_name\x18\x01 \x01(\t\x12\x12\n\ntest_query\x18\x02 \x01(\t\x12\x36\n\x05param\x18\x07 \x03(\x0b\x32\'.zetasql.ComplianceTestCaseLabels.Param\x12\x30\n\x0ftest_error_mode\x18\x03 \x01(\x0e\x32\x17.zetasql.KnownErrorMode\x12\x19\n\x11\x63ompliance_labels\x18\x04 \x03(\t\x12\x12\n\ntest_shard\x18\x08 \x01(\x03\x12\x41\n\rtest_location\x18\t \x01(\x0b\x32*.zetasql.ComplianceTestCaseLabels.Location\x1a\x38\n\x05Param\x12\x12\n\nparam_name\x18\x01 \x01(\t\x12\x1b\n\x13param_value_literal\x18\x02 \x01(\t\x1a&\n\x08Location\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0c\n\x04line\x18\x02 \x01(\x05')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.compliance.compliance_label_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMPLIANCETESTSLABELS']._serialized_start=92
  _globals['_COMPLIANCETESTSLABELS']._serialized_end=170
  _globals['_COMPLIANCETESTCASELABELS']._serialized_start=173
  _globals['_COMPLIANCETESTCASELABELS']._serialized_end=556
  _globals['_COMPLIANCETESTCASELABELS_PARAM']._serialized_start=460
  _globals['_COMPLIANCETESTCASELABELS_PARAM']._serialized_end=516
  _globals['_COMPLIANCETESTCASELABELS_LOCATION']._serialized_start=518
  _globals['_COMPLIANCETESTCASELABELS_LOCATION']._serialized_end=556
# @@protoc_insertion_point(module_scope)
