# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/local_service/local_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/local_service/local_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from zetasql.wasi._pb2.zetasql.parser import parse_tree_pb2 as zetasql_dot_parser_dot_parse__tree__pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.proto import options_pb2 as zetasql_dot_proto_dot_options__pb2
from zetasql.wasi._pb2.zetasql.proto import simple_catalog_pb2 as zetasql_dot_proto_dot_simple__catalog__pb2
from zetasql.wasi._pb2.zetasql.public import formatter_options_pb2 as zetasql_dot_public_dot_formatter__options__pb2
from zetasql.wasi._pb2.zetasql.public import options_pb2 as zetasql_dot_public_dot_options__pb2
from zetasql.wasi._pb2.zetasql.public import parse_resume_location_pb2 as zetasql_dot_public_dot_parse__resume__location__pb2
from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as zetasql_dot_public_dot_simple__table__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as zetasql_dot_public_dot_value__pb2
from zetasql.wasi._pb2.zetasql.resolved_ast import resolved_ast_pb2 as zetasql_dot_resolved__ast_dot_resolved__ast__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)zetasql/local_service/local_service.proto\x12\x15zetasql.local_service\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/descriptor.proto\x1a\x1fzetasql/parser/parse_tree.proto\x1a\x1czetasql/proto/function.proto\x1a\x1bzetasql/proto/options.proto\x1a\"zetasql/proto/simple_catalog.proto\x1a&zetasql/public/formatter_options.proto\x1a\x1czetasql/public/options.proto\x1a*zetasql/public/parse_resume_location.proto\x1a!zetasql/public/simple_table.proto\x1a\x19zetasql/public/type.proto\x1a\x1azetasql/public/value.proto\x1a\'zetasql/resolved_ast/resolved_ast.proto\"\xb8\x02\n\x17\x44\x65scriptorPoolListProto\x12N\n\x0b\x64\x65\x66initions\x18\x01 \x03(\x0b\x32\x39.zetasql.local_service.DescriptorPoolListProto.Definition\x1a\t\n\x07\x42uiltin\x1a\xc1\x01\n\nDefinition\x12\x41\n\x13\x66ile_descriptor_set\x18\x01 \x01(\x0b\x32\".google.protobuf.FileDescriptorSetH\x00\x12\x17\n\rregistered_id\x18\x02 \x01(\x03H\x00\x12I\n\x07\x62uiltin\x18\x03 \x01(\x0b\x32\x36.zetasql.local_service.DescriptorPoolListProto.BuiltinH\x00\x42\x0c\n\ndefinition\"2\n\x14\x44\x65scriptorPoolIdList\x12\x1a\n\x0eregistered_ids\x18\x01 \x03(\x03\x42\x02\x10\x01\"\xf5\x01\n\x0ePrepareRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x06 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x33\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12\x1d\n\x15registered_catalog_id\x18\x05 \x01(\x03J\x04\x08\x03\x10\x04\"\x85\x02\n\rPreparedState\x12\x1e\n\x16prepared_expression_id\x18\x01 \x01(\x03\x12\'\n\x0boutput_type\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x1a\n\x12referenced_columns\x18\x03 \x03(\t\x12\x1d\n\x15referenced_parameters\x18\x04 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x05 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x06 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"U\n\x0fPrepareResponse\x12\x36\n\x08prepared\x18\x03 \x01(\x0b\x32$.zetasql.local_service.PreparedStateJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\x8c\x03\n\x0f\x45valuateRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12\x41\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x30.zetasql.local_service.EvaluateRequest.Parameter\x12@\n\x06params\x18\x03 \x03(\x0b\x32\x30.zetasql.local_service.EvaluateRequest.Parameter\x12L\n\x14\x64\x65scriptor_pool_list\x18\x07 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1e\n\x16prepared_expression_id\x18\x05 \x01(\x03\x12.\n\x07options\x18\x06 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x1a\x43\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProtoJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"z\n\x10\x45valuateResponse\x12\"\n\x05value\x18\x01 \x01(\x0b\x32\x13.zetasql.ValueProto\x12\x36\n\x08prepared\x18\x04 \x01(\x0b\x32$.zetasql.local_service.PreparedStateJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"O\n\x14\x45valuateRequestBatch\x12\x37\n\x07request\x18\x01 \x03(\x0b\x32&.zetasql.local_service.EvaluateRequest\"R\n\x15\x45valuateResponseBatch\x12\x39\n\x08response\x18\x01 \x03(\x0b\x32\'.zetasql.local_service.EvaluateResponse\"2\n\x10UnprepareRequest\x12\x1e\n\x16prepared_expression_id\x18\x01 \x01(\x03\"\xb2\x03\n\x13PrepareQueryRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12S\n\rtable_content\x18\x06 \x03(\x0b\x32<.zetasql.local_service.PrepareQueryRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\xed\x01\n\x12PreparedQueryState\x12\x19\n\x11prepared_query_id\x18\x01 \x01(\x03\x12\x1d\n\x15referenced_parameters\x18\x02 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x03 \x01(\x03\x12+\n\x07\x63olumns\x18\x04 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProto\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x05 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"S\n\x14PrepareQueryResponse\x12;\n\x08prepared\x18\x01 \x01(\x0b\x32).zetasql.local_service.PreparedQueryState\"C\n\tParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProtoJ\x04\x08\x03\x10\x04\"2\n\x15UnprepareQueryRequest\x12\x19\n\x11prepared_query_id\x18\x01 \x01(\x03\"\x83\x04\n\x14\x45valuateQueryRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12\x1b\n\x11prepared_query_id\x18\x06 \x01(\x03H\x00\x12T\n\rtable_content\x18\x07 \x03(\x0b\x32=.zetasql.local_service.EvaluateQueryRequest.TableContentEntry\x12\x30\n\x06params\x18\x08 \x03(\x0b\x32 .zetasql.local_service.Parameter\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\x8a\x01\n\x15\x45valuateQueryResponse\x12\x34\n\x07\x63ontent\x18\x01 \x01(\x0b\x32#.zetasql.local_service.TableContent\x12;\n\x08prepared\x18\x02 \x01(\x0b\x32).zetasql.local_service.PreparedQueryState\"Y\n\x19\x45valuateQueryBatchRequest\x12<\n\x07request\x18\x01 \x03(\x0b\x32+.zetasql.local_service.EvaluateQueryRequest\"\\\n\x1a\x45valuateQueryBatchResponse\x12>\n\x08response\x18\x01 \x03(\x0b\x32,.zetasql.local_service.EvaluateQueryResponse\"\xb4\x03\n\x14PrepareModifyRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12T\n\rtable_content\x18\x06 \x03(\x0b\x32=.zetasql.local_service.PrepareModifyRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\xc2\x01\n\x13PreparedModifyState\x12\x1a\n\x12prepared_modify_id\x18\x01 \x01(\x03\x12\x1d\n\x15referenced_parameters\x18\x02 \x03(\t\x12\"\n\x1apositional_parameter_count\x18\x03 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x05 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"U\n\x15PrepareModifyResponse\x12<\n\x08prepared\x18\x01 \x01(\x0b\x32*.zetasql.local_service.PreparedModifyState\"4\n\x16UnprepareModifyRequest\x12\x1a\n\x12prepared_modify_id\x18\x01 \x01(\x03\"\x86\x04\n\x15\x45valuateModifyRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x35\n\x0esimple_catalog\x18\x04 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProtoH\x00\x12\x1f\n\x15registered_catalog_id\x18\x05 \x01(\x03H\x00\x12\x1c\n\x12prepared_modify_id\x18\x06 \x01(\x03H\x00\x12U\n\rtable_content\x18\x07 \x03(\x0b\x32>.zetasql.local_service.EvaluateModifyRequest.TableContentEntry\x12\x30\n\x06params\x18\x08 \x03(\x0b\x32 .zetasql.local_service.Parameter\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01\x42\t\n\x07\x63\x61talog\"\x95\x03\n\x16\x45valuateModifyResponse\x12\x12\n\ntable_name\x18\x01 \x01(\t\x12\x42\n\x07\x63ontent\x18\x02 \x03(\x0b\x32\x31.zetasql.local_service.EvaluateModifyResponse.Row\x12<\n\x08prepared\x18\x03 \x01(\x0b\x32*.zetasql.local_service.PreparedModifyState\x1a\xe4\x01\n\x03Row\x12N\n\toperation\x18\x01 \x01(\x0e\x32;.zetasql.local_service.EvaluateModifyResponse.Row.Operation\x12!\n\x04\x63\x65ll\x18\x02 \x03(\x0b\x32\x13.zetasql.ValueProto\x12,\n\x0fold_primary_key\x18\x03 \x03(\x0b\x32\x13.zetasql.ValueProto\"<\n\tOperation\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06INSERT\x10\x01\x12\n\n\x06\x44\x45LETE\x10\x02\x12\n\n\x06UPDATE\x10\x03\"[\n\x1a\x45valuateModifyBatchRequest\x12=\n\x07request\x18\x01 \x03(\x0b\x32,.zetasql.local_service.EvaluateModifyRequest\"^\n\x1b\x45valuateModifyBatchResponse\x12?\n\x08response\x18\x01 \x03(\x0b\x32-.zetasql.local_service.EvaluateModifyResponse\"\x80\x01\n\x15TableFromProtoRequest\x12&\n\x05proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12?\n\x13\x66ile_descriptor_set\x18\x02 \x01(\x0b\x32\".google.protobuf.FileDescriptorSet\"\xef\x02\n\x0e\x41nalyzeRequest\x12.\n\x07options\x18\x01 \x01(\x0b\x32\x1d.zetasql.AnalyzerOptionsProto\x12\x33\n\x0esimple_catalog\x18\x02 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\t \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1d\n\x15registered_catalog_id\x18\x04 \x01(\x03\x12\x17\n\rsql_statement\x18\x05 \x01(\tH\x00\x12\x42\n\x15parse_resume_location\x18\x06 \x01(\x0b\x32!.zetasql.ParseResumeLocationProtoH\x00\x12\x18\n\x0esql_expression\x18\x08 \x01(\tH\x00\x42\x08\n\x06targetJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\"\xb9\x01\n\x0f\x41nalyzeResponse\x12@\n\x12resolved_statement\x18\x01 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProtoH\x00\x12<\n\x13resolved_expression\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProtoH\x00\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x42\x08\n\x06result\"\xc3\x02\n\x0f\x42uildSqlRequest\x12\x33\n\x0esimple_catalog\x18\x01 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x06 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12\x1d\n\x15registered_catalog_id\x18\x03 \x01(\x03\x12@\n\x12resolved_statement\x18\x04 \x01(\x0b\x32\".zetasql.AnyResolvedStatementProtoH\x00\x12<\n\x13resolved_expression\x18\x05 \x01(\x0b\x32\x1d.zetasql.AnyResolvedExprProtoH\x00\x42\x08\n\x06targetJ\x04\x08\x02\x10\x03\"\x1f\n\x10\x42uildSqlResponse\x12\x0b\n\x03sql\x18\x01 \x01(\t\"\x84\x01\n%ExtractTableNamesFromStatementRequest\x12\x15\n\rsql_statement\x18\x01 \x01(\t\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12\x14\n\x0c\x61llow_script\x18\x03 \x01(\x08\"\xae\x01\n&ExtractTableNamesFromStatementResponse\x12[\n\ntable_name\x18\x01 \x03(\x0b\x32G.zetasql.local_service.ExtractTableNamesFromStatementResponse.TableName\x1a\'\n\tTableName\x12\x1a\n\x12table_name_segment\x18\x01 \x03(\t\"\x9d\x01\n)ExtractTableNamesFromNextStatementRequest\x12@\n\x15parse_resume_location\x18\x01 \x02(\x0b\x32!.zetasql.ParseResumeLocationProto\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\"\xd4\x01\n*ExtractTableNamesFromNextStatementResponse\x12_\n\ntable_name\x18\x01 \x03(\x0b\x32K.zetasql.local_service.ExtractTableNamesFromNextStatementResponse.TableName\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x1a\'\n\tTableName\x12\x1a\n\x12table_name_segment\x18\x01 \x03(\t\"\x83\x01\n\x10\x46ormatSqlRequest\x12\x0b\n\x03sql\x18\x01 \x01(\t\x12/\n\x07options\x18\x02 \x01(\x0b\x32\x1e.zetasql.FormatterOptionsProto\x12\x31\n\x0b\x62yte_ranges\x18\x03 \x03(\x0b\x32\x1c.zetasql.FormatterRangeProto\" \n\x11\x46ormatSqlResponse\x12\x0b\n\x03sql\x18\x01 \x01(\t\"\xd3\x02\n\x16RegisterCatalogRequest\x12\x33\n\x0esimple_catalog\x18\x01 \x01(\x0b\x32\x1b.zetasql.SimpleCatalogProto\x12L\n\x14\x64\x65scriptor_pool_list\x18\x03 \x01(\x0b\x32..zetasql.local_service.DescriptorPoolListProto\x12V\n\rtable_content\x18\x04 \x03(\x0b\x32?.zetasql.local_service.RegisterCatalogRequest.TableContentEntry\x1aX\n\x11TableContentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.zetasql.local_service.TableContent:\x02\x38\x01J\x04\x08\x02\x10\x03\"D\n\x0cTableContent\x12\x34\n\ntable_data\x18\x01 \x01(\x0b\x32 .zetasql.local_service.TableData\"h\n\tTableData\x12\x31\n\x03row\x18\x01 \x03(\x0b\x32$.zetasql.local_service.TableData.Row\x1a(\n\x03Row\x12!\n\x04\x63\x65ll\x18\x01 \x03(\x0b\x32\x13.zetasql.ValueProto\"w\n\x10RegisterResponse\x12\x15\n\rregistered_id\x18\x01 \x01(\x03\x12L\n\x17\x64\x65scriptor_pool_id_list\x18\x02 \x01(\x0b\x32+.zetasql.local_service.DescriptorPoolIdList\"*\n\x11UnregisterRequest\x12\x15\n\rregistered_id\x18\x01 \x01(\x03\"\x99\x02\n\x1bGetBuiltinFunctionsResponse\x12(\n\x08\x66unction\x18\x01 \x03(\x0b\x32\x16.zetasql.FunctionProto\x12L\n\x05types\x18\x02 \x03(\x0b\x32=.zetasql.local_service.GetBuiltinFunctionsResponse.TypesEntry\x12@\n\x15table_valued_function\x18\x03 \x03(\x0b\x32!.zetasql.TableValuedFunctionProto\x1a@\n\nTypesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12!\n\x05value\x18\x02 \x01(\x0b\x32\x12.zetasql.TypeProto:\x02\x38\x01\"f\n\x16LanguageOptionsRequest\x12\x18\n\x10maximum_features\x18\x01 \x01(\x08\x12\x32\n\x10language_version\x18\x02 \x01(\x0e\x32\x18.zetasql.LanguageVersion\"\x18\n\x16\x41nalyzerOptionsRequest\"\xbb\x01\n\x0cParseRequest\x12\x17\n\rsql_statement\x18\x01 \x01(\tH\x00\x12\x42\n\x15parse_resume_location\x18\x03 \x01(\x0b\x32!.zetasql.ParseResumeLocationProtoH\x00\x12.\n\x07options\x18\x02 \x01(\x0b\x32\x1d.zetasql.LanguageOptionsProto\x12\x14\n\x0c\x61llow_script\x18\x04 \x01(\x08\x42\x08\n\x06target\"\xa4\x01\n\rParseResponse\x12\x39\n\x10parsed_statement\x18\x01 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProtoH\x00\x12\x30\n\rparsed_script\x18\x03 \x01(\x0b\x32\x17.zetasql.ASTScriptProtoH\x00\x12\x1c\n\x14resume_byte_position\x18\x02 \x01(\x05\x42\x08\n\x06result2\xa2\x15\n\x13ZetaSqlLocalService\x12Z\n\x07Prepare\x12%.zetasql.local_service.PrepareRequest\x1a&.zetasql.local_service.PrepareResponse\"\x00\x12]\n\x08\x45valuate\x12&.zetasql.local_service.EvaluateRequest\x1a\'.zetasql.local_service.EvaluateResponse\"\x00\x12q\n\x0e\x45valuateStream\x12+.zetasql.local_service.EvaluateRequestBatch\x1a,.zetasql.local_service.EvaluateResponseBatch\"\x00(\x01\x30\x01\x12N\n\tUnprepare\x12\'.zetasql.local_service.UnprepareRequest\x1a\x16.google.protobuf.Empty\"\x00\x12i\n\x0cPrepareQuery\x12*.zetasql.local_service.PrepareQueryRequest\x1a+.zetasql.local_service.PrepareQueryResponse\"\x00\x12X\n\x0eUnprepareQuery\x12,.zetasql.local_service.UnprepareQueryRequest\x1a\x16.google.protobuf.Empty\"\x00\x12l\n\rEvaluateQuery\x12+.zetasql.local_service.EvaluateQueryRequest\x1a,.zetasql.local_service.EvaluateQueryResponse\"\x00\x12\x80\x01\n\x13\x45valuateQueryStream\x12\x30.zetasql.local_service.EvaluateQueryBatchRequest\x1a\x31.zetasql.local_service.EvaluateQueryBatchResponse\"\x00(\x01\x30\x01\x12l\n\rPrepareModify\x12+.zetasql.local_service.PrepareModifyRequest\x1a,.zetasql.local_service.PrepareModifyResponse\"\x00\x12Z\n\x0fUnprepareModify\x12-.zetasql.local_service.UnprepareModifyRequest\x1a\x16.google.protobuf.Empty\"\x00\x12o\n\x0e\x45valuateModify\x12,.zetasql.local_service.EvaluateModifyRequest\x1a-.zetasql.local_service.EvaluateModifyResponse\"\x00\x12\x83\x01\n\x14\x45valuateModifyStream\x12\x31.zetasql.local_service.EvaluateModifyBatchRequest\x1a\x32.zetasql.local_service.EvaluateModifyBatchResponse\"\x00(\x01\x30\x01\x12^\n\x11GetTableFromProto\x12,.zetasql.local_service.TableFromProtoRequest\x1a\x19.zetasql.SimpleTableProto\"\x00\x12k\n\x0fRegisterCatalog\x12-.zetasql.local_service.RegisterCatalogRequest\x1a\'.zetasql.local_service.RegisterResponse\"\x00\x12Z\n\x07\x41nalyze\x12%.zetasql.local_service.AnalyzeRequest\x1a&.zetasql.local_service.AnalyzeResponse\"\x00\x12]\n\x08\x42uildSql\x12&.zetasql.local_service.BuildSqlRequest\x1a\'.zetasql.local_service.BuildSqlResponse\"\x00\x12\x9f\x01\n\x1e\x45xtractTableNamesFromStatement\x12<.zetasql.local_service.ExtractTableNamesFromStatementRequest\x1a=.zetasql.local_service.ExtractTableNamesFromStatementResponse\"\x00\x12\xab\x01\n\"ExtractTableNamesFromNextStatement\x12@.zetasql.local_service.ExtractTableNamesFromNextStatementRequest\x1a\x41.zetasql.local_service.ExtractTableNamesFromNextStatementResponse\"\x00\x12`\n\tFormatSql\x12\'.zetasql.local_service.FormatSqlRequest\x1a(.zetasql.local_service.FormatSqlResponse\"\x00\x12g\n\x10LenientFormatSql\x12\'.zetasql.local_service.FormatSqlRequest\x1a(.zetasql.local_service.FormatSqlResponse\"\x00\x12W\n\x11UnregisterCatalog\x12(.zetasql.local_service.UnregisterRequest\x1a\x16.google.protobuf.Empty\"\x00\x12x\n\x13GetBuiltinFunctions\x12+.zetasql.ZetaSQLBuiltinFunctionOptionsProto\x1a\x32.zetasql.local_service.GetBuiltinFunctionsResponse\"\x00\x12\x64\n\x12GetLanguageOptions\x12-.zetasql.local_service.LanguageOptionsRequest\x1a\x1d.zetasql.LanguageOptionsProto\"\x00\x12\x64\n\x12GetAnalyzerOptions\x12-.zetasql.local_service.AnalyzerOptionsRequest\x1a\x1d.zetasql.AnalyzerOptionsProto\"\x00\x12T\n\x05Parse\x12#.zetasql.local_service.ParseRequest\x1a$.zetasql.local_service.ParseResponse\"\x00\x42\"\n\x12\x63om.google.zetasqlB\x0cLocalService')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.local_service.local_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\014LocalService'
  _globals['_DESCRIPTORPOOLIDLIST'].fields_by_name['registered_ids']._loaded_options = None
  _globals['_DESCRIPTORPOOLIDLIST'].fields_by_name['registered_ids']._serialized_options = b'\020\001'
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._loaded_options = None
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_options = b'8\001'
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._loaded_options = None
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_options = b'8\001'
  _globals['_DESCRIPTORPOOLLISTPROTO']._serialized_start=505
  _globals['_DESCRIPTORPOOLLISTPROTO']._serialized_end=817
  _globals['_DESCRIPTORPOOLLISTPROTO_BUILTIN']._serialized_start=612
  _globals['_DESCRIPTORPOOLLISTPROTO_BUILTIN']._serialized_end=621
  _globals['_DESCRIPTORPOOLLISTPROTO_DEFINITION']._serialized_start=624
  _globals['_DESCRIPTORPOOLLISTPROTO_DEFINITION']._serialized_end=817
  _globals['_DESCRIPTORPOOLIDLIST']._serialized_start=819
  _globals['_DESCRIPTORPOOLIDLIST']._serialized_end=869
  _globals['_PREPAREREQUEST']._serialized_start=872
  _globals['_PREPAREREQUEST']._serialized_end=1117
  _globals['_PREPAREDSTATE']._serialized_start=1120
  _globals['_PREPAREDSTATE']._serialized_end=1381
  _globals['_PREPARERESPONSE']._serialized_start=1383
  _globals['_PREPARERESPONSE']._serialized_end=1468
  _globals['_EVALUATEREQUEST']._serialized_start=1471
  _globals['_EVALUATEREQUEST']._serialized_end=1867
  _globals['_EVALUATEREQUEST_PARAMETER']._serialized_start=1794
  _globals['_EVALUATEREQUEST_PARAMETER']._serialized_end=1861
  _globals['_EVALUATERESPONSE']._serialized_start=1869
  _globals['_EVALUATERESPONSE']._serialized_end=1991
  _globals['_EVALUATEREQUESTBATCH']._serialized_start=1993
  _globals['_EVALUATEREQUESTBATCH']._serialized_end=2072
  _globals['_EVALUATERESPONSEBATCH']._serialized_start=2074
  _globals['_EVALUATERESPONSEBATCH']._serialized_end=2156
  _globals['_UNPREPAREREQUEST']._serialized_start=2158
  _globals['_UNPREPAREREQUEST']._serialized_end=2208
  _globals['_PREPAREQUERYREQUEST']._serialized_start=2211
  _globals['_PREPAREQUERYREQUEST']._serialized_end=2645
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_PREPAREQUERYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_PREPAREDQUERYSTATE']._serialized_start=2648
  _globals['_PREPAREDQUERYSTATE']._serialized_end=2885
  _globals['_PREPAREQUERYRESPONSE']._serialized_start=2887
  _globals['_PREPAREQUERYRESPONSE']._serialized_end=2970
  _globals['_PARAMETER']._serialized_start=1794
  _globals['_PARAMETER']._serialized_end=1861
  _globals['_UNPREPAREQUERYREQUEST']._serialized_start=3041
  _globals['_UNPREPAREQUERYREQUEST']._serialized_end=3091
  _globals['_EVALUATEQUERYREQUEST']._serialized_start=3094
  _globals['_EVALUATEQUERYREQUEST']._serialized_end=3609
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_EVALUATEQUERYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_EVALUATEQUERYRESPONSE']._serialized_start=3612
  _globals['_EVALUATEQUERYRESPONSE']._serialized_end=3750
  _globals['_EVALUATEQUERYBATCHREQUEST']._serialized_start=3752
  _globals['_EVALUATEQUERYBATCHREQUEST']._serialized_end=3841
  _globals['_EVALUATEQUERYBATCHRESPONSE']._serialized_start=3843
  _globals['_EVALUATEQUERYBATCHRESPONSE']._serialized_end=3935
  _globals['_PREPAREMODIFYREQUEST']._serialized_start=3938
  _globals['_PREPAREMODIFYREQUEST']._serialized_end=4374
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_PREPAREMODIFYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_PREPAREDMODIFYSTATE']._serialized_start=4377
  _globals['_PREPAREDMODIFYSTATE']._serialized_end=4571
  _globals['_PREPAREMODIFYRESPONSE']._serialized_start=4573
  _globals['_PREPAREMODIFYRESPONSE']._serialized_end=4658
  _globals['_UNPREPAREMODIFYREQUEST']._serialized_start=4660
  _globals['_UNPREPAREMODIFYREQUEST']._serialized_end=4712
  _globals['_EVALUATEMODIFYREQUEST']._serialized_start=4715
  _globals['_EVALUATEMODIFYREQUEST']._serialized_end=5233
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_EVALUATEMODIFYREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_EVALUATEMODIFYRESPONSE']._serialized_start=5236
  _globals['_EVALUATEMODIFYRESPONSE']._serialized_end=5641
  _globals['_EVALUATEMODIFYRESPONSE_ROW']._serialized_start=5413
  _globals['_EVALUATEMODIFYRESPONSE_ROW']._serialized_end=5641
  _globals['_EVALUATEMODIFYRESPONSE_ROW_OPERATION']._serialized_start=5581
  _globals['_EVALUATEMODIFYRESPONSE_ROW_OPERATION']._serialized_end=5641
  _globals['_EVALUATEMODIFYBATCHREQUEST']._serialized_start=5643
  _globals['_EVALUATEMODIFYBATCHREQUEST']._serialized_end=5734
  _globals['_EVALUATEMODIFYBATCHRESPONSE']._serialized_start=5736
  _globals['_EVALUATEMODIFYBATCHRESPONSE']._serialized_end=5830
  _globals['_TABLEFROMPROTOREQUEST']._serialized_start=5833
  _globals['_TABLEFROMPROTOREQUEST']._serialized_end=5961
  _globals['_ANALYZEREQUEST']._serialized_start=5964
  _globals['_ANALYZEREQUEST']._serialized_end=6331
  _globals['_ANALYZERESPONSE']._serialized_start=6334
  _globals['_ANALYZERESPONSE']._serialized_end=6519
  _globals['_BUILDSQLREQUEST']._serialized_start=6522
  _globals['_BUILDSQLREQUEST']._serialized_end=6845
  _globals['_BUILDSQLRESPONSE']._serialized_start=6847
  _globals['_BUILDSQLRESPONSE']._serialized_end=6878
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTREQUEST']._serialized_start=6881
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTREQUEST']._serialized_end=7013
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE']._serialized_start=7016
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE']._serialized_end=7190
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE_TABLENAME']._serialized_start=7151
  _globals['_EXTRACTTABLENAMESFROMSTATEMENTRESPONSE_TABLENAME']._serialized_end=7190
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTREQUEST']._serialized_start=7193
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTREQUEST']._serialized_end=7350
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE']._serialized_start=7353
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE']._serialized_end=7565
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE_TABLENAME']._serialized_start=7151
  _globals['_EXTRACTTABLENAMESFROMNEXTSTATEMENTRESPONSE_TABLENAME']._serialized_end=7190
  _globals['_FORMATSQLREQUEST']._serialized_start=7568
  _globals['_FORMATSQLREQUEST']._serialized_end=7699
  _globals['_FORMATSQLRESPONSE']._serialized_start=7701
  _globals['_FORMATSQLRESPONSE']._serialized_end=7733
  _globals['_REGISTERCATALOGREQUEST']._serialized_start=7736
  _globals['_REGISTERCATALOGREQUEST']._serialized_end=8075
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_start=2546
  _globals['_REGISTERCATALOGREQUEST_TABLECONTENTENTRY']._serialized_end=2634
  _globals['_TABLECONTENT']._serialized_start=8077
  _globals['_TABLECONTENT']._serialized_end=8145
  _globals['_TABLEDATA']._serialized_start=8147
  _globals['_TABLEDATA']._serialized_end=8251
  _globals['_TABLEDATA_ROW']._serialized_start=8211
  _globals['_TABLEDATA_ROW']._serialized_end=8251
  _globals['_REGISTERRESPONSE']._serialized_start=8253
  _globals['_REGISTERRESPONSE']._serialized_end=8372
  _globals['_UNREGISTERREQUEST']._serialized_start=8374
  _globals['_UNREGISTERREQUEST']._serialized_end=8416
  _globals['_GETBUILTINFUNCTIONSRESPONSE']._serialized_start=8419
  _globals['_GETBUILTINFUNCTIONSRESPONSE']._serialized_end=8700
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_start=8636
  _globals['_GETBUILTINFUNCTIONSRESPONSE_TYPESENTRY']._serialized_end=8700
  _globals['_LANGUAGEOPTIONSREQUEST']._serialized_start=8702
  _globals['_LANGUAGEOPTIONSREQUEST']._serialized_end=8804
  _globals['_ANALYZEROPTIONSREQUEST']._serialized_start=8806
  _globals['_ANALYZEROPTIONSREQUEST']._serialized_end=8830
  _globals['_PARSEREQUEST']._serialized_start=8833
  _globals['_PARSEREQUEST']._serialized_end=9020
  _globals['_PARSERESPONSE']._serialized_start=9023
  _globals['_PARSERESPONSE']._serialized_end=9187
  _globals['_ZETASQLLOCALSERVICE']._serialized_start=9190
  _globals['_ZETASQLLOCALSERVICE']._serialized_end=11912
# @@protoc_insertion_point(module_scope)
