# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/functions/bitwise_agg_mode.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/functions/bitwise_agg_mode.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/zetasql/public/functions/bitwise_agg_mode.proto\x12\x11zetasql.functions\x1a\x19zetasql/public/type.proto\"z\n\x0f\x42itwiseAggEnums\"g\n\x0e\x42itwiseAggMode\x12&\n\x18\x42ITWISE_AGG_MODE_INVALID\x10\x00\x1a\x08\xb2\xf2\xb0\x92\x0e\x02\x08\x01\x12\n\n\x06STRICT\x10\x01\x12\x07\n\x03PAD\x10\x02\x1a\x18\xb2\xd0\xaf\xfa\r\x12\n\x10\x42ITWISE_AGG_MODEB5\n\x1c\x63om.google.zetasql.functionsB\x15ZetaSQLBitwiseAggMode')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.functions.bitwise_agg_mode_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.google.zetasql.functionsB\025ZetaSQLBitwiseAggMode'
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._loaded_options = None
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_options = b'\262\320\257\372\r\022\n\020BITWISE_AGG_MODE'
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE'].values_by_name["BITWISE_AGG_MODE_INVALID"]._loaded_options = None
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE'].values_by_name["BITWISE_AGG_MODE_INVALID"]._serialized_options = b'\262\362\260\222\016\002\010\001'
  _globals['_BITWISEAGGENUMS']._serialized_start=97
  _globals['_BITWISEAGGENUMS']._serialized_end=219
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_start=116
  _globals['_BITWISEAGGENUMS_BITWISEAGGMODE']._serialized_end=219
# @@protoc_insertion_point(module_scope)
