# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/function.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/function.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dzetasql/public/function.proto\x12\x07zetasql\"\xa0\x08\n\rFunctionEnums\"?\n\x13\x41rgumentCardinality\x12\x0c\n\x08REQUIRED\x10\x00\x12\x0c\n\x08REPEATED\x10\x01\x12\x0c\n\x08OPTIONAL\x10\x02\"@\n\x15ProcedureArgumentMode\x12\x0b\n\x07NOT_SET\x10\x00\x12\x06\n\x02IN\x10\x01\x12\x07\n\x03OUT\x10\x02\x12\t\n\x05INOUT\x10\x03\"S\n\x12WindowOrderSupport\x12\x15\n\x11ORDER_UNSUPPORTED\x10\x00\x12\x12\n\x0eORDER_OPTIONAL\x10\x01\x12\x12\n\x0eORDER_REQUIRED\x10\x02\"/\n\x04Mode\x12\n\n\x06SCALAR\x10\x01\x12\r\n\tAGGREGATE\x10\x02\x12\x0c\n\x08\x41NALYTIC\x10\x03\"5\n\nVolatility\x12\r\n\tIMMUTABLE\x10\x00\x12\n\n\x06STABLE\x10\x01\x12\x0c\n\x08VOLATILE\x10\x02\"\xd9\x01\n\x17TableValuedFunctionType\x12\x0b\n\x07INVALID\x10\x00\x12\x1b\n\x17\x46IXED_OUTPUT_SCHEMA_TVF\x10\x01\x12-\n)FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_TVF\x10\x02\x12\x15\n\x11TEMPLATED_SQL_TVF\x10\x03\x12?\n;FORWARD_INPUT_SCHEMA_TO_OUTPUT_SCHEMA_WITH_APPENDED_COLUMNS\x10\x07\x12\r\n\tBASIS_TVF\x10\x08\"\x80\x01\n\x15\x41rgumentCollationMode\x12\x10\n\x0c\x41\x46\x46\x45\x43TS_NONE\x10\x00\x12\x15\n\x11\x41\x46\x46\x45\x43TS_OPERATION\x10\x01\x12\x17\n\x13\x41\x46\x46\x45\x43TS_PROPAGATION\x10\x02\x12%\n!AFFECTS_OPERATION_AND_PROPAGATION\x10\x03\"v\n\x11NamedArgumentKind\x12#\n\x1fNAMED_ARGUMENT_KIND_UNSPECIFIED\x10\x00\x12\x13\n\x0fPOSITIONAL_ONLY\x10\x01\x12\x17\n\x13POSITIONAL_OR_NAMED\x10\x02\x12\x0e\n\nNAMED_ONLY\x10\x03\"h\n\x11\x41rgumentAliasKind\x12#\n\x1f\x41RGUMENT_ALIAS_KIND_UNSPECIFIED\x10\x00\x12\x18\n\x14\x41RGUMENT_NON_ALIASED\x10\x01\x12\x14\n\x10\x41RGUMENT_ALIASED\x10\x02\"\x8d\x01\n\x13\x44\x65\x66\x61ultNullHandling\x12%\n!DEFAULT_NULL_HANDLING_UNSPECIFIED\x10\x00\x12&\n\"DEFAULT_NULL_HANDLING_IGNORE_NULLS\x10\x01\x12\'\n#DEFAULT_NULL_HANDLING_RESPECT_NULLS\x10\x02*\xdc\x06\n\x15SignatureArgumentKind\x12\x12\n\x0e\x41RG_TYPE_FIXED\x10\x00\x12\x12\n\x0e\x41RG_TYPE_ANY_1\x10\x01\x12\x12\n\x0e\x41RG_TYPE_ANY_2\x10\x02\x12\x12\n\x0e\x41RG_TYPE_ANY_3\x10\x17\x12\x12\n\x0e\x41RG_TYPE_ANY_4\x10\x19\x12\x12\n\x0e\x41RG_TYPE_ANY_5\x10\x1b\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_1\x10\x03\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_2\x10\x04\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_3\x10\x18\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_4\x10\x1a\x12\x18\n\x14\x41RG_ARRAY_TYPE_ANY_5\x10\x1c\x12\x15\n\x11\x41RG_PROTO_MAP_ANY\x10\x0e\x12\x19\n\x15\x41RG_PROTO_MAP_KEY_ANY\x10\x0f\x12\x1b\n\x17\x41RG_PROTO_MAP_VALUE_ANY\x10\x10\x12\x11\n\rARG_PROTO_ANY\x10\x05\x12\x12\n\x0e\x41RG_STRUCT_ANY\x10\x06\x12\x10\n\x0c\x41RG_ENUM_ANY\x10\x07\x12\x16\n\x12\x41RG_TYPE_ARBITRARY\x10\x08\x12\x15\n\x11\x41RG_TYPE_RELATION\x10\t\x12\x11\n\rARG_TYPE_VOID\x10\n\x12\x12\n\x0e\x41RG_TYPE_MODEL\x10\x0b\x12\x17\n\x13\x41RG_TYPE_CONNECTION\x10\x0c\x12\x17\n\x13\x41RG_TYPE_DESCRIPTOR\x10\r\x12\x13\n\x0f\x41RG_TYPE_LAMBDA\x10\x11\x12\x18\n\x14\x41RG_RANGE_TYPE_ANY_1\x10\x12\x12\x17\n\x13\x41RG_TYPE_GRAPH_NODE\x10\x13\x12\x17\n\x13\x41RG_TYPE_GRAPH_EDGE\x10\x14\x12\x1a\n\x16\x41RG_TYPE_GRAPH_ELEMENT\x10\x15\x12\x17\n\x13\x41RG_TYPE_GRAPH_PATH\x10\x1e\x12\x12\n\x0e\x41RG_TYPE_GRAPH\x10 \x12\x15\n\x11\x41RG_TYPE_SEQUENCE\x10\x16\x12\x1a\n\x16\x41RG_MEASURE_TYPE_ANY_1\x10\x1f\x12\x18\n\x14\x41RG_MAP_TYPE_ANY_1_2\x10\x1d\x12\x42\n5__SignatureArgumentKind__switch_must_have_a_default__\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x42&\n\x12\x63om.google.zetasqlB\x10ZetaSQLFunctions')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.function_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\020ZetaSQLFunctions'
  _globals['_SIGNATUREARGUMENTKIND']._serialized_start=1102
  _globals['_SIGNATUREARGUMENTKIND']._serialized_end=1962
  _globals['_FUNCTIONENUMS']._serialized_start=43
  _globals['_FUNCTIONENUMS']._serialized_end=1099
  _globals['_FUNCTIONENUMS_ARGUMENTCARDINALITY']._serialized_start=60
  _globals['_FUNCTIONENUMS_ARGUMENTCARDINALITY']._serialized_end=123
  _globals['_FUNCTIONENUMS_PROCEDUREARGUMENTMODE']._serialized_start=125
  _globals['_FUNCTIONENUMS_PROCEDUREARGUMENTMODE']._serialized_end=189
  _globals['_FUNCTIONENUMS_WINDOWORDERSUPPORT']._serialized_start=191
  _globals['_FUNCTIONENUMS_WINDOWORDERSUPPORT']._serialized_end=274
  _globals['_FUNCTIONENUMS_MODE']._serialized_start=276
  _globals['_FUNCTIONENUMS_MODE']._serialized_end=323
  _globals['_FUNCTIONENUMS_VOLATILITY']._serialized_start=325
  _globals['_FUNCTIONENUMS_VOLATILITY']._serialized_end=378
  _globals['_FUNCTIONENUMS_TABLEVALUEDFUNCTIONTYPE']._serialized_start=381
  _globals['_FUNCTIONENUMS_TABLEVALUEDFUNCTIONTYPE']._serialized_end=598
  _globals['_FUNCTIONENUMS_ARGUMENTCOLLATIONMODE']._serialized_start=601
  _globals['_FUNCTIONENUMS_ARGUMENTCOLLATIONMODE']._serialized_end=729
  _globals['_FUNCTIONENUMS_NAMEDARGUMENTKIND']._serialized_start=731
  _globals['_FUNCTIONENUMS_NAMEDARGUMENTKIND']._serialized_end=849
  _globals['_FUNCTIONENUMS_ARGUMENTALIASKIND']._serialized_start=851
  _globals['_FUNCTIONENUMS_ARGUMENTALIASKIND']._serialized_end=955
  _globals['_FUNCTIONENUMS_DEFAULTNULLHANDLING']._serialized_start=958
  _globals['_FUNCTIONENUMS_DEFAULTNULLHANDLING']._serialized_end=1099
# @@protoc_insertion_point(module_scope)
