# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/scripting/script_executor_state.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/scripting/script_executor_state.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from zetasql.wasi._pb2.zetasql.proto import function_pb2 as zetasql_dot_proto_dot_function__pb2
from zetasql.wasi._pb2.zetasql.proto import script_exception_pb2 as zetasql_dot_proto_dot_script__exception__pb2
from zetasql.wasi._pb2.zetasql.scripting import procedure_extension_pb2 as zetasql_dot_scripting_dot_procedure__extension__pb2
from zetasql.wasi._pb2.zetasql.scripting import variable_pb2 as zetasql_dot_scripting_dot_variable__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-zetasql/scripting/script_executor_state.proto\x12\x07zetasql\x1a\x19google/protobuf/any.proto\x1a\x1czetasql/proto/function.proto\x1a$zetasql/proto/script_exception.proto\x1a+zetasql/scripting/procedure_extension.proto\x1a zetasql/scripting/variable.proto\"\xaa\n\n\x18ScriptExecutorStateProto\x12?\n\tcallstack\x18\x01 \x03(\x0b\x32,.zetasql.ScriptExecutorStateProto.StackFrame\x12\x34\n\x12pending_exceptions\x18\x02 \x03(\x0b\x32\x18.zetasql.ScriptException\x12K\n\x12triggered_features\x18\x03 \x03(\x0e\x32/.zetasql.ScriptExecutorStateProto.ScriptFeature\x12\x10\n\x08timezone\x18\x04 \x01(\t\x12#\n\x1b\x63\x61se_stmt_true_branch_index\x18\x05 \x01(\x03\x12&\n\x1e\x63\x61se_stmt_current_branch_index\x18\x06 \x01(\x03\x12O\n\x11sql_feature_usage\x18\x07 \x01(\x0b\x32\x34.zetasql.ScriptExecutorStateProto.ScriptFeatureUsage\x1a\xc9\x01\n\x13ProcedureDefinition\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\tsignature\x18\x02 \x01(\x0b\x32\x1f.zetasql.FunctionSignatureProto\x12\x1a\n\x12\x61rgument_name_list\x18\x03 \x03(\t\x12\x0c\n\x04\x62ody\x18\x04 \x01(\t\x12\x16\n\x0eis_dynamic_sql\x18\x05 \x01(\x08\x12.\n\textension\x18\x06 \x01(\x0b\x32\x1b.zetasql.ProcedureExtension\x1a\x88\x04\n\nStackFrame\x12S\n\x14procedure_definition\x18\x01 \x01(\x0b\x32\x35.zetasql.ScriptExecutorStateProto.ProcedureDefinition\x12$\n\tvariables\x18\x02 \x03(\x0b\x32\x11.zetasql.Variable\x12$\n\x1c\x63urrent_location_byte_offset\x18\x03 \x01(\x05\x12\x1e\n\x16\x63ontrol_flow_node_kind\x18\x05 \x01(\x05\x12K\n\nparameters\x18\x04 \x01(\x0b\x32\x37.zetasql.ScriptExecutorStateProto.StackFrame.Parameters\x12,\n\x0e\x66or_loop_stack\x18\x06 \x03(\x0b\x32\x14.google.protobuf.Any\x1a\xbd\x01\n\nParameters\x12S\n\x04mode\x18\x04 \x01(\x0e\x32\x45.zetasql.ScriptExecutorStateProto.StackFrame.Parameters.ParameterMode\x12$\n\tvariables\x18\x05 \x03(\x0b\x32\x11.zetasql.Variable\"4\n\rParameterMode\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05NAMED\x10\x01\x12\x0e\n\nPOSITIONAL\x10\x02\x1aZ\n\x12ScriptFeatureUsage\x12\x11\n\texception\x18\x01 \x01(\x05\x12\x11\n\tcall_stmt\x18\x02 \x01(\x05\x12\x1e\n\x16\x65xecute_immediate_stmt\x18\x03 \x01(\x05\"g\n\rScriptFeature\x12\x0b\n\x07INVALID\x10\x00\x12\x14\n\x10\x45XCEPTION_CAUGHT\x10\x01\x12\x12\n\x0e\x43\x41LL_STATEMENT\x10\x02\x12\x1f\n\x1b\x45XECUTE_IMMEDIATE_STATEMENT\x10\x03')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.scripting.script_executor_state_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTEXECUTORSTATEPROTO']._serialized_start=233
  _globals['_SCRIPTEXECUTORSTATEPROTO']._serialized_end=1555
  _globals['_SCRIPTEXECUTORSTATEPROTO_PROCEDUREDEFINITION']._serialized_start=634
  _globals['_SCRIPTEXECUTORSTATEPROTO_PROCEDUREDEFINITION']._serialized_end=835
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME']._serialized_start=838
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS']._serialized_start=1169
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS_PARAMETERMODE']._serialized_start=1306
  _globals['_SCRIPTEXECUTORSTATEPROTO_STACKFRAME_PARAMETERS_PARAMETERMODE']._serialized_end=1358
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATUREUSAGE']._serialized_start=1360
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATUREUSAGE']._serialized_end=1450
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATURE']._serialized_start=1452
  _globals['_SCRIPTEXECUTORSTATEPROTO_SCRIPTFEATURE']._serialized_end=1555
# @@protoc_insertion_point(module_scope)
