# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/resolved_ast/serialization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/resolved_ast/serialization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import annotation_pb2 as zetasql_dot_public_dot_annotation__pb2
from zetasql.wasi._pb2.zetasql.public import parse_location_range_pb2 as zetasql_dot_public_dot_parse__location__range__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2
from zetasql.wasi._pb2.zetasql.public import value_pb2 as zetasql_dot_public_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(zetasql/resolved_ast/serialization.proto\x12\x07zetasql\x1a\x1fzetasql/public/annotation.proto\x1a)zetasql/public/parse_location_range.proto\x1a\x19zetasql/public/type.proto\x1a\x1azetasql/public/value.proto\"\xa1\x01\n\x13ResolvedColumnProto\x12\x11\n\tcolumn_id\x18\x01 \x01(\x03\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12 \n\x04type\x18\x04 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\x33\n\x0e\x61nnotation_map\x18\x05 \x01(\x0b\x32\x1b.zetasql.AnnotationMapProto\"Z\n\x12ValueWithTypeProto\x12 \n\x04type\x18\x01 \x01(\x0b\x32\x12.zetasql.TypeProto\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.zetasql.ValueProto\"J\n\rTableRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x11\n\tfull_name\x18\x03 \x01(\t\"J\n\rModelRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10serialization_id\x18\x02 \x01(\x03\x12\x11\n\tfull_name\x18\x03 \x01(\t\"5\n\x12\x43onnectionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x03 \x01(\t\"3\n\x10SequenceRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tfull_name\x18\x02 \x01(\t\" \n\x10\x43onstantRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\" \n\x10\x46unctionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x1bTableValuedFunctionRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"S\n\x11ResolvedNodeProto\x12>\n\x14parse_location_range\x18\x01 \x01(\x0b\x32 .zetasql.ParseLocationRangeProto\"\\\n\x17\x46ieldDescriptorRefProto\x12\x31\n\x10\x63ontaining_proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12\x0e\n\x06number\x18\x02 \x01(\x05\"[\n\x17OneofDescriptorRefProto\x12\x31\n\x10\x63ontaining_proto\x18\x01 \x01(\x0b\x32\x17.zetasql.ProtoTypeProto\x12\r\n\x05index\x18\x02 \x01(\x05\"!\n\x11ProcedureRefProto\x12\x0c\n\x04name\x18\x01 \x01(\t\"e\n\x16ResolvedCollationProto\x12\x16\n\x0e\x63ollation_name\x18\x01 \x01(\t\x12\x33\n\nchild_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ResolvedCollationProto\"I\n\x0e\x43olumnRefProto\x12)\n\ttable_ref\x18\x01 \x01(\x0b\x32\x16.zetasql.TableRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"*\n\x15PropertyGraphRefProto\x12\x11\n\tfull_name\x18\x01 \x01(\t\"h\n GraphPropertyDeclarationRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x19GraphElementLabelRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\t\"a\n\x19GraphElementTableRefProto\x12\x36\n\x0eproperty_graph\x18\x01 \x01(\x0b\x32\x1e.zetasql.PropertyGraphRefProto\x12\x0c\n\x04name\x18\x02 \x01(\tB,\n\x12\x63om.google.zetasqlB\x14ZetaSQLSerializationP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.resolved_ast.serialization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\024ZetaSQLSerializationP\001'
  _globals['_RESOLVEDCOLUMNPROTO']._serialized_start=185
  _globals['_RESOLVEDCOLUMNPROTO']._serialized_end=346
  _globals['_VALUEWITHTYPEPROTO']._serialized_start=348
  _globals['_VALUEWITHTYPEPROTO']._serialized_end=438
  _globals['_TABLEREFPROTO']._serialized_start=440
  _globals['_TABLEREFPROTO']._serialized_end=514
  _globals['_MODELREFPROTO']._serialized_start=516
  _globals['_MODELREFPROTO']._serialized_end=590
  _globals['_CONNECTIONREFPROTO']._serialized_start=592
  _globals['_CONNECTIONREFPROTO']._serialized_end=645
  _globals['_SEQUENCEREFPROTO']._serialized_start=647
  _globals['_SEQUENCEREFPROTO']._serialized_end=698
  _globals['_CONSTANTREFPROTO']._serialized_start=700
  _globals['_CONSTANTREFPROTO']._serialized_end=732
  _globals['_FUNCTIONREFPROTO']._serialized_start=734
  _globals['_FUNCTIONREFPROTO']._serialized_end=766
  _globals['_TABLEVALUEDFUNCTIONREFPROTO']._serialized_start=768
  _globals['_TABLEVALUEDFUNCTIONREFPROTO']._serialized_end=811
  _globals['_RESOLVEDNODEPROTO']._serialized_start=813
  _globals['_RESOLVEDNODEPROTO']._serialized_end=896
  _globals['_FIELDDESCRIPTORREFPROTO']._serialized_start=898
  _globals['_FIELDDESCRIPTORREFPROTO']._serialized_end=990
  _globals['_ONEOFDESCRIPTORREFPROTO']._serialized_start=992
  _globals['_ONEOFDESCRIPTORREFPROTO']._serialized_end=1083
  _globals['_PROCEDUREREFPROTO']._serialized_start=1085
  _globals['_PROCEDUREREFPROTO']._serialized_end=1118
  _globals['_RESOLVEDCOLLATIONPROTO']._serialized_start=1120
  _globals['_RESOLVEDCOLLATIONPROTO']._serialized_end=1221
  _globals['_COLUMNREFPROTO']._serialized_start=1223
  _globals['_COLUMNREFPROTO']._serialized_end=1296
  _globals['_PROPERTYGRAPHREFPROTO']._serialized_start=1298
  _globals['_PROPERTYGRAPHREFPROTO']._serialized_end=1340
  _globals['_GRAPHPROPERTYDECLARATIONREFPROTO']._serialized_start=1342
  _globals['_GRAPHPROPERTYDECLARATIONREFPROTO']._serialized_end=1446
  _globals['_GRAPHELEMENTLABELREFPROTO']._serialized_start=1448
  _globals['_GRAPHELEMENTLABELREFPROTO']._serialized_end=1545
  _globals['_GRAPHELEMENTTABLEREFPROTO']._serialized_start=1547
  _globals['_GRAPHELEMENTTABLEREFPROTO']._serialized_end=1644
# @@protoc_insertion_point(module_scope)
