# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/common/reflection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/common/reflection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fzetasql/common/reflection.proto\x12\x12zetasql.reflection\"_\n\x06\x43olumn\x12\x13\n\x0btable_alias\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x1d\n\x15is_value_table_column\x18\x04 \x01(\x08\"K\n\nTableAlias\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x03(\t\x12\x1a\n\x12pseudo_column_name\x18\x03 \x03(\t\"\x8e\x02\n\x0bResultTable\x12*\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x1a.zetasql.reflection.Column\x12\x31\n\rpseudo_column\x18\x02 \x03(\x0b\x32\x1a.zetasql.reflection.Column\x12\x33\n\x0btable_alias\x18\x03 \x03(\x0b\x32\x1e.zetasql.reflection.TableAlias\x12?\n\x17\x63ommon_table_expression\x18\x04 \x03(\x0b\x32\x1e.zetasql.reflection.TableAlias\x12\x16\n\x0eis_value_table\x18\x05 \x01(\x08\x12\x12\n\nis_ordered\x18\x06 \x01(\x08\x42\x02P\x01\x62\x08\x65\x64itionsp\xe8\x07')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.common.reflection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_COLUMN']._serialized_start=55
  _globals['_COLUMN']._serialized_end=150
  _globals['_TABLEALIAS']._serialized_start=152
  _globals['_TABLEALIAS']._serialized_end=227
  _globals['_RESULTTABLE']._serialized_start=230
  _globals['_RESULTTABLE']._serialized_end=500
# @@protoc_insertion_point(module_scope)
