# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/type_annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/type_annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public.proto import type_annotation_pb2 as zetasql_dot_public_dot_proto_dot_type__annotation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/type_annotation.proto\x12\x0fzetasql.storage\x1a*zetasql/public/proto/type_annotation.protoB\x1e\n\x12\x63om.google.zetasql\xa2\x02\x07ZETASQL')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.type_annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql\242\002\007ZETASQL'
# @@protoc_insertion_point(module_scope)
