# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/constness_level.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/constness_level.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/constness_level.proto\x12\x07zetasql\"\xa4\x01\n\x13\x43onstnessLevelProto\"\x8c\x01\n\x05Level\x12\x19\n\x15\x43ONSTNESS_UNSPECIFIED\x10\x00\x12\x11\n\rFOREVER_CONST\x10\x01\x12\x12\n\x0e\x41NALYSIS_CONST\x10\x02\x12 \n\x1bLEGACY_LITERAL_OR_PARAMETER\x10\xe8\x07\x12\x1f\n\x1aLEGACY_CONSTANT_EXPRESSION\x10\xe9\x07\x42,\n\x12\x63om.google.zetasqlB\x14\x43onstnessLevelProtosP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.constness_level_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\024ConstnessLevelProtosP\001'
  _globals['_CONSTNESSLEVELPROTO']._serialized_start=50
  _globals['_CONSTNESSLEVELPROTO']._serialized_end=214
  _globals['_CONSTNESSLEVELPROTO_LEVEL']._serialized_start=74
  _globals['_CONSTNESSLEVELPROTO_LEVEL']._serialized_end=214
# @@protoc_insertion_point(module_scope)
