# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/placeholder_descriptor.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/placeholder_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*zetasql/proto/placeholder_descriptor.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\x9b\x01\n\x1aPlaceholderDescriptorProto\x12\x16\n\x0eis_placeholder\x18\x01 \x01(\x08\x32\x65\n\x16placeholder_descriptor\x12\x1f.google.protobuf.MessageOptions\x18\xb4m \x01(\x0b\x32#.zetasql.PlaceholderDescriptorProtoB1\n\x12\x63om.google.zetasqlB\x1bPlaceholderDescriptorProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.placeholder_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033PlaceholderDescriptorProtos'
  _globals['_PLACEHOLDERDESCRIPTORPROTO']._serialized_start=90
  _globals['_PLACEHOLDERDESCRIPTORPROTO']._serialized_end=245
# @@protoc_insertion_point(module_scope)
