# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/internal_error_location.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/internal_error_location.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as zetasql_dot_public_dot_error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+zetasql/proto/internal_error_location.proto\x12\x07zetasql\x1a#zetasql/public/error_location.proto\"j\n\x15InternalErrorLocation\x12\x13\n\x0b\x62yte_offset\x18\x03 \x01(\x05\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12*\n\x0c\x65rror_source\x18\x05 \x03(\x0b\x32\x14.zetasql.ErrorSourceB1\n\x12\x63om.google.zetasqlB\x1bInternalErrorLocationProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.internal_error_location_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033InternalErrorLocationProtos'
  _globals['_INTERNALERRORLOCATION']._serialized_start=93
  _globals['_INTERNALERRORLOCATION']._serialized_end=199
# @@protoc_insertion_point(module_scope)
