# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/script_exception.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/script_exception.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/proto/script_exception.proto\x12\x07zetasql\"\x9a\x02\n\x0fScriptException\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x33\n\x08internal\x18\x02 \x01(\x0b\x32!.zetasql.ScriptException.Internal\x1aS\n\x0fStackTraceFrame\x12\x0c\n\x04line\x18\x01 \x01(\x03\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\x03\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x1a\x61\n\x08Internal\x12\x16\n\x0estatement_text\x18\x01 \x01(\t\x12=\n\x0bstack_trace\x18\x02 \x03(\x0b\x32(.zetasql.ScriptException.StackTraceFrame*\t\x08\x90N\x10\x80\x80\x80\x80\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.script_exception_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTEXCEPTION']._serialized_start=50
  _globals['_SCRIPTEXCEPTION']._serialized_end=332
  _globals['_SCRIPTEXCEPTION_STACKTRACEFRAME']._serialized_start=139
  _globals['_SCRIPTEXCEPTION_STACKTRACEFRAME']._serialized_end=222
  _globals['_SCRIPTEXCEPTION_INTERNAL']._serialized_start=224
  _globals['_SCRIPTEXCEPTION_INTERNAL']._serialized_end=321
# @@protoc_insertion_point(module_scope)
