# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/parser/parse_tree.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/parser/parse_tree.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.parser import ast_enums_pb2 as zetasql_dot_parser_dot_ast__enums__pb2
from zetasql.wasi._pb2.zetasql.public import parse_location_range_pb2 as zetasql_dot_public_dot_parse__location__range__pb2
from zetasql.wasi._pb2.zetasql.public import type_pb2 as zetasql_dot_public_dot_type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fzetasql/parser/parse_tree.proto\x12\x07zetasql\x1a\x1ezetasql/parser/ast_enums.proto\x1a)zetasql/public/parse_location_range.proto\x1a\x19zetasql/public/type.proto\"\xaay\n\x0f\x41nyASTNodeProto\x12;\n\x12\x61st_statement_node\x18\x01 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProtoH\x00\x12H\n\x19\x61st_query_expression_node\x18\x03 \x01(\x0b\x32#.zetasql.AnyASTQueryExpressionProtoH\x00\x12;\n\x14\x61st_select_list_node\x18\x06 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProtoH\x00\x12?\n\x16\x61st_select_column_node\x18\x07 \x01(\x0b\x32\x1d.zetasql.ASTSelectColumnProtoH\x00\x12=\n\x13\x61st_expression_node\x18\x08 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProtoH\x00\x12\x30\n\x0e\x61st_alias_node\x18\x0c \x01(\x0b\x32\x16.zetasql.ASTAliasProtoH\x00\x12H\n\x19\x61st_table_expression_node\x18\x0f \x01(\x0b\x32#.zetasql.AnyASTTableExpressionProtoH\x00\x12;\n\x14\x61st_from_clause_node\x18\x11 \x01(\x0b\x32\x1b.zetasql.ASTFromClauseProtoH\x00\x12=\n\x15\x61st_where_clause_node\x18\x12 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProtoH\x00\x12?\n\x16\x61st_grouping_item_node\x18\x19 \x01(\x0b\x32\x1d.zetasql.ASTGroupingItemProtoH\x00\x12\x35\n\x11\x61st_group_by_node\x18\x1a \x01(\x0b\x32\x18.zetasql.ASTGroupByProtoH\x00\x12K\n\x1c\x61st_ordering_expression_node\x18\x1b \x01(\x0b\x32#.zetasql.ASTOrderingExpressionProtoH\x00\x12\x35\n\x11\x61st_order_by_node\x18\x1c \x01(\x0b\x32\x18.zetasql.ASTOrderByProtoH\x00\x12=\n\x15\x61st_limit_offset_node\x18\x1d \x01(\x0b\x32\x1c.zetasql.ASTLimitOffsetProtoH\x00\x12\x37\n\x12\x61st_on_clause_node\x18  \x01(\x0b\x32\x19.zetasql.ASTOnClauseProtoH\x00\x12?\n\x16\x61st_aliased_query_node\x18! \x01(\x0b\x32\x1d.zetasql.ASTAliasedQueryProtoH\x00\x12;\n\x14\x61st_with_clause_node\x18# \x01(\x0b\x32\x1b.zetasql.ASTWithClauseProtoH\x00\x12\x32\n\x0f\x61st_having_node\x18$ \x01(\x0b\x32\x17.zetasql.ASTHavingProtoH\x00\x12\x31\n\rast_type_node\x18% \x01(\x0b\x32\x18.zetasql.AnyASTTypeProtoH\x00\x12=\n\x15\x61st_struct_field_node\x18( \x01(\x0b\x32\x1c.zetasql.ASTStructFieldProtoH\x00\x12\x37\n\x12\x61st_select_as_node\x18+ \x01(\x0b\x32\x19.zetasql.ASTSelectAsProtoH\x00\x12\x32\n\x0f\x61st_rollup_node\x18, \x01(\x0b\x32\x17.zetasql.ASTRollupProtoH\x00\x12P\n\x1f\x61st_struct_constructor_arg_node\x18/ \x01(\x0b\x32%.zetasql.ASTStructConstructorArgProtoH\x00\x12\x33\n\x10\x61st_in_list_node\x18\x33 \x01(\x0b\x32\x17.zetasql.ASTInListProtoH\x00\x12\x34\n\x10\x61st_collate_node\x18? \x01(\x0b\x32\x18.zetasql.ASTCollateProtoH\x00\x12\x43\n\x18\x61st_having_modifier_node\x18\x46 \x01(\x0b\x32\x1f.zetasql.ASTHavingModifierProtoH\x00\x12\x39\n\x13\x61st_null_order_node\x18I \x01(\x0b\x32\x1a.zetasql.ASTNullOrderProtoH\x00\x12P\n ast_on_or_using_clause_list_node\x18J \x01(\x0b\x32$.zetasql.ASTOnOrUsingClauseListProtoH\x00\x12=\n\x15\x61st_partition_by_node\x18L \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProtoH\x00\x12\x44\n\x19\x61st_star_except_list_node\x18N \x01(\x0b\x32\x1f.zetasql.ASTStarExceptListProtoH\x00\x12\x41\n\x17\x61st_star_modifiers_node\x18O \x01(\x0b\x32\x1e.zetasql.ASTStarModifiersProtoH\x00\x12\x46\n\x1a\x61st_star_replace_item_node\x18P \x01(\x0b\x32 .zetasql.ASTStarReplaceItemProtoH\x00\x12G\n\x1a\x61st_unnest_expression_node\x18T \x01(\x0b\x32!.zetasql.ASTUnnestExpressionProtoH\x00\x12?\n\x16\x61st_window_clause_node\x18U \x01(\x0b\x32\x1d.zetasql.ASTWindowClauseProtoH\x00\x12G\n\x1a\x61st_window_definition_node\x18V \x01(\x0b\x32!.zetasql.ASTWindowDefinitionProtoH\x00\x12=\n\x15\x61st_window_frame_node\x18W \x01(\x0b\x32\x1c.zetasql.ASTWindowFrameProtoH\x00\x12\x46\n\x1a\x61st_window_frame_expr_node\x18X \x01(\x0b\x32 .zetasql.ASTWindowFrameExprProtoH\x00\x12M\n\x1d\x61st_window_specification_node\x18Z \x01(\x0b\x32$.zetasql.ASTWindowSpecificationProtoH\x00\x12;\n\x14\x61st_with_offset_node\x18[ \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProtoH\x00\x12\x41\n\x18\x61st_any_some_all_op_node\x18\\ \x01(\x0b\x32\x1d.zetasql.ASTAnySomeAllOpProtoH\x00\x12\x41\n\x17\x61st_statement_list_node\x18^ \x01(\x0b\x32\x1e.zetasql.ASTStatementListProtoH\x00\x12H\n\x19\x61st_transaction_mode_node\x18\x64 \x01(\x0b\x32#.zetasql.AnyASTTransactionModeProtoH\x00\x12N\n\x1e\x61st_transaction_mode_list_node\x18g \x01(\x0b\x32$.zetasql.ASTTransactionModeListProtoH\x00\x12P\n\x1f\x61st_with_connection_clause_node\x18z \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProtoH\x00\x12\x39\n\x13\x61st_into_alias_node\x18{ \x01(\x0b\x32\x1a.zetasql.ASTIntoAliasProtoH\x00\x12v\n4ast_unnest_expression_with_opt_alias_and_offset_node\x18| \x01(\x0b\x32\x36.zetasql.ASTUnnestExpressionWithOptAliasAndOffsetProtoH\x00\x12\x45\n\x19\x61st_pivot_expression_node\x18} \x01(\x0b\x32 .zetasql.ASTPivotExpressionProtoH\x00\x12;\n\x14\x61st_pivot_value_node\x18~ \x01(\x0b\x32\x1b.zetasql.ASTPivotValueProtoH\x00\x12N\n\x1e\x61st_pivot_expression_list_node\x18\x7f \x01(\x0b\x32$.zetasql.ASTPivotExpressionListProtoH\x00\x12\x45\n\x19\x61st_pivot_value_list_node\x18\x80\x01 \x01(\x0b\x32\x1f.zetasql.ASTPivotValueListProtoH\x00\x12\x43\n\x18\x61st_unpivot_in_item_node\x18\x82\x01 \x01(\x0b\x32\x1e.zetasql.ASTUnpivotInItemProtoH\x00\x12L\n\x1d\x61st_unpivot_in_item_list_node\x18\x83\x01 \x01(\x0b\x32\".zetasql.ASTUnpivotInItemListProtoH\x00\x12>\n\x15\x61st_using_clause_node\x18\x85\x01 \x01(\x0b\x32\x1c.zetasql.ASTUsingClauseProtoH\x00\x12\x43\n\x18\x61st_for_system_time_node\x18\x86\x01 \x01(\x0b\x32\x1e.zetasql.ASTForSystemTimeProtoH\x00\x12\x35\n\x10\x61st_qualify_node\x18\x87\x01 \x01(\x0b\x32\x18.zetasql.ASTQualifyProtoH\x00\x12U\n!ast_clamped_between_modifier_node\x18\x88\x01 \x01(\x0b\x32\'.zetasql.ASTClampedBetweenModifierProtoH\x00\x12@\n\x16\x61st_format_clause_node\x18\x89\x01 \x01(\x0b\x32\x1d.zetasql.ASTFormatClauseProtoH\x00\x12M\n\x1d\x61st_path_expression_list_node\x18\x8a\x01 \x01(\x0b\x32#.zetasql.ASTPathExpressionListProtoH\x00\x12:\n\x13\x61st_cluster_by_node\x18\x91\x01 \x01(\x0b\x32\x1a.zetasql.ASTClusterByProtoH\x00\x12K\n\x1c\x61st_new_constructor_arg_node\x18\x92\x01 \x01(\x0b\x32\".zetasql.ASTNewConstructorArgProtoH\x00\x12>\n\x15\x61st_options_list_node\x18\x94\x01 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProtoH\x00\x12@\n\x16\x61st_options_entry_node\x18\x95\x01 \x01(\x0b\x32\x1d.zetasql.ASTOptionsEntryProtoH\x00\x12J\n\x1b\x61st_function_parameter_node\x18\x97\x01 \x01(\x0b\x32\".zetasql.ASTFunctionParameterProtoH\x00\x12L\n\x1c\x61st_function_parameters_node\x18\x98\x01 \x01(\x0b\x32#.zetasql.ASTFunctionParametersProtoH\x00\x12N\n\x1d\x61st_function_declaration_node\x18\x99\x01 \x01(\x0b\x32$.zetasql.ASTFunctionDeclarationProtoH\x00\x12G\n\x1a\x61st_sql_function_body_node\x18\x9a\x01 \x01(\x0b\x32 .zetasql.ASTSqlFunctionBodyProtoH\x00\x12>\n\x15\x61st_tvf_argument_node\x18\x9b\x01 \x01(\x0b\x32\x1c.zetasql.ASTTVFArgumentProtoH\x00\x12>\n\x15\x61st_model_clause_node\x18\x9e\x01 \x01(\x0b\x32\x1c.zetasql.ASTModelClauseProtoH\x00\x12H\n\x1a\x61st_connection_clause_node\x18\x9f\x01 \x01(\x0b\x32!.zetasql.ASTConnectionClauseProtoH\x00\x12P\n\x1f\x61st_clone_data_source_list_node\x18\xa3\x01 \x01(\x0b\x32$.zetasql.ASTCloneDataSourceListProtoH\x00\x12\x46\n\x19\x61st_transform_clause_node\x18\xa9\x01 \x01(\x0b\x32 .zetasql.ASTTransformClauseProtoH\x00\x12\x43\n\x18\x61st_index_item_list_node\x18\xac\x01 \x01(\x0b\x32\x1e.zetasql.ASTIndexItemListProtoH\x00\x12^\n&ast_index_storing_expression_list_node\x18\xad\x01 \x01(\x0b\x32+.zetasql.ASTIndexStoringExpressionListProtoH\x00\x12\\\n%ast_index_unnest_expression_list_node\x18\xae\x01 \x01(\x0b\x32*.zetasql.ASTIndexUnnestExpressionListProtoH\x00\x12^\n&ast_with_partition_columns_clause_node\x18\xb4\x01 \x01(\x0b\x32+.zetasql.ASTWithPartitionColumnsClauseProtoH\x00\x12K\n\x1c\x61st_type_parameter_list_node\x18\xb6\x01 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProtoH\x00\x12:\n\x13\x61st_tvf_schema_node\x18\xb7\x01 \x01(\x0b\x32\x1a.zetasql.ASTTVFSchemaProtoH\x00\x12G\n\x1a\x61st_tvf_schema_column_node\x18\xb8\x01 \x01(\x0b\x32 .zetasql.ASTTVFSchemaColumnProtoH\x00\x12N\n\x1e\x61st_table_and_column_info_node\x18\xb9\x01 \x01(\x0b\x32#.zetasql.ASTTableAndColumnInfoProtoH\x00\x12W\n#ast_table_and_column_info_list_node\x18\xba\x01 \x01(\x0b\x32\'.zetasql.ASTTableAndColumnInfoListProtoH\x00\x12U\n!ast_templated_parameter_type_node\x18\xbb\x01 \x01(\x0b\x32\'.zetasql.ASTTemplatedParameterTypeProtoH\x00\x12M\n\x1d\x61st_assert_rows_modified_node\x18\xbf\x01 \x01(\x0b\x32#.zetasql.ASTAssertRowsModifiedProtoH\x00\x12\x46\n\x19\x61st_returning_clause_node\x18\xc0\x01 \x01(\x0b\x32 .zetasql.ASTReturningClauseProtoH\x00\x12I\n\x19\x61st_column_attribute_node\x18\xc2\x01 \x01(\x0b\x32#.zetasql.AnyASTColumnAttributeProtoH\x00\x12O\n\x1e\x61st_column_attribute_list_node\x18\xc7\x01 \x01(\x0b\x32$.zetasql.ASTColumnAttributeListProtoH\x00\x12K\n\x1c\x61st_struct_column_field_node\x18\xc8\x01 \x01(\x0b\x32\".zetasql.ASTStructColumnFieldProtoH\x00\x12O\n\x1e\x61st_generated_column_info_node\x18\xc9\x01 \x01(\x0b\x32$.zetasql.ASTGeneratedColumnInfoProtoH\x00\x12\x43\n\x16\x61st_table_element_node\x18\xca\x01 \x01(\x0b\x32 .zetasql.AnyASTTableElementProtoH\x00\x12I\n\x1b\x61st_table_element_list_node\x18\xcc\x01 \x01(\x0b\x32!.zetasql.ASTTableElementListProtoH\x00\x12<\n\x14\x61st_column_list_node\x18\xcd\x01 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProtoH\x00\x12\x44\n\x18\x61st_column_position_node\x18\xce\x01 \x01(\x0b\x32\x1f.zetasql.ASTColumnPositionProtoH\x00\x12G\n\x1a\x61st_insert_values_row_node\x18\xcf\x01 \x01(\x0b\x32 .zetasql.ASTInsertValuesRowProtoH\x00\x12P\n\x1f\x61st_insert_values_row_list_node\x18\xd0\x01 \x01(\x0b\x32$.zetasql.ASTInsertValuesRowListProtoH\x00\x12\x45\n\x19\x61st_update_set_value_node\x18\xd2\x01 \x01(\x0b\x32\x1f.zetasql.ASTUpdateSetValueProtoH\x00\x12<\n\x14\x61st_update_item_node\x18\xd3\x01 \x01(\x0b\x32\x1b.zetasql.ASTUpdateItemProtoH\x00\x12\x45\n\x19\x61st_update_item_list_node\x18\xd4\x01 \x01(\x0b\x32\x1f.zetasql.ASTUpdateItemListProtoH\x00\x12>\n\x15\x61st_merge_action_node\x18\xd7\x01 \x01(\x0b\x32\x1c.zetasql.ASTMergeActionProtoH\x00\x12G\n\x1a\x61st_merge_when_clause_node\x18\xd8\x01 \x01(\x0b\x32 .zetasql.ASTMergeWhenClauseProtoH\x00\x12P\n\x1f\x61st_merge_when_clause_list_node\x18\xd9\x01 \x01(\x0b\x32$.zetasql.ASTMergeWhenClauseListProtoH\x00\x12\x39\n\x12\x61st_privilege_node\x18\xdb\x01 \x01(\x0b\x32\x1a.zetasql.ASTPrivilegeProtoH\x00\x12;\n\x13\x61st_privileges_node\x18\xdc\x01 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProtoH\x00\x12>\n\x15\x61st_grantee_list_node\x18\xdd\x01 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProtoH\x00\x12H\n\x1a\x61st_repeatable_clause_node\x18\xe0\x01 \x01(\x0b\x32!.zetasql.ASTRepeatableClauseProtoH\x00\x12G\n\x1a\x61st_filter_fields_arg_node\x18\xe1\x01 \x01(\x0b\x32 .zetasql.ASTFilterFieldsArgProtoH\x00\x12I\n\x1b\x61st_replace_fields_arg_node\x18\xe3\x01 \x01(\x0b\x32!.zetasql.ASTReplaceFieldsArgProtoH\x00\x12<\n\x14\x61st_sample_size_node\x18\xe5\x01 \x01(\x0b\x32\x1b.zetasql.ASTSampleSizeProtoH\x00\x12<\n\x14\x61st_with_weight_node\x18\xe6\x01 \x01(\x0b\x32\x1b.zetasql.ASTWithWeightProtoH\x00\x12@\n\x16\x61st_sample_suffix_node\x18\xe7\x01 \x01(\x0b\x32\x1d.zetasql.ASTSampleSuffixProtoH\x00\x12\x41\n\x15\x61st_alter_action_node\x18\xe9\x01 \x01(\x0b\x32\x1f.zetasql.AnyASTAlterActionProtoH\x00\x12G\n\x1a\x61st_alter_action_list_node\x18\xfc\x01 \x01(\x0b\x32 .zetasql.ASTAlterActionListProtoH\x00\x12K\n\x1c\x61st_foreign_key_actions_node\x18\xfe\x01 \x01(\x0b\x32\".zetasql.ASTForeignKeyActionsProtoH\x00\x12O\n\x1e\x61st_foreign_key_reference_node\x18\xff\x01 \x01(\x0b\x32$.zetasql.ASTForeignKeyReferenceProtoH\x00\x12\x33\n\x0f\x61st_script_node\x18\x80\x02 \x01(\x0b\x32\x17.zetasql.ASTScriptProtoH\x00\x12@\n\x16\x61st_elseif_clause_node\x18\x81\x02 \x01(\x0b\x32\x1d.zetasql.ASTElseifClauseProtoH\x00\x12I\n\x1b\x61st_elseif_clause_list_node\x18\x82\x02 \x01(\x0b\x32!.zetasql.ASTElseifClauseListProtoH\x00\x12\x45\n\x19\x61st_when_then_clause_node\x18\x84\x02 \x01(\x0b\x32\x1f.zetasql.ASTWhenThenClauseProtoH\x00\x12N\n\x1e\x61st_when_then_clause_list_node\x18\x85\x02 \x01(\x0b\x32#.zetasql.ASTWhenThenClauseListProtoH\x00\x12/\n\rast_hint_node\x18\x87\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProtoH\x00\x12:\n\x13\x61st_hint_entry_node\x18\x88\x02 \x01(\x0b\x32\x1a.zetasql.ASTHintEntryProtoH\x00\x12N\n\x1e\x61st_unpivot_in_item_label_node\x18\x89\x02 \x01(\x0b\x32#.zetasql.ASTUnpivotInItemLabelProtoH\x00\x12;\n\x13\x61st_descriptor_node\x18\x8a\x02 \x01(\x0b\x32\x1b.zetasql.ASTDescriptorProtoH\x00\x12\x43\n\x16\x61st_column_schema_node\x18\x8b\x02 \x01(\x0b\x32 .zetasql.AnyASTColumnSchemaProtoH\x00\x12H\n\x1a\x61st_descriptor_column_node\x18\x92\x02 \x01(\x0b\x32!.zetasql.ASTDescriptorColumnProtoH\x00\x12Q\n\x1f\x61st_descriptor_column_list_node\x18\x93\x02 \x01(\x0b\x32%.zetasql.ASTDescriptorColumnListProtoH\x00\x12H\n\x1a\x61st_exception_handler_node\x18\x96\x02 \x01(\x0b\x32!.zetasql.ASTExceptionHandlerProtoH\x00\x12Q\n\x1f\x61st_exception_handler_list_node\x18\x97\x02 \x01(\x0b\x32%.zetasql.ASTExceptionHandlerListProtoH\x00\x12\x44\n\x18\x61st_identifier_list_node\x18\x99\x02 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProtoH\x00\x12>\n\x15\x61st_until_clause_node\x18\x9b\x02 \x01(\x0b\x32\x1c.zetasql.ASTUntilClauseProtoH\x00\x12K\n\x1c\x61st_execute_into_clause_node\x18\xbe\x02 \x01(\x0b\x32\".zetasql.ASTExecuteIntoClauseProtoH\x00\x12Q\n\x1f\x61st_execute_using_argument_node\x18\xbf\x02 \x01(\x0b\x32%.zetasql.ASTExecuteUsingArgumentProtoH\x00\x12M\n\x1d\x61st_execute_using_clause_node\x18\xc0\x02 \x01(\x0b\x32#.zetasql.ASTExecuteUsingClauseProtoH\x00\x12`\n\'ast_braced_constructor_field_value_node\x18\xca\x02 \x01(\x0b\x32,.zetasql.ASTBracedConstructorFieldValueProtoH\x00\x12U\n!ast_braced_constructor_field_node\x18\xcb\x02 \x01(\x0b\x32\'.zetasql.ASTBracedConstructorFieldProtoH\x00\x12M\n\x1d\x61st_with_report_modifier_node\x18\xce\x02 \x01(\x0b\x32#.zetasql.ASTWithReportModifierProtoH\x00\x12\x37\n\x11\x61st_location_node\x18\xd1\x02 \x01(\x0b\x32\x19.zetasql.ASTLocationProtoH\x00\x12k\n.ast_aux_load_data_from_files_options_list_node\x18\xd5\x02 \x01(\x0b\x32\x30.zetasql.ASTAuxLoadDataFromFilesOptionsListProtoH\x00\x12\x31\n\x0e\x61st_label_node\x18\xd7\x02 \x01(\x0b\x32\x16.zetasql.ASTLabelProtoH\x00\x12K\n\x1c\x61st_primary_key_element_node\x18\xd8\x02 \x01(\x0b\x32\".zetasql.ASTPrimaryKeyElementProtoH\x00\x12T\n!ast_primary_key_element_list_node\x18\xd9\x02 \x01(\x0b\x32&.zetasql.ASTPrimaryKeyElementListProtoH\x00\x12O\n\x1e\x61st_spanner_table_options_node\x18\xda\x02 \x01(\x0b\x32$.zetasql.ASTSpannerTableOptionsProtoH\x00\x12W\n\"ast_spanner_interleave_clause_node\x18\xdb\x02 \x01(\x0b\x32(.zetasql.ASTSpannerInterleaveClauseProtoH\x00\x12:\n\x13\x61st_ttl_clause_node\x18\xdc\x02 \x01(\x0b\x32\x1a.zetasql.ASTTtlClauseProtoH\x00\x12K\n\x1c\x61st_input_output_clause_node\x18\xe3\x02 \x01(\x0b\x32\".zetasql.ASTInputOutputClauseProtoH\x00\x12T\n\x1f\x61st_graph_label_expression_node\x18\xe7\x02 \x01(\x0b\x32(.zetasql.AnyASTGraphLabelExpressionProtoH\x00\x12I\n\x1b\x61st_graph_label_filter_node\x18\xeb\x02 \x01(\x0b\x32!.zetasql.ASTGraphLabelFilterProtoH\x00\x12<\n\x14\x61st_select_with_node\x18\xec\x02 \x01(\x0b\x32\x1b.zetasql.ASTSelectWithProtoH\x00\x12I\n\x1b\x61st_aliased_query_list_node\x18\xed\x02 \x01(\x0b\x32!.zetasql.ASTAliasedQueryListProtoH\x00\x12K\n\x1c\x61st_column_with_options_node\x18\xee\x02 \x01(\x0b\x32\".zetasql.ASTColumnWithOptionsProtoH\x00\x12T\n!ast_column_with_options_list_node\x18\xef\x02 \x01(\x0b\x32&.zetasql.ASTColumnWithOptionsListProtoH\x00\x12\\\n%ast_graph_element_pattern_filler_node\x18\xf2\x02 \x01(\x0b\x32*.zetasql.ASTGraphElementPatternFillerProtoH\x00\x12T\n!ast_graph_element_table_list_node\x18\xf6\x02 \x01(\x0b\x32&.zetasql.ASTGraphElementTableListProtoH\x00\x12K\n\x1c\x61st_graph_element_table_node\x18\xf7\x02 \x01(\x0b\x32\".zetasql.ASTGraphElementTableProtoH\x00\x12X\n#ast_graph_node_table_reference_node\x18\xf8\x02 \x01(\x0b\x32(.zetasql.ASTGraphNodeTableReferenceProtoH\x00\x12\x61\n(ast_aux_load_data_partitions_clause_node\x18\xfa\x02 \x01(\x0b\x32,.zetasql.ASTAuxLoadDataPartitionsClauseProtoH\x00\x12p\n0ast_graph_element_label_and_properties_list_node\x18\xfb\x02 \x01(\x0b\x32\x33.zetasql.ASTGraphElementLabelAndPropertiesListProtoH\x00\x12g\n+ast_graph_element_label_and_properties_node\x18\xfc\x02 \x01(\x0b\x32/.zetasql.ASTGraphElementLabelAndPropertiesProtoH\x00\x12\x46\n\x19\x61st_graph_properties_node\x18\xfd\x02 \x01(\x0b\x32 .zetasql.ASTGraphPropertiesProtoH\x00\x12Z\n$ast_set_operation_metadata_list_node\x18\x80\x03 \x01(\x0b\x32).zetasql.ASTSetOperationMetadataListProtoH\x00\x12]\n&ast_set_operation_all_or_distinct_node\x18\x81\x03 \x01(\x0b\x32*.zetasql.ASTSetOperationAllOrDistinctProtoH\x00\x12I\n\x1b\x61st_set_operation_type_node\x18\x82\x03 \x01(\x0b\x32!.zetasql.ASTSetOperationTypeProtoH\x00\x12Q\n\x1f\x61st_set_operation_metadata_node\x18\x83\x03 \x01(\x0b\x32%.zetasql.ASTSetOperationMetadataProtoH\x00\x12\x61\n(ast_set_operation_column_match_mode_node\x18\x85\x03 \x01(\x0b\x32,.zetasql.ASTSetOperationColumnMatchModeProtoH\x00\x12m\n.ast_set_operation_column_propagation_mode_node\x18\x86\x03 \x01(\x0b\x32\x32.zetasql.ASTSetOperationColumnPropagationModeProtoH\x00\x12@\n\x16\x61st_graph_pattern_node\x18\x8a\x03 \x01(\x0b\x32\x1d.zetasql.ASTGraphPatternProtoH\x00\x12/\n\rast_cube_node\x18\x8f\x03 \x01(\x0b\x32\x15.zetasql.ASTCubeProtoH\x00\x12>\n\x15\x61st_grouping_set_node\x18\x90\x03 \x01(\x0b\x32\x1c.zetasql.ASTGroupingSetProtoH\x00\x12G\n\x1a\x61st_grouping_set_list_node\x18\x91\x03 \x01(\x0b\x32 .zetasql.ASTGroupingSetListProtoH\x00\x12V\n\"ast_expression_with_opt_alias_node\x18\x92\x03 \x01(\x0b\x32\'.zetasql.ASTExpressionWithOptAliasProtoH\x00\x12=\n\x15\x61st_group_by_all_node\x18\x93\x03 \x01(\x0b\x32\x1b.zetasql.ASTGroupByAllProtoH\x00\x12P\n\x1f\x61st_function_type_arg_list_node\x18\x94\x03 \x01(\x0b\x32$.zetasql.ASTFunctionTypeArgListProtoH\x00\x12\x43\n\x16\x61st_pipe_operator_node\x18\x98\x03 \x01(\x0b\x32 .zetasql.AnyASTPipeOperatorProtoH\x00\x12\x41\n\x17\x61st_graph_lhs_hint_node\x18\x9a\x03 \x01(\x0b\x32\x1d.zetasql.ASTGraphLhsHintProtoH\x00\x12\x41\n\x17\x61st_graph_rhs_hint_node\x18\x9b\x03 \x01(\x0b\x32\x1d.zetasql.ASTGraphRhsHintProtoH\x00\x12M\n\x1d\x61st_identity_column_info_node\x18\xa8\x03 \x01(\x0b\x32#.zetasql.ASTIdentityColumnInfoProtoH\x00\x12X\n#ast_identity_column_start_with_node\x18\xa9\x03 \x01(\x0b\x32(.zetasql.ASTIdentityColumnStartWithProtoH\x00\x12\\\n%ast_identity_column_increment_by_node\x18\xaa\x03 \x01(\x0b\x32*.zetasql.ASTIdentityColumnIncrementByProtoH\x00\x12V\n\"ast_identity_column_max_value_node\x18\xab\x03 \x01(\x0b\x32\'.zetasql.ASTIdentityColumnMaxValueProtoH\x00\x12V\n\"ast_identity_column_min_value_node\x18\xac\x03 \x01(\x0b\x32\'.zetasql.ASTIdentityColumnMinValueProtoH\x00\x12\x46\n\x18\x61st_graph_path_base_node\x18\xad\x03 \x01(\x0b\x32!.zetasql.AnyASTGraphPathBaseProtoH\x00\x12\x41\n\x15\x61st_gql_operator_node\x18\xb0\x03 \x01(\x0b\x32\x1f.zetasql.AnyASTGqlOperatorProtoH\x00\x12\x63\n)ast_gql_let_variable_definition_list_node\x18\xba\x03 \x01(\x0b\x32-.zetasql.ASTGqlLetVariableDefinitionListProtoH\x00\x12Z\n$ast_gql_let_variable_definition_node\x18\xbb\x03 \x01(\x0b\x32).zetasql.ASTGqlLetVariableDefinitionProtoH\x00\x12?\n\x16\x61st_pipe_set_item_node\x18\xc2\x03 \x01(\x0b\x32\x1c.zetasql.ASTPipeSetItemProtoH\x00\x12]\n%ast_graph_property_specification_node\x18\xc7\x03 \x01(\x0b\x32+.zetasql.ASTGraphPropertySpecificationProtoH\x00\x12]\n&ast_graph_property_name_and_value_node\x18\xc8\x03 \x01(\x0b\x32*.zetasql.ASTGraphPropertyNameAndValueProtoH\x00\x12\x41\n\x17\x61st_gql_page_limit_node\x18\xca\x03 \x01(\x0b\x32\x1d.zetasql.ASTGqlPageLimitProtoH\x00\x12\x43\n\x18\x61st_gql_page_offset_node\x18\xcb\x03 \x01(\x0b\x32\x1e.zetasql.ASTGqlPageOffsetProtoH\x00\x12\x36\n\x11\x61st_gql_page_node\x18\xcc\x03 \x01(\x0b\x32\x18.zetasql.ASTGqlPageProtoH\x00\x12S\n ast_aliased_query_modifiers_node\x18\xcf\x03 \x01(\x0b\x32&.zetasql.ASTAliasedQueryModifiersProtoH\x00\x12U\n!ast_recursion_depth_modifier_node\x18\xd1\x03 \x01(\x0b\x32\'.zetasql.ASTRecursionDepthModifierProtoH\x00\x12K\n\x1c\x61st_grouping_item_order_node\x18\xd2\x03 \x01(\x0b\x32\".zetasql.ASTGroupingItemOrderProtoH\x00\x12\x43\n\x18\x61st_graph_path_mode_node\x18\xd5\x03 \x01(\x0b\x32\x1e.zetasql.ASTGraphPathModeProtoH\x00\x12T\n!ast_graph_path_search_prefix_node\x18\xd7\x03 \x01(\x0b\x32&.zetasql.ASTGraphPathSearchPrefixProtoH\x00\x12\x38\n\x12\x61st_lock_mode_node\x18\xe1\x03 \x01(\x0b\x32\x19.zetasql.ASTLockModeProtoH\x00\x12T\n\x1f\x61st_row_pattern_expression_node\x18\xe5\x03 \x01(\x0b\x32(.zetasql.AnyASTRowPatternExpressionProtoH\x00\x12T\n\x1f\x61st_postfix_table_operator_node\x18\xe8\x03 \x01(\x0b\x32(.zetasql.AnyASTPostfixTableOperatorProtoH\x00\x12>\n\x13\x61st_quantifier_node\x18\xeb\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTQuantifierProtoH\x00\x12\x46\n\x19\x61st_quantifier_bound_node\x18\xed\x03 \x01(\x0b\x32 .zetasql.ASTQuantifierBoundProtoH\x00\x12=\n\x14\x61st_subpipeline_node\x18\xf1\x03 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProtoH\x00\x12R\n ast_after_match_skip_clause_node\x18\xf3\x03 \x01(\x0b\x32%.zetasql.ASTAfterMatchSkipClauseProtoH\x00\x12I\n\x1b\x61st_on_conflict_clause_node\x18\xf5\x03 \x01(\x0b\x32!.zetasql.ASTOnConflictClauseProtoH\x00\x12K\n\x1c\x61st_graph_dynamic_label_node\x18\xff\x03 \x01(\x0b\x32\".zetasql.ASTGraphDynamicLabelProtoH\x00\x12U\n!ast_graph_dynamic_properties_node\x18\x80\x04 \x01(\x0b\x32\'.zetasql.ASTGraphDynamicPropertiesProtoH\x00\x12_\n\'ast_graph_path_search_prefix_count_node\x18\x81\x04 \x01(\x0b\x32+.zetasql.ASTGraphPathSearchPrefixCountProtoH\x00\x12G\n\x1a\x61st_chained_base_expr_node\x18\x8a\x04 \x01(\x0b\x32 .zetasql.ASTChainedBaseExprProtoH\x00\x12\x43\n\x18\x61st_yield_item_list_node\x18\x8d\x04 \x01(\x0b\x32\x1e.zetasql.ASTYieldItemListProtoH\x00\x12\x38\n\x12\x61st_limit_all_node\x18\x96\x04 \x01(\x0b\x32\x19.zetasql.ASTLimitAllProtoH\x00\x12\x31\n\x0e\x61st_limit_node\x18\x97\x04 \x01(\x0b\x32\x16.zetasql.ASTLimitProtoH\x00\x12Q\n\x1f\x61st_graph_derived_property_node\x18\xa0\x04 \x01(\x0b\x32%.zetasql.ASTGraphDerivedPropertyProtoH\x00\x12Z\n$ast_graph_derived_property_list_node\x18\xa1\x04 \x01(\x0b\x32).zetasql.ASTGraphDerivedPropertyListProtoH\x00\x42\x06\n\x04node\"N\n\x0c\x41STNodeProto\x12>\n\x14parse_location_range\x18\x01 \x01(\x0b\x32 .zetasql.ParseLocationRangeProto\"\xd9\x1a\n\x14\x41nyASTStatementProto\x12\x43\n\x18\x61st_query_statement_node\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTQueryStatementProtoH\x00\x12H\n\x19\x61st_script_statement_node\x18_ \x01(\x0b\x32#.zetasql.AnyASTScriptStatementProtoH\x00\x12\x45\n\x19\x61st_hinted_statement_node\x18` \x01(\x0b\x32 .zetasql.ASTHintedStatementProtoH\x00\x12G\n\x1a\x61st_explain_statement_node\x18\x61 \x01(\x0b\x32!.zetasql.ASTExplainStatementProtoH\x00\x12I\n\x1b\x61st_describe_statement_node\x18\x62 \x01(\x0b\x32\".zetasql.ASTDescribeStatementProtoH\x00\x12\x41\n\x17\x61st_show_statement_node\x18\x63 \x01(\x0b\x32\x1e.zetasql.ASTShowStatementProtoH\x00\x12\x43\n\x18\x61st_begin_statement_node\x18h \x01(\x0b\x32\x1f.zetasql.ASTBeginStatementProtoH\x00\x12V\n\"ast_set_transaction_statement_node\x18i \x01(\x0b\x32(.zetasql.ASTSetTransactionStatementProtoH\x00\x12\x45\n\x19\x61st_commit_statement_node\x18j \x01(\x0b\x32 .zetasql.ASTCommitStatementProtoH\x00\x12I\n\x1b\x61st_rollback_statement_node\x18k \x01(\x0b\x32\".zetasql.ASTRollbackStatementProtoH\x00\x12N\n\x1e\x61st_start_batch_statement_node\x18l \x01(\x0b\x32$.zetasql.ASTStartBatchStatementProtoH\x00\x12J\n\x1c\x61st_run_batch_statement_node\x18m \x01(\x0b\x32\".zetasql.ASTRunBatchStatementProtoH\x00\x12N\n\x1e\x61st_abort_batch_statement_node\x18n \x01(\x0b\x32$.zetasql.ASTAbortBatchStatementProtoH\x00\x12\x42\n\x16\x61st_ddl_statement_node\x18o \x01(\x0b\x32 .zetasql.AnyASTDdlStatementProtoH\x00\x12m\n/ast_drop_all_row_access_policies_statement_node\x18s \x01(\x0b\x32\x32.zetasql.ASTDropAllRowAccessPoliciesStatementProtoH\x00\x12\x45\n\x19\x61st_rename_statement_node\x18w \x01(\x0b\x32 .zetasql.ASTRenameStatementProtoH\x00\x12\x45\n\x19\x61st_import_statement_node\x18x \x01(\x0b\x32 .zetasql.ASTImportStatementProtoH\x00\x12\x45\n\x19\x61st_module_statement_node\x18y \x01(\x0b\x32 .zetasql.ASTModuleStatementProtoH\x00\x12M\n\x1d\x61st_clone_data_statement_node\x18\xa4\x01 \x01(\x0b\x32#.zetasql.ASTCloneDataStatementProtoH\x00\x12W\n\"ast_create_database_statement_node\x18\xa6\x01 \x01(\x0b\x32(.zetasql.ASTCreateDatabaseStatementProtoH\x00\x12O\n\x1e\x61st_export_data_statement_node\x18\xb0\x01 \x01(\x0b\x32$.zetasql.ASTExportDataStatementProtoH\x00\x12Q\n\x1f\x61st_export_model_statement_node\x18\xb1\x01 \x01(\x0b\x32%.zetasql.ASTExportModelStatementProtoH\x00\x12\x42\n\x17\x61st_call_statement_node\x18\xb2\x01 \x01(\x0b\x32\x1e.zetasql.ASTCallStatementProtoH\x00\x12Q\n\x1f\x61st_define_table_statement_node\x18\xb3\x01 \x01(\x0b\x32%.zetasql.ASTDefineTableStatementProtoH\x00\x12H\n\x1a\x61st_analyze_statement_node\x18\xbd\x01 \x01(\x0b\x32!.zetasql.ASTAnalyzeStatementProtoH\x00\x12\x46\n\x19\x61st_assert_statement_node\x18\xbe\x01 \x01(\x0b\x32 .zetasql.ASTAssertStatementProtoH\x00\x12\x46\n\x19\x61st_delete_statement_node\x18\xc1\x01 \x01(\x0b\x32 .zetasql.ASTDeleteStatementProtoH\x00\x12\x46\n\x19\x61st_insert_statement_node\x18\xd1\x01 \x01(\x0b\x32 .zetasql.ASTInsertStatementProtoH\x00\x12\x46\n\x19\x61st_update_statement_node\x18\xd5\x01 \x01(\x0b\x32 .zetasql.ASTUpdateStatementProtoH\x00\x12J\n\x1b\x61st_truncate_statement_node\x18\xd6\x01 \x01(\x0b\x32\".zetasql.ASTTruncateStatementProtoH\x00\x12\x44\n\x18\x61st_merge_statement_node\x18\xda\x01 \x01(\x0b\x32\x1f.zetasql.ASTMergeStatementProtoH\x00\x12\x44\n\x18\x61st_grant_statement_node\x18\xde\x01 \x01(\x0b\x32\x1f.zetasql.ASTGrantStatementProtoH\x00\x12\x46\n\x19\x61st_revoke_statement_node\x18\xdf\x01 \x01(\x0b\x32 .zetasql.ASTRevokeStatementProtoH\x00\x12p\n0ast_alter_all_row_access_policies_statement_node\x18\xfd\x01 \x01(\x0b\x32\x33.zetasql.ASTAlterAllRowAccessPoliciesStatementProtoH\x00\x12N\n\x1d\x61st_parameter_assignment_node\x18\xa4\x02 \x01(\x0b\x32$.zetasql.ASTParameterAssignmentProtoH\x00\x12Y\n#ast_system_variable_assignment_node\x18\xa5\x02 \x01(\x0b\x32).zetasql.ASTSystemVariableAssignmentProtoH\x00\x12[\n$ast_execute_immediate_statement_node\x18\xc1\x02 \x01(\x0b\x32*.zetasql.ASTExecuteImmediateStatementProtoH\x00\x12Q\n\x1f\x61st_define_macro_statement_node\x18\xf1\x02 \x01(\x0b\x32%.zetasql.ASTDefineMacroStatementProtoH\x00\x12W\n\"ast_export_metadata_statement_node\x18\x8e\x03 \x01(\x0b\x32(.zetasql.ASTExportMetadataStatementProtoH\x00\x12\x62\n(ast_create_locality_group_statement_node\x18\x89\x04 \x01(\x0b\x32-.zetasql.ASTCreateLocalityGroupStatementProtoH\x00\x12@\n\x16\x61st_run_statement_node\x18\x92\x04 \x01(\x0b\x32\x1d.zetasql.ASTRunStatementProtoH\x00\x12P\n\x1e\x61st_subpipeline_statement_node\x18\x98\x04 \x01(\x0b\x32%.zetasql.ASTSubpipelineStatementProtoH\x00\x12^\n&ast_statement_with_pipe_operators_node\x18\x99\x04 \x01(\x0b\x32+.zetasql.ASTStatementWithPipeOperatorsProtoH\x00\x42\x06\n\x04node\":\n\x11\x41STStatementProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"k\n\x16\x41STQueryStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12%\n\x05query\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\"}\n\x1c\x41STSubpipelineStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x31\n\x0bsubpipeline\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"\xfa\x04\n\x1a\x41nyASTQueryExpressionProto\x12\x30\n\x0e\x61st_query_node\x18\x04 \x01(\x0b\x32\x16.zetasql.ASTQueryProtoH\x00\x12\x32\n\x0f\x61st_select_node\x18\x05 \x01(\x0b\x32\x17.zetasql.ASTSelectProtoH\x00\x12?\n\x16\x61st_set_operation_node\x18M \x01(\x0b\x32\x1d.zetasql.ASTSetOperationProtoH\x00\x12>\n\x15\x61st_table_clause_node\x18\x9d\x01 \x01(\x0b\x32\x1c.zetasql.ASTTableClauseProtoH\x00\x12:\n\x13\x61st_from_query_node\x18\x9e\x03 \x01(\x0b\x32\x1a.zetasql.ASTFromQueryProtoH\x00\x12\x38\n\x12\x61st_gql_query_node\x18\xc9\x03 \x01(\x0b\x32\x19.zetasql.ASTGqlQueryProtoH\x00\x12U\n!ast_aliased_query_expression_node\x18\xdb\x03 \x01(\x0b\x32\'.zetasql.ASTAliasedQueryExpressionProtoH\x00\x12R\n ast_gql_graph_pattern_query_node\x18\xdd\x03 \x01(\x0b\x32%.zetasql.ASTGqlGraphPatternQueryProtoH\x00\x12L\n\x1d\x61st_gql_linear_ops_query_node\x18\xde\x03 \x01(\x0b\x32\".zetasql.ASTGqlLinearOpsQueryProtoH\x00\x42\x06\n\x04node\"W\n\x17\x41STQueryExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x15\n\rparenthesized\x18\x02 \x01(\x08\"\xa0\x01\n\x1e\x41STAliasedQueryExpressionProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12%\n\x05query\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xa3\x03\n\rASTQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x30\n\x0bwith_clause\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTWithClauseProto\x12\x37\n\nquery_expr\x18\x03 \x01(\x0b\x32#.zetasql.AnyASTQueryExpressionProto\x12*\n\x08order_by\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\x12\x32\n\x0climit_offset\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTLimitOffsetProto\x12\x11\n\tis_nested\x18\x06 \x01(\x08\x12\x16\n\x0eis_pivot_input\x18\x07 \x01(\x08\x12<\n\x12pipe_operator_list\x18\x08 \x03(\x0b\x32 .zetasql.AnyASTPipeOperatorProto\x12,\n\tlock_mode\x18\t \x01(\x0b\x32\x19.zetasql.ASTLockModeProto\"w\n\x11\x41STFromQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x30\n\x0b\x66rom_clause\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTFromClauseProto\"\x91\x01\n\x13\x41STSubpipelineProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x12pipe_operator_list\x18\x02 \x03(\x0b\x32 .zetasql.AnyASTPipeOperatorProto\x12\x15\n\rparenthesized\x18\x03 \x01(\x08\"\xeb\x10\n\x17\x41nyASTPipeOperatorProto\x12<\n\x14\x61st_pipe_extend_node\x18\x99\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeExtendProtoH\x00\x12\x42\n\x17\x61st_pipe_aggregate_node\x18\x9c\x03 \x01(\x0b\x32\x1e.zetasql.ASTPipeAggregateProtoH\x00\x12I\n\x1b\x61st_pipe_set_operation_node\x18\x9d\x03 \x01(\x0b\x32!.zetasql.ASTPipeSetOperationProtoH\x00\x12\x38\n\x12\x61st_pipe_join_node\x18\x9f\x03 \x01(\x0b\x32\x19.zetasql.ASTPipeJoinProtoH\x00\x12\x38\n\x12\x61st_pipe_call_node\x18\xa1\x03 \x01(\x0b\x32\x19.zetasql.ASTPipeCallProtoH\x00\x12<\n\x14\x61st_pipe_window_node\x18\xa2\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeWindowProtoH\x00\x12:\n\x13\x61st_pipe_where_node\x18\xa3\x03 \x01(\x0b\x32\x1a.zetasql.ASTPipeWhereProtoH\x00\x12<\n\x14\x61st_pipe_select_node\x18\xa4\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeSelectProtoH\x00\x12G\n\x1a\x61st_pipe_limit_offset_node\x18\xa5\x03 \x01(\x0b\x32 .zetasql.ASTPipeLimitOffsetProtoH\x00\x12?\n\x16\x61st_pipe_order_by_node\x18\xa6\x03 \x01(\x0b\x32\x1c.zetasql.ASTPipeOrderByProtoH\x00\x12@\n\x16\x61st_pipe_distinct_node\x18\xaf\x03 \x01(\x0b\x32\x1d.zetasql.ASTPipeDistinctProtoH\x00\x12\x46\n\x19\x61st_pipe_tablesample_node\x18\xb3\x03 \x01(\x0b\x32 .zetasql.ASTPipeTablesampleProtoH\x00\x12\x34\n\x10\x61st_pipe_as_node\x18\xb5\x03 \x01(\x0b\x32\x17.zetasql.ASTPipeAsProtoH\x00\x12M\n\x1d\x61st_pipe_static_describe_node\x18\xbf\x03 \x01(\x0b\x32#.zetasql.ASTPipeStaticDescribeProtoH\x00\x12<\n\x14\x61st_pipe_assert_node\x18\xc0\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeAssertProtoH\x00\x12\x38\n\x12\x61st_pipe_drop_node\x18\xc1\x03 \x01(\x0b\x32\x19.zetasql.ASTPipeDropProtoH\x00\x12\x36\n\x11\x61st_pipe_set_node\x18\xc3\x03 \x01(\x0b\x32\x18.zetasql.ASTPipeSetProtoH\x00\x12:\n\x13\x61st_pipe_pivot_node\x18\xd3\x03 \x01(\x0b\x32\x1a.zetasql.ASTPipePivotProtoH\x00\x12>\n\x15\x61st_pipe_unpivot_node\x18\xd4\x03 \x01(\x0b\x32\x1c.zetasql.ASTPipeUnpivotProtoH\x00\x12\x45\n\x19\x61st_pipe_rename_item_node\x18\xe2\x03 \x01(\x0b\x32\x1f.zetasql.ASTPipeRenameItemProtoH\x00\x12<\n\x14\x61st_pipe_rename_node\x18\xe3\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeRenameProtoH\x00\x12\x36\n\x11\x61st_pipe_log_node\x18\xf2\x03 \x01(\x0b\x32\x18.zetasql.ASTPipeLogProtoH\x00\x12\x34\n\x10\x61st_pipe_if_node\x18\xf6\x03 \x01(\x0b\x32\x17.zetasql.ASTPipeIfProtoH\x00\x12=\n\x15\x61st_pipe_if_case_node\x18\xf7\x03 \x01(\x0b\x32\x1b.zetasql.ASTPipeIfCaseProtoH\x00\x12\x38\n\x12\x61st_pipe_fork_node\x18\xf8\x03 \x01(\x0b\x32\x19.zetasql.ASTPipeForkProtoH\x00\x12\x45\n\x19\x61st_pipe_export_data_node\x18\xf9\x03 \x01(\x0b\x32\x1f.zetasql.ASTPipeExportDataProtoH\x00\x12M\n\x1d\x61st_pipe_recursive_union_node\x18\xfa\x03 \x01(\x0b\x32#.zetasql.ASTPipeRecursiveUnionProtoH\x00\x12M\n\x1d\x61st_pipe_match_recognize_node\x18\xfc\x03 \x01(\x0b\x32#.zetasql.ASTPipeMatchRecognizeProtoH\x00\x12G\n\x1a\x61st_pipe_create_table_node\x18\xfd\x03 \x01(\x0b\x32 .zetasql.ASTPipeCreateTableProtoH\x00\x12\x36\n\x11\x61st_pipe_tee_node\x18\xfe\x03 \x01(\x0b\x32\x18.zetasql.ASTPipeTeeProtoH\x00\x12<\n\x14\x61st_pipe_insert_node\x18\x87\x04 \x01(\x0b\x32\x1b.zetasql.ASTPipeInsertProtoH\x00\x12\x38\n\x12\x61st_pipe_with_node\x18\x88\x04 \x01(\x0b\x32\x19.zetasql.ASTPipeWithProtoH\x00\x12@\n\x16\x61st_pipe_describe_node\x18\x8f\x04 \x01(\x0b\x32\x1d.zetasql.ASTPipeDescribeProtoH\x00\x42\x06\n\x04node\"=\n\x14\x41STPipeOperatorProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"l\n\x12\x41STPipeExtendProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\"\xa5\x01\n\x16\x41STPipeRenameItemProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12-\n\x08old_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x08new_name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"~\n\x12\x41STPipeRenameProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x39\n\x10rename_item_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ASTPipeRenameItemProto\"\xa1\x01\n\x15\x41STPipeAggregateProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\x12\x30\n\x0bselect_with\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTSelectWithProto\"\xb7\x01\n\x18\x41STPipeSetOperationProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x37\n\x08metadata\x18\x02 \x01(\x0b\x32%.zetasql.ASTSetOperationMetadataProto\x12\x33\n\x06inputs\x18\x03 \x03(\x0b\x32#.zetasql.AnyASTQueryExpressionProto\"f\n\x10\x41STPipeJoinProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12#\n\x04join\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTJoinProto\"d\n\x10\x41STPipeCallProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12!\n\x03tvf\x18\x02 \x01(\x0b\x32\x14.zetasql.ASTTVFProto\"l\n\x12\x41STPipeWindowProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\"o\n\x11\x41STPipeWhereProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12+\n\x05where\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\"l\n\x12\x41STPipeSelectProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\"|\n\x17\x41STPipeLimitOffsetProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x32\n\x0climit_offset\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTLimitOffsetProto\"p\n\x13\x41STPipeOrderByProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12*\n\x08order_by\x18\x02 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\"E\n\x14\x41STPipeDistinctProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\"w\n\x17\x41STPipeTablesampleProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12-\n\x06sample\x18\x02 \x01(\x0b\x32\x1d.zetasql.ASTSampleClauseProto\"\x8b\x01\n\x1a\x41STPipeMatchRecognizeProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12>\n\x0fmatch_recognize\x18\x02 \x01(\x0b\x32%.zetasql.ASTMatchRecognizeClauseProto\"f\n\x0e\x41STPipeAsProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12%\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"E\n\x14\x41STPipeDescribeProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\"K\n\x1a\x41STPipeStaticDescribeProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\"\xac\x01\n\x12\x41STPipeAssertProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x34\n\x0cmessage_list\x18\x03 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x98\x01\n\x0f\x41STPipeLogProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x31\n\x0bsubpipeline\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"w\n\x10\x41STPipeDropProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x34\n\x0b\x63olumn_list\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProto\"\x9d\x01\n\x13\x41STPipeSetItemProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"u\n\x0f\x41STPipeSetProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x33\n\rset_item_list\x18\x02 \x03(\x0b\x32\x1c.zetasql.ASTPipeSetItemProto\"v\n\x11\x41STPipePivotProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x32\n\x0cpivot_clause\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTPivotClauseProto\"|\n\x13\x41STPipeUnpivotProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x36\n\x0eunpivot_clause\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTUnpivotClauseProto\"\xcb\x01\n\x0e\x41STPipeIfProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12-\n\x08if_cases\x18\x03 \x03(\x0b\x32\x1b.zetasql.ASTPipeIfCaseProto\x12\x36\n\x10\x65lse_subpipeline\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"\xa9\x01\n\x12\x41STPipeIfCaseProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x31\n\x0bsubpipeline\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"\x9e\x01\n\x10\x41STPipeForkProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x36\n\x10subpipeline_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"\x9d\x01\n\x0f\x41STPipeTeeProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x36\n\x10subpipeline_list\x18\x03 \x03(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\"s\n\x10\x41STPipeWithProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x30\n\x0bwith_clause\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTWithClauseProto\"\x8c\x01\n\x16\x41STPipeExportDataProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x43\n\x15\x65xport_data_statement\x18\x02 \x01(\x0b\x32$.zetasql.ASTExportDataStatementProto\"\x8f\x01\n\x17\x41STPipeCreateTableProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x45\n\x16\x63reate_table_statement\x18\x02 \x01(\x0b\x32%.zetasql.ASTCreateTableStatementProto\"\x7f\n\x12\x41STPipeInsertProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12:\n\x10insert_statement\x18\x02 \x01(\x0b\x32 .zetasql.ASTInsertStatementProto\"\xa7\x04\n\x0e\x41STSelectProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x30\n\x0bselect_with\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTSelectWithProto\x12\x10\n\x08\x64istinct\x18\x04 \x01(\x08\x12,\n\tselect_as\x18\x05 \x01(\x0b\x32\x19.zetasql.ASTSelectAsProto\x12\x30\n\x0bselect_list\x18\x06 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12\x30\n\x0b\x66rom_clause\x18\x07 \x01(\x0b\x32\x1b.zetasql.ASTFromClauseProto\x12\x32\n\x0cwhere_clause\x18\x08 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\x12*\n\x08group_by\x18\t \x01(\x0b\x32\x18.zetasql.ASTGroupByProto\x12\'\n\x06having\x18\n \x01(\x0b\x32\x17.zetasql.ASTHavingProto\x12)\n\x07qualify\x18\x0b \x01(\x0b\x32\x18.zetasql.ASTQualifyProto\x12\x34\n\rwindow_clause\x18\x0c \x01(\x0b\x32\x1d.zetasql.ASTWindowClauseProto\"k\n\x12\x41STSelectListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x1d.zetasql.ASTSelectColumnProto\"\xd9\x01\n\x14\x41STSelectColumnProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12?\n\x13grouping_item_order\x18\x04 \x01(\x0b\x32\".zetasql.ASTGroupingItemOrderProto\"\xa1\x1a\n\x15\x41nyASTExpressionProto\x12\x31\n\rast_leaf_node\x18\t \x01(\x0b\x32\x18.zetasql.AnyASTLeafProtoH\x00\x12:\n\x13\x61st_identifier_node\x18\x0b \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProtoH\x00\x12]\n$ast_generalized_path_expression_node\x18\r \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProtoH\x00\x12\x35\n\x11\x61st_and_expr_node\x18\x14 \x01(\x0b\x32\x18.zetasql.ASTAndExprProtoH\x00\x12G\n\x1a\x61st_binary_expression_node\x18\x15 \x01(\x0b\x32!.zetasql.ASTBinaryExpressionProtoH\x00\x12\x33\n\x10\x61st_or_expr_node\x18\x18 \x01(\x0b\x32\x17.zetasql.ASTOrExprProtoH\x00\x12\x43\n\x18\x61st_cast_expression_node\x18* \x01(\x0b\x32\x1f.zetasql.ASTCastExpressionProtoH\x00\x12?\n\x16\x61st_function_call_node\x18- \x01(\x0b\x32\x1d.zetasql.ASTFunctionCallProtoH\x00\x12G\n\x1a\x61st_array_constructor_node\x18. \x01(\x0b\x32!.zetasql.ASTArrayConstructorProtoH\x00\x12_\n\'ast_struct_constructor_with_parens_node\x18\x30 \x01(\x0b\x32,.zetasql.ASTStructConstructorWithParensProtoH\x00\x12\x61\n(ast_struct_constructor_with_keyword_node\x18\x31 \x01(\x0b\x32-.zetasql.ASTStructConstructorWithKeywordProtoH\x00\x12?\n\x16\x61st_in_expression_node\x18\x32 \x01(\x0b\x32\x1d.zetasql.ASTInExpressionProtoH\x00\x12I\n\x1b\x61st_between_expression_node\x18\x34 \x01(\x0b\x32\".zetasql.ASTBetweenExpressionProtoH\x00\x12K\n\x1d\x61st_date_or_time_literal_node\x18\x38 \x01(\x0b\x32\".zetasql.ASTDateOrTimeLiteralProtoH\x00\x12N\n\x1e\x61st_case_value_expression_node\x18; \x01(\x0b\x32$.zetasql.ASTCaseValueExpressionProtoH\x00\x12S\n!ast_case_no_value_expression_node\x18< \x01(\x0b\x32&.zetasql.ASTCaseNoValueExpressionProtoH\x00\x12T\n!ast_bitwise_shift_expression_node\x18> \x01(\x0b\x32\'.zetasql.ASTBitwiseShiftExpressionProtoH\x00\x12\x35\n\x11\x61st_dot_star_node\x18\x42 \x01(\x0b\x32\x18.zetasql.ASTDotStarProtoH\x00\x12Q\n ast_dot_star_with_modifiers_node\x18\x43 \x01(\x0b\x32%.zetasql.ASTDotStarWithModifiersProtoH\x00\x12K\n\x1c\x61st_expression_subquery_node\x18\x44 \x01(\x0b\x32#.zetasql.ASTExpressionSubqueryProtoH\x00\x12I\n\x1b\x61st_extract_expression_node\x18\x45 \x01(\x0b\x32\".zetasql.ASTExtractExpressionProtoH\x00\x12?\n\x16\x61st_interval_expr_node\x18G \x01(\x0b\x32\x1d.zetasql.ASTIntervalExprProtoH\x00\x12\x41\n\x17\x61st_named_argument_node\x18H \x01(\x0b\x32\x1e.zetasql.ASTNamedArgumentProtoH\x00\x12J\n\x1c\x61st_star_with_modifiers_node\x18Q \x01(\x0b\x32\".zetasql.ASTStarWithModifiersProtoH\x00\x12\x45\n\x19\x61st_unary_expression_node\x18S \x01(\x0b\x32 .zetasql.ASTUnaryExpressionProtoH\x00\x12\x43\n\x18\x61st_like_expression_node\x18Y \x01(\x0b\x32\x1f.zetasql.ASTLikeExpressionProtoH\x00\x12M\n\x1c\x61st_parameter_expr_base_node\x18] \x01(\x0b\x32%.zetasql.AnyASTParameterExprBaseProtoH\x00\x12\x33\n\x0f\x61st_lambda_node\x18\x8e\x01 \x01(\x0b\x32\x17.zetasql.ASTLambdaProtoH\x00\x12Q\n\x1f\x61st_analytic_function_call_node\x18\x8f\x01 \x01(\x0b\x32%.zetasql.ASTAnalyticFunctionCallProtoH\x00\x12\x44\n\x18\x61st_new_constructor_node\x18\x93\x01 \x01(\x0b\x32\x1f.zetasql.ASTNewConstructorProtoH\x00\x12\x44\n\x18\x61st_default_literal_node\x18\xbc\x01 \x01(\x0b\x32\x1f.zetasql.ASTDefaultLiteralProtoH\x00\x12W\n\"ast_replace_fields_expression_node\x18\xe4\x01 \x01(\x0b\x32(.zetasql.ASTReplaceFieldsExpressionProtoH\x00\x12J\n\x1b\x61st_braced_constructor_node\x18\xcc\x02 \x01(\x0b\x32\".zetasql.ASTBracedConstructorProtoH\x00\x12Q\n\x1f\x61st_braced_new_constructor_node\x18\xcd\x02 \x01(\x0b\x32%.zetasql.ASTBracedNewConstructorProtoH\x00\x12\x44\n\x18\x61st_with_expression_node\x18\xcf\x02 \x01(\x0b\x32\x1f.zetasql.ASTWithExpressionProtoH\x00\x12@\n\x16\x61st_range_literal_node\x18\xe2\x02 \x01(\x0b\x32\x1d.zetasql.ASTRangeLiteralProtoH\x00\x12>\n\x15\x61st_sequence_arg_node\x18\x87\x03 \x01(\x0b\x32\x1c.zetasql.ASTSequenceArgProtoH\x00\x12O\n\x1e\x61st_expression_with_alias_node\x18\x8b\x03 \x01(\x0b\x32$.zetasql.ASTExpressionWithAliasProtoH\x00\x12W\n\"ast_struct_braced_constructor_node\x18\xce\x03 \x01(\x0b\x32(.zetasql.ASTStructBracedConstructorProtoH\x00\x12\x45\n\x19\x61st_int_or_unbounded_node\x18\xd0\x03 \x01(\x0b\x32\x1f.zetasql.ASTIntOrUnboundedProtoH\x00\x12X\n#ast_graph_is_labeled_predicate_node\x18\xda\x03 \x01(\x0b\x32(.zetasql.ASTGraphIsLabeledPredicateProtoH\x00\x12Q\n\x1f\x61st_braced_constructor_lhs_node\x18\xe9\x03 \x01(\x0b\x32%.zetasql.ASTBracedConstructorLhsProtoH\x00\x12J\n\x1b\x61st_update_constructor_node\x18\x83\x04 \x01(\x0b\x32\".zetasql.ASTUpdateConstructorProtoH\x00\x12M\n\x1d\x61st_input_table_argument_node\x18\x91\x04 \x01(\x0b\x32#.zetasql.ASTInputTableArgumentProtoH\x00\x12<\n\x14\x61st_concat_expr_node\x18\x9f\x04 \x01(\x0b\x32\x1b.zetasql.ASTConcatExprProtoH\x00\x42\x06\n\x04node\"R\n\x12\x41STExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x15\n\rparenthesized\x18\x02 \x01(\x08\"\xb3\x03\n\x0f\x41nyASTLeafProto\x12\x41\n\x17\x61st_string_literal_node\x18\x16 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProtoH\x00\x12\x43\n\x18\x61st_numeric_literal_node\x18\x35 \x01(\x0b\x32\x1f.zetasql.ASTNumericLiteralProtoH\x00\x12I\n\x1b\x61st_bignumeric_literal_node\x18\x36 \x01(\x0b\x32\".zetasql.ASTBigNumericLiteralProtoH\x00\x12?\n\x16\x61st_bytes_literal_node\x18\x37 \x01(\x0b\x32\x1d.zetasql.ASTBytesLiteralProtoH\x00\x12=\n\x15\x61st_json_literal_node\x18: \x01(\x0b\x32\x1c.zetasql.ASTJSONLiteralProtoH\x00\x12\x45\n\x17\x61st_printable_leaf_node\x18\xc4\x03 \x01(\x0b\x32!.zetasql.AnyASTPrintableLeafProtoH\x00\x42\x06\n\x04node\";\n\x0c\x41STLeafProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\"\xc2\x05\n\x18\x41nyASTPrintableLeafProto\x12;\n\x14\x61st_int_literal_node\x18\n \x01(\x0b\x32\x1b.zetasql.ASTIntLiteralProtoH\x00\x12\x43\n\x18\x61st_boolean_literal_node\x18\x13 \x01(\x0b\x32\x1f.zetasql.ASTBooleanLiteralProtoH\x00\x12.\n\rast_star_node\x18\x17 \x01(\x0b\x32\x15.zetasql.ASTStarProtoH\x00\x12?\n\x16\x61st_float_literal_node\x18\x1e \x01(\x0b\x32\x1d.zetasql.ASTFloatLiteralProtoH\x00\x12=\n\x15\x61st_null_literal_node\x18\x1f \x01(\x0b\x32\x1c.zetasql.ASTNullLiteralProtoH\x00\x12;\n\x14\x61st_max_literal_node\x18\x39 \x01(\x0b\x32\x1b.zetasql.ASTMaxLiteralProtoH\x00\x12G\n\x1a\x61st_index_all_columns_node\x18\xab\x01 \x01(\x0b\x32 .zetasql.ASTIndexAllColumnsProtoH\x00\x12:\n\x13\x61st_macro_body_node\x18\xf0\x02 \x01(\x0b\x32\x1a.zetasql.ASTMacroBodyProtoH\x00\x12U\n!ast_string_literal_component_node\x18\xc5\x03 \x01(\x0b\x32\'.zetasql.ASTStringLiteralComponentProtoH\x00\x12S\n ast_bytes_literal_component_node\x18\xc6\x03 \x01(\x0b\x32&.zetasql.ASTBytesLiteralComponentProtoH\x00\x42\x06\n\x04node\"M\n\x15\x41STPrintableLeafProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12\r\n\x05image\x18\x02 \x01(\t\"D\n\x12\x41STIntLiteralProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"g\n\x12\x41STIdentifierProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x11\n\tid_string\x18\x02 \x01(\t\x12\x11\n\tis_quoted\x18\x03 \x01(\x08\"g\n\rASTAliasProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\x9e\x03\n$AnyASTGeneralizedPathExpressionProto\x12\x43\n\x18\x61st_path_expression_node\x18\x0e \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProtoH\x00\x12?\n\x16\x61st_array_element_node\x18= \x01(\x0b\x32\x1d.zetasql.ASTArrayElementProtoH\x00\x12N\n\x1e\x61st_dot_generalized_field_node\x18@ \x01(\x0b\x32$.zetasql.ASTDotGeneralizedFieldProtoH\x00\x12\x41\n\x17\x61st_dot_identifier_node\x18\x41 \x01(\x0b\x32\x1e.zetasql.ASTDotIdentifierProtoH\x00\x12U\n!ast_extended_path_expression_node\x18\x82\x04 \x01(\x0b\x32\'.zetasql.ASTExtendedPathExpressionProtoH\x00\x42\x06\n\x04node\"P\n!ASTGeneralizedPathExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\"\x80\x01\n\x16\x41STPathExpressionProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ASTGeneralizedPathExpressionProto\x12*\n\x05names\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xc2\x02\n\x1f\x41nyASTPostfixTableOperatorProto\x12>\n\x15\x61st_pivot_clause_node\x18\x81\x01 \x01(\x0b\x32\x1c.zetasql.ASTPivotClauseProtoH\x00\x12\x42\n\x17\x61st_unpivot_clause_node\x18\x84\x01 \x01(\x0b\x32\x1e.zetasql.ASTUnpivotClauseProtoH\x00\x12@\n\x16\x61st_sample_clause_node\x18\xe8\x01 \x01(\x0b\x32\x1d.zetasql.ASTSampleClauseProtoH\x00\x12Q\n\x1f\x61st_match_recognize_clause_node\x18\xe4\x03 \x01(\x0b\x32%.zetasql.ASTMatchRecognizeClauseProtoH\x00\x42\x06\n\x04node\"E\n\x1c\x41STPostfixTableOperatorProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xce\x04\n\x1a\x41nyASTTableExpressionProto\x12N\n\x1e\x61st_table_path_expression_node\x18\x10 \x01(\x0b\x32$.zetasql.ASTTablePathExpressionProtoH\x00\x12.\n\rast_join_node\x18\" \x01(\x0b\x32\x15.zetasql.ASTJoinProtoH\x00\x12I\n\x1b\x61st_parenthesized_join_node\x18K \x01(\x0b\x32\".zetasql.ASTParenthesizedJoinProtoH\x00\x12\x41\n\x17\x61st_table_subquery_node\x18R \x01(\x0b\x32\x1e.zetasql.ASTTableSubqueryProtoH\x00\x12-\n\x0c\x61st_tvf_node\x18\x9c\x01 \x01(\x0b\x32\x14.zetasql.ASTTVFProtoH\x00\x12J\n\x1a\x61st_table_data_source_node\x18\xa0\x01 \x01(\x0b\x32#.zetasql.AnyASTTableDataSourceProtoH\x00\x12G\n\x1a\x61st_graph_table_query_node\x18\xe4\x02 \x01(\x0b\x32 .zetasql.ASTGraphTableQueryProtoH\x00\x12V\n\"ast_pipe_join_lhs_placeholder_node\x18\xa0\x03 \x01(\x0b\x32\'.zetasql.ASTPipeJoinLhsPlaceholderProtoH\x00\x42\x06\n\x04node\"\x85\x01\n\x17\x41STTableExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x43\n\x11postfix_operators\x18\x02 \x03(\x0b\x32(.zetasql.AnyASTPostfixTableOperatorProto\"\xf2\x02\n\x1b\x41STTablePathExpressionProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12\x32\n\tpath_expr\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x36\n\x0bunnest_expr\x18\x03 \x01(\x0b\x32!.zetasql.ASTUnnestExpressionProto\x12#\n\x04hint\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12%\n\x05\x61lias\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x30\n\x0bwith_offset\x18\x06 \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProto\x12\x37\n\x0f\x66or_system_time\x18\t \x01(\x0b\x32\x1e.zetasql.ASTForSystemTimeProto\"R\n\x1e\x41STPipeJoinLhsPlaceholderProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\"z\n\x12\x41STFromClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12=\n\x10table_expression\x18\x02 \x01(\x0b\x32#.zetasql.AnyASTTableExpressionProto\"p\n\x13\x41STWhereClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"W\n\x16\x41STBooleanLiteralProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\x12\r\n\x05value\x18\x02 \x01(\x08\"q\n\x0f\x41STAndExprProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\tconjuncts\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xe3\x01\n\x18\x41STBinaryExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x30\n\x02op\x18\x02 \x01(\x0e\x32$.zetasql.ASTBinaryExpressionEnums.Op\x12\x0e\n\x06is_not\x18\x03 \x01(\x08\x12+\n\x03lhs\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12+\n\x03rhs\x18\x05 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x91\x01\n\x15\x41STStringLiteralProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12;\n\ncomponents\x18\x02 \x03(\x0b\x32\'.zetasql.ASTStringLiteralComponentProto\x12\x14\n\x0cstring_value\x18\x03 \x01(\t\"f\n\x1e\x41STStringLiteralComponentProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\x12\x14\n\x0cstring_value\x18\x02 \x01(\t\">\n\x0c\x41STStarProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"p\n\x0e\x41STOrExprProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\tdisjuncts\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"s\n\x12\x41STConcatExprProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x30\n\x08operands\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xce\x02\n\x1a\x41STOrderingExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12)\n\x07\x63ollate\x18\x03 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\x12.\n\nnull_order\x18\x04 \x01(\x0b\x32\x1a.zetasql.ASTNullOrderProto\x12G\n\rordering_spec\x18\x05 \x01(\x0e\x32\x30.zetasql.ASTOrderingExpressionEnums.OrderingSpec\x12\x31\n\x0boption_list\x18\x06 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xa0\x01\n\x0f\x41STOrderByProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x41\n\x14ordering_expressions\x18\x03 \x03(\x0b\x32#.zetasql.ASTOrderingExpressionProto\"\xbb\x01\n\x19\x41STGroupingItemOrderProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12G\n\rordering_spec\x18\x02 \x01(\x0e\x32\x30.zetasql.ASTOrderingExpressionEnums.OrderingSpec\x12.\n\nnull_order\x18\x03 \x01(\x0b\x32\x1a.zetasql.ASTNullOrderProto\"\xe4\x02\n\x14\x41STGroupingItemProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\'\n\x06rollup\x18\x03 \x01(\x0b\x32\x17.zetasql.ASTRollupProto\x12#\n\x04\x63ube\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTCubeProto\x12;\n\x11grouping_set_list\x18\x05 \x01(\x0b\x32 .zetasql.ASTGroupingSetListProto\x12%\n\x05\x61lias\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12?\n\x13grouping_item_order\x18\x07 \x01(\x0b\x32\".zetasql.ASTGroupingItemOrderProto\"\xd4\x01\n\x0f\x41STGroupByProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12(\n\x03\x61ll\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTGroupByAllProto\x12\x35\n\x0egrouping_items\x18\x04 \x03(\x0b\x32\x1d.zetasql.ASTGroupingItemProto\x12\x14\n\x0c\x61nd_order_by\x18\x05 \x01(\x08\";\n\x12\x41STGroupByAllProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"9\n\x10\x41STLimitAllProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\x92\x01\n\rASTLimitProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12&\n\x03\x61ll\x18\x02 \x01(\x0b\x32\x19.zetasql.ASTLimitAllProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x93\x01\n\x13\x41STLimitOffsetProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12%\n\x05limit\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTLimitProto\x12.\n\x06offset\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"F\n\x14\x41STFloatLiteralProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"E\n\x13\x41STNullLiteralProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"m\n\x10\x41STOnClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xcb\x01\n\x14\x41STAliasedQueryProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12*\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12%\n\x05query\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12\x39\n\tmodifiers\x18\x04 \x01(\x0b\x32&.zetasql.ASTAliasedQueryModifiersProto\"\xe9\x04\n\x0c\x41STJoinProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12\x30\n\x03lhs\x18\x02 \x01(\x0b\x32#.zetasql.AnyASTTableExpressionProto\x12#\n\x04hint\x18\x03 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x30\n\x03rhs\x18\x04 \x01(\x0b\x32#.zetasql.AnyASTTableExpressionProto\x12,\n\ton_clause\x18\x05 \x01(\x0b\x32\x19.zetasql.ASTOnClauseProto\x12\x32\n\x0cusing_clause\x18\x06 \x01(\x0b\x32\x1c.zetasql.ASTUsingClauseProto\x12\x39\n\x0b\x63lause_list\x18\x07 \x01(\x0b\x32$.zetasql.ASTOnOrUsingClauseListProto\x12\x31\n\tjoin_type\x18\x08 \x01(\x0e\x32\x1e.zetasql.ASTJoinEnums.JoinType\x12\x31\n\tjoin_hint\x18\t \x01(\x0e\x32\x1e.zetasql.ASTJoinEnums.JoinHint\x12\x0f\n\x07natural\x18\n \x01(\x08\x12\x1c\n\x14unmatched_join_count\x18\x0b \x01(\x03\x12\x1d\n\x15transformation_needed\x18\x0c \x01(\x08\x12\x1b\n\x13\x63ontains_comma_join\x18\r \x01(\x08\x12\x30\n\rjoin_location\x18\x0e \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"{\n\x12\x41STWithClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x04with\x18\x02 \x03(\x0b\x32\x1d.zetasql.ASTAliasedQueryProto\x12\x11\n\trecursive\x18\x03 \x01(\x08\"k\n\x0e\x41STHavingProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x84\x03\n\x0f\x41nyASTTypeProto\x12;\n\x14\x61st_simple_type_node\x18& \x01(\x0b\x32\x1b.zetasql.ASTSimpleTypeProtoH\x00\x12\x39\n\x13\x61st_array_type_node\x18\' \x01(\x0b\x32\x1a.zetasql.ASTArrayTypeProtoH\x00\x12;\n\x14\x61st_struct_type_node\x18) \x01(\x0b\x32\x1b.zetasql.ASTStructTypeProtoH\x00\x12:\n\x13\x61st_range_type_node\x18\xe6\x02 \x01(\x0b\x32\x1a.zetasql.ASTRangeTypeProtoH\x00\x12@\n\x16\x61st_function_type_node\x18\x95\x03 \x01(\x0b\x32\x1d.zetasql.ASTFunctionTypeProtoH\x00\x12\x36\n\x11\x61st_map_type_node\x18\xd6\x03 \x01(\x0b\x32\x18.zetasql.ASTMapTypeProtoH\x00\x42\x06\n\x04node\"5\n\x0c\x41STTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xd7\x01\n\x12\x41STSimpleTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12\x32\n\ttype_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12;\n\x0ftype_parameters\x18\x03 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\xd2\x01\n\x11\x41STArrayTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12.\n\x0c\x65lement_type\x18\x02 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12;\n\x0ftype_parameters\x18\x03 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\x8f\x01\n\x13\x41STStructFieldProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12&\n\x04type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\"\xd8\x01\n\x12\x41STStructTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12\x33\n\rstruct_fields\x18\x02 \x03(\x0b\x32\x1c.zetasql.ASTStructFieldProto\x12;\n\x0ftype_parameters\x18\x03 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"l\n\x1b\x41STFunctionTypeArgListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12&\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x18.zetasql.AnyASTTypeProto\"\x8c\x02\n\x14\x41STFunctionTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12\x36\n\x08\x61rg_list\x18\x02 \x01(\x0b\x32$.zetasql.ASTFunctionTypeArgListProto\x12-\n\x0breturn_type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12;\n\x0ftype_parameters\x18\x04 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x05 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\xe0\x01\n\x16\x41STCastExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12&\n\x04type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12-\n\x06\x66ormat\x18\x04 \x01(\x0b\x32\x1d.zetasql.ASTFormatClauseProto\x12\x14\n\x0cis_safe_cast\x18\x05 \x01(\x08\"\xa0\x01\n\x10\x41STSelectAsProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\ttype_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x31\n\x07\x61s_mode\x18\x03 \x01(\x0e\x32 .zetasql.ASTSelectAsEnums.AsMode\"l\n\x0e\x41STRollupProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\x0b\x65xpressions\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"j\n\x0c\x41STCubeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\x0b\x65xpressions\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xbe\x01\n\x13\x41STGroupingSetProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\'\n\x06rollup\x18\x03 \x01(\x0b\x32\x17.zetasql.ASTRollupProto\x12#\n\x04\x63ube\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTCubeProto\"u\n\x17\x41STGroupingSetListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\rgrouping_sets\x18\x02 \x03(\x0b\x32\x1c.zetasql.ASTGroupingSetProto\"\xa5\x01\n\x1b\x41STExpressionWithAliasProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xb3\x06\n\x14\x41STFunctionCallProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x31\n\targuments\x18\x03 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x38\n\x0fhaving_modifier\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTHavingModifierProto\x12I\n\x18\x63lamped_between_modifier\x18\x05 \x01(\x0b\x32\'.zetasql.ASTClampedBetweenModifierProto\x12*\n\x08order_by\x18\x06 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\x12\x32\n\x0climit_offset\x18\x07 \x01(\x0b\x32\x1c.zetasql.ASTLimitOffsetProto\x12#\n\x04hint\x18\x08 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12R\n\x16null_handling_modifier\x18\n \x01(\x0e\x32\x32.zetasql.ASTFunctionCallEnums.NullHandlingModifier\x12\x10\n\x08\x64istinct\x18\x0b \x01(\x08\x12\x30\n(is_current_date_time_without_parentheses\x18\x0c \x01(\x08\x12\x41\n\x14with_report_modifier\x18\r \x01(\x0b\x32#.zetasql.ASTWithReportModifierProto\x12*\n\x08group_by\x18\x0e \x01(\x0b\x32\x18.zetasql.ASTGroupByProto\x12\x30\n\nwhere_expr\x18\x0f \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\x12,\n\x0bhaving_expr\x18\x10 \x01(\x0b\x32\x17.zetasql.ASTHavingProto\x12\x17\n\x0fis_chained_call\x18\x11 \x01(\x08\"n\n\x17\x41STChainedBaseExprProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa3\x01\n\x18\x41STArrayConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.zetasql.ASTArrayTypeProto\x12\x30\n\x08\x65lements\x18\x03 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa0\x01\n\x1c\x41STStructConstructorArgProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\x8d\x01\n#ASTStructConstructorWithParensProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x39\n\x11\x66ield_expressions\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xbc\x01\n$ASTStructConstructorWithKeywordProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x30\n\x0bstruct_type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTStructTypeProto\x12\x35\n\x06\x66ields\x18\x03 \x03(\x0b\x32%.zetasql.ASTStructConstructorArgProto\"\xde\x02\n\x14\x41STInExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12+\n\x03lhs\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12#\n\x04hint\x18\x03 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12(\n\x07in_list\x18\x04 \x01(\x0b\x32\x17.zetasql.ASTInListProto\x12%\n\x05query\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12\x36\n\x0bunnest_expr\x18\x06 \x01(\x0b\x32!.zetasql.ASTUnnestExpressionProto\x12\x0e\n\x06is_not\x18\x07 \x01(\x08\x12.\n\x0bin_location\x18\x08 \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"e\n\x0e\x41STInListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x04list\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x95\x02\n\x19\x41STBetweenExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12+\n\x03lhs\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12+\n\x03low\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x04high\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x0e\n\x06is_not\x18\x05 \x01(\x08\x12\x33\n\x10\x62\x65tween_location\x18\x06 \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"w\n\x16\x41STNumericLiteralProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12\x36\n\x0estring_literal\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"z\n\x19\x41STBigNumericLiteralProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12\x36\n\x0estring_literal\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"\x8e\x01\n\x14\x41STBytesLiteralProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12:\n\ncomponents\x18\x02 \x03(\x0b\x32&.zetasql.ASTBytesLiteralComponentProto\x12\x13\n\x0b\x62ytes_value\x18\x03 \x01(\t\"O\n\x1d\x41STBytesLiteralComponentProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"\xa6\x01\n\x19\x41STDateOrTimeLiteralProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x36\n\x0estring_literal\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12$\n\ttype_kind\x18\x03 \x01(\x0e\x32\x11.zetasql.TypeKind\"D\n\x12\x41STMaxLiteralProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"t\n\x13\x41STJSONLiteralProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTLeafProto\x12\x36\n\x0estring_literal\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"}\n\x1b\x41STCaseValueExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\targuments\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x7f\n\x1d\x41STCaseNoValueExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\targuments\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xed\x01\n\x14\x41STArrayElementProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ASTGeneralizedPathExpressionProto\x12-\n\x05\x61rray\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x30\n\x08position\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x38\n\x15open_bracket_location\x18\x04 \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"\xf4\x01\n\x1e\x41STBitwiseShiftExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12+\n\x03lhs\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12+\n\x03rhs\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x15\n\ris_left_shift\x18\x04 \x01(\x08\x12\x34\n\x11operator_location\x18\x05 \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"p\n\x0f\x41STCollateProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x0e\x63ollation_name\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb6\x01\n\x1b\x41STDotGeneralizedFieldProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ASTGeneralizedPathExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12-\n\x04path\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xac\x01\n\x15\x41STDotIdentifierProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ASTGeneralizedPathExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12)\n\x04name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"l\n\x0f\x41STDotStarProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xac\x01\n\x1c\x41STDotStarWithModifiersProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x31\n\tmodifiers\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStarModifiersProto\"\xd5\x01\n\x1a\x41STExpressionSubqueryProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12%\n\x05query\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12>\n\x08modifier\x18\x04 \x01(\x0e\x32,.zetasql.ASTExpressionSubqueryEnums.Modifier\"\xe4\x01\n\x19\x41STExtractExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x30\n\x08lhs_expr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x30\n\x08rhs_expr\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x36\n\x0etime_zone_expr\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb2\x01\n\x16\x41STHavingModifierProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x43\n\rmodifier_kind\x18\x03 \x01(\x0e\x32,.zetasql.ASTHavingModifierEnums.ModifierKind\"\xe8\x01\n\x14\x41STIntervalExprProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x36\n\x0einterval_value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x33\n\x0e\x64\x61te_part_name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x36\n\x11\x64\x61te_part_name_to\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"z\n\x13\x41STSequenceArgProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x36\n\rsequence_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\x9d\x01\n\x15\x41STNamedArgumentProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12,\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"I\n\x1a\x41STInputTableArgumentProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\"O\n\x11\x41STNullOrderProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x13\n\x0bnulls_first\x18\x02 \x01(\x08\"|\n\x1b\x41STOnOrUsingClauseListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x17on_or_using_clause_list\x18\x02 \x03(\x0b\x32\x15.zetasql.ASTNodeProto\"r\n\x19\x41STParenthesizedJoinProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12#\n\x04join\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTJoinProto\"\xa3\x01\n\x13\x41STPartitionByProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12@\n\x18partitioning_expressions\x18\x03 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xba\x01\n\x14\x41STSetOperationProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12;\n\x08metadata\x18\x02 \x01(\x0b\x32).zetasql.ASTSetOperationMetadataListProto\x12\x33\n\x06inputs\x18\x03 \x03(\x0b\x32#.zetasql.AnyASTQueryExpressionProto\"\x95\x01\n ASTSetOperationMetadataListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12J\n\x1bset_operation_metadata_list\x18\x02 \x03(\x0b\x32%.zetasql.ASTSetOperationMetadataProto\"\x86\x01\n!ASTSetOperationAllOrDistinctProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\x05value\x18\x02 \x01(\x0e\x32+.zetasql.ASTSetOperationEnums.AllOrDistinct\"}\n\x18\x41STSetOperationTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\x05value\x18\x02 \x01(\x0e\x32+.zetasql.ASTSetOperationEnums.OperationType\"\x8a\x01\n#ASTSetOperationColumnMatchModeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x05value\x18\x02 \x01(\x0e\x32-.zetasql.ASTSetOperationEnums.ColumnMatchMode\"\x96\x01\n)ASTSetOperationColumnPropagationModeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x42\n\x05value\x18\x02 \x01(\x0e\x32\x33.zetasql.ASTSetOperationEnums.ColumnPropagationMode\"\xc4\x03\n\x1c\x41STSetOperationMetadataProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\x07op_type\x18\x02 \x01(\x0b\x32!.zetasql.ASTSetOperationTypeProto\x12\x43\n\x0f\x61ll_or_distinct\x18\x03 \x01(\x0b\x32*.zetasql.ASTSetOperationAllOrDistinctProto\x12#\n\x04hint\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12G\n\x11\x63olumn_match_mode\x18\x05 \x01(\x0b\x32,.zetasql.ASTSetOperationColumnMatchModeProto\x12S\n\x17\x63olumn_propagation_mode\x18\x06 \x01(\x0b\x32\x32.zetasql.ASTSetOperationColumnPropagationModeProto\x12\x41\n\x1c\x63orresponding_by_column_list\x18\x07 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\"q\n\x16\x41STStarExceptListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x0bidentifiers\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xad\x01\n\x15\x41STStarModifiersProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0b\x65xcept_list\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTStarExceptListProto\x12\x37\n\rreplace_items\x18\x03 \x03(\x0b\x32 .zetasql.ASTStarReplaceItemProto\"\xa0\x01\n\x17\x41STStarReplaceItemProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12*\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"{\n\x19\x41STStarWithModifiersProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x31\n\tmodifiers\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStarModifiersProto\"\xae\x01\n\x15\x41STTableSubqueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12(\n\x08subquery\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x12\n\nis_lateral\x18\x04 \x01(\x08\"\xa8\x01\n\x17\x41STUnaryExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12/\n\x07operand\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12/\n\x02op\x18\x03 \x01(\x0e\x32#.zetasql.ASTUnaryExpressionEnums.Op\"\xab\x01\n\x1e\x41STExpressionWithOptAliasProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12.\n\x0eoptional_alias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xb7\x01\n\x18\x41STUnnestExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x0b\x65xpressions\x18\x02 \x03(\x0b\x32\'.zetasql.ASTExpressionWithOptAliasProto\x12\x36\n\x0e\x61rray_zip_mode\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTNamedArgumentProto\"q\n\x14\x41STWindowClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\x07windows\x18\x02 \x03(\x0b\x32!.zetasql.ASTWindowDefinitionProto\"\xa7\x01\n\x18\x41STWindowDefinitionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x39\n\x0bwindow_spec\x18\x03 \x01(\x0b\x32$.zetasql.ASTWindowSpecificationProto\"\xe2\x01\n\x13\x41STWindowFrameProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\nstart_expr\x18\x02 \x01(\x0b\x32 .zetasql.ASTWindowFrameExprProto\x12\x32\n\x08\x65nd_expr\x18\x03 \x01(\x0b\x32 .zetasql.ASTWindowFrameExprProto\x12:\n\nframe_unit\x18\x04 \x01(\x0e\x32&.zetasql.ASTWindowFrameEnums.FrameUnit\"\xba\x01\n\x17\x41STWindowFrameExprProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x44\n\rboundary_type\x18\x03 \x01(\x0e\x32-.zetasql.ASTWindowFrameExprEnums.BoundaryType\"\x8d\x03\n\x16\x41STLikeExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12+\n\x03lhs\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12)\n\x02op\x18\x03 \x01(\x0b\x32\x1d.zetasql.ASTAnySomeAllOpProto\x12#\n\x04hint\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12(\n\x07in_list\x18\x05 \x01(\x0b\x32\x17.zetasql.ASTInListProto\x12%\n\x05query\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12\x36\n\x0bunnest_expr\x18\x07 \x01(\x0b\x32!.zetasql.ASTUnnestExpressionProto\x12\x0e\n\x06is_not\x18\x08 \x01(\x08\x12\x30\n\rlike_location\x18\t \x01(\x0b\x32\x19.zetasql.ASTLocationProto\"\x8f\x02\n\x1b\x41STWindowSpecificationProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x10\x62\x61se_window_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0cpartition_by\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12*\n\x08order_by\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\x12\x32\n\x0cwindow_frame\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTWindowFrameProto\"b\n\x12\x41STWithOffsetProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12%\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"k\n\x14\x41STAnySomeAllOpProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x02op\x18\x02 \x01(\x0e\x32 .zetasql.ASTAnySomeAllOpEnums.Op\"\xb9\x01\n\x1c\x41nyASTParameterExprBaseProto\x12\x42\n\x17\x61st_parameter_expr_node\x18\x8b\x01 \x01(\x0b\x32\x1e.zetasql.ASTParameterExprProtoH\x00\x12M\n\x1d\x61st_system_variable_expr_node\x18\x8c\x01 \x01(\x0b\x32#.zetasql.ASTSystemVariableExprProtoH\x00\x42\x06\n\x04node\"H\n\x19\x41STParameterExprBaseProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\"\x9c\x01\n\x15\x41STStatementListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x0estatement_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.AnyASTStatementProto\x12%\n\x1dvariable_declarations_allowed\x18\x03 \x01(\x08\"\x89\x06\n\x1a\x41nyASTScriptStatementProto\x12>\n\x15\x61st_if_statement_node\x18\x83\x02 \x01(\x0b\x32\x1c.zetasql.ASTIfStatementProtoH\x00\x12\x42\n\x17\x61st_case_statement_node\x18\x86\x02 \x01(\x0b\x32\x1e.zetasql.ASTCaseStatementProtoH\x00\x12\x44\n\x18\x61st_raise_statement_node\x18\x95\x02 \x01(\x0b\x32\x1f.zetasql.ASTRaiseStatementProtoH\x00\x12\x43\n\x18\x61st_begin_end_block_node\x18\x98\x02 \x01(\x0b\x32\x1e.zetasql.ASTBeginEndBlockProtoH\x00\x12N\n\x1d\x61st_variable_declaration_node\x18\x9a\x02 \x01(\x0b\x32$.zetasql.ASTVariableDeclarationProtoH\x00\x12X\n!ast_break_continue_statement_node\x18\x9c\x02 \x01(\x0b\x32*.zetasql.AnyASTBreakContinueStatementProtoH\x00\x12\x46\n\x19\x61st_return_statement_node\x18\xa2\x02 \x01(\x0b\x32 .zetasql.ASTReturnStatementProtoH\x00\x12H\n\x1a\x61st_single_assignment_node\x18\xa3\x02 \x01(\x0b\x32!.zetasql.ASTSingleAssignmentProtoH\x00\x12Q\n\x1f\x61st_assignment_from_struct_node\x18\xa6\x02 \x01(\x0b\x32%.zetasql.ASTAssignmentFromStructProtoH\x00\x12\x45\n\x17\x61st_loop_statement_node\x18\xad\x02 \x01(\x0b\x32!.zetasql.AnyASTLoopStatementProtoH\x00\x42\x06\n\x04node\"E\n\x17\x41STScriptStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"\x9c\x01\n\x17\x41STHintedStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x30\n\tstatement\x18\x03 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProto\"\xc7\x01\n\"ASTStatementWithPipeOperatorsProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x30\n\tstatement\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProto\x12\x43\n\x14pipe_operator_suffix\x18\x03 \x01(\x0b\x32%.zetasql.ASTSubpipelineStatementProto\"x\n\x18\x41STExplainStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x30\n\tstatement\x18\x02 \x01(\x0b\x32\x1d.zetasql.AnyASTStatementProto\"\xed\x01\n\x19\x41STDescribeStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x38\n\x13optional_identifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x04name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12;\n\x12optional_from_name\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xea\x01\n\x15\x41STShowStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x36\n\roptional_name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12<\n\x14optional_like_string\x18\x04 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"\xdb\x01\n\x1a\x41nyASTTransactionModeProto\x12Z\n$ast_transaction_isolation_level_node\x18\x65 \x01(\x0b\x32*.zetasql.ASTTransactionIsolationLevelProtoH\x00\x12Y\n$ast_transaction_read_write_mode_node\x18\x66 \x01(\x0b\x32).zetasql.ASTTransactionReadWriteModeProtoH\x00\x42\x06\n\x04node\"@\n\x17\x41STTransactionModeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xb9\x01\n!ASTTransactionIsolationLevelProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTransactionModeProto\x12\x30\n\x0bidentifier1\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x30\n\x0bidentifier2\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\x92\x01\n ASTTransactionReadWriteModeProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTransactionModeProto\x12<\n\x04mode\x18\x02 \x01(\x0e\x32..zetasql.ASTTransactionReadWriteModeEnums.Mode\"{\n\x1b\x41STTransactionModeListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x08\x65lements\x18\x02 \x03(\x0b\x32#.zetasql.AnyASTTransactionModeProto\"}\n\x16\x41STBeginStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x37\n\tmode_list\x18\x02 \x01(\x0b\x32$.zetasql.ASTTransactionModeListProto\"\x86\x01\n\x1f\x41STSetTransactionStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x37\n\tmode_list\x18\x02 \x01(\x0b\x32$.zetasql.ASTTransactionModeListProto\"E\n\x17\x41STCommitStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"G\n\x19\x41STRollbackStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"z\n\x1b\x41STStartBatchStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12/\n\nbatch_type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"G\n\x19\x41STRunBatchStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"I\n\x1b\x41STAbortBatchStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"\xb6\x08\n\x17\x41nyASTDdlStatementProto\x12N\n\x1e\x61st_drop_entity_statement_node\x18p \x01(\x0b\x32$.zetasql.ASTDropEntityStatementProtoH\x00\x12R\n ast_drop_function_statement_node\x18q \x01(\x0b\x32&.zetasql.ASTDropFunctionStatementProtoH\x00\x12]\n&ast_drop_table_function_statement_node\x18r \x01(\x0b\x32+.zetasql.ASTDropTableFunctionStatementProtoH\x00\x12\x63\n)ast_drop_materialized_view_statement_node\x18t \x01(\x0b\x32..zetasql.ASTDropMaterializedViewStatementProtoH\x00\x12]\n&ast_drop_snapshot_table_statement_node\x18u \x01(\x0b\x32+.zetasql.ASTDropSnapshotTableStatementProtoH\x00\x12I\n\x19\x61st_create_statement_node\x18\x96\x01 \x01(\x0b\x32#.zetasql.AnyASTCreateStatementProtoH\x00\x12\x63\n)ast_drop_row_access_policy_statement_node\x18\x9f\x02 \x01(\x0b\x32-.zetasql.ASTDropRowAccessPolicyStatementProtoH\x00\x12\x42\n\x17\x61st_drop_statement_node\x18\xa1\x02 \x01(\x0b\x32\x1e.zetasql.ASTDropStatementProtoH\x00\x12P\n\x1d\x61st_alter_statement_base_node\x18\xb1\x02 \x01(\x0b\x32&.zetasql.AnyASTAlterStatementBaseProtoH\x00\x12l\n-ast_drop_privilege_restriction_statement_node\x18\xc6\x02 \x01(\x0b\x32\x32.zetasql.ASTDropPrivilegeRestrictionStatementProtoH\x00\x12\x46\n\x19\x61st_undrop_statement_node\x18\x84\x03 \x01(\x0b\x32 .zetasql.ASTUndropStatementProtoH\x00\x12P\n\x1d\x61st_drop_index_statement_node\x18\x97\x03 \x01(\x0b\x32&.zetasql.AnyASTDropIndexStatementProtoH\x00\x42\x06\n\x04node\"B\n\x14\x41STDdlStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\"\xc3\x01\n\x1b\x41STDropEntityStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12\x30\n\x0b\x65ntity_type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x04name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xcc\x01\n\x1d\x41STDropFunctionStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32#.zetasql.ASTFunctionParametersProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\x98\x01\n\"ASTDropTableFunctionStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\xa8\x01\n)ASTDropAllRowAccessPoliciesStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x33\n\ntable_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x1a\n\x12has_access_keyword\x18\x03 \x01(\x08\"\x9b\x01\n%ASTDropMaterializedViewStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\x98\x01\n\"ASTDropSnapshotTableStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\xde\x01\n\x1d\x41nyASTDropIndexStatementProto\x12Y\n$ast_drop_search_index_statement_node\x18v \x01(\x0b\x32).zetasql.ASTDropSearchIndexStatementProtoH\x00\x12Z\n$ast_drop_vector_index_statement_node\x18\x96\x03 \x01(\x0b\x32).zetasql.ASTDropVectorIndexStatementProtoH\x00\x42\x06\n\x04node\"\xc5\x01\n\x1a\x41STDropIndexStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x33\n\ntable_name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"W\n ASTDropSearchIndexStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTDropIndexStatementProto\"W\n ASTDropVectorIndexStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTDropIndexStatementProto\"\xdc\x01\n\x17\x41STRenameStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x31\n\x08old_name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x31\n\x08new_name\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xf7\x02\n\x17\x41STImportStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x34\n\x0cstring_value\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12%\n\x05\x61lias\x18\x04 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12.\n\ninto_alias\x18\x05 \x01(\x0b\x32\x1a.zetasql.ASTIntoAliasProto\x12\x32\n\x0coptions_list\x18\x06 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12@\n\x0bimport_kind\x18\x07 \x01(\x0e\x32+.zetasql.ASTImportStatementEnums.ImportKind\"\xa8\x01\n\x17\x41STModuleStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x83\x01\n\x1c\x41STWithConnectionClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x11\x63onnection_clause\x18\x02 \x01(\x0b\x32!.zetasql.ASTConnectionClauseProto\"k\n\x11\x41STIntoAliasProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xff\x01\n-ASTUnnestExpressionWithOptAliasAndOffsetProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x11unnest_expression\x18\x02 \x01(\x0b\x32!.zetasql.ASTUnnestExpressionProto\x12.\n\x0eoptional_alias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x39\n\x14optional_with_offset\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProto\"\x9b\x01\n\x17\x41STPivotExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\x91\x01\n\x12\x41STPivotValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"{\n\x1b\x41STPivotExpressionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x0b\x65xpressions\x18\x02 \x03(\x0b\x32 .zetasql.ASTPivotExpressionProto\"l\n\x16\x41STPivotValueListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x06values\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTPivotValueProto\"\xaa\x02\n\x13\x41STPivotClauseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTPostfixTableOperatorProto\x12?\n\x11pivot_expressions\x18\x02 \x01(\x0b\x32$.zetasql.ASTPivotExpressionListProto\x12\x36\n\x0e\x66or_expression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x35\n\x0cpivot_values\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPivotValueListProto\x12,\n\x0coutput_alias\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xb0\x01\n\x15\x41STUnpivotInItemProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x0funpivot_columns\x18\x02 \x01(\x0b\x32#.zetasql.ASTPathExpressionListProto\x12\x32\n\x05\x61lias\x18\x03 \x01(\x0b\x32#.zetasql.ASTUnpivotInItemLabelProto\"t\n\x19\x41STUnpivotInItemListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x08in_items\x18\x02 \x03(\x0b\x32\x1e.zetasql.ASTUnpivotInItemProto\"\x8a\x03\n\x15\x41STUnpivotClauseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTPostfixTableOperatorProto\x12I\n\x1cunpivot_output_value_columns\x18\x02 \x01(\x0b\x32#.zetasql.ASTPathExpressionListProto\x12\x43\n\x1aunpivot_output_name_column\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12<\n\x10unpivot_in_items\x18\x04 \x01(\x0b\x32\".zetasql.ASTUnpivotInItemListProto\x12,\n\x0coutput_alias\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12>\n\x0bnull_filter\x18\x06 \x01(\x0e\x32).zetasql.ASTUnpivotClauseEnums.NullFilter\"g\n\x13\x41STUsingClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04keys\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"r\n\x15\x41STForSystemTimeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x90\x04\n\x1c\x41STMatchRecognizeClauseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTPostfixTableOperatorProto\x12\x32\n\x0cpartition_by\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12*\n\x08order_by\x18\x03 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\x12-\n\x08measures\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12\x46\n\x17\x61\x66ter_match_skip_clause\x18\x05 \x01(\x0b\x32%.zetasql.ASTAfterMatchSkipClauseProto\x12\x39\n\x07pattern\x18\x06 \x01(\x0b\x32(.zetasql.AnyASTRowPatternExpressionProto\x12\x45\n pattern_variable_definition_list\x18\x08 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12,\n\x0coutput_alias\x18\t \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x32\n\x0coptions_list\x18\n \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x9a\x01\n\x1c\x41STAfterMatchSkipClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12S\n\x0btarget_type\x18\x02 \x01(\x0e\x32>.zetasql.ASTAfterMatchSkipClauseEnums.AfterMatchSkipTargetType\"\xb8\x03\n\x1f\x41nyASTRowPatternExpressionProto\x12M\n\x1d\x61st_row_pattern_variable_node\x18\xe6\x03 \x01(\x0b\x32#.zetasql.ASTRowPatternVariableProtoH\x00\x12O\n\x1e\x61st_row_pattern_operation_node\x18\xe7\x03 \x01(\x0b\x32$.zetasql.ASTRowPatternOperationProtoH\x00\x12G\n\x1a\x61st_empty_row_pattern_node\x18\xea\x03 \x01(\x0b\x32 .zetasql.ASTEmptyRowPatternProtoH\x00\x12Y\n#ast_row_pattern_quantification_node\x18\xf0\x03 \x01(\x0b\x32).zetasql.ASTRowPatternQuantificationProtoH\x00\x12I\n\x1b\x61st_row_pattern_anchor_node\x18\xf4\x03 \x01(\x0b\x32!.zetasql.ASTRowPatternAnchorProtoH\x00\x42\x06\n\x04node\"\\\n\x1c\x41STRowPatternExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x15\n\rparenthesized\x18\x02 \x01(\x08\"~\n\x1a\x41STRowPatternVariableProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTRowPatternExpressionProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xd3\x01\n\x1b\x41STRowPatternOperationProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTRowPatternExpressionProto\x12\x43\n\x07op_type\x18\x02 \x01(\x0e\x32\x32.zetasql.ASTRowPatternOperationEnums.OperationType\x12\x38\n\x06inputs\x18\x03 \x03(\x0b\x32(.zetasql.AnyASTRowPatternExpressionProto\"P\n\x17\x41STEmptyRowPatternProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTRowPatternExpressionProto\"\x8b\x01\n\x18\x41STRowPatternAnchorProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTRowPatternExpressionProto\x12\x38\n\x06\x61nchor\x18\x02 \x01(\x0e\x32(.zetasql.ASTRowPatternAnchorEnums.Anchor\"\xfd\x01\n\x15\x41nyASTQuantifierProto\x12J\n\x1b\x61st_bounded_quantifier_node\x18\xec\x03 \x01(\x0b\x32\".zetasql.ASTBoundedQuantifierProtoH\x00\x12\x46\n\x19\x61st_fixed_quantifier_node\x18\xee\x03 \x01(\x0b\x32 .zetasql.ASTFixedQuantifierProtoH\x00\x12H\n\x1a\x61st_symbol_quantifier_node\x18\xef\x03 \x01(\x0b\x32!.zetasql.ASTSymbolQuantifierProtoH\x00\x42\x06\n\x04node\"Q\n\x12\x41STQuantifierProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x14\n\x0cis_reluctant\x18\x02 \x01(\x08\"\xb6\x01\n\x19\x41STBoundedQuantifierProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTQuantifierProto\x12\x35\n\x0blower_bound\x18\x02 \x01(\x0b\x32 .zetasql.ASTQuantifierBoundProto\x12\x35\n\x0bupper_bound\x18\x03 \x01(\x0b\x32 .zetasql.ASTQuantifierBoundProto\"o\n\x17\x41STQuantifierBoundProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"u\n\x17\x41STFixedQuantifierProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTQuantifierProto\x12-\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x81\x01\n\x18\x41STSymbolQuantifierProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTQuantifierProto\x12\x38\n\x06symbol\x18\x02 \x01(\x0e\x32(.zetasql.ASTSymbolQuantifierEnums.Symbol\"\xc8\x01\n ASTRowPatternQuantificationProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTRowPatternExpressionProto\x12\x39\n\x07operand\x18\x02 \x01(\x0b\x32(.zetasql.AnyASTRowPatternExpressionProto\x12\x32\n\nquantifier\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTQuantifierProto\"l\n\x0f\x41STQualifyProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa2\x01\n\x1e\x41STClampedBetweenModifierProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x03low\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x04high\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"w\n\x1a\x41STWithReportModifierProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\x0coptions_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xa5\x01\n\x14\x41STFormatClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x06\x66ormat\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x36\n\x0etime_zone_expr\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x82\x01\n\x1a\x41STPathExpressionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12=\n\x14path_expression_list\x18\x02 \x03(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\x88\x01\n\x15\x41STParameterExprProto\x12\x32\n\x06parent\x18\x01 \x01(\x0b\x32\".zetasql.ASTParameterExprBaseProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x10\n\x08position\x18\x03 \x01(\x03\"\x7f\n\x1a\x41STSystemVariableExprProto\x12\x32\n\x06parent\x18\x01 \x01(\x0b\x32\".zetasql.ASTParameterExprBaseProto\x12-\n\x04path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xa2\x01\n\x0e\x41STLambdaProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x35\n\rargument_list\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb7\x01\n\x1c\x41STAnalyticFunctionCallProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12/\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x1d.zetasql.ASTFunctionCallProto\x12\x39\n\x0bwindow_spec\x18\x03 \x01(\x0b\x32$.zetasql.ASTWindowSpecificationProto\"z\n\x11\x41STClusterByProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12>\n\x16\x63lustering_expressions\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xf3\x01\n\x19\x41STNewConstructorArgProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x38\n\x13optional_identifier\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x41\n\x18optional_path_expression\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xac\x01\n\x16\x41STNewConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12.\n\ttype_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTSimpleTypeProto\x12\x35\n\targuments\x18\x03 \x03(\x0b\x32\".zetasql.ASTNewConstructorArgProto\"\xda\x01\n\x1c\x41STBracedConstructorLhsProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12I\n\x12\x65xtended_path_expr\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12\x42\n\toperation\x18\x03 \x01(\x0e\x32/.zetasql.ASTBracedConstructorLhsEnums.Operation\"\x98\x01\n#ASTBracedConstructorFieldValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x16\n\x0e\x63olon_prefixed\x18\x03 \x01(\x08\"\xe4\x01\n\x1e\x41STBracedConstructorFieldProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12;\n\x05value\x18\x04 \x01(\x0b\x32,.zetasql.ASTBracedConstructorFieldValueProto\x12\x17\n\x0f\x63omma_separated\x18\x05 \x01(\x08\x12\x45\n\x16\x62raced_constructor_lhs\x18\x06 \x01(\x0b\x32%.zetasql.ASTBracedConstructorLhsProto\"\x81\x01\n\x19\x41STBracedConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x37\n\x06\x66ields\x18\x03 \x03(\x0b\x32\'.zetasql.ASTBracedConstructorFieldProto\"\xbb\x01\n\x1c\x41STBracedNewConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12.\n\ttype_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTSimpleTypeProto\x12>\n\x12\x62raced_constructor\x18\x03 \x01(\x0b\x32\".zetasql.ASTBracedConstructorProto\"\xfb\x01\n\x1e\x41STExtendedPathExpressionProto\x12:\n\x06parent\x18\x01 \x01(\x0b\x32*.zetasql.ASTGeneralizedPathExpressionProto\x12I\n\x12parenthesized_path\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12R\n\x1bgeneralized_path_expression\x18\x03 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\"\xb9\x01\n\x19\x41STUpdateConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12/\n\x08\x66unction\x18\x02 \x01(\x0b\x32\x1d.zetasql.ASTFunctionCallProto\x12>\n\x12\x62raced_constructor\x18\x03 \x01(\x0b\x32\".zetasql.ASTBracedConstructorProto\"\xbb\x01\n\x1f\x41STStructBracedConstructorProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12+\n\ttype_name\x18\x02 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12>\n\x12\x62raced_constructor\x18\x03 \x01(\x0b\x32\".zetasql.ASTBracedConstructorProto\"t\n\x13\x41STOptionsListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x0foptions_entries\x18\x02 \x03(\x0b\x32\x1d.zetasql.ASTOptionsEntryProto\"\xda\x01\n\x14\x41STOptionsEntryProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x05value\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x41\n\rassignment_op\x18\x04 \x01(\x0e\x32*.zetasql.ASTOptionsEntryEnums.AssignmentOp\"\xe9\x0b\n\x1a\x41nyASTCreateStatementProto\x12W\n\"ast_create_constant_statement_node\x18\xa5\x01 \x01(\x0b\x32(.zetasql.ASTCreateConstantStatementProtoH\x00\x12Y\n#ast_create_procedure_statement_node\x18\xa7\x01 \x01(\x0b\x32).zetasql.ASTCreateProcedureStatementProtoH\x00\x12Q\n\x1f\x61st_create_model_statement_node\x18\xaa\x01 \x01(\x0b\x32%.zetasql.ASTCreateModelStatementProtoH\x00\x12Q\n\x1f\x61st_create_index_statement_node\x18\xaf\x01 \x01(\x0b\x32%.zetasql.ASTCreateIndexStatementProtoH\x00\x12\x62\n(ast_create_snapshot_table_statement_node\x18\xb5\x01 \x01(\x0b\x32-.zetasql.ASTCreateSnapshotTableStatementProtoH\x00\x12S\n ast_create_entity_statement_node\x18\x94\x02 \x01(\x0b\x32&.zetasql.ASTCreateEntityStatementProtoH\x00\x12g\n+ast_create_row_access_policy_statement_node\x18\xa0\x02 \x01(\x0b\x32/.zetasql.ASTCreateRowAccessPolicyStatementProtoH\x00\x12S\n\x1f\x61st_create_table_stmt_base_node\x18\xa7\x02 \x01(\x0b\x32\'.zetasql.AnyASTCreateTableStmtBaseProtoH\x00\x12[\n#ast_create_view_statement_base_node\x18\xaa\x02 \x01(\x0b\x32+.zetasql.AnyASTCreateViewStatementBaseProtoH\x00\x12Y\n\"ast_create_function_stmt_base_node\x18\xb9\x02 \x01(\x0b\x32*.zetasql.AnyASTCreateFunctionStmtBaseProtoH\x00\x12p\n/ast_create_privilege_restriction_statement_node\x18\xc4\x02 \x01(\x0b\x32\x34.zetasql.ASTCreatePrivilegeRestrictionStatementProtoH\x00\x12\x62\n(ast_create_property_graph_statement_node\x18\xf5\x02 \x01(\x0b\x32-.zetasql.ASTCreatePropertyGraphStatementProtoH\x00\x12W\n\"ast_create_snapshot_statement_node\x18\xae\x03 \x01(\x0b\x32(.zetasql.ASTCreateSnapshotStatementProtoH\x00\x12U\n ast_create_schema_stmt_base_node\x18\xb6\x03 \x01(\x0b\x32(.zetasql.AnyASTCreateSchemaStmtBaseProtoH\x00\x12[\n$ast_create_connection_statement_node\x18\xdf\x03 \x01(\x0b\x32*.zetasql.ASTCreateConnectionStatementProtoH\x00\x12W\n\"ast_create_sequence_statement_node\x18\x94\x04 \x01(\x0b\x32(.zetasql.ASTCreateSequenceStatementProtoH\x00\x42\x06\n\x04node\"\xb0\x01\n\x17\x41STCreateStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12\x35\n\x05scope\x18\x02 \x01(\x0e\x32&.zetasql.ASTCreateStatementEnums.Scope\x12\x15\n\ris_or_replace\x18\x03 \x01(\x08\x12\x18\n\x10is_if_not_exists\x18\x04 \x01(\x08\"\xe5\x03\n\x19\x41STFunctionParameterProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12&\n\x04type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12I\n\x18templated_parameter_type\x18\x04 \x01(\x0b\x32\'.zetasql.ASTTemplatedParameterTypeProto\x12.\n\ntvf_schema\x18\x05 \x01(\x0b\x32\x1a.zetasql.ASTTVFSchemaProto\x12%\n\x05\x61lias\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x35\n\rdefault_value\x18\x07 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12[\n\x18procedure_parameter_mode\x18\x08 \x01(\x0e\x32\x39.zetasql.ASTFunctionParameterEnums.ProcedureParameterMode\x12\x18\n\x10is_not_aggregate\x18\t \x01(\x08\"\x82\x01\n\x1a\x41STFunctionParametersProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12=\n\x11parameter_entries\x18\x02 \x03(\x0b\x32\".zetasql.ASTFunctionParameterProto\"\xac\x01\n\x1b\x41STFunctionDeclarationProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32#.zetasql.ASTFunctionParametersProto\"t\n\x17\x41STSqlFunctionBodyProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xbb\x02\n\x13\x41STTVFArgumentProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x32\n\x0ctable_clause\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTTableClauseProto\x12\x32\n\x0cmodel_clause\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTModelClauseProto\x12<\n\x11\x63onnection_clause\x18\x05 \x01(\x0b\x32!.zetasql.ASTConnectionClauseProto\x12)\n\x04\x64\x65sc\x18\x06 \x01(\x0b\x32\x1b.zetasql.ASTDescriptorProto\"\x86\x02\n\x0b\x41STTVFProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x36\n\x10\x61rgument_entries\x18\x03 \x03(\x0b\x32\x1c.zetasql.ASTTVFArgumentProto\x12#\n\x04hint\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12%\n\x05\x61lias\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x12\n\nis_lateral\x18\x06 \x01(\x08\"\xd3\x01\n\x13\x41STTableClauseProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x33\n\ntable_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12!\n\x03tvf\x18\x03 \x01(\x0b\x32\x14.zetasql.ASTTVFProto\x12\x32\n\x0cwhere_clause\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\"q\n\x13\x41STModelClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\nmodel_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"z\n\x18\x41STConnectionClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x37\n\x0f\x63onnection_path\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb4\x01\n\x1a\x41nyASTTableDataSourceProto\x12G\n\x1a\x61st_clone_data_source_node\x18\xa1\x01 \x01(\x0b\x32 .zetasql.ASTCloneDataSourceProtoH\x00\x12\x45\n\x19\x61st_copy_data_source_node\x18\xa2\x01 \x01(\x0b\x32\x1f.zetasql.ASTCopyDataSourceProtoH\x00\x42\x06\n\x04node\"\xec\x01\n\x17\x41STTableDataSourceProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12\x32\n\tpath_expr\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x37\n\x0f\x66or_system_time\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTForSystemTimeProto\x12\x32\n\x0cwhere_clause\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\"K\n\x17\x41STCloneDataSourceProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableDataSourceProto\"J\n\x16\x41STCopyDataSourceProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableDataSourceProto\"|\n\x1b\x41STCloneDataSourceListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x0c\x64\x61ta_sources\x18\x02 \x03(\x0b\x32 .zetasql.ASTCloneDataSourceProto\"\xbe\x01\n\x1a\x41STCloneDataStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x34\n\x0btarget_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12>\n\x10\x64\x61ta_source_list\x18\x03 \x01(\x0b\x32$.zetasql.ASTCloneDataSourceListProto\"\xb8\x01\n!ASTCreateConnectionStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xb0\x01\n\x1f\x41STCreateConstantStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12,\n\x04\x65xpr\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb0\x01\n\x1f\x41STCreateDatabaseStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x84\x04\n ASTCreateProcedureStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x37\n\nparameters\x18\x03 \x01(\x0b\x32#.zetasql.ASTFunctionParametersProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12%\n\x04\x62ody\x18\x05 \x01(\x0b\x32\x17.zetasql.ASTScriptProto\x12\x45\n\x16with_connection_clause\x18\x06 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\x12-\n\x08language\x18\x07 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12,\n\x04\x63ode\x18\x08 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12G\n\x11\x65xternal_security\x18\t \x01(\x0e\x32,.zetasql.ASTCreateStatementEnums.SqlSecurity\"\xe4\x01\n\x1f\x41nyASTCreateSchemaStmtBaseProto\x12S\n ast_create_schema_statement_node\x18\xa8\x01 \x01(\x0b\x32&.zetasql.ASTCreateSchemaStatementProtoH\x00\x12\x64\n)ast_create_external_schema_statement_node\x18\xb7\x03 \x01(\x0b\x32..zetasql.ASTCreateExternalSchemaStatementProtoH\x00\x42\x06\n\x04node\"\xb3\x01\n\x1c\x41STCreateSchemaStmtBaseProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x81\x01\n\x1d\x41STCreateSchemaStatementProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTCreateSchemaStmtBaseProto\x12)\n\x07\x63ollate\x18\x02 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\xa5\x01\n%ASTCreateExternalSchemaStatementProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTCreateSchemaStmtBaseProto\x12\x45\n\x16with_connection_clause\x18\x02 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\"|\n\x18\x41STAliasedQueryListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x39\n\x12\x61liased_query_list\x18\x02 \x03(\x0b\x32\x1d.zetasql.ASTAliasedQueryProto\"r\n\x17\x41STTransformClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x0bselect_list\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\"\xf0\x03\n\x1c\x41STCreateModelStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12:\n\x10transform_clause\x18\x03 \x01(\x0b\x32 .zetasql.ASTTransformClauseProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12%\n\x05query\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12?\n\x13input_output_clause\x18\x06 \x01(\x0b\x32\".zetasql.ASTInputOutputClauseProto\x12\x11\n\tis_remote\x18\x07 \x01(\x08\x12\x45\n\x16with_connection_clause\x18\x08 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\x12=\n\x12\x61liased_query_list\x18\t \x01(\x0b\x32!.zetasql.ASTAliasedQueryListProto\"\x81\x01\n\x17\x41STIndexAllColumnsProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\x12\x36\n\x0e\x63olumn_options\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTIndexItemListProto\"\x81\x01\n\x15\x41STIndexItemListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x41\n\x14ordering_expressions\x18\x02 \x03(\x0b\x32#.zetasql.ASTOrderingExpressionProto\"\x80\x01\n\"ASTIndexStoringExpressionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\x0b\x65xpressions\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x9e\x01\n!ASTIndexUnnestExpressionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12R\n\x12unnest_expressions\x18\x02 \x03(\x0b\x32\x36.zetasql.ASTUnnestExpressionWithOptAliasAndOffsetProto\"\xf0\x05\n\x1c\x41STCreateIndexStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x33\n\ntable_name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x34\n\x14optional_table_alias\x18\x04 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12Y\n%optional_index_unnest_expression_list\x18\x05 \x01(\x0b\x32*.zetasql.ASTIndexUnnestExpressionListProto\x12\x37\n\x0findex_item_list\x18\x06 \x01(\x0b\x32\x1e.zetasql.ASTIndexItemListProto\x12W\n\"optional_index_storing_expressions\x18\x07 \x01(\x0b\x32+.zetasql.ASTIndexStoringExpressionListProto\x12;\n\x15optional_partition_by\x18\x08 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12\x32\n\x0coptions_list\x18\t \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x11\n\tis_unique\x18\n \x01(\x08\x12\x11\n\tis_search\x18\x0b \x01(\x08\x12K\n\x19spanner_interleave_clause\x18\x0c \x01(\x0b\x32(.zetasql.ASTSpannerInterleaveClauseProto\x12 \n\x18spanner_is_null_filtered\x18\r \x01(\x08\x12\x11\n\tis_vector\x18\x0e \x01(\x08\"\xeb\x01\n\x1b\x41STExportDataStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x45\n\x16with_connection_clause\x18\x02 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12%\n\x05query\x18\x04 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\"\xff\x01\n\x1c\x41STExportModelStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x38\n\x0fmodel_name_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x45\n\x16with_connection_clause\x18\x03 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xb3\x02\n\x1f\x41STExportMetadataStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x35\n\x12schema_object_kind\x18\x02 \x01(\x0e\x32\x19.zetasql.SchemaObjectKind\x12\x32\n\tname_path\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x45\n\x16with_connection_clause\x18\x04 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\x12\x32\n\x0coptions_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xad\x01\n\x15\x41STCallStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x37\n\x0eprocedure_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12/\n\targuments\x18\x03 \x03(\x0b\x32\x1c.zetasql.ASTTVFArgumentProto\"\xad\x01\n\x1c\x41STDefineTableStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xb5\x01\n$ASTCreateLocalityGroupStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x8a\x01\n\"ASTWithPartitionColumnsClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12=\n\x12table_element_list\x18\x02 \x01(\x0b\x32!.zetasql.ASTTableElementListProto\"\xaa\x02\n\x1f\x41STCreateSnapshotStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12\x35\n\x12schema_object_kind\x18\x02 \x01(\x0e\x32\x19.zetasql.SchemaObjectKind\x12-\n\x04name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12;\n\x11\x63lone_data_source\x18\x04 \x01(\x0b\x32 .zetasql.ASTCloneDataSourceProto\x12\x32\n\x0coptions_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xf8\x01\n$ASTCreateSnapshotTableStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12;\n\x11\x63lone_data_source\x18\x03 \x01(\x0b\x32 .zetasql.ASTCloneDataSourceProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"p\n\x19\x41STTypeParameterListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\nparameters\x18\x02 \x03(\x0b\x32\x18.zetasql.AnyASTLeafProto\"m\n\x11\x41STTVFSchemaProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x31\n\x07\x63olumns\x18\x02 \x03(\x0b\x32 .zetasql.ASTTVFSchemaColumnProto\"\x93\x01\n\x17\x41STTVFSchemaColumnProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12&\n\x04type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\"\xaa\x01\n\x1a\x41STTableAndColumnInfoProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\ntable_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x30\n\x0b\x63olumn_list\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\"\x93\x01\n\x1e\x41STTableAndColumnInfoListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12J\n\x1dtable_and_column_info_entries\x18\x02 \x03(\x0b\x32#.zetasql.ASTTableAndColumnInfoProto\"\x90\x01\n\x1e\x41STTemplatedParameterTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12G\n\x04kind\x18\x02 \x01(\x0e\x32\x39.zetasql.ASTTemplatedParameterTypeEnums.TemplatedTypeKind\"E\n\x16\x41STDefaultLiteralProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\"\xc7\x01\n\x18\x41STAnalyzeStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x32\n\x0coptions_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12K\n\x1atable_and_column_info_list\x18\x03 \x01(\x0b\x32\'.zetasql.ASTTableAndColumnInfoListProto\"\xa8\x01\n\x17\x41STAssertStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x33\n\x0b\x64\x65scription\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"u\n\x1a\x41STAssertRowsModifiedProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x08num_rows\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa0\x01\n\x17\x41STReturningClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x0bselect_list\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12,\n\x0c\x61\x63tion_alias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xf7\x02\n\x18\x41STOnConflictClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12I\n\x0f\x63onflict_action\x18\x02 \x01(\x0e\x32\x30.zetasql.ASTOnConflictClauseEnums.ConflictAction\x12\x34\n\x0f\x63onflict_target\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12;\n\x16unique_constraint_name\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x39\n\x10update_item_list\x18\x05 \x01(\x0b\x32\x1f.zetasql.ASTUpdateItemListProto\x12;\n\x13update_where_clause\x18\x06 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa9\x03\n\x17\x41STDeleteStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x42\n\x0btarget_path\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12+\n\x06offset\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProto\x12-\n\x05where\x18\x05 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x41\n\x14\x61ssert_rows_modified\x18\x06 \x01(\x0b\x32#.zetasql.ASTAssertRowsModifiedProto\x12\x33\n\treturning\x18\x07 \x01(\x0b\x32 .zetasql.ASTReturningClauseProto\x12#\n\x04hint\x18\x08 \x01(\x0b\x32\x15.zetasql.ASTHintProto\"\x8d\x03\n\x1a\x41nyASTColumnAttributeProto\x12V\n\"ast_not_null_column_attribute_node\x18\xc3\x01 \x01(\x0b\x32\'.zetasql.ASTNotNullColumnAttributeProtoH\x00\x12S\n ast_hidden_column_attribute_node\x18\xc4\x01 \x01(\x0b\x32&.zetasql.ASTHiddenColumnAttributeProtoH\x00\x12\\\n%ast_primary_key_column_attribute_node\x18\xc5\x01 \x01(\x0b\x32*.zetasql.ASTPrimaryKeyColumnAttributeProtoH\x00\x12\\\n%ast_foreign_key_column_attribute_node\x18\xc6\x01 \x01(\x0b\x32*.zetasql.ASTForeignKeyColumnAttributeProtoH\x00\x42\x06\n\x04node\"@\n\x17\x41STColumnAttributeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"R\n\x1e\x41STNotNullColumnAttributeProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTColumnAttributeProto\"Q\n\x1d\x41STHiddenColumnAttributeProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTColumnAttributeProto\"g\n!ASTPrimaryKeyColumnAttributeProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTColumnAttributeProto\x12\x10\n\x08\x65nforced\x18\x02 \x01(\x08\"\xc4\x01\n!ASTForeignKeyColumnAttributeProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTColumnAttributeProto\x12\x34\n\x0f\x63onstraint_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x37\n\treference\x18\x03 \x01(\x0b\x32$.zetasql.ASTForeignKeyReferenceProto\"y\n\x1b\x41STColumnAttributeListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\x06values\x18\x02 \x03(\x0b\x32#.zetasql.AnyASTColumnAttributeProto\"\x9f\x01\n\x19\x41STStructColumnFieldProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x30\n\x06schema\x18\x03 \x01(\x0b\x32 .zetasql.AnyASTColumnSchemaProto\"\xcd\x02\n\x1b\x41STGeneratedColumnInfoProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x44\n\x0bstored_mode\x18\x03 \x01(\x0e\x32/.zetasql.ASTGeneratedColumnInfoEnums.StoredMode\x12J\n\x0egenerated_mode\x18\x04 \x01(\x0e\x32\x32.zetasql.ASTGeneratedColumnInfoEnums.GeneratedMode\x12\x41\n\x14identity_column_info\x18\x05 \x01(\x0b\x32#.zetasql.ASTIdentityColumnInfoProto\"\xb6\x01\n\x17\x41nyASTTableElementProto\x12H\n\x1a\x61st_column_definition_node\x18\xcb\x01 \x01(\x0b\x32!.zetasql.ASTColumnDefinitionProtoH\x00\x12I\n\x19\x61st_table_constraint_node\x18\x8e\x02 \x01(\x0b\x32#.zetasql.AnyASTTableConstraintProtoH\x00\x42\x06\n\x04node\"=\n\x14\x41STTableElementProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xa6\x01\n\x18\x41STColumnDefinitionProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTTableElementProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x30\n\x06schema\x18\x03 \x01(\x0b\x32 .zetasql.AnyASTColumnSchemaProto\"u\n\x18\x41STTableElementListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\x08\x65lements\x18\x02 \x03(\x0b\x32 .zetasql.AnyASTTableElementProto\"m\n\x12\x41STColumnListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x0bidentifiers\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xb4\x01\n\x16\x41STColumnPositionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x42\n\x04type\x18\x03 \x01(\x0e\x32\x34.zetasql.ASTColumnPositionEnums.RelativePositionType\"p\n\x17\x41STInsertValuesRowProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x06values\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"t\n\x1b\x41STInsertValuesRowListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x04rows\x18\x02 \x03(\x0b\x32 .zetasql.ASTInsertValuesRowProto\"\xd0\x04\n\x17\x41STInsertStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x42\n\x0btarget_path\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12\x30\n\x0b\x63olumn_list\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12\x32\n\x04rows\x18\x04 \x01(\x0b\x32$.zetasql.ASTInsertValuesRowListProto\x12%\n\x05query\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12\x41\n\x14\x61ssert_rows_modified\x18\x06 \x01(\x0b\x32#.zetasql.ASTAssertRowsModifiedProto\x12\x33\n\treturning\x18\x07 \x01(\x0b\x32 .zetasql.ASTReturningClauseProto\x12!\n\x19\x64\x65precated_parse_progress\x18\x08 \x01(\x03\x12@\n\x0binsert_mode\x18\t \x01(\x0e\x32+.zetasql.ASTInsertStatementEnums.InsertMode\x12#\n\x04hint\x18\n \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x36\n\x0bon_conflict\x18\x0b \x01(\x0b\x32!.zetasql.ASTOnConflictClauseProto\"\xab\x01\n\x16\x41STUpdateSetValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12;\n\x04path\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12-\n\x05value\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa3\x02\n\x12\x41STUpdateItemProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\tset_value\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTUpdateSetValueProto\x12:\n\x10insert_statement\x18\x03 \x01(\x0b\x32 .zetasql.ASTInsertStatementProto\x12:\n\x10\x64\x65lete_statement\x18\x04 \x01(\x0b\x32 .zetasql.ASTDeleteStatementProto\x12:\n\x10update_statement\x18\x05 \x01(\x0b\x32 .zetasql.ASTUpdateStatementProto\"r\n\x16\x41STUpdateItemListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x31\n\x0cupdate_items\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTUpdateItemProto\"\x96\x04\n\x17\x41STUpdateStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x42\n\x0btarget_path\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12+\n\x06offset\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProto\x12\x39\n\x10update_item_list\x18\x05 \x01(\x0b\x32\x1f.zetasql.ASTUpdateItemListProto\x12\x30\n\x0b\x66rom_clause\x18\x06 \x01(\x0b\x32\x1b.zetasql.ASTFromClauseProto\x12-\n\x05where\x18\x07 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x41\n\x14\x61ssert_rows_modified\x18\x08 \x01(\x0b\x32#.zetasql.ASTAssertRowsModifiedProto\x12\x33\n\treturning\x18\t \x01(\x0b\x32 .zetasql.ASTReturningClauseProto\x12#\n\x04hint\x18\n \x01(\x0b\x32\x15.zetasql.ASTHintProto\"\xac\x01\n\x19\x41STTruncateStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x34\n\x0btarget_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12-\n\x05where\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa4\x02\n\x13\x41STMergeActionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x37\n\x12insert_column_list\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12\x34\n\ninsert_row\x18\x03 \x01(\x0b\x32 .zetasql.ASTInsertValuesRowProto\x12\x39\n\x10update_item_list\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTUpdateItemListProto\x12<\n\x0b\x61\x63tion_type\x18\x05 \x01(\x0e\x32\'.zetasql.ASTMergeActionEnums.ActionType\"\xe8\x01\n\x17\x41STMergeWhenClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x38\n\x10search_condition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTMergeActionProto\x12>\n\nmatch_type\x18\x04 \x01(\x0e\x32*.zetasql.ASTMergeWhenClauseEnums.MatchType\"{\n\x1b\x41STMergeWhenClauseListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x0b\x63lause_list\x18\x02 \x03(\x0b\x32 .zetasql.ASTMergeWhenClauseProto\"\xd5\x02\n\x16\x41STMergeStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x34\n\x0btarget_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12=\n\x10table_expression\x18\x04 \x01(\x0b\x32#.zetasql.AnyASTTableExpressionProto\x12\x37\n\x0fmerge_condition\x18\x05 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12:\n\x0cwhen_clauses\x18\x06 \x01(\x0b\x32$.zetasql.ASTMergeWhenClauseListProto\"\xa5\x01\n\x11\x41STPrivilegeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x10privilege_action\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x05paths\x18\x03 \x01(\x0b\x32#.zetasql.ASTPathExpressionListProto\"k\n\x12\x41STPrivilegesProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\nprivileges\x18\x02 \x03(\x0b\x32\x1a.zetasql.ASTPrivilegeProto\"r\n\x13\x41STGranteeListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0cgrantee_list\x18\x02 \x03(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x97\x02\n\x16\x41STGrantStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12/\n\nprivileges\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProto\x12\x36\n\x11target_type_parts\x18\x03 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x34\n\x0btarget_path\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0cgrantee_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\"\x98\x02\n\x17\x41STRevokeStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12/\n\nprivileges\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProto\x12\x36\n\x11target_type_parts\x18\x03 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x34\n\x0btarget_path\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0cgrantee_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\"s\n\x18\x41STRepeatableClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x08\x61rgument\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xca\x01\n\x17\x41STFilterFieldsArgProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x46\n\x0fpath_expression\x18\x02 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\x12@\n\x0b\x66ilter_type\x18\x03 \x01(\x0e\x32+.zetasql.ASTFilterFieldsArgEnums.FilterType\"\xbd\x01\n\x18\x41STReplaceFieldsArgProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x46\n\x0fpath_expression\x18\x03 \x01(\x0b\x32-.zetasql.AnyASTGeneralizedPathExpressionProto\"\xb2\x01\n\x1f\x41STReplaceFieldsExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12,\n\x04\x65xpr\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x34\n\targuments\x18\x03 \x03(\x0b\x32!.zetasql.ASTReplaceFieldsArgProto\"\xcd\x01\n\x12\x41STSampleSizeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12,\n\x04size\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x32\n\x0cpartition_by\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12.\n\x04unit\x18\x04 \x01(\x0e\x32 .zetasql.ASTSampleSizeEnums.Unit\"b\n\x12\x41STWithWeightProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12%\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\x9d\x01\n\x14\x41STSampleSuffixProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x06weight\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTWithWeightProto\x12\x31\n\x06repeat\x18\x03 \x01(\x0b\x32!.zetasql.ASTRepeatableClauseProto\"\xe9\x01\n\x14\x41STSampleClauseProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTPostfixTableOperatorProto\x12\x32\n\rsample_method\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x30\n\x0bsample_size\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTSampleSizeProto\x12\x34\n\rsample_suffix\x18\x04 \x01(\x0b\x32\x1d.zetasql.ASTSampleSuffixProto\"\xb4\x17\n\x16\x41nyASTAlterActionProto\x12I\n\x1b\x61st_set_options_action_node\x18\xea\x01 \x01(\x0b\x32!.zetasql.ASTSetOptionsActionProtoH\x00\x12?\n\x16\x61st_set_as_action_node\x18\xeb\x01 \x01(\x0b\x32\x1c.zetasql.ASTSetAsActionProtoH\x00\x12O\n\x1e\x61st_add_constraint_action_node\x18\xec\x01 \x01(\x0b\x32$.zetasql.ASTAddConstraintActionProtoH\x00\x12R\n ast_drop_primary_key_action_node\x18\xed\x01 \x01(\x0b\x32%.zetasql.ASTDropPrimaryKeyActionProtoH\x00\x12Q\n\x1f\x61st_drop_constraint_action_node\x18\xee\x01 \x01(\x0b\x32%.zetasql.ASTDropConstraintActionProtoH\x00\x12j\n,ast_alter_constraint_enforcement_action_node\x18\xef\x01 \x01(\x0b\x32\x31.zetasql.ASTAlterConstraintEnforcementActionProtoH\x00\x12i\n,ast_alter_constraint_set_options_action_node\x18\xf0\x01 \x01(\x0b\x32\x30.zetasql.ASTAlterConstraintSetOptionsActionProtoH\x00\x12G\n\x1a\x61st_add_column_action_node\x18\xf1\x01 \x01(\x0b\x32 .zetasql.ASTAddColumnActionProtoH\x00\x12I\n\x1b\x61st_drop_column_action_node\x18\xf2\x01 \x01(\x0b\x32!.zetasql.ASTDropColumnActionProtoH\x00\x12M\n\x1d\x61st_rename_column_action_node\x18\xf3\x01 \x01(\x0b\x32#.zetasql.ASTRenameColumnActionProtoH\x00\x12T\n!ast_alter_column_type_action_node\x18\xf4\x01 \x01(\x0b\x32&.zetasql.ASTAlterColumnTypeActionProtoH\x00\x12Z\n$ast_alter_column_options_action_node\x18\xf5\x01 \x01(\x0b\x32).zetasql.ASTAlterColumnOptionsActionProtoH\x00\x12\x64\n*ast_alter_column_drop_not_null_action_node\x18\xf6\x01 \x01(\x0b\x32-.zetasql.ASTAlterColumnDropNotNullActionProtoH\x00\x12\x43\n\x18\x61st_grant_to_clause_node\x18\xf7\x01 \x01(\x0b\x32\x1e.zetasql.ASTGrantToClauseProtoH\x00\x12K\n\x1c\x61st_filter_using_clause_node\x18\xf8\x01 \x01(\x0b\x32\".zetasql.ASTFilterUsingClauseProtoH\x00\x12I\n\x1b\x61st_revoke_from_clause_node\x18\xf9\x01 \x01(\x0b\x32!.zetasql.ASTRevokeFromClauseProtoH\x00\x12\x45\n\x19\x61st_rename_to_clause_node\x18\xfa\x01 \x01(\x0b\x32\x1f.zetasql.ASTRenameToClauseProtoH\x00\x12I\n\x1b\x61st_set_collate_clause_node\x18\xfb\x01 \x01(\x0b\x32!.zetasql.ASTSetCollateClauseProtoH\x00\x12\x61\n(ast_alter_column_set_default_action_node\x18\xc2\x02 \x01(\x0b\x32,.zetasql.ASTAlterColumnSetDefaultActionProtoH\x00\x12\x63\n)ast_alter_column_drop_default_action_node\x18\xc3\x02 \x01(\x0b\x32-.zetasql.ASTAlterColumnDropDefaultActionProtoH\x00\x12I\n\x1b\x61st_restrict_to_clause_node\x18\xc7\x02 \x01(\x0b\x32!.zetasql.ASTRestrictToClauseProtoH\x00\x12]\n&ast_add_to_restrictee_list_clause_node\x18\xc8\x02 \x01(\x0b\x32*.zetasql.ASTAddToRestricteeListClauseProtoH\x00\x12g\n+ast_remove_from_restrictee_list_clause_node\x18\xc9\x02 \x01(\x0b\x32/.zetasql.ASTRemoveFromRestricteeListClauseProtoH\x00\x12R\n ast_alter_sub_entity_action_node\x18\xd2\x02 \x01(\x0b\x32%.zetasql.ASTAlterSubEntityActionProtoH\x00\x12N\n\x1e\x61st_add_sub_entity_action_node\x18\xd3\x02 \x01(\x0b\x32#.zetasql.ASTAddSubEntityActionProtoH\x00\x12P\n\x1f\x61st_drop_sub_entity_action_node\x18\xd4\x02 \x01(\x0b\x32$.zetasql.ASTDropSubEntityActionProtoH\x00\x12\x41\n\x17\x61st_add_ttl_action_node\x18\xdd\x02 \x01(\x0b\x32\x1d.zetasql.ASTAddTtlActionProtoH\x00\x12I\n\x1b\x61st_replace_ttl_action_node\x18\xde\x02 \x01(\x0b\x32!.zetasql.ASTReplaceTtlActionProtoH\x00\x12\x43\n\x18\x61st_drop_ttl_action_node\x18\xdf\x02 \x01(\x0b\x32\x1e.zetasql.ASTDropTtlActionProtoH\x00\x12Z\n$ast_spanner_alter_column_action_node\x18\xe0\x02 \x01(\x0b\x32).zetasql.ASTSpannerAlterColumnActionProtoH\x00\x12[\n%ast_spanner_set_on_delete_action_node\x18\xe1\x02 \x01(\x0b\x32).zetasql.ASTSpannerSetOnDeleteActionProtoH\x00\x12g\n+ast_alter_column_drop_generated_action_node\x18\xa7\x03 \x01(\x0b\x32/.zetasql.ASTAlterColumnDropGeneratedActionProtoH\x00\x12\\\n%ast_add_column_identifier_action_node\x18\x84\x04 \x01(\x0b\x32*.zetasql.ASTAddColumnIdentifierActionProtoH\x00\x12\x42\n\x17\x61st_rebuild_action_node\x18\x85\x04 \x01(\x0b\x32\x1e.zetasql.ASTRebuildActionProtoH\x00\x12\x65\n*ast_alter_column_set_generated_action_node\x18\x90\x04 \x01(\x0b\x32..zetasql.ASTAlterColumnSetGeneratedActionProtoH\x00\x42\x06\n\x04node\"<\n\x13\x41STAlterActionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"|\n\x18\x41STSetOptionsActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x32\n\x0coptions_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xa7\x01\n\x13\x41STSetAsActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12/\n\tjson_body\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTJSONLiteralProto\x12\x31\n\ttext_body\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"\x9e\x01\n\x1b\x41STAddConstraintActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x37\n\nconstraint\x18\x02 \x01(\x0b\x32#.zetasql.AnyASTTableConstraintProto\x12\x18\n\x10is_if_not_exists\x18\x03 \x01(\x08\"b\n\x1c\x41STDropPrimaryKeyActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\"\x98\x01\n\x1c\x41STDropConstraintActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x34\n\x0f\x63onstraint_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\xb9\x01\n(ASTAlterConstraintEnforcementActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x34\n\x0f\x63onstraint_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\x12\x13\n\x0bis_enforced\x18\x04 \x01(\x08\"\xd7\x01\n\'ASTAlterConstraintSetOptionsActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x34\n\x0f\x63onstraint_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xd1\x01\n!ASTAddColumnIdentifierActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x18\n\x10is_if_not_exists\x18\x04 \x01(\x08\"\x92\x02\n\x17\x41STAddColumnActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12<\n\x11\x63olumn_definition\x18\x02 \x01(\x0b\x32!.zetasql.ASTColumnDefinitionProto\x12\x38\n\x0f\x63olumn_position\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTColumnPositionProto\x12\x37\n\x0f\x66ill_expression\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x18\n\x10is_if_not_exists\x18\x05 \x01(\x08\"\x90\x01\n\x18\x41STDropColumnActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\xc8\x01\n\x1a\x41STRenameColumnActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x34\n\x0fnew_column_name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xf2\x01\n\x1d\x41STAlterColumnTypeActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x30\n\x06schema\x18\x03 \x01(\x0b\x32 .zetasql.AnyASTColumnSchemaProto\x12)\n\x07\x63ollate\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\x12\x14\n\x0cis_if_exists\x18\x05 \x01(\x08\"\xcc\x01\n ASTAlterColumnOptionsActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xd7\x01\n#ASTAlterColumnSetDefaultActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12:\n\x12\x64\x65\x66\x61ult_expression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\x9c\x01\n$ASTAlterColumnDropDefaultActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\x9c\x01\n$ASTAlterColumnDropNotNullActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\x9e\x01\n&ASTAlterColumnDropGeneratedActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"\xe2\x01\n%ASTAlterColumnSetGeneratedActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x30\n\x0b\x63olumn_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x43\n\x15generated_column_info\x18\x03 \x01(\x0b\x32$.zetasql.ASTGeneratedColumnInfoProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\x9f\x01\n\x15\x41STGrantToClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x32\n\x0cgrantee_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\x12$\n\x1chas_grant_keyword_and_parens\x18\x03 \x01(\x08\"\x7f\n\x18\x41STRestrictToClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x35\n\x0frestrictee_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\"\xa2\x01\n!ASTAddToRestricteeListClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x18\n\x10is_if_not_exists\x18\x02 \x01(\x08\x12\x35\n\x0frestrictee_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\"\xa3\x01\n&ASTRemoveFromRestricteeListClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12\x35\n\x0frestrictee_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\"\x98\x01\n\x19\x41STFilterUsingClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x31\n\tpredicate\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x1a\n\x12has_filter_keyword\x18\x03 \x01(\x08\"\x9c\x01\n\x18\x41STRevokeFromClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x36\n\x10revoke_from_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTGranteeListProto\x12\x1a\n\x12is_revoke_from_all\x18\x03 \x01(\x08\"y\n\x16\x41STRenameToClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x31\n\x08new_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"s\n\x18\x41STSetCollateClauseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12)\n\x07\x63ollate\x18\x02 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\xe9\x01\n\x1c\x41STAlterSubEntityActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12)\n\x04name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12/\n\x06\x61\x63tion\x18\x04 \x01(\x0b\x32\x1f.zetasql.AnyASTAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x05 \x01(\x08\"\xee\x01\n\x1a\x41STAddSubEntityActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12)\n\x04name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x18\n\x10is_if_not_exists\x18\x05 \x01(\x08\"\xb7\x01\n\x1b\x41STDropSubEntityActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12)\n\x04name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x14\n\x0cis_if_exists\x18\x05 \x01(\x08\"\x92\x01\n\x14\x41STAddTtlActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x18\n\x10is_if_not_exists\x18\x03 \x01(\x08\"\x92\x01\n\x18\x41STReplaceTtlActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x14\n\x0cis_if_exists\x18\x03 \x01(\x08\"[\n\x15\x41STDropTtlActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\"r\n\x17\x41STAlterActionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32\x1f.zetasql.AnyASTAlterActionProto\"\xc9\x01\n*ASTAlterAllRowAccessPoliciesStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x38\n\x0ftable_name_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x35\n\x0c\x61lter_action\x18\x03 \x01(\x0b\x32\x1f.zetasql.AnyASTAlterActionProto\"\xc6\x01\n\x19\x41STForeignKeyActionsProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12@\n\rupdate_action\x18\x02 \x01(\x0e\x32).zetasql.ASTForeignKeyActionsEnums.Action\x12@\n\rdelete_action\x18\x03 \x01(\x0e\x32).zetasql.ASTForeignKeyActionsEnums.Action\"\xad\x02\n\x1b\x41STForeignKeyReferenceProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\ntable_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x30\n\x0b\x63olumn_list\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12\x33\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32\".zetasql.ASTForeignKeyActionsProto\x12\x39\n\x05match\x18\x05 \x01(\x0e\x32*.zetasql.ASTForeignKeyReferenceEnums.Match\x12\x10\n\x08\x65nforced\x18\x06 \x01(\x08\"t\n\x0e\x41STScriptProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12;\n\x13statement_list_node\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"\x9e\x01\n\x14\x41STElseifClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"x\n\x18\x41STElseifClauseListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x35\n\x0e\x65lseif_clauses\x18\x02 \x03(\x0b\x32\x1d.zetasql.ASTElseifClauseProto\"\x9b\x02\n\x13\x41STIfStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x31\n\tthen_list\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\x12\x39\n\x0e\x65lseif_clauses\x18\x04 \x01(\x0b\x32!.zetasql.ASTElseifClauseListProto\x12\x31\n\telse_list\x18\x05 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"\xa0\x01\n\x16\x41STWhenThenClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12,\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"\x7f\n\x1a\x41STWhenThenClauseListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\x11when_then_clauses\x18\x02 \x03(\x0b\x32\x1f.zetasql.ASTWhenThenClauseProto\"\xf0\x01\n\x15\x41STCaseStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12>\n\x11when_then_clauses\x18\x03 \x01(\x0b\x32#.zetasql.ASTWhenThenClauseListProto\x12\x31\n\telse_list\x18\x04 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"\x9d\x01\n\x0c\x41STHintProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0fnum_shards_hint\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIntLiteralProto\x12\x30\n\x0chint_entries\x18\x03 \x03(\x0b\x32\x1a.zetasql.ASTHintEntryProto\"\xc4\x01\n\x11\x41STHintEntryProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\tqualifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12)\n\x04name\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x05value\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa9\x01\n\x1a\x41STUnpivotInItemLabelProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0cstring_label\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12.\n\tint_label\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIntLiteralProto\"s\n\x12\x41STDescriptorProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x07\x63olumns\x18\x02 \x01(\x0b\x32%.zetasql.ASTDescriptorColumnListProto\"\xf8\x02\n\x17\x41nyASTColumnSchemaProto\x12M\n\x1d\x61st_simple_column_schema_node\x18\x8c\x02 \x01(\x0b\x32#.zetasql.ASTSimpleColumnSchemaProtoH\x00\x12M\n\x1d\x61st_struct_column_schema_node\x18\xbc\x02 \x01(\x0b\x32#.zetasql.ASTStructColumnSchemaProtoH\x00\x12Z\n$ast_inferred_type_column_schema_node\x18\xbd\x02 \x01(\x0b\x32).zetasql.ASTInferredTypeColumnSchemaProtoH\x00\x12[\n#ast_element_type_column_schema_node\x18\xfe\x02 \x01(\x0b\x32+.zetasql.AnyASTElementTypeColumnSchemaProtoH\x00\x42\x06\n\x04node\"\x94\x03\n\x14\x41STColumnSchemaProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12;\n\x0ftype_parameters\x18\x02 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12\x43\n\x15generated_column_info\x18\x03 \x01(\x0b\x32$.zetasql.ASTGeneratedColumnInfoProto\x12:\n\x12\x64\x65\x66\x61ult_expression\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12)\n\x07\x63ollate\x18\x05 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\x12\x38\n\nattributes\x18\x06 \x01(\x0b\x32$.zetasql.ASTColumnAttributeListProto\x12\x32\n\x0coptions_list\x18\x07 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x7f\n\x1a\x41STSimpleColumnSchemaProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTColumnSchemaProto\x12\x32\n\ttype_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xc6\x01\n\"AnyASTElementTypeColumnSchemaProto\x12K\n\x1c\x61st_array_column_schema_node\x18\x8d\x02 \x01(\x0b\x32\".zetasql.ASTArrayColumnSchemaProtoH\x00\x12K\n\x1c\x61st_range_column_schema_node\x18\xff\x02 \x01(\x0b\x32\".zetasql.ASTRangeColumnSchemaProtoH\x00\x42\x06\n\x04node\"\x8a\x01\n\x1f\x41STElementTypeColumnSchemaProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTColumnSchemaProto\x12\x38\n\x0e\x65lement_schema\x18\x02 \x01(\x0b\x32 .zetasql.AnyASTColumnSchemaProto\"U\n\x19\x41STArrayColumnSchemaProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ASTElementTypeColumnSchemaProto\"U\n\x19\x41STRangeColumnSchemaProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ASTElementTypeColumnSchemaProto\"\xe8\x01\n\x19\x41STPrimaryKeyElementProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12+\n\x06\x63olumn\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12G\n\rordering_spec\x18\x03 \x01(\x0e\x32\x30.zetasql.ASTOrderingExpressionEnums.OrderingSpec\x12.\n\nnull_order\x18\x04 \x01(\x0b\x32\x1a.zetasql.ASTNullOrderProto\"|\n\x1d\x41STPrimaryKeyElementListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x08\x65lements\x18\x02 \x03(\x0b\x32\".zetasql.ASTPrimaryKeyElementProto\"\xe8\x01\n\x1a\x41nyASTTableConstraintProto\x12<\n\x14\x61st_primary_key_node\x18\x8f\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrimaryKeyProtoH\x00\x12<\n\x14\x61st_foreign_key_node\x18\x90\x02 \x01(\x0b\x32\x1b.zetasql.ASTForeignKeyProtoH\x00\x12\x46\n\x19\x61st_check_constraint_node\x18\x91\x02 \x01(\x0b\x32 .zetasql.ASTCheckConstraintProtoH\x00\x42\x06\n\x04node\"H\n\x17\x41STTableConstraintProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTTableElementProto\"\x80\x02\n\x12\x41STPrimaryKeyProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableConstraintProto\x12<\n\x0c\x65lement_list\x18\x02 \x01(\x0b\x32&.zetasql.ASTPrimaryKeyElementListProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x34\n\x0f\x63onstraint_name\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x10\n\x08\x65nforced\x18\x05 \x01(\x08\"\x9b\x02\n\x12\x41STForeignKeyProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableConstraintProto\x12\x30\n\x0b\x63olumn_list\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12\x37\n\treference\x18\x03 \x01(\x0b\x32$.zetasql.ASTForeignKeyReferenceProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x34\n\x0f\x63onstraint_name\x18\x05 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xfe\x01\n\x17\x41STCheckConstraintProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableConstraintProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x34\n\x0f\x63onstraint_name\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x13\n\x0bis_enforced\x18\x05 \x01(\x08\"l\n\x18\x41STDescriptorColumnProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\x88\x01\n\x1c\x41STDescriptorColumnListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x41\n\x16\x64\x65scriptor_column_list\x18\x02 \x03(\x0b\x32!.zetasql.ASTDescriptorColumnProto\"\xc3\x02\n\x1d\x41STCreateEntityStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x04name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12/\n\tjson_body\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTJSONLiteralProto\x12\x31\n\ttext_body\x18\x06 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"{\n\x16\x41STRaiseStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12/\n\x07message\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"y\n\x18\x41STExceptionHandlerProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x36\n\x0estatement_list\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"\x88\x01\n\x1c\x41STExceptionHandlerListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x41\n\x16\x65xception_handler_list\x18\x02 \x03(\x0b\x32!.zetasql.ASTExceptionHandlerProto\"\xea\x01\n\x15\x41STBeginEndBlockProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12%\n\x05label\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTLabelProto\x12;\n\x13statement_list_node\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\x12;\n\x0chandler_list\x18\x04 \x01(\x0b\x32%.zetasql.ASTExceptionHandlerListProto\"u\n\x16\x41STIdentifierListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0fidentifier_list\x18\x02 \x03(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xe6\x01\n\x1b\x41STVariableDeclarationProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12\x36\n\rvariable_list\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProto\x12&\n\x04type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12\x35\n\rdefault_value\x18\x04 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"o\n\x13\x41STUntilClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xbd\x01\n!AnyASTBreakContinueStatementProto\x12\x44\n\x18\x61st_break_statement_node\x18\x9d\x02 \x01(\x0b\x32\x1f.zetasql.ASTBreakStatementProtoH\x00\x12J\n\x1b\x61st_continue_statement_node\x18\x9e\x02 \x01(\x0b\x32\".zetasql.ASTContinueStatementProtoH\x00\x42\x06\n\x04node\"y\n\x1e\x41STBreakContinueStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12%\n\x05label\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTLabelProto\"\xa0\x01\n\x16\x41STBreakStatementProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ASTBreakContinueStatementProto\x12M\n\x07keyword\x18\x02 \x01(\x0e\x32<.zetasql.ASTBreakContinueStatementEnums.BreakContinueKeyword\"\xa3\x01\n\x19\x41STContinueStatementProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ASTBreakContinueStatementProto\x12M\n\x07keyword\x18\x02 \x01(\x0e\x32<.zetasql.ASTBreakContinueStatementEnums.BreakContinueKeyword\"\x87\x02\n)ASTDropPrivilegeRestrictionStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12\x14\n\x0cis_if_exists\x18\x02 \x01(\x08\x12/\n\nprivileges\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProto\x12\x30\n\x0bobject_type\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\tname_path\x18\x05 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"\xcf\x01\n$ASTDropRowAccessPolicyStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x33\n\ntable_name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"\xae\x02\n+ASTCreatePrivilegeRestrictionStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12/\n\nprivileges\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProto\x12\x30\n\x0bobject_type\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\tname_path\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x36\n\x0brestrict_to\x18\x05 \x01(\x0b\x32!.zetasql.ASTRestrictToClauseProto\"\xc7\x02\n&ASTCreateRowAccessPolicyStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12\x34\n\x0btarget_path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x30\n\x08grant_to\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTGrantToClauseProto\x12\x38\n\x0c\x66ilter_using\x18\x04 \x01(\x0b\x32\".zetasql.ASTFilterUsingClauseProto\x12-\n\x04name\x18\x05 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x1a\n\x12has_access_keyword\x18\x06 \x01(\x08\"\xfe\x01\n\x15\x41STDropStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12:\n\tdrop_mode\x18\x03 \x01(\x0e\x32\'.zetasql.ASTDropStatementEnums.DropMode\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\x12\x35\n\x12schema_object_kind\x18\x05 \x01(\x0e\x32\x19.zetasql.SchemaObjectKind\"K\n\x17\x41STReturnStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\"\xaf\x01\n\x18\x41STSingleAssignmentProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12-\n\x08variable\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb0\x01\n\x1b\x41STParameterAssignmentProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12\x31\n\tparameter\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTParameterExprProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xc0\x01\n ASTSystemVariableAssignmentProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12<\n\x0fsystem_variable\x18\x02 \x01(\x0b\x32#.zetasql.ASTSystemVariableExprProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xbf\x01\n\x1c\x41STAssignmentFromStructProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12\x32\n\tvariables\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProto\x12\x39\n\x11struct_expression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xb3\x02\n\x1e\x41nyASTCreateTableStmtBaseProto\x12Q\n\x1f\x61st_create_table_statement_node\x18\xa8\x02 \x01(\x0b\x32%.zetasql.ASTCreateTableStatementProtoH\x00\x12\x62\n(ast_create_external_table_statement_node\x18\xa9\x02 \x01(\x0b\x32-.zetasql.ASTCreateExternalTableStatementProtoH\x00\x12R\n ast_aux_load_data_statement_node\x18\xd6\x02 \x01(\x0b\x32%.zetasql.ASTAuxLoadDataStatementProtoH\x00\x42\x06\n\x04node\"\x9d\x03\n\x1b\x41STCreateTableStmtBaseProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12=\n\x12table_element_list\x18\x03 \x01(\x0b\x32!.zetasql.ASTTableElementListProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12\x38\n\x0flike_table_name\x18\x05 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12)\n\x07\x63ollate\x18\x06 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\x12\x45\n\x16with_connection_clause\x18\x07 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\"\xbf\x03\n\x1c\x41STCreateTableStatementProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ASTCreateTableStmtBaseProto\x12;\n\x11\x63lone_data_source\x18\x02 \x01(\x0b\x32 .zetasql.ASTCloneDataSourceProto\x12\x39\n\x10\x63opy_data_source\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTCopyDataSourceProto\x12\x32\n\x0cpartition_by\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12.\n\ncluster_by\x18\x05 \x01(\x0b\x32\x1a.zetasql.ASTClusterByProto\x12%\n\x05query\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12=\n\x0fspanner_options\x18\x07 \x01(\x0b\x32$.zetasql.ASTSpannerTableOptionsProto\x12\'\n\x03ttl\x18\x08 \x01(\x0b\x32\x1a.zetasql.ASTTtlClauseProto\"\xb0\x01\n$ASTCreateExternalTableStatementProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ASTCreateTableStmtBaseProto\x12R\n\x1dwith_partition_columns_clause\x18\x02 \x01(\x0b\x32+.zetasql.ASTWithPartitionColumnsClauseProto\"\xc5\x02\n\"AnyASTCreateViewStatementBaseProto\x12O\n\x1e\x61st_create_view_statement_node\x18\xab\x02 \x01(\x0b\x32$.zetasql.ASTCreateViewStatementProtoH\x00\x12h\n+ast_create_materialized_view_statement_node\x18\xac\x02 \x01(\x0b\x32\x30.zetasql.ASTCreateMaterializedViewStatementProtoH\x00\x12\\\n%ast_create_approx_view_statement_node\x18\x8d\x03 \x01(\x0b\x32*.zetasql.ASTCreateApproxViewStatementProtoH\x00\x42\x06\n\x04node\"\xfe\x02\n\x1f\x41STCreateViewStatementBaseProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12H\n\x18\x63olumn_with_options_list\x18\x03 \x01(\x0b\x32&.zetasql.ASTColumnWithOptionsListProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12%\n\x05query\x18\x05 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\x12\x42\n\x0csql_security\x18\x06 \x01(\x0e\x32,.zetasql.ASTCreateStatementEnums.SqlSecurity\x12\x11\n\trecursive\x18\x07 \x01(\x08\"W\n\x1b\x41STCreateViewStatementProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ASTCreateViewStatementBaseProto\"\x80\x02\n\'ASTCreateMaterializedViewStatementProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ASTCreateViewStatementBaseProto\x12\x32\n\x0cpartition_by\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12.\n\ncluster_by\x18\x03 \x01(\x0b\x32\x1a.zetasql.ASTClusterByProto\x12\x37\n\x0ereplica_source\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\"]\n!ASTCreateApproxViewStatementProto\x12\x38\n\x06parent\x18\x01 \x01(\x0b\x32(.zetasql.ASTCreateViewStatementBaseProto\"\xf7\x01\n\x18\x41nyASTLoopStatementProto\x12\x44\n\x18\x61st_while_statement_node\x18\xae\x02 \x01(\x0b\x32\x1f.zetasql.ASTWhileStatementProtoH\x00\x12\x46\n\x19\x61st_repeat_statement_node\x18\xaf\x02 \x01(\x0b\x32 .zetasql.ASTRepeatStatementProtoH\x00\x12\x45\n\x19\x61st_for_in_statement_node\x18\xb0\x02 \x01(\x0b\x32\x1f.zetasql.ASTForInStatementProtoH\x00\x42\x06\n\x04node\"\x9e\x01\n\x15\x41STLoopStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTScriptStatementProto\x12%\n\x05label\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTLabelProto\x12,\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStatementListProto\"{\n\x16\x41STWhileStatementProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTLoopStatementProto\x12\x31\n\tcondition\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"}\n\x17\x41STRepeatStatementProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTLoopStatementProto\x12\x32\n\x0cuntil_clause\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTUntilClauseProto\"\x9e\x01\n\x16\x41STForInStatementProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTLoopStatementProto\x12-\n\x08variable\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12%\n\x05query\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\"\x97\n\n\x1d\x41nyASTAlterStatementBaseProto\x12U\n!ast_alter_database_statement_node\x18\xb2\x02 \x01(\x0b\x32\'.zetasql.ASTAlterDatabaseStatementProtoH\x00\x12Q\n\x1f\x61st_alter_schema_statement_node\x18\xb3\x02 \x01(\x0b\x32%.zetasql.ASTAlterSchemaStatementProtoH\x00\x12O\n\x1e\x61st_alter_table_statement_node\x18\xb4\x02 \x01(\x0b\x32$.zetasql.ASTAlterTableStatementProtoH\x00\x12M\n\x1d\x61st_alter_view_statement_node\x18\xb5\x02 \x01(\x0b\x32#.zetasql.ASTAlterViewStatementProtoH\x00\x12\x66\n*ast_alter_materialized_view_statement_node\x18\xb6\x02 \x01(\x0b\x32/.zetasql.ASTAlterMaterializedViewStatementProtoH\x00\x12\x65\n*ast_alter_row_access_policy_statement_node\x18\xb7\x02 \x01(\x0b\x32..zetasql.ASTAlterRowAccessPolicyStatementProtoH\x00\x12Q\n\x1f\x61st_alter_entity_statement_node\x18\xb8\x02 \x01(\x0b\x32%.zetasql.ASTAlterEntityStatementProtoH\x00\x12n\n.ast_alter_privilege_restriction_statement_node\x18\xc5\x02 \x01(\x0b\x32\x33.zetasql.ASTAlterPrivilegeRestrictionStatementProtoH\x00\x12O\n\x1e\x61st_alter_model_statement_node\x18\xd0\x02 \x01(\x0b\x32$.zetasql.ASTAlterModelStatementProtoH\x00\x12Z\n$ast_alter_approx_view_statement_node\x18\x8c\x03 \x01(\x0b\x32).zetasql.ASTAlterApproxViewStatementProtoH\x00\x12\x62\n(ast_alter_external_schema_statement_node\x18\xb8\x03 \x01(\x0b\x32-.zetasql.ASTAlterExternalSchemaStatementProtoH\x00\x12Y\n#ast_alter_connection_statement_node\x18\xe0\x03 \x01(\x0b\x32).zetasql.ASTAlterConnectionStatementProtoH\x00\x12O\n\x1e\x61st_alter_index_statement_node\x18\x86\x04 \x01(\x0b\x32$.zetasql.ASTAlterIndexStatementProtoH\x00\x12U\n!ast_alter_sequence_statement_node\x18\x95\x04 \x01(\x0b\x32\'.zetasql.ASTAlterSequenceStatementProtoH\x00\x42\x06\n\x04node\"\xc7\x01\n\x1a\x41STAlterStatementBaseProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12-\n\x04path\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x35\n\x0b\x61\x63tion_list\x18\x03 \x01(\x0b\x32 .zetasql.ASTAlterActionListProto\x12\x14\n\x0cis_if_exists\x18\x04 \x01(\x08\"W\n ASTAlterConnectionStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"U\n\x1e\x41STAlterDatabaseStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"S\n\x1c\x41STAlterSchemaStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"[\n$ASTAlterExternalSchemaStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"R\n\x1b\x41STAlterTableStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"Q\n\x1a\x41STAlterViewStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"]\n&ASTAlterMaterializedViewStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"W\n ASTAlterApproxViewStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"R\n\x1b\x41STAlterModelStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\"\xc4\x01\n*ASTAlterPrivilegeRestrictionStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\x12/\n\nprivileges\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrivilegesProto\x12\x30\n\x0bobject_type\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\x87\x01\n%ASTAlterRowAccessPolicyStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"~\n\x1c\x41STAlterEntityStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\x12)\n\x04type\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"E\n\x15\x41STRebuildActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\"\xcb\x01\n\x1b\x41STAlterIndexStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProto\x12\x33\n\ntable_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x42\n\nindex_type\x18\x03 \x01(\x0e\x32..zetasql.ASTAlterIndexStatementEnums.IndexType\"\xe8\x01\n!AnyASTCreateFunctionStmtBaseProto\x12W\n\"ast_create_function_statement_node\x18\xba\x02 \x01(\x0b\x32(.zetasql.ASTCreateFunctionStatementProtoH\x00\x12\x62\n(ast_create_table_function_statement_node\x18\xbb\x02 \x01(\x0b\x32-.zetasql.ASTCreateTableFunctionStatementProtoH\x00\x42\x06\n\x04node\"\xc0\x03\n\x1e\x41STCreateFunctionStmtBaseProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12\x42\n\x14\x66unction_declaration\x18\x02 \x01(\x0b\x32$.zetasql.ASTFunctionDeclarationProto\x12-\n\x08language\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12,\n\x04\x63ode\x18\x04 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12\x32\n\x0coptions_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\x12S\n\x11\x64\x65terminism_level\x18\x06 \x01(\x0e\x32\x38.zetasql.ASTCreateFunctionStmtBaseEnums.DeterminismLevel\x12\x42\n\x0csql_security\x18\x07 \x01(\x0e\x32,.zetasql.ASTCreateStatementEnums.SqlSecurity\"\xb6\x02\n\x1f\x41STCreateFunctionStatementProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ASTCreateFunctionStmtBaseProto\x12-\n\x0breturn_type\x18\x02 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12;\n\x11sql_function_body\x18\x03 \x01(\x0b\x32 .zetasql.ASTSqlFunctionBodyProto\x12\x14\n\x0cis_aggregate\x18\x04 \x01(\x08\x12\x11\n\tis_remote\x18\x05 \x01(\x08\x12\x45\n\x16with_connection_clause\x18\x06 \x01(\x0b\x32%.zetasql.ASTWithConnectionClauseProto\"\xbd\x01\n$ASTCreateTableFunctionStatementProto\x12\x37\n\x06parent\x18\x01 \x01(\x0b\x32\'.zetasql.ASTCreateFunctionStmtBaseProto\x12\x35\n\x11return_tvf_schema\x18\x02 \x01(\x0b\x32\x1a.zetasql.ASTTVFSchemaProto\x12%\n\x05query\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\"\x86\x01\n\x1a\x41STStructColumnSchemaProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTColumnSchemaProto\x12\x39\n\rstruct_fields\x18\x02 \x03(\x0b\x32\".zetasql.ASTStructColumnFieldProto\"Q\n ASTInferredTypeColumnSchemaProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTColumnSchemaProto\"x\n\x19\x41STExecuteIntoClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x34\n\x0bidentifiers\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProto\"\xa0\x01\n\x1c\x41STExecuteUsingArgumentProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"}\n\x1a\x41STExecuteUsingClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x38\n\targuments\x18\x02 \x03(\x0b\x32%.zetasql.ASTExecuteUsingArgumentProto\"\xf0\x01\n!ASTExecuteImmediateStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12+\n\x03sql\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x37\n\x0binto_clause\x18\x03 \x01(\x0b\x32\".zetasql.ASTExecuteIntoClauseProto\x12\x39\n\x0cusing_clause\x18\x04 \x01(\x0b\x32#.zetasql.ASTExecuteUsingClauseProto\"\x84\x01\n\'ASTAuxLoadDataFromFilesOptionsListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\x0coptions_list\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x9c\x01\n#ASTAuxLoadDataPartitionsClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x38\n\x10partition_filter\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x14\n\x0cis_overwrite\x18\x03 \x01(\x08\"\x89\x04\n\x1c\x41STAuxLoadDataStatementProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ASTCreateTableStmtBaseProto\x12K\n\x0einsertion_mode\x18\x02 \x01(\x0e\x32\x33.zetasql.ASTAuxLoadDataStatementEnums.InsertionMode\x12\x32\n\x0cpartition_by\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTPartitionByProto\x12.\n\ncluster_by\x18\x04 \x01(\x0b\x32\x1a.zetasql.ASTClusterByProto\x12\x44\n\nfrom_files\x18\x05 \x01(\x0b\x32\x30.zetasql.ASTAuxLoadDataFromFilesOptionsListProto\x12R\n\x1dwith_partition_columns_clause\x18\x06 \x01(\x0b\x32+.zetasql.ASTWithPartitionColumnsClauseProto\x12Q\n\x1bload_data_partitions_clause\x18\x08 \x01(\x0b\x32,.zetasql.ASTAuxLoadDataPartitionsClauseProto\x12\x15\n\ris_temp_table\x18\t \x01(\x08\"a\n\rASTLabelProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xa9\x01\n\x16\x41STWithExpressionProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12.\n\tvariables\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"n\n\x11\x41STTtlClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"9\n\x10\x41STLocationProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xa7\x01\n\x19\x41STInputOutputClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x05input\x18\x02 \x01(\x0b\x32!.zetasql.ASTTableElementListProto\x12\x31\n\x06output\x18\x03 \x01(\x0b\x32!.zetasql.ASTTableElementListProto\"\xbb\x01\n\x1b\x41STSpannerTableOptionsProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x0bprimary_key\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTPrimaryKeyProto\x12\x43\n\x11interleave_clause\x18\x03 \x01(\x0b\x32(.zetasql.ASTSpannerInterleaveClauseProto\"\xf5\x01\n\x1f\x41STSpannerInterleaveClauseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x33\n\ntable_name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12;\n\x04type\x18\x03 \x01(\x0e\x32-.zetasql.ASTSpannerInterleaveClauseEnums.Type\x12\x39\n\x06\x61\x63tion\x18\x04 \x01(\x0e\x32).zetasql.ASTForeignKeyActionsEnums.Action\"\x8e\x01\n ASTSpannerAlterColumnActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12<\n\x11\x63olumn_definition\x18\x02 \x01(\x0b\x32!.zetasql.ASTColumnDefinitionProto\"\x8b\x01\n ASTSpannerSetOnDeleteActionProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTAlterActionProto\x12\x39\n\x06\x61\x63tion\x18\x02 \x01(\x0e\x32).zetasql.ASTForeignKeyActionsEnums.Action\"\xa2\x01\n\x14\x41STRangeLiteralProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12(\n\x04type\x18\x02 \x01(\x0b\x32\x1a.zetasql.ASTRangeTypeProto\x12\x33\n\x0brange_value\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\"\xd2\x01\n\x11\x41STRangeTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12.\n\x0c\x65lement_type\x18\x02 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12;\n\x0ftype_parameters\x18\x03 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x04 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"\xbd\x02\n$ASTCreatePropertyGraphStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12?\n\x0fnode_table_list\x18\x03 \x01(\x0b\x32&.zetasql.ASTGraphElementTableListProto\x12?\n\x0f\x65\x64ge_table_list\x18\x04 \x01(\x0b\x32&.zetasql.ASTGraphElementTableListProto\x12\x32\n\x0coptions_list\x18\x05 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x82\x01\n\x1d\x41STGraphElementTableListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\x0e\x65lement_tables\x18\x02 \x03(\x0b\x32\".zetasql.ASTGraphElementTableProto\"\xab\x04\n\x19\x41STGraphElementTableProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12-\n\x08key_list\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12G\n\x15source_node_reference\x18\x05 \x01(\x0b\x32(.zetasql.ASTGraphNodeTableReferenceProto\x12\x45\n\x13\x64\x65st_node_reference\x18\x06 \x01(\x0b\x32(.zetasql.ASTGraphNodeTableReferenceProto\x12R\n\x15label_properties_list\x18\x07 \x01(\x0b\x32\x33.zetasql.ASTGraphElementLabelAndPropertiesListProto\x12\x39\n\rdynamic_label\x18\x08 \x01(\x0b\x32\".zetasql.ASTGraphDynamicLabelProto\x12\x43\n\x12\x64ynamic_properties\x18\t \x01(\x0b\x32\'.zetasql.ASTGraphDynamicPropertiesProto\"\xcf\x02\n\x1f\x41STGraphNodeTableReferenceProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\x15node_table_identifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x37\n\x12\x65\x64ge_table_columns\x18\x03 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12\x37\n\x12node_table_columns\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\x12W\n\x13node_reference_type\x18\x05 \x01(\x0e\x32:.zetasql.ASTGraphNodeTableReferenceEnums.NodeReferenceType\"\xa3\x01\n*ASTGraphElementLabelAndPropertiesListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12N\n\x15label_properties_list\x18\x02 \x03(\x0b\x32/.zetasql.ASTGraphElementLabelAndPropertiesProto\"\xf0\x01\n&ASTGraphElementLabelAndPropertiesProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nlabel_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x34\n\nproperties\x18\x03 \x01(\x0b\x32 .zetasql.ASTGraphPropertiesProto\x12\x38\n\x12label_options_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xd4\x01\n\x1c\x41STGraphDerivedPropertyProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nexpression\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12%\n\x05\x61lias\x18\x03 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x32\n\x0coptions_list\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x84\x01\n ASTGraphDerivedPropertyListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x39\n\nproperties\x18\x02 \x03(\x0b\x32%.zetasql.ASTGraphDerivedPropertyProto\"\xda\x01\n\x17\x41STGraphPropertiesProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x15\n\rno_properties\x18\x02 \x01(\x08\x12H\n\x15\x64\x65rived_property_list\x18\x03 \x01(\x0b\x32).zetasql.ASTGraphDerivedPropertyListProto\x12\x37\n\x12\x61ll_except_columns\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTColumnListProto\"q\n\x19\x41STGraphDynamicLabelProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05label\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"{\n\x1e\x41STGraphDynamicPropertiesProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nproperties\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xa3\x01\n\x14\x41STGraphPatternProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x30\n\x05paths\x18\x02 \x03(\x0b\x32!.zetasql.ASTGraphPathPatternProto\x12\x32\n\x0cwhere_clause\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\"{\n\x10\x41STGqlQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x35\n\x0bgraph_table\x18\x02 \x01(\x0b\x32 .zetasql.ASTGraphTableQueryProto\"\xc0\x01\n\x1c\x41STGqlGraphPatternQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x38\n\x0fgraph_reference\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x34\n\rgraph_pattern\x18\x03 \x01(\x0b\x32\x1d.zetasql.ASTGraphPatternProto\"\xbd\x01\n\x19\x41STGqlLinearOpsQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTQueryExpressionProto\x12\x38\n\x0fgraph_reference\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x34\n\nlinear_ops\x18\x03 \x01(\x0b\x32 .zetasql.ASTGqlOperatorListProto\"\x97\x02\n\x17\x41STGraphTableQueryProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTTableExpressionProto\x12\x38\n\x0fgraph_reference\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x31\n\x08graph_op\x18\x03 \x01(\x0b\x32\x1f.zetasql.AnyASTGqlOperatorProto\x12\x36\n\x11graph_table_shape\x18\x05 \x01(\x0b\x32\x1b.zetasql.ASTSelectListProto\x12%\n\x05\x61lias\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\x96\x02\n\x1f\x41nyASTGraphLabelExpressionProto\x12K\n\x1c\x61st_graph_element_label_node\x18\xe8\x02 \x01(\x0b\x32\".zetasql.ASTGraphElementLabelProtoH\x00\x12M\n\x1d\x61st_graph_wildcard_label_node\x18\xe9\x02 \x01(\x0b\x32#.zetasql.ASTGraphWildcardLabelProtoH\x00\x12O\n\x1e\x61st_graph_label_operation_node\x18\xea\x02 \x01(\x0b\x32$.zetasql.ASTGraphLabelOperationProtoH\x00\x42\x06\n\x04node\"\\\n\x1c\x41STGraphLabelExpressionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x15\n\rparenthesized\x18\x02 \x01(\x08\"}\n\x19\x41STGraphElementLabelProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTGraphLabelExpressionProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"S\n\x1a\x41STGraphWildcardLabelProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTGraphLabelExpressionProto\"\xd3\x01\n\x1b\x41STGraphLabelOperationProto\x12\x35\n\x06parent\x18\x01 \x01(\x0b\x32%.zetasql.ASTGraphLabelExpressionProto\x12\x43\n\x07op_type\x18\x02 \x01(\x0e\x32\x32.zetasql.ASTGraphLabelOperationEnums.OperationType\x12\x38\n\x06inputs\x18\x03 \x03(\x0b\x32(.zetasql.AnyASTGraphLabelExpressionProto\"\x85\x01\n\x18\x41STGraphLabelFilterProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x42\n\x10label_expression\x18\x03 \x01(\x0b\x32(.zetasql.AnyASTGraphLabelExpressionProto\"\xd3\x01\n\x1f\x41STGraphIsLabeledPredicateProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12\x0e\n\x06is_not\x18\x02 \x01(\x08\x12/\n\x07operand\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x42\n\x10label_expression\x18\x04 \x01(\x0b\x32(.zetasql.AnyASTGraphLabelExpressionProto\"\x90\x03\n!ASTGraphElementPatternFillerProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\rvariable_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x37\n\x0clabel_filter\x18\x03 \x01(\x0b\x32!.zetasql.ASTGraphLabelFilterProto\x12\x32\n\x0cwhere_clause\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\x12K\n\x16property_specification\x18\x05 \x01(\x0b\x32+.zetasql.ASTGraphPropertySpecificationProto\x12#\n\x04hint\x18\x06 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x31\n\tedge_cost\x18\x07 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x98\x01\n\"ASTGraphPropertySpecificationProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12K\n\x17property_name_and_value\x18\x02 \x03(\x0b\x32*.zetasql.ASTGraphPropertyNameAndValueProto\"\xad\x01\n!ASTGraphPropertyNameAndValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\rproperty_name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x05value\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xc1\x01\n\x18\x41nyASTGraphPathBaseProto\x12R\n\x1e\x61st_graph_element_pattern_node\x18\xf3\x02 \x01(\x0b\x32\'.zetasql.AnyASTGraphElementPatternProtoH\x00\x12I\n\x1b\x61st_graph_path_pattern_node\x18\xf9\x02 \x01(\x0b\x32!.zetasql.ASTGraphPathPatternProtoH\x00\x42\x06\n\x04node\"r\n\x15\x41STGraphPathBaseProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\nquantifier\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTQuantifierProto\"\xbe\x01\n\x1e\x41nyASTGraphElementPatternProto\x12I\n\x1b\x61st_graph_node_pattern_node\x18\xe5\x02 \x01(\x0b\x32!.zetasql.ASTGraphNodePatternProtoH\x00\x12I\n\x1b\x61st_graph_edge_pattern_node\x18\xf4\x02 \x01(\x0b\x32!.zetasql.ASTGraphEdgePatternProtoH\x00\x42\x06\n\x04node\"\x89\x01\n\x1b\x41STGraphElementPatternProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTGraphPathBaseProto\x12:\n\x06\x66iller\x18\x02 \x01(\x0b\x32*.zetasql.ASTGraphElementPatternFillerProto\"P\n\x18\x41STGraphNodePatternProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ASTGraphElementPatternProto\"b\n\x14\x41STGraphLhsHintProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\"b\n\x14\x41STGraphRhsHintProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\"\xd2\x01\n\x1d\x41STGraphPathSearchPrefixProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12I\n\x04type\x18\x02 \x01(\x0e\x32;.zetasql.ASTGraphPathSearchPrefixEnums.PathSearchPrefixType\x12?\n\npath_count\x18\x03 \x01(\x0b\x32+.zetasql.ASTGraphPathSearchPrefixCountProto\"\x7f\n\"ASTGraphPathSearchPrefixCountProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x32\n\npath_count\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xfa\x01\n\x18\x41STGraphEdgePatternProto\x12\x34\n\x06parent\x18\x01 \x01(\x0b\x32$.zetasql.ASTGraphElementPatternProto\x12\x46\n\x0borientation\x18\x02 \x01(\x0e\x32\x31.zetasql.ASTGraphEdgePatternEnums.EdgeOrientation\x12/\n\x08lhs_hint\x18\x03 \x01(\x0b\x32\x1d.zetasql.ASTGraphLhsHintProto\x12/\n\x08rhs_hint\x18\x04 \x01(\x0b\x32\x1d.zetasql.ASTGraphRhsHintProto\"z\n\x15\x41STGraphPathModeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12:\n\tpath_mode\x18\x02 \x01(\x0e\x32\'.zetasql.ASTGraphPathModeEnums.PathMode\"\x9b\x03\n\x18\x41STGraphPathPatternProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTGraphPathBaseProto\x12#\n\x04hint\x18\x02 \x01(\x0b\x32\x15.zetasql.ASTHintProto\x12\x32\n\x0cwhere_clause\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\x12\x31\n\tpath_mode\x18\x04 \x01(\x0b\x32\x1e.zetasql.ASTGraphPathModeProto\x12=\n\x12input_pattern_list\x18\x05 \x03(\x0b\x32!.zetasql.AnyASTGraphPathBaseProto\x12\x15\n\rparenthesized\x18\x06 \x01(\x08\x12=\n\rsearch_prefix\x18\x07 \x01(\x0b\x32&.zetasql.ASTGraphPathSearchPrefixProto\x12.\n\tpath_name\x18\x08 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\"\xd7\x05\n\x16\x41nyASTGqlOperatorProto\x12\x38\n\x12\x61st_gql_match_node\x18\xb1\x03 \x01(\x0b\x32\x19.zetasql.ASTGqlMatchProtoH\x00\x12:\n\x13\x61st_gql_return_node\x18\xb2\x03 \x01(\x0b\x32\x1a.zetasql.ASTGqlReturnProtoH\x00\x12G\n\x1a\x61st_gql_operator_list_node\x18\xb4\x03 \x01(\x0b\x32 .zetasql.ASTGqlOperatorListProtoH\x00\x12\x34\n\x10\x61st_gql_let_node\x18\xb9\x03 \x01(\x0b\x32\x17.zetasql.ASTGqlLetProtoH\x00\x12:\n\x13\x61st_gql_filter_node\x18\xbc\x03 \x01(\x0b\x32\x1a.zetasql.ASTGqlFilterProtoH\x00\x12M\n\x1e\x61st_gql_order_by_and_page_node\x18\xcd\x03 \x01(\x0b\x32\".zetasql.ASTGqlOrderByAndPageProtoH\x00\x12G\n\x1a\x61st_gql_set_operation_node\x18\xd8\x03 \x01(\x0b\x32 .zetasql.ASTGqlSetOperationProtoH\x00\x12\x36\n\x11\x61st_gql_with_node\x18\xd9\x03 \x01(\x0b\x32\x18.zetasql.ASTGqlWithProtoH\x00\x12\x34\n\x10\x61st_gql_for_node\x18\xdc\x03 \x01(\x0b\x32\x17.zetasql.ASTGqlForProtoH\x00\x12:\n\x13\x61st_gql_sample_node\x18\xfb\x03 \x01(\x0b\x32\x1a.zetasql.ASTGqlSampleProtoH\x00\x12\x42\n\x16\x61st_gql_call_base_node\x18\x8b\x04 \x01(\x0b\x32\x1f.zetasql.AnyASTGqlCallBaseProtoH\x00\x42\x06\n\x04node\"<\n\x13\x41STGqlOperatorProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\"\xad\x01\n\x10\x41STGqlMatchProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12\x34\n\rgraph_pattern\x18\x02 \x01(\x0b\x32\x1d.zetasql.ASTGraphPatternProto\x12\x10\n\x08optional\x18\x03 \x01(\x08\x12#\n\x04hint\x18\x04 \x01(\x0b\x32\x15.zetasql.ASTHintProto\"\xa5\x01\n\x11\x41STGqlReturnProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\x12\x39\n\rorder_by_page\x18\x03 \x01(\x0b\x32\".zetasql.ASTGqlOrderByAndPageProto\"h\n\x0f\x41STGqlWithProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12\'\n\x06select\x18\x02 \x01(\x0b\x32\x17.zetasql.ASTSelectProto\"\xd5\x01\n\x0e\x41STGqlForProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\x12\x30\n\x0bwith_offset\x18\x04 \x01(\x0b\x32\x1b.zetasql.ASTWithOffsetProto\"\xb9\x01\n\x16\x41nyASTGqlCallBaseProto\x12\x41\n\x17\x61st_gql_named_call_node\x18\x8c\x04 \x01(\x0b\x32\x1d.zetasql.ASTGqlNamedCallProtoH\x00\x12T\n!ast_gql_inline_subquery_call_node\x18\x8e\x04 \x01(\x0b\x32&.zetasql.ASTGqlInlineSubqueryCallProtoH\x00\x42\x06\n\x04node\"\xaa\x01\n\x13\x41STGqlCallBaseProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12\x10\n\x08optional\x18\x02 \x01(\x08\x12\x17\n\x0fis_partitioning\x18\x03 \x01(\x08\x12:\n\x11name_capture_list\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTIdentifierListProto\"\xa2\x01\n\x14\x41STGqlNamedCallProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlCallBaseProto\x12&\n\x08tvf_call\x18\x02 \x01(\x0b\x32\x14.zetasql.ASTTVFProto\x12\x34\n\x0cyield_clause\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTYieldItemListProto\"|\n\x15\x41STYieldItemListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x0byield_items\x18\x02 \x03(\x0b\x32\'.zetasql.ASTExpressionWithOptAliasProto\"w\n\x1d\x41STGqlInlineSubqueryCallProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlCallBaseProto\x12(\n\x08subquery\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTQueryProto\"\x8f\x01\n\x0e\x41STGqlLetProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12O\n\x18variable_definition_list\x18\x02 \x01(\x0b\x32-.zetasql.ASTGqlLetVariableDefinitionListProto\"\x96\x01\n$ASTGqlLetVariableDefinitionListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12G\n\x14variable_definitions\x18\x02 \x03(\x0b\x32).zetasql.ASTGqlLetVariableDefinitionProto\"\xae\x01\n ASTGqlLetVariableDefinitionProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\nexpression\x18\x03 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"r\n\x11\x41STGqlFilterProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12/\n\tcondition\x18\x02 \x01(\x0b\x32\x1c.zetasql.ASTWhereClauseProto\"{\n\x17\x41STGqlOperatorListProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12\x32\n\toperators\x18\x02 \x03(\x0b\x32\x1f.zetasql.AnyASTGqlOperatorProto\"\xb5\x01\n\x17\x41STGqlSetOperationProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12;\n\x08metadata\x18\x02 \x01(\x0b\x32).zetasql.ASTSetOperationMetadataListProto\x12/\n\x06inputs\x18\x03 \x03(\x0b\x32\x1f.zetasql.AnyASTGqlOperatorProto\"l\n\x14\x41STGqlPageLimitProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05limit\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"n\n\x15\x41STGqlPageOffsetProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x06offset\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x96\x01\n\x0f\x41STGqlPageProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12.\n\x06offset\x18\x02 \x01(\x0b\x32\x1e.zetasql.ASTGqlPageOffsetProto\x12,\n\x05limit\x18\x03 \x01(\x0b\x32\x1d.zetasql.ASTGqlPageLimitProto\"\x9d\x01\n\x19\x41STGqlOrderByAndPageProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12*\n\x08order_by\x18\x02 \x01(\x0b\x32\x18.zetasql.ASTOrderByProto\x12&\n\x04page\x18\x03 \x01(\x0b\x32\x18.zetasql.ASTGqlPageProto\"p\n\x11\x41STGqlSampleProto\x12,\n\x06parent\x18\x01 \x01(\x0b\x32\x1c.zetasql.ASTGqlOperatorProto\x12-\n\x06sample\x18\x02 \x01(\x0b\x32\x1d.zetasql.ASTSampleClauseProto\"\x9b\x01\n\x12\x41STSelectWithProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12/\n\nidentifier\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12-\n\x07options\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xa1\x01\n\x19\x41STColumnWithOptionsProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\x87\x01\n\x1d\x41STColumnWithOptionsListProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12?\n\x13\x63olumn_with_options\x18\x02 \x03(\x0b\x32\".zetasql.ASTColumnWithOptionsProto\"C\n\x11\x41STMacroBodyProto\x12.\n\x06parent\x18\x01 \x01(\x0b\x32\x1e.zetasql.ASTPrintableLeafProto\"\x9f\x01\n\x1c\x41STDefineMacroStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12)\n\x04name\x18\x02 \x01(\x0b\x32\x1b.zetasql.ASTIdentifierProto\x12(\n\x04\x62ody\x18\x03 \x01(\x0b\x32\x1a.zetasql.ASTMacroBodyProto\"\xb5\x02\n\x17\x41STUndropStatementProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTDdlStatementProto\x12\x35\n\x12schema_object_kind\x18\x02 \x01(\x0e\x32\x19.zetasql.SchemaObjectKind\x12-\n\x04name\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x18\n\x10is_if_not_exists\x18\x04 \x01(\x08\x12\x37\n\x0f\x66or_system_time\x18\x05 \x01(\x0b\x32\x1e.zetasql.ASTForSystemTimeProto\x12\x32\n\x0coptions_list\x18\x06 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"\xe0\x02\n\x1a\x41STIdentityColumnInfoProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12\x42\n\x10start_with_value\x18\x02 \x01(\x0b\x32(.zetasql.ASTIdentityColumnStartWithProto\x12\x46\n\x12increment_by_value\x18\x03 \x01(\x0b\x32*.zetasql.ASTIdentityColumnIncrementByProto\x12:\n\tmax_value\x18\x04 \x01(\x0b\x32\'.zetasql.ASTIdentityColumnMaxValueProto\x12:\n\tmin_value\x18\x05 \x01(\x0b\x32\'.zetasql.ASTIdentityColumnMinValueProto\x12\x17\n\x0f\x63ycling_enabled\x18\x06 \x01(\x08\"w\n\x1f\x41STIdentityColumnStartWithProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"y\n!ASTIdentityColumnIncrementByProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"v\n\x1e\x41STIdentityColumnMaxValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"v\n\x1e\x41STIdentityColumnMinValueProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12-\n\x05value\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\x91\x01\n\x1d\x41STAliasedQueryModifiersProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12I\n\x18recursion_depth_modifier\x18\x02 \x01(\x0b\x32\'.zetasql.ASTRecursionDepthModifierProto\"t\n\x16\x41STIntOrUnboundedProto\x12+\n\x06parent\x18\x01 \x01(\x0b\x32\x1b.zetasql.ASTExpressionProto\x12-\n\x05\x62ound\x18\x02 \x01(\x0b\x32\x1e.zetasql.AnyASTExpressionProto\"\xda\x01\n\x1e\x41STRecursionDepthModifierProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12%\n\x05\x61lias\x18\x02 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\x12\x34\n\x0blower_bound\x18\x03 \x01(\x0b\x32\x1f.zetasql.ASTIntOrUnboundedProto\x12\x34\n\x0bupper_bound\x18\x04 \x01(\x0b\x32\x1f.zetasql.ASTIntOrUnboundedProto\"\xfa\x01\n\x0f\x41STMapTypeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTTypeProto\x12*\n\x08key_type\x18\x02 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12,\n\nvalue_type\x18\x03 \x01(\x0b\x32\x18.zetasql.AnyASTTypeProto\x12;\n\x0ftype_parameters\x18\x04 \x01(\x0b\x32\".zetasql.ASTTypeParameterListProto\x12)\n\x07\x63ollate\x18\x05 \x01(\x0b\x32\x18.zetasql.ASTCollateProto\"w\n\x10\x41STLockModeProto\x12%\n\x06parent\x18\x01 \x01(\x0b\x32\x15.zetasql.ASTNodeProto\x12<\n\x08strength\x18\x02 \x01(\x0e\x32*.zetasql.ASTLockModeEnums.LockStrengthSpec\"\xec\x02\n\x1a\x41STPipeRecursiveUnionProto\x12-\n\x06parent\x18\x01 \x01(\x0b\x32\x1d.zetasql.ASTPipeOperatorProto\x12\x37\n\x08metadata\x18\x02 \x01(\x0b\x32%.zetasql.ASTSetOperationMetadataProto\x12I\n\x18recursion_depth_modifier\x18\x03 \x01(\x0b\x32\'.zetasql.ASTRecursionDepthModifierProto\x12\x37\n\x11input_subpipeline\x18\x04 \x01(\x0b\x32\x1c.zetasql.ASTSubpipelineProto\x12;\n\x0einput_subquery\x18\x05 \x01(\x0b\x32#.zetasql.AnyASTQueryExpressionProto\x12%\n\x05\x61lias\x18\x06 \x01(\x0b\x32\x16.zetasql.ASTAliasProto\"\xf5\x01\n\x14\x41STRunStatementProto\x12*\n\x06parent\x18\x01 \x01(\x0b\x32\x1a.zetasql.ASTStatementProto\x12?\n\x16target_path_expression\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12=\n\x15target_string_literal\x18\x03 \x01(\x0b\x32\x1e.zetasql.ASTStringLiteralProto\x12\x31\n\targuments\x18\x04 \x03(\x0b\x32\x1e.zetasql.ASTNamedArgumentProto\"\xb6\x01\n\x1f\x41STCreateSequenceStatementProto\x12\x30\n\x06parent\x18\x01 \x01(\x0b\x32 .zetasql.ASTCreateStatementProto\x12-\n\x04name\x18\x02 \x01(\x0b\x32\x1f.zetasql.ASTPathExpressionProto\x12\x32\n\x0coptions_list\x18\x03 \x01(\x0b\x32\x1c.zetasql.ASTOptionsListProto\"U\n\x1e\x41STAlterSequenceStatementProto\x12\x33\n\x06parent\x18\x01 \x01(\x0b\x32#.zetasql.ASTAlterStatementBaseProtoB\x1d\n\x19\x63om.google.zetasql.parserP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.parser.parse_tree_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.google.zetasql.parserP\001'
  _globals['_ANYASTNODEPROTO']._serialized_start=147
  _globals['_ANYASTNODEPROTO']._serialized_end=15677
  _globals['_ASTNODEPROTO']._serialized_start=15679
  _globals['_ASTNODEPROTO']._serialized_end=15757
  _globals['_ANYASTSTATEMENTPROTO']._serialized_start=15760
  _globals['_ANYASTSTATEMENTPROTO']._serialized_end=19177
  _globals['_ASTSTATEMENTPROTO']._serialized_start=19179
  _globals['_ASTSTATEMENTPROTO']._serialized_end=19237
  _globals['_ASTQUERYSTATEMENTPROTO']._serialized_start=19239
  _globals['_ASTQUERYSTATEMENTPROTO']._serialized_end=19346
  _globals['_ASTSUBPIPELINESTATEMENTPROTO']._serialized_start=19348
  _globals['_ASTSUBPIPELINESTATEMENTPROTO']._serialized_end=19473
  _globals['_ANYASTQUERYEXPRESSIONPROTO']._serialized_start=19476
  _globals['_ANYASTQUERYEXPRESSIONPROTO']._serialized_end=20110
  _globals['_ASTQUERYEXPRESSIONPROTO']._serialized_start=20112
  _globals['_ASTQUERYEXPRESSIONPROTO']._serialized_end=20199
  _globals['_ASTALIASEDQUERYEXPRESSIONPROTO']._serialized_start=20202
  _globals['_ASTALIASEDQUERYEXPRESSIONPROTO']._serialized_end=20362
  _globals['_ASTQUERYPROTO']._serialized_start=20365
  _globals['_ASTQUERYPROTO']._serialized_end=20784
  _globals['_ASTFROMQUERYPROTO']._serialized_start=20786
  _globals['_ASTFROMQUERYPROTO']._serialized_end=20905
  _globals['_ASTSUBPIPELINEPROTO']._serialized_start=20908
  _globals['_ASTSUBPIPELINEPROTO']._serialized_end=21053
  _globals['_ANYASTPIPEOPERATORPROTO']._serialized_start=21056
  _globals['_ANYASTPIPEOPERATORPROTO']._serialized_end=23211
  _globals['_ASTPIPEOPERATORPROTO']._serialized_start=23213
  _globals['_ASTPIPEOPERATORPROTO']._serialized_end=23274
  _globals['_ASTPIPEEXTENDPROTO']._serialized_start=23276
  _globals['_ASTPIPEEXTENDPROTO']._serialized_end=23384
  _globals['_ASTPIPERENAMEITEMPROTO']._serialized_start=23387
  _globals['_ASTPIPERENAMEITEMPROTO']._serialized_end=23552
  _globals['_ASTPIPERENAMEPROTO']._serialized_start=23554
  _globals['_ASTPIPERENAMEPROTO']._serialized_end=23680
  _globals['_ASTPIPEAGGREGATEPROTO']._serialized_start=23683
  _globals['_ASTPIPEAGGREGATEPROTO']._serialized_end=23844
  _globals['_ASTPIPESETOPERATIONPROTO']._serialized_start=23847
  _globals['_ASTPIPESETOPERATIONPROTO']._serialized_end=24030
  _globals['_ASTPIPEJOINPROTO']._serialized_start=24032
  _globals['_ASTPIPEJOINPROTO']._serialized_end=24134
  _globals['_ASTPIPECALLPROTO']._serialized_start=24136
  _globals['_ASTPIPECALLPROTO']._serialized_end=24236
  _globals['_ASTPIPEWINDOWPROTO']._serialized_start=24238
  _globals['_ASTPIPEWINDOWPROTO']._serialized_end=24346
  _globals['_ASTPIPEWHEREPROTO']._serialized_start=24348
  _globals['_ASTPIPEWHEREPROTO']._serialized_end=24459
  _globals['_ASTPIPESELECTPROTO']._serialized_start=24461
  _globals['_ASTPIPESELECTPROTO']._serialized_end=24569
  _globals['_ASTPIPELIMITOFFSETPROTO']._serialized_start=24571
  _globals['_ASTPIPELIMITOFFSETPROTO']._serialized_end=24695
  _globals['_ASTPIPEORDERBYPROTO']._serialized_start=24697
  _globals['_ASTPIPEORDERBYPROTO']._serialized_end=24809
  _globals['_ASTPIPEDISTINCTPROTO']._serialized_start=24811
  _globals['_ASTPIPEDISTINCTPROTO']._serialized_end=24880
  _globals['_ASTPIPETABLESAMPLEPROTO']._serialized_start=24882
  _globals['_ASTPIPETABLESAMPLEPROTO']._serialized_end=25001
  _globals['_ASTPIPEMATCHRECOGNIZEPROTO']._serialized_start=25004
  _globals['_ASTPIPEMATCHRECOGNIZEPROTO']._serialized_end=25143
  _globals['_ASTPIPEASPROTO']._serialized_start=25145
  _globals['_ASTPIPEASPROTO']._serialized_end=25247
  _globals['_ASTPIPEDESCRIBEPROTO']._serialized_start=25249
  _globals['_ASTPIPEDESCRIBEPROTO']._serialized_end=25318
  _globals['_ASTPIPESTATICDESCRIBEPROTO']._serialized_start=25320
  _globals['_ASTPIPESTATICDESCRIBEPROTO']._serialized_end=25395
  _globals['_ASTPIPEASSERTPROTO']._serialized_start=25398
  _globals['_ASTPIPEASSERTPROTO']._serialized_end=25570
  _globals['_ASTPIPELOGPROTO']._serialized_start=25573
  _globals['_ASTPIPELOGPROTO']._serialized_end=25725
  _globals['_ASTPIPEDROPPROTO']._serialized_start=25727
  _globals['_ASTPIPEDROPPROTO']._serialized_end=25846
  _globals['_ASTPIPESETITEMPROTO']._serialized_start=25849
  _globals['_ASTPIPESETITEMPROTO']._serialized_end=26006
  _globals['_ASTPIPESETPROTO']._serialized_start=26008
  _globals['_ASTPIPESETPROTO']._serialized_end=26125
  _globals['_ASTPIPEPIVOTPROTO']._serialized_start=26127
  _globals['_ASTPIPEPIVOTPROTO']._serialized_end=26245
  _globals['_ASTPIPEUNPIVOTPROTO']._serialized_start=26247
  _globals['_ASTPIPEUNPIVOTPROTO']._serialized_end=26371
  _globals['_ASTPIPEIFPROTO']._serialized_start=26374
  _globals['_ASTPIPEIFPROTO']._serialized_end=26577
  _globals['_ASTPIPEIFCASEPROTO']._serialized_start=26580
  _globals['_ASTPIPEIFCASEPROTO']._serialized_end=26749
  _globals['_ASTPIPEFORKPROTO']._serialized_start=26752
  _globals['_ASTPIPEFORKPROTO']._serialized_end=26910
  _globals['_ASTPIPETEEPROTO']._serialized_start=26913
  _globals['_ASTPIPETEEPROTO']._serialized_end=27070
  _globals['_ASTPIPEWITHPROTO']._serialized_start=27072
  _globals['_ASTPIPEWITHPROTO']._serialized_end=27187
  _globals['_ASTPIPEEXPORTDATAPROTO']._serialized_start=27190
  _globals['_ASTPIPEEXPORTDATAPROTO']._serialized_end=27330
  _globals['_ASTPIPECREATETABLEPROTO']._serialized_start=27333
  _globals['_ASTPIPECREATETABLEPROTO']._serialized_end=27476
  _globals['_ASTPIPEINSERTPROTO']._serialized_start=27478
  _globals['_ASTPIPEINSERTPROTO']._serialized_end=27605
  _globals['_ASTSELECTPROTO']._serialized_start=27608
  _globals['_ASTSELECTPROTO']._serialized_end=28159
  _globals['_ASTSELECTLISTPROTO']._serialized_start=28161
  _globals['_ASTSELECTLISTPROTO']._serialized_end=28268
  _globals['_ASTSELECTCOLUMNPROTO']._serialized_start=28271
  _globals['_ASTSELECTCOLUMNPROTO']._serialized_end=28488
  _globals['_ANYASTEXPRESSIONPROTO']._serialized_start=28491
  _globals['_ANYASTEXPRESSIONPROTO']._serialized_end=31852
  _globals['_ASTEXPRESSIONPROTO']._serialized_start=31854
  _globals['_ASTEXPRESSIONPROTO']._serialized_end=31936
  _globals['_ANYASTLEAFPROTO']._serialized_start=31939
  _globals['_ANYASTLEAFPROTO']._serialized_end=32374
  _globals['_ASTLEAFPROTO']._serialized_start=32376
  _globals['_ASTLEAFPROTO']._serialized_end=32435
  _globals['_ANYASTPRINTABLELEAFPROTO']._serialized_start=32438
  _globals['_ANYASTPRINTABLELEAFPROTO']._serialized_end=33144
  _globals['_ASTPRINTABLELEAFPROTO']._serialized_start=33146
  _globals['_ASTPRINTABLELEAFPROTO']._serialized_end=33223
  _globals['_ASTINTLITERALPROTO']._serialized_start=33225
  _globals['_ASTINTLITERALPROTO']._serialized_end=33293
  _globals['_ASTIDENTIFIERPROTO']._serialized_start=33295
  _globals['_ASTIDENTIFIERPROTO']._serialized_end=33398
  _globals['_ASTALIASPROTO']._serialized_start=33400
  _globals['_ASTALIASPROTO']._serialized_end=33503
  _globals['_ANYASTGENERALIZEDPATHEXPRESSIONPROTO']._serialized_start=33506
  _globals['_ANYASTGENERALIZEDPATHEXPRESSIONPROTO']._serialized_end=33920
  _globals['_ASTGENERALIZEDPATHEXPRESSIONPROTO']._serialized_start=33922
  _globals['_ASTGENERALIZEDPATHEXPRESSIONPROTO']._serialized_end=34002
  _globals['_ASTPATHEXPRESSIONPROTO']._serialized_start=34005
  _globals['_ASTPATHEXPRESSIONPROTO']._serialized_end=34133
  _globals['_ANYASTPOSTFIXTABLEOPERATORPROTO']._serialized_start=34136
  _globals['_ANYASTPOSTFIXTABLEOPERATORPROTO']._serialized_end=34458
  _globals['_ASTPOSTFIXTABLEOPERATORPROTO']._serialized_start=34460
  _globals['_ASTPOSTFIXTABLEOPERATORPROTO']._serialized_end=34529
  _globals['_ANYASTTABLEEXPRESSIONPROTO']._serialized_start=34532
  _globals['_ANYASTTABLEEXPRESSIONPROTO']._serialized_end=35122
  _globals['_ASTTABLEEXPRESSIONPROTO']._serialized_start=35125
  _globals['_ASTTABLEEXPRESSIONPROTO']._serialized_end=35258
  _globals['_ASTTABLEPATHEXPRESSIONPROTO']._serialized_start=35261
  _globals['_ASTTABLEPATHEXPRESSIONPROTO']._serialized_end=35631
  _globals['_ASTPIPEJOINLHSPLACEHOLDERPROTO']._serialized_start=35633
  _globals['_ASTPIPEJOINLHSPLACEHOLDERPROTO']._serialized_end=35715
  _globals['_ASTFROMCLAUSEPROTO']._serialized_start=35717
  _globals['_ASTFROMCLAUSEPROTO']._serialized_end=35839
  _globals['_ASTWHERECLAUSEPROTO']._serialized_start=35841
  _globals['_ASTWHERECLAUSEPROTO']._serialized_end=35953
  _globals['_ASTBOOLEANLITERALPROTO']._serialized_start=35955
  _globals['_ASTBOOLEANLITERALPROTO']._serialized_end=36042
  _globals['_ASTANDEXPRPROTO']._serialized_start=36044
  _globals['_ASTANDEXPRPROTO']._serialized_end=36157
  _globals['_ASTBINARYEXPRESSIONPROTO']._serialized_start=36160
  _globals['_ASTBINARYEXPRESSIONPROTO']._serialized_end=36387
  _globals['_ASTSTRINGLITERALPROTO']._serialized_start=36390
  _globals['_ASTSTRINGLITERALPROTO']._serialized_end=36535
  _globals['_ASTSTRINGLITERALCOMPONENTPROTO']._serialized_start=36537
  _globals['_ASTSTRINGLITERALCOMPONENTPROTO']._serialized_end=36639
  _globals['_ASTSTARPROTO']._serialized_start=36641
  _globals['_ASTSTARPROTO']._serialized_end=36703
  _globals['_ASTOREXPRPROTO']._serialized_start=36705
  _globals['_ASTOREXPRPROTO']._serialized_end=36817
  _globals['_ASTCONCATEXPRPROTO']._serialized_start=36819
  _globals['_ASTCONCATEXPRPROTO']._serialized_end=36934
  _globals['_ASTORDERINGEXPRESSIONPROTO']._serialized_start=36937
  _globals['_ASTORDERINGEXPRESSIONPROTO']._serialized_end=37271
  _globals['_ASTORDERBYPROTO']._serialized_start=37274
  _globals['_ASTORDERBYPROTO']._serialized_end=37434
  _globals['_ASTGROUPINGITEMORDERPROTO']._serialized_start=37437
  _globals['_ASTGROUPINGITEMORDERPROTO']._serialized_end=37624
  _globals['_ASTGROUPINGITEMPROTO']._serialized_start=37627
  _globals['_ASTGROUPINGITEMPROTO']._serialized_end=37983
  _globals['_ASTGROUPBYPROTO']._serialized_start=37986
  _globals['_ASTGROUPBYPROTO']._serialized_end=38198
  _globals['_ASTGROUPBYALLPROTO']._serialized_start=38200
  _globals['_ASTGROUPBYALLPROTO']._serialized_end=38259
  _globals['_ASTLIMITALLPROTO']._serialized_start=38261
  _globals['_ASTLIMITALLPROTO']._serialized_end=38318
  _globals['_ASTLIMITPROTO']._serialized_start=38321
  _globals['_ASTLIMITPROTO']._serialized_end=38467
  _globals['_ASTLIMITOFFSETPROTO']._serialized_start=38470
  _globals['_ASTLIMITOFFSETPROTO']._serialized_end=38617
  _globals['_ASTFLOATLITERALPROTO']._serialized_start=38619
  _globals['_ASTFLOATLITERALPROTO']._serialized_end=38689
  _globals['_ASTNULLLITERALPROTO']._serialized_start=38691
  _globals['_ASTNULLLITERALPROTO']._serialized_end=38760
  _globals['_ASTONCLAUSEPROTO']._serialized_start=38762
  _globals['_ASTONCLAUSEPROTO']._serialized_end=38871
  _globals['_ASTALIASEDQUERYPROTO']._serialized_start=38874
  _globals['_ASTALIASEDQUERYPROTO']._serialized_end=39077
  _globals['_ASTJOINPROTO']._serialized_start=39080
  _globals['_ASTJOINPROTO']._serialized_end=39697
  _globals['_ASTWITHCLAUSEPROTO']._serialized_start=39699
  _globals['_ASTWITHCLAUSEPROTO']._serialized_end=39822
  _globals['_ASTHAVINGPROTO']._serialized_start=39824
  _globals['_ASTHAVINGPROTO']._serialized_end=39931
  _globals['_ANYASTTYPEPROTO']._serialized_start=39934
  _globals['_ANYASTTYPEPROTO']._serialized_end=40322
  _globals['_ASTTYPEPROTO']._serialized_start=40324
  _globals['_ASTTYPEPROTO']._serialized_end=40377
  _globals['_ASTSIMPLETYPEPROTO']._serialized_start=40380
  _globals['_ASTSIMPLETYPEPROTO']._serialized_end=40595
  _globals['_ASTARRAYTYPEPROTO']._serialized_start=40598
  _globals['_ASTARRAYTYPEPROTO']._serialized_end=40808
  _globals['_ASTSTRUCTFIELDPROTO']._serialized_start=40811
  _globals['_ASTSTRUCTFIELDPROTO']._serialized_end=40954
  _globals['_ASTSTRUCTTYPEPROTO']._serialized_start=40957
  _globals['_ASTSTRUCTTYPEPROTO']._serialized_end=41173
  _globals['_ASTFUNCTIONTYPEARGLISTPROTO']._serialized_start=41175
  _globals['_ASTFUNCTIONTYPEARGLISTPROTO']._serialized_end=41283
  _globals['_ASTFUNCTIONTYPEPROTO']._serialized_start=41286
  _globals['_ASTFUNCTIONTYPEPROTO']._serialized_end=41554
  _globals['_ASTCASTEXPRESSIONPROTO']._serialized_start=41557
  _globals['_ASTCASTEXPRESSIONPROTO']._serialized_end=41781
  _globals['_ASTSELECTASPROTO']._serialized_start=41784
  _globals['_ASTSELECTASPROTO']._serialized_end=41944
  _globals['_ASTROLLUPPROTO']._serialized_start=41946
  _globals['_ASTROLLUPPROTO']._serialized_end=42054
  _globals['_ASTCUBEPROTO']._serialized_start=42056
  _globals['_ASTCUBEPROTO']._serialized_end=42162
  _globals['_ASTGROUPINGSETPROTO']._serialized_start=42165
  _globals['_ASTGROUPINGSETPROTO']._serialized_end=42355
  _globals['_ASTGROUPINGSETLISTPROTO']._serialized_start=42357
  _globals['_ASTGROUPINGSETLISTPROTO']._serialized_end=42474
  _globals['_ASTEXPRESSIONWITHALIASPROTO']._serialized_start=42477
  _globals['_ASTEXPRESSIONWITHALIASPROTO']._serialized_end=42642
  _globals['_ASTFUNCTIONCALLPROTO']._serialized_start=42645
  _globals['_ASTFUNCTIONCALLPROTO']._serialized_end=43464
  _globals['_ASTCHAINEDBASEEXPRPROTO']._serialized_start=43466
  _globals['_ASTCHAINEDBASEEXPRPROTO']._serialized_end=43576
  _globals['_ASTARRAYCONSTRUCTORPROTO']._serialized_start=43579
  _globals['_ASTARRAYCONSTRUCTORPROTO']._serialized_end=43742
  _globals['_ASTSTRUCTCONSTRUCTORARGPROTO']._serialized_start=43745
  _globals['_ASTSTRUCTCONSTRUCTORARGPROTO']._serialized_end=43905
  _globals['_ASTSTRUCTCONSTRUCTORWITHPARENSPROTO']._serialized_start=43908
  _globals['_ASTSTRUCTCONSTRUCTORWITHPARENSPROTO']._serialized_end=44049
  _globals['_ASTSTRUCTCONSTRUCTORWITHKEYWORDPROTO']._serialized_start=44052
  _globals['_ASTSTRUCTCONSTRUCTORWITHKEYWORDPROTO']._serialized_end=44240
  _globals['_ASTINEXPRESSIONPROTO']._serialized_start=44243
  _globals['_ASTINEXPRESSIONPROTO']._serialized_end=44593
  _globals['_ASTINLISTPROTO']._serialized_start=44595
  _globals['_ASTINLISTPROTO']._serialized_end=44696
  _globals['_ASTBETWEENEXPRESSIONPROTO']._serialized_start=44699
  _globals['_ASTBETWEENEXPRESSIONPROTO']._serialized_end=44976
  _globals['_ASTNUMERICLITERALPROTO']._serialized_start=44978
  _globals['_ASTNUMERICLITERALPROTO']._serialized_end=45097
  _globals['_ASTBIGNUMERICLITERALPROTO']._serialized_start=45099
  _globals['_ASTBIGNUMERICLITERALPROTO']._serialized_end=45221
  _globals['_ASTBYTESLITERALPROTO']._serialized_start=45224
  _globals['_ASTBYTESLITERALPROTO']._serialized_end=45366
  _globals['_ASTBYTESLITERALCOMPONENTPROTO']._serialized_start=45368
  _globals['_ASTBYTESLITERALCOMPONENTPROTO']._serialized_end=45447
  _globals['_ASTDATEORTIMELITERALPROTO']._serialized_start=45450
  _globals['_ASTDATEORTIMELITERALPROTO']._serialized_end=45616
  _globals['_ASTMAXLITERALPROTO']._serialized_start=45618
  _globals['_ASTMAXLITERALPROTO']._serialized_end=45686
  _globals['_ASTJSONLITERALPROTO']._serialized_start=45688
  _globals['_ASTJSONLITERALPROTO']._serialized_end=45804
  _globals['_ASTCASEVALUEEXPRESSIONPROTO']._serialized_start=45806
  _globals['_ASTCASEVALUEEXPRESSIONPROTO']._serialized_end=45931
  _globals['_ASTCASENOVALUEEXPRESSIONPROTO']._serialized_start=45933
  _globals['_ASTCASENOVALUEEXPRESSIONPROTO']._serialized_end=46060
  _globals['_ASTARRAYELEMENTPROTO']._serialized_start=46063
  _globals['_ASTARRAYELEMENTPROTO']._serialized_end=46300
  _globals['_ASTBITWISESHIFTEXPRESSIONPROTO']._serialized_start=46303
  _globals['_ASTBITWISESHIFTEXPRESSIONPROTO']._serialized_end=46547
  _globals['_ASTCOLLATEPROTO']._serialized_start=46549
  _globals['_ASTCOLLATEPROTO']._serialized_end=46661
  _globals['_ASTDOTGENERALIZEDFIELDPROTO']._serialized_start=46664
  _globals['_ASTDOTGENERALIZEDFIELDPROTO']._serialized_end=46846
  _globals['_ASTDOTIDENTIFIERPROTO']._serialized_start=46849
  _globals['_ASTDOTIDENTIFIERPROTO']._serialized_end=47021
  _globals['_ASTDOTSTARPROTO']._serialized_start=47023
  _globals['_ASTDOTSTARPROTO']._serialized_end=47131
  _globals['_ASTDOTSTARWITHMODIFIERSPROTO']._serialized_start=47134
  _globals['_ASTDOTSTARWITHMODIFIERSPROTO']._serialized_end=47306
  _globals['_ASTEXPRESSIONSUBQUERYPROTO']._serialized_start=47309
  _globals['_ASTEXPRESSIONSUBQUERYPROTO']._serialized_end=47522
  _globals['_ASTEXTRACTEXPRESSIONPROTO']._serialized_start=47525
  _globals['_ASTEXTRACTEXPRESSIONPROTO']._serialized_end=47753
  _globals['_ASTHAVINGMODIFIERPROTO']._serialized_start=47756
  _globals['_ASTHAVINGMODIFIERPROTO']._serialized_end=47934
  _globals['_ASTINTERVALEXPRPROTO']._serialized_start=47937
  _globals['_ASTINTERVALEXPRPROTO']._serialized_end=48169
  _globals['_ASTSEQUENCEARGPROTO']._serialized_start=48171
  _globals['_ASTSEQUENCEARGPROTO']._serialized_end=48293
  _globals['_ASTNAMEDARGUMENTPROTO']._serialized_start=48296
  _globals['_ASTNAMEDARGUMENTPROTO']._serialized_end=48453
  _globals['_ASTINPUTTABLEARGUMENTPROTO']._serialized_start=48455
  _globals['_ASTINPUTTABLEARGUMENTPROTO']._serialized_end=48528
  _globals['_ASTNULLORDERPROTO']._serialized_start=48530
  _globals['_ASTNULLORDERPROTO']._serialized_end=48609
  _globals['_ASTONORUSINGCLAUSELISTPROTO']._serialized_start=48611
  _globals['_ASTONORUSINGCLAUSELISTPROTO']._serialized_end=48735
  _globals['_ASTPARENTHESIZEDJOINPROTO']._serialized_start=48737
  _globals['_ASTPARENTHESIZEDJOINPROTO']._serialized_end=48851
  _globals['_ASTPARTITIONBYPROTO']._serialized_start=48854
  _globals['_ASTPARTITIONBYPROTO']._serialized_end=49017
  _globals['_ASTSETOPERATIONPROTO']._serialized_start=49020
  _globals['_ASTSETOPERATIONPROTO']._serialized_end=49206
  _globals['_ASTSETOPERATIONMETADATALISTPROTO']._serialized_start=49209
  _globals['_ASTSETOPERATIONMETADATALISTPROTO']._serialized_end=49358
  _globals['_ASTSETOPERATIONALLORDISTINCTPROTO']._serialized_start=49361
  _globals['_ASTSETOPERATIONALLORDISTINCTPROTO']._serialized_end=49495
  _globals['_ASTSETOPERATIONTYPEPROTO']._serialized_start=49497
  _globals['_ASTSETOPERATIONTYPEPROTO']._serialized_end=49622
  _globals['_ASTSETOPERATIONCOLUMNMATCHMODEPROTO']._serialized_start=49625
  _globals['_ASTSETOPERATIONCOLUMNMATCHMODEPROTO']._serialized_end=49763
  _globals['_ASTSETOPERATIONCOLUMNPROPAGATIONMODEPROTO']._serialized_start=49766
  _globals['_ASTSETOPERATIONCOLUMNPROPAGATIONMODEPROTO']._serialized_end=49916
  _globals['_ASTSETOPERATIONMETADATAPROTO']._serialized_start=49919
  _globals['_ASTSETOPERATIONMETADATAPROTO']._serialized_end=50371
  _globals['_ASTSTAREXCEPTLISTPROTO']._serialized_start=50373
  _globals['_ASTSTAREXCEPTLISTPROTO']._serialized_end=50486
  _globals['_ASTSTARMODIFIERSPROTO']._serialized_start=50489
  _globals['_ASTSTARMODIFIERSPROTO']._serialized_end=50662
  _globals['_ASTSTARREPLACEITEMPROTO']._serialized_start=50665
  _globals['_ASTSTARREPLACEITEMPROTO']._serialized_end=50825
  _globals['_ASTSTARWITHMODIFIERSPROTO']._serialized_start=50827
  _globals['_ASTSTARWITHMODIFIERSPROTO']._serialized_end=50950
  _globals['_ASTTABLESUBQUERYPROTO']._serialized_start=50953
  _globals['_ASTTABLESUBQUERYPROTO']._serialized_end=51127
  _globals['_ASTUNARYEXPRESSIONPROTO']._serialized_start=51130
  _globals['_ASTUNARYEXPRESSIONPROTO']._serialized_end=51298
  _globals['_ASTEXPRESSIONWITHOPTALIASPROTO']._serialized_start=51301
  _globals['_ASTEXPRESSIONWITHOPTALIASPROTO']._serialized_end=51472
  _globals['_ASTUNNESTEXPRESSIONPROTO']._serialized_start=51475
  _globals['_ASTUNNESTEXPRESSIONPROTO']._serialized_end=51658
  _globals['_ASTWINDOWCLAUSEPROTO']._serialized_start=51660
  _globals['_ASTWINDOWCLAUSEPROTO']._serialized_end=51773
  _globals['_ASTWINDOWDEFINITIONPROTO']._serialized_start=51776
  _globals['_ASTWINDOWDEFINITIONPROTO']._serialized_end=51943
  _globals['_ASTWINDOWFRAMEPROTO']._serialized_start=51946
  _globals['_ASTWINDOWFRAMEPROTO']._serialized_end=52172
  _globals['_ASTWINDOWFRAMEEXPRPROTO']._serialized_start=52175
  _globals['_ASTWINDOWFRAMEEXPRPROTO']._serialized_end=52361
  _globals['_ASTLIKEEXPRESSIONPROTO']._serialized_start=52364
  _globals['_ASTLIKEEXPRESSIONPROTO']._serialized_end=52761
  _globals['_ASTWINDOWSPECIFICATIONPROTO']._serialized_start=52764
  _globals['_ASTWINDOWSPECIFICATIONPROTO']._serialized_end=53035
  _globals['_ASTWITHOFFSETPROTO']._serialized_start=53037
  _globals['_ASTWITHOFFSETPROTO']._serialized_end=53135
  _globals['_ASTANYSOMEALLOPPROTO']._serialized_start=53137
  _globals['_ASTANYSOMEALLOPPROTO']._serialized_end=53244
  _globals['_ANYASTPARAMETEREXPRBASEPROTO']._serialized_start=53247
  _globals['_ANYASTPARAMETEREXPRBASEPROTO']._serialized_end=53432
  _globals['_ASTPARAMETEREXPRBASEPROTO']._serialized_start=53434
  _globals['_ASTPARAMETEREXPRBASEPROTO']._serialized_end=53506
  _globals['_ASTSTATEMENTLISTPROTO']._serialized_start=53509
  _globals['_ASTSTATEMENTLISTPROTO']._serialized_end=53665
  _globals['_ANYASTSCRIPTSTATEMENTPROTO']._serialized_start=53668
  _globals['_ANYASTSCRIPTSTATEMENTPROTO']._serialized_end=54445
  _globals['_ASTSCRIPTSTATEMENTPROTO']._serialized_start=54447
  _globals['_ASTSCRIPTSTATEMENTPROTO']._serialized_end=54516
  _globals['_ASTHINTEDSTATEMENTPROTO']._serialized_start=54519
  _globals['_ASTHINTEDSTATEMENTPROTO']._serialized_end=54675
  _globals['_ASTSTATEMENTWITHPIPEOPERATORSPROTO']._serialized_start=54678
  _globals['_ASTSTATEMENTWITHPIPEOPERATORSPROTO']._serialized_end=54877
  _globals['_ASTEXPLAINSTATEMENTPROTO']._serialized_start=54879
  _globals['_ASTEXPLAINSTATEMENTPROTO']._serialized_end=54999
  _globals['_ASTDESCRIBESTATEMENTPROTO']._serialized_start=55002
  _globals['_ASTDESCRIBESTATEMENTPROTO']._serialized_end=55239
  _globals['_ASTSHOWSTATEMENTPROTO']._serialized_start=55242
  _globals['_ASTSHOWSTATEMENTPROTO']._serialized_end=55476
  _globals['_ANYASTTRANSACTIONMODEPROTO']._serialized_start=55479
  _globals['_ANYASTTRANSACTIONMODEPROTO']._serialized_end=55698
  _globals['_ASTTRANSACTIONMODEPROTO']._serialized_start=55700
  _globals['_ASTTRANSACTIONMODEPROTO']._serialized_end=55764
  _globals['_ASTTRANSACTIONISOLATIONLEVELPROTO']._serialized_start=55767
  _globals['_ASTTRANSACTIONISOLATIONLEVELPROTO']._serialized_end=55952
  _globals['_ASTTRANSACTIONREADWRITEMODEPROTO']._serialized_start=55955
  _globals['_ASTTRANSACTIONREADWRITEMODEPROTO']._serialized_end=56101
  _globals['_ASTTRANSACTIONMODELISTPROTO']._serialized_start=56103
  _globals['_ASTTRANSACTIONMODELISTPROTO']._serialized_end=56226
  _globals['_ASTBEGINSTATEMENTPROTO']._serialized_start=56228
  _globals['_ASTBEGINSTATEMENTPROTO']._serialized_end=56353
  _globals['_ASTSETTRANSACTIONSTATEMENTPROTO']._serialized_start=56356
  _globals['_ASTSETTRANSACTIONSTATEMENTPROTO']._serialized_end=56490
  _globals['_ASTCOMMITSTATEMENTPROTO']._serialized_start=56492
  _globals['_ASTCOMMITSTATEMENTPROTO']._serialized_end=56561
  _globals['_ASTROLLBACKSTATEMENTPROTO']._serialized_start=56563
  _globals['_ASTROLLBACKSTATEMENTPROTO']._serialized_end=56634
  _globals['_ASTSTARTBATCHSTATEMENTPROTO']._serialized_start=56636
  _globals['_ASTSTARTBATCHSTATEMENTPROTO']._serialized_end=56758
  _globals['_ASTRUNBATCHSTATEMENTPROTO']._serialized_start=56760
  _globals['_ASTRUNBATCHSTATEMENTPROTO']._serialized_end=56831
  _globals['_ASTABORTBATCHSTATEMENTPROTO']._serialized_start=56833
  _globals['_ASTABORTBATCHSTATEMENTPROTO']._serialized_end=56906
  _globals['_ANYASTDDLSTATEMENTPROTO']._serialized_start=56909
  _globals['_ANYASTDDLSTATEMENTPROTO']._serialized_end=57987
  _globals['_ASTDDLSTATEMENTPROTO']._serialized_start=57989
  _globals['_ASTDDLSTATEMENTPROTO']._serialized_end=58055
  _globals['_ASTDROPENTITYSTATEMENTPROTO']._serialized_start=58058
  _globals['_ASTDROPENTITYSTATEMENTPROTO']._serialized_end=58253
  _globals['_ASTDROPFUNCTIONSTATEMENTPROTO']._serialized_start=58256
  _globals['_ASTDROPFUNCTIONSTATEMENTPROTO']._serialized_end=58460
  _globals['_ASTDROPTABLEFUNCTIONSTATEMENTPROTO']._serialized_start=58463
  _globals['_ASTDROPTABLEFUNCTIONSTATEMENTPROTO']._serialized_end=58615
  _globals['_ASTDROPALLROWACCESSPOLICIESSTATEMENTPROTO']._serialized_start=58618
  _globals['_ASTDROPALLROWACCESSPOLICIESSTATEMENTPROTO']._serialized_end=58786
  _globals['_ASTDROPMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_start=58789
  _globals['_ASTDROPMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_end=58944
  _globals['_ASTDROPSNAPSHOTTABLESTATEMENTPROTO']._serialized_start=58947
  _globals['_ASTDROPSNAPSHOTTABLESTATEMENTPROTO']._serialized_end=59099
  _globals['_ANYASTDROPINDEXSTATEMENTPROTO']._serialized_start=59102
  _globals['_ANYASTDROPINDEXSTATEMENTPROTO']._serialized_end=59324
  _globals['_ASTDROPINDEXSTATEMENTPROTO']._serialized_start=59327
  _globals['_ASTDROPINDEXSTATEMENTPROTO']._serialized_end=59524
  _globals['_ASTDROPSEARCHINDEXSTATEMENTPROTO']._serialized_start=59526
  _globals['_ASTDROPSEARCHINDEXSTATEMENTPROTO']._serialized_end=59613
  _globals['_ASTDROPVECTORINDEXSTATEMENTPROTO']._serialized_start=59615
  _globals['_ASTDROPVECTORINDEXSTATEMENTPROTO']._serialized_end=59702
  _globals['_ASTRENAMESTATEMENTPROTO']._serialized_start=59705
  _globals['_ASTRENAMESTATEMENTPROTO']._serialized_end=59925
  _globals['_ASTIMPORTSTATEMENTPROTO']._serialized_start=59928
  _globals['_ASTIMPORTSTATEMENTPROTO']._serialized_end=60303
  _globals['_ASTMODULESTATEMENTPROTO']._serialized_start=60306
  _globals['_ASTMODULESTATEMENTPROTO']._serialized_end=60474
  _globals['_ASTWITHCONNECTIONCLAUSEPROTO']._serialized_start=60477
  _globals['_ASTWITHCONNECTIONCLAUSEPROTO']._serialized_end=60608
  _globals['_ASTINTOALIASPROTO']._serialized_start=60610
  _globals['_ASTINTOALIASPROTO']._serialized_end=60717
  _globals['_ASTUNNESTEXPRESSIONWITHOPTALIASANDOFFSETPROTO']._serialized_start=60720
  _globals['_ASTUNNESTEXPRESSIONWITHOPTALIASANDOFFSETPROTO']._serialized_end=60975
  _globals['_ASTPIVOTEXPRESSIONPROTO']._serialized_start=60978
  _globals['_ASTPIVOTEXPRESSIONPROTO']._serialized_end=61133
  _globals['_ASTPIVOTVALUEPROTO']._serialized_start=61136
  _globals['_ASTPIVOTVALUEPROTO']._serialized_end=61281
  _globals['_ASTPIVOTEXPRESSIONLISTPROTO']._serialized_start=61283
  _globals['_ASTPIVOTEXPRESSIONLISTPROTO']._serialized_end=61406
  _globals['_ASTPIVOTVALUELISTPROTO']._serialized_start=61408
  _globals['_ASTPIVOTVALUELISTPROTO']._serialized_end=61516
  _globals['_ASTPIVOTCLAUSEPROTO']._serialized_start=61519
  _globals['_ASTPIVOTCLAUSEPROTO']._serialized_end=61817
  _globals['_ASTUNPIVOTINITEMPROTO']._serialized_start=61820
  _globals['_ASTUNPIVOTINITEMPROTO']._serialized_end=61996
  _globals['_ASTUNPIVOTINITEMLISTPROTO']._serialized_start=61998
  _globals['_ASTUNPIVOTINITEMLISTPROTO']._serialized_end=62114
  _globals['_ASTUNPIVOTCLAUSEPROTO']._serialized_start=62117
  _globals['_ASTUNPIVOTCLAUSEPROTO']._serialized_end=62511
  _globals['_ASTUSINGCLAUSEPROTO']._serialized_start=62513
  _globals['_ASTUSINGCLAUSEPROTO']._serialized_end=62616
  _globals['_ASTFORSYSTEMTIMEPROTO']._serialized_start=62618
  _globals['_ASTFORSYSTEMTIMEPROTO']._serialized_end=62732
  _globals['_ASTMATCHRECOGNIZECLAUSEPROTO']._serialized_start=62735
  _globals['_ASTMATCHRECOGNIZECLAUSEPROTO']._serialized_end=63263
  _globals['_ASTAFTERMATCHSKIPCLAUSEPROTO']._serialized_start=63266
  _globals['_ASTAFTERMATCHSKIPCLAUSEPROTO']._serialized_end=63420
  _globals['_ANYASTROWPATTERNEXPRESSIONPROTO']._serialized_start=63423
  _globals['_ANYASTROWPATTERNEXPRESSIONPROTO']._serialized_end=63863
  _globals['_ASTROWPATTERNEXPRESSIONPROTO']._serialized_start=63865
  _globals['_ASTROWPATTERNEXPRESSIONPROTO']._serialized_end=63957
  _globals['_ASTROWPATTERNVARIABLEPROTO']._serialized_start=63959
  _globals['_ASTROWPATTERNVARIABLEPROTO']._serialized_end=64085
  _globals['_ASTROWPATTERNOPERATIONPROTO']._serialized_start=64088
  _globals['_ASTROWPATTERNOPERATIONPROTO']._serialized_end=64299
  _globals['_ASTEMPTYROWPATTERNPROTO']._serialized_start=64301
  _globals['_ASTEMPTYROWPATTERNPROTO']._serialized_end=64381
  _globals['_ASTROWPATTERNANCHORPROTO']._serialized_start=64384
  _globals['_ASTROWPATTERNANCHORPROTO']._serialized_end=64523
  _globals['_ANYASTQUANTIFIERPROTO']._serialized_start=64526
  _globals['_ANYASTQUANTIFIERPROTO']._serialized_end=64779
  _globals['_ASTQUANTIFIERPROTO']._serialized_start=64781
  _globals['_ASTQUANTIFIERPROTO']._serialized_end=64862
  _globals['_ASTBOUNDEDQUANTIFIERPROTO']._serialized_start=64865
  _globals['_ASTBOUNDEDQUANTIFIERPROTO']._serialized_end=65047
  _globals['_ASTQUANTIFIERBOUNDPROTO']._serialized_start=65049
  _globals['_ASTQUANTIFIERBOUNDPROTO']._serialized_end=65160
  _globals['_ASTFIXEDQUANTIFIERPROTO']._serialized_start=65162
  _globals['_ASTFIXEDQUANTIFIERPROTO']._serialized_end=65279
  _globals['_ASTSYMBOLQUANTIFIERPROTO']._serialized_start=65282
  _globals['_ASTSYMBOLQUANTIFIERPROTO']._serialized_end=65411
  _globals['_ASTROWPATTERNQUANTIFICATIONPROTO']._serialized_start=65414
  _globals['_ASTROWPATTERNQUANTIFICATIONPROTO']._serialized_end=65614
  _globals['_ASTQUALIFYPROTO']._serialized_start=65616
  _globals['_ASTQUALIFYPROTO']._serialized_end=65724
  _globals['_ASTCLAMPEDBETWEENMODIFIERPROTO']._serialized_start=65727
  _globals['_ASTCLAMPEDBETWEENMODIFIERPROTO']._serialized_end=65889
  _globals['_ASTWITHREPORTMODIFIERPROTO']._serialized_start=65891
  _globals['_ASTWITHREPORTMODIFIERPROTO']._serialized_end=66010
  _globals['_ASTFORMATCLAUSEPROTO']._serialized_start=66013
  _globals['_ASTFORMATCLAUSEPROTO']._serialized_end=66178
  _globals['_ASTPATHEXPRESSIONLISTPROTO']._serialized_start=66181
  _globals['_ASTPATHEXPRESSIONLISTPROTO']._serialized_end=66311
  _globals['_ASTPARAMETEREXPRPROTO']._serialized_start=66314
  _globals['_ASTPARAMETEREXPRPROTO']._serialized_end=66450
  _globals['_ASTSYSTEMVARIABLEEXPRPROTO']._serialized_start=66452
  _globals['_ASTSYSTEMVARIABLEEXPRPROTO']._serialized_end=66579
  _globals['_ASTLAMBDAPROTO']._serialized_start=66582
  _globals['_ASTLAMBDAPROTO']._serialized_end=66744
  _globals['_ASTANALYTICFUNCTIONCALLPROTO']._serialized_start=66747
  _globals['_ASTANALYTICFUNCTIONCALLPROTO']._serialized_end=66930
  _globals['_ASTCLUSTERBYPROTO']._serialized_start=66932
  _globals['_ASTCLUSTERBYPROTO']._serialized_end=67054
  _globals['_ASTNEWCONSTRUCTORARGPROTO']._serialized_start=67057
  _globals['_ASTNEWCONSTRUCTORARGPROTO']._serialized_end=67300
  _globals['_ASTNEWCONSTRUCTORPROTO']._serialized_start=67303
  _globals['_ASTNEWCONSTRUCTORPROTO']._serialized_end=67475
  _globals['_ASTBRACEDCONSTRUCTORLHSPROTO']._serialized_start=67478
  _globals['_ASTBRACEDCONSTRUCTORLHSPROTO']._serialized_end=67696
  _globals['_ASTBRACEDCONSTRUCTORFIELDVALUEPROTO']._serialized_start=67699
  _globals['_ASTBRACEDCONSTRUCTORFIELDVALUEPROTO']._serialized_end=67851
  _globals['_ASTBRACEDCONSTRUCTORFIELDPROTO']._serialized_start=67854
  _globals['_ASTBRACEDCONSTRUCTORFIELDPROTO']._serialized_end=68082
  _globals['_ASTBRACEDCONSTRUCTORPROTO']._serialized_start=68085
  _globals['_ASTBRACEDCONSTRUCTORPROTO']._serialized_end=68214
  _globals['_ASTBRACEDNEWCONSTRUCTORPROTO']._serialized_start=68217
  _globals['_ASTBRACEDNEWCONSTRUCTORPROTO']._serialized_end=68404
  _globals['_ASTEXTENDEDPATHEXPRESSIONPROTO']._serialized_start=68407
  _globals['_ASTEXTENDEDPATHEXPRESSIONPROTO']._serialized_end=68658
  _globals['_ASTUPDATECONSTRUCTORPROTO']._serialized_start=68661
  _globals['_ASTUPDATECONSTRUCTORPROTO']._serialized_end=68846
  _globals['_ASTSTRUCTBRACEDCONSTRUCTORPROTO']._serialized_start=68849
  _globals['_ASTSTRUCTBRACEDCONSTRUCTORPROTO']._serialized_end=69036
  _globals['_ASTOPTIONSLISTPROTO']._serialized_start=69038
  _globals['_ASTOPTIONSLISTPROTO']._serialized_end=69154
  _globals['_ASTOPTIONSENTRYPROTO']._serialized_start=69157
  _globals['_ASTOPTIONSENTRYPROTO']._serialized_end=69375
  _globals['_ANYASTCREATESTATEMENTPROTO']._serialized_start=69378
  _globals['_ANYASTCREATESTATEMENTPROTO']._serialized_end=70891
  _globals['_ASTCREATESTATEMENTPROTO']._serialized_start=70894
  _globals['_ASTCREATESTATEMENTPROTO']._serialized_end=71070
  _globals['_ASTFUNCTIONPARAMETERPROTO']._serialized_start=71073
  _globals['_ASTFUNCTIONPARAMETERPROTO']._serialized_end=71558
  _globals['_ASTFUNCTIONPARAMETERSPROTO']._serialized_start=71561
  _globals['_ASTFUNCTIONPARAMETERSPROTO']._serialized_end=71691
  _globals['_ASTFUNCTIONDECLARATIONPROTO']._serialized_start=71694
  _globals['_ASTFUNCTIONDECLARATIONPROTO']._serialized_end=71866
  _globals['_ASTSQLFUNCTIONBODYPROTO']._serialized_start=71868
  _globals['_ASTSQLFUNCTIONBODYPROTO']._serialized_end=71984
  _globals['_ASTTVFARGUMENTPROTO']._serialized_start=71987
  _globals['_ASTTVFARGUMENTPROTO']._serialized_end=72302
  _globals['_ASTTVFPROTO']._serialized_start=72305
  _globals['_ASTTVFPROTO']._serialized_end=72567
  _globals['_ASTTABLECLAUSEPROTO']._serialized_start=72570
  _globals['_ASTTABLECLAUSEPROTO']._serialized_end=72781
  _globals['_ASTMODELCLAUSEPROTO']._serialized_start=72783
  _globals['_ASTMODELCLAUSEPROTO']._serialized_end=72896
  _globals['_ASTCONNECTIONCLAUSEPROTO']._serialized_start=72898
  _globals['_ASTCONNECTIONCLAUSEPROTO']._serialized_end=73020
  _globals['_ANYASTTABLEDATASOURCEPROTO']._serialized_start=73023
  _globals['_ANYASTTABLEDATASOURCEPROTO']._serialized_end=73203
  _globals['_ASTTABLEDATASOURCEPROTO']._serialized_start=73206
  _globals['_ASTTABLEDATASOURCEPROTO']._serialized_end=73442
  _globals['_ASTCLONEDATASOURCEPROTO']._serialized_start=73444
  _globals['_ASTCLONEDATASOURCEPROTO']._serialized_end=73519
  _globals['_ASTCOPYDATASOURCEPROTO']._serialized_start=73521
  _globals['_ASTCOPYDATASOURCEPROTO']._serialized_end=73595
  _globals['_ASTCLONEDATASOURCELISTPROTO']._serialized_start=73597
  _globals['_ASTCLONEDATASOURCELISTPROTO']._serialized_end=73721
  _globals['_ASTCLONEDATASTATEMENTPROTO']._serialized_start=73724
  _globals['_ASTCLONEDATASTATEMENTPROTO']._serialized_end=73914
  _globals['_ASTCREATECONNECTIONSTATEMENTPROTO']._serialized_start=73917
  _globals['_ASTCREATECONNECTIONSTATEMENTPROTO']._serialized_end=74101
  _globals['_ASTCREATECONSTANTSTATEMENTPROTO']._serialized_start=74104
  _globals['_ASTCREATECONSTANTSTATEMENTPROTO']._serialized_end=74280
  _globals['_ASTCREATEDATABASESTATEMENTPROTO']._serialized_start=74283
  _globals['_ASTCREATEDATABASESTATEMENTPROTO']._serialized_end=74459
  _globals['_ASTCREATEPROCEDURESTATEMENTPROTO']._serialized_start=74462
  _globals['_ASTCREATEPROCEDURESTATEMENTPROTO']._serialized_end=74978
  _globals['_ANYASTCREATESCHEMASTMTBASEPROTO']._serialized_start=74981
  _globals['_ANYASTCREATESCHEMASTMTBASEPROTO']._serialized_end=75209
  _globals['_ASTCREATESCHEMASTMTBASEPROTO']._serialized_start=75212
  _globals['_ASTCREATESCHEMASTMTBASEPROTO']._serialized_end=75391
  _globals['_ASTCREATESCHEMASTATEMENTPROTO']._serialized_start=75394
  _globals['_ASTCREATESCHEMASTATEMENTPROTO']._serialized_end=75523
  _globals['_ASTCREATEEXTERNALSCHEMASTATEMENTPROTO']._serialized_start=75526
  _globals['_ASTCREATEEXTERNALSCHEMASTATEMENTPROTO']._serialized_end=75691
  _globals['_ASTALIASEDQUERYLISTPROTO']._serialized_start=75693
  _globals['_ASTALIASEDQUERYLISTPROTO']._serialized_end=75817
  _globals['_ASTTRANSFORMCLAUSEPROTO']._serialized_start=75819
  _globals['_ASTTRANSFORMCLAUSEPROTO']._serialized_end=75933
  _globals['_ASTCREATEMODELSTATEMENTPROTO']._serialized_start=75936
  _globals['_ASTCREATEMODELSTATEMENTPROTO']._serialized_end=76432
  _globals['_ASTINDEXALLCOLUMNSPROTO']._serialized_start=76435
  _globals['_ASTINDEXALLCOLUMNSPROTO']._serialized_end=76564
  _globals['_ASTINDEXITEMLISTPROTO']._serialized_start=76567
  _globals['_ASTINDEXITEMLISTPROTO']._serialized_end=76696
  _globals['_ASTINDEXSTORINGEXPRESSIONLISTPROTO']._serialized_start=76699
  _globals['_ASTINDEXSTORINGEXPRESSIONLISTPROTO']._serialized_end=76827
  _globals['_ASTINDEXUNNESTEXPRESSIONLISTPROTO']._serialized_start=76830
  _globals['_ASTINDEXUNNESTEXPRESSIONLISTPROTO']._serialized_end=76988
  _globals['_ASTCREATEINDEXSTATEMENTPROTO']._serialized_start=76991
  _globals['_ASTCREATEINDEXSTATEMENTPROTO']._serialized_end=77743
  _globals['_ASTEXPORTDATASTATEMENTPROTO']._serialized_start=77746
  _globals['_ASTEXPORTDATASTATEMENTPROTO']._serialized_end=77981
  _globals['_ASTEXPORTMODELSTATEMENTPROTO']._serialized_start=77984
  _globals['_ASTEXPORTMODELSTATEMENTPROTO']._serialized_end=78239
  _globals['_ASTEXPORTMETADATASTATEMENTPROTO']._serialized_start=78242
  _globals['_ASTEXPORTMETADATASTATEMENTPROTO']._serialized_end=78549
  _globals['_ASTCALLSTATEMENTPROTO']._serialized_start=78552
  _globals['_ASTCALLSTATEMENTPROTO']._serialized_end=78725
  _globals['_ASTDEFINETABLESTATEMENTPROTO']._serialized_start=78728
  _globals['_ASTDEFINETABLESTATEMENTPROTO']._serialized_end=78901
  _globals['_ASTCREATELOCALITYGROUPSTATEMENTPROTO']._serialized_start=78904
  _globals['_ASTCREATELOCALITYGROUPSTATEMENTPROTO']._serialized_end=79085
  _globals['_ASTWITHPARTITIONCOLUMNSCLAUSEPROTO']._serialized_start=79088
  _globals['_ASTWITHPARTITIONCOLUMNSCLAUSEPROTO']._serialized_end=79226
  _globals['_ASTCREATESNAPSHOTSTATEMENTPROTO']._serialized_start=79229
  _globals['_ASTCREATESNAPSHOTSTATEMENTPROTO']._serialized_end=79527
  _globals['_ASTCREATESNAPSHOTTABLESTATEMENTPROTO']._serialized_start=79530
  _globals['_ASTCREATESNAPSHOTTABLESTATEMENTPROTO']._serialized_end=79778
  _globals['_ASTTYPEPARAMETERLISTPROTO']._serialized_start=79780
  _globals['_ASTTYPEPARAMETERLISTPROTO']._serialized_end=79892
  _globals['_ASTTVFSCHEMAPROTO']._serialized_start=79894
  _globals['_ASTTVFSCHEMAPROTO']._serialized_end=80003
  _globals['_ASTTVFSCHEMACOLUMNPROTO']._serialized_start=80006
  _globals['_ASTTVFSCHEMACOLUMNPROTO']._serialized_end=80153
  _globals['_ASTTABLEANDCOLUMNINFOPROTO']._serialized_start=80156
  _globals['_ASTTABLEANDCOLUMNINFOPROTO']._serialized_end=80326
  _globals['_ASTTABLEANDCOLUMNINFOLISTPROTO']._serialized_start=80329
  _globals['_ASTTABLEANDCOLUMNINFOLISTPROTO']._serialized_end=80476
  _globals['_ASTTEMPLATEDPARAMETERTYPEPROTO']._serialized_start=80479
  _globals['_ASTTEMPLATEDPARAMETERTYPEPROTO']._serialized_end=80623
  _globals['_ASTDEFAULTLITERALPROTO']._serialized_start=80625
  _globals['_ASTDEFAULTLITERALPROTO']._serialized_end=80694
  _globals['_ASTANALYZESTATEMENTPROTO']._serialized_start=80697
  _globals['_ASTANALYZESTATEMENTPROTO']._serialized_end=80896
  _globals['_ASTASSERTSTATEMENTPROTO']._serialized_start=80899
  _globals['_ASTASSERTSTATEMENTPROTO']._serialized_end=81067
  _globals['_ASTASSERTROWSMODIFIEDPROTO']._serialized_start=81069
  _globals['_ASTASSERTROWSMODIFIEDPROTO']._serialized_end=81186
  _globals['_ASTRETURNINGCLAUSEPROTO']._serialized_start=81189
  _globals['_ASTRETURNINGCLAUSEPROTO']._serialized_end=81349
  _globals['_ASTONCONFLICTCLAUSEPROTO']._serialized_start=81352
  _globals['_ASTONCONFLICTCLAUSEPROTO']._serialized_end=81727
  _globals['_ASTDELETESTATEMENTPROTO']._serialized_start=81730
  _globals['_ASTDELETESTATEMENTPROTO']._serialized_end=82155
  _globals['_ANYASTCOLUMNATTRIBUTEPROTO']._serialized_start=82158
  _globals['_ANYASTCOLUMNATTRIBUTEPROTO']._serialized_end=82555
  _globals['_ASTCOLUMNATTRIBUTEPROTO']._serialized_start=82557
  _globals['_ASTCOLUMNATTRIBUTEPROTO']._serialized_end=82621
  _globals['_ASTNOTNULLCOLUMNATTRIBUTEPROTO']._serialized_start=82623
  _globals['_ASTNOTNULLCOLUMNATTRIBUTEPROTO']._serialized_end=82705
  _globals['_ASTHIDDENCOLUMNATTRIBUTEPROTO']._serialized_start=82707
  _globals['_ASTHIDDENCOLUMNATTRIBUTEPROTO']._serialized_end=82788
  _globals['_ASTPRIMARYKEYCOLUMNATTRIBUTEPROTO']._serialized_start=82790
  _globals['_ASTPRIMARYKEYCOLUMNATTRIBUTEPROTO']._serialized_end=82893
  _globals['_ASTFOREIGNKEYCOLUMNATTRIBUTEPROTO']._serialized_start=82896
  _globals['_ASTFOREIGNKEYCOLUMNATTRIBUTEPROTO']._serialized_end=83092
  _globals['_ASTCOLUMNATTRIBUTELISTPROTO']._serialized_start=83094
  _globals['_ASTCOLUMNATTRIBUTELISTPROTO']._serialized_end=83215
  _globals['_ASTSTRUCTCOLUMNFIELDPROTO']._serialized_start=83218
  _globals['_ASTSTRUCTCOLUMNFIELDPROTO']._serialized_end=83377
  _globals['_ASTGENERATEDCOLUMNINFOPROTO']._serialized_start=83380
  _globals['_ASTGENERATEDCOLUMNINFOPROTO']._serialized_end=83713
  _globals['_ANYASTTABLEELEMENTPROTO']._serialized_start=83716
  _globals['_ANYASTTABLEELEMENTPROTO']._serialized_end=83898
  _globals['_ASTTABLEELEMENTPROTO']._serialized_start=83900
  _globals['_ASTTABLEELEMENTPROTO']._serialized_end=83961
  _globals['_ASTCOLUMNDEFINITIONPROTO']._serialized_start=83964
  _globals['_ASTCOLUMNDEFINITIONPROTO']._serialized_end=84130
  _globals['_ASTTABLEELEMENTLISTPROTO']._serialized_start=84132
  _globals['_ASTTABLEELEMENTLISTPROTO']._serialized_end=84249
  _globals['_ASTCOLUMNLISTPROTO']._serialized_start=84251
  _globals['_ASTCOLUMNLISTPROTO']._serialized_end=84360
  _globals['_ASTCOLUMNPOSITIONPROTO']._serialized_start=84363
  _globals['_ASTCOLUMNPOSITIONPROTO']._serialized_end=84543
  _globals['_ASTINSERTVALUESROWPROTO']._serialized_start=84545
  _globals['_ASTINSERTVALUESROWPROTO']._serialized_end=84657
  _globals['_ASTINSERTVALUESROWLISTPROTO']._serialized_start=84659
  _globals['_ASTINSERTVALUESROWLISTPROTO']._serialized_end=84775
  _globals['_ASTINSERTSTATEMENTPROTO']._serialized_start=84778
  _globals['_ASTINSERTSTATEMENTPROTO']._serialized_end=85370
  _globals['_ASTUPDATESETVALUEPROTO']._serialized_start=85373
  _globals['_ASTUPDATESETVALUEPROTO']._serialized_end=85544
  _globals['_ASTUPDATEITEMPROTO']._serialized_start=85547
  _globals['_ASTUPDATEITEMPROTO']._serialized_end=85838
  _globals['_ASTUPDATEITEMLISTPROTO']._serialized_start=85840
  _globals['_ASTUPDATEITEMLISTPROTO']._serialized_end=85954
  _globals['_ASTUPDATESTATEMENTPROTO']._serialized_start=85957
  _globals['_ASTUPDATESTATEMENTPROTO']._serialized_end=86491
  _globals['_ASTTRUNCATESTATEMENTPROTO']._serialized_start=86494
  _globals['_ASTTRUNCATESTATEMENTPROTO']._serialized_end=86666
  _globals['_ASTMERGEACTIONPROTO']._serialized_start=86669
  _globals['_ASTMERGEACTIONPROTO']._serialized_end=86961
  _globals['_ASTMERGEWHENCLAUSEPROTO']._serialized_start=86964
  _globals['_ASTMERGEWHENCLAUSEPROTO']._serialized_end=87196
  _globals['_ASTMERGEWHENCLAUSELISTPROTO']._serialized_start=87198
  _globals['_ASTMERGEWHENCLAUSELISTPROTO']._serialized_end=87321
  _globals['_ASTMERGESTATEMENTPROTO']._serialized_start=87324
  _globals['_ASTMERGESTATEMENTPROTO']._serialized_end=87665
  _globals['_ASTPRIVILEGEPROTO']._serialized_start=87668
  _globals['_ASTPRIVILEGEPROTO']._serialized_end=87833
  _globals['_ASTPRIVILEGESPROTO']._serialized_start=87835
  _globals['_ASTPRIVILEGESPROTO']._serialized_end=87942
  _globals['_ASTGRANTEELISTPROTO']._serialized_start=87944
  _globals['_ASTGRANTEELISTPROTO']._serialized_end=88058
  _globals['_ASTGRANTSTATEMENTPROTO']._serialized_start=88061
  _globals['_ASTGRANTSTATEMENTPROTO']._serialized_end=88340
  _globals['_ASTREVOKESTATEMENTPROTO']._serialized_start=88343
  _globals['_ASTREVOKESTATEMENTPROTO']._serialized_end=88623
  _globals['_ASTREPEATABLECLAUSEPROTO']._serialized_start=88625
  _globals['_ASTREPEATABLECLAUSEPROTO']._serialized_end=88740
  _globals['_ASTFILTERFIELDSARGPROTO']._serialized_start=88743
  _globals['_ASTFILTERFIELDSARGPROTO']._serialized_end=88945
  _globals['_ASTREPLACEFIELDSARGPROTO']._serialized_start=88948
  _globals['_ASTREPLACEFIELDSARGPROTO']._serialized_end=89137
  _globals['_ASTREPLACEFIELDSEXPRESSIONPROTO']._serialized_start=89140
  _globals['_ASTREPLACEFIELDSEXPRESSIONPROTO']._serialized_end=89318
  _globals['_ASTSAMPLESIZEPROTO']._serialized_start=89321
  _globals['_ASTSAMPLESIZEPROTO']._serialized_end=89526
  _globals['_ASTWITHWEIGHTPROTO']._serialized_start=89528
  _globals['_ASTWITHWEIGHTPROTO']._serialized_end=89626
  _globals['_ASTSAMPLESUFFIXPROTO']._serialized_start=89629
  _globals['_ASTSAMPLESUFFIXPROTO']._serialized_end=89786
  _globals['_ASTSAMPLECLAUSEPROTO']._serialized_start=89789
  _globals['_ASTSAMPLECLAUSEPROTO']._serialized_end=90022
  _globals['_ANYASTALTERACTIONPROTO']._serialized_start=90025
  _globals['_ANYASTALTERACTIONPROTO']._serialized_end=93021
  _globals['_ASTALTERACTIONPROTO']._serialized_start=93023
  _globals['_ASTALTERACTIONPROTO']._serialized_end=93083
  _globals['_ASTSETOPTIONSACTIONPROTO']._serialized_start=93085
  _globals['_ASTSETOPTIONSACTIONPROTO']._serialized_end=93209
  _globals['_ASTSETASACTIONPROTO']._serialized_start=93212
  _globals['_ASTSETASACTIONPROTO']._serialized_end=93379
  _globals['_ASTADDCONSTRAINTACTIONPROTO']._serialized_start=93382
  _globals['_ASTADDCONSTRAINTACTIONPROTO']._serialized_end=93540
  _globals['_ASTDROPPRIMARYKEYACTIONPROTO']._serialized_start=93542
  _globals['_ASTDROPPRIMARYKEYACTIONPROTO']._serialized_end=93640
  _globals['_ASTDROPCONSTRAINTACTIONPROTO']._serialized_start=93643
  _globals['_ASTDROPCONSTRAINTACTIONPROTO']._serialized_end=93795
  _globals['_ASTALTERCONSTRAINTENFORCEMENTACTIONPROTO']._serialized_start=93798
  _globals['_ASTALTERCONSTRAINTENFORCEMENTACTIONPROTO']._serialized_end=93983
  _globals['_ASTALTERCONSTRAINTSETOPTIONSACTIONPROTO']._serialized_start=93986
  _globals['_ASTALTERCONSTRAINTSETOPTIONSACTIONPROTO']._serialized_end=94201
  _globals['_ASTADDCOLUMNIDENTIFIERACTIONPROTO']._serialized_start=94204
  _globals['_ASTADDCOLUMNIDENTIFIERACTIONPROTO']._serialized_end=94413
  _globals['_ASTADDCOLUMNACTIONPROTO']._serialized_start=94416
  _globals['_ASTADDCOLUMNACTIONPROTO']._serialized_end=94690
  _globals['_ASTDROPCOLUMNACTIONPROTO']._serialized_start=94693
  _globals['_ASTDROPCOLUMNACTIONPROTO']._serialized_end=94837
  _globals['_ASTRENAMECOLUMNACTIONPROTO']._serialized_start=94840
  _globals['_ASTRENAMECOLUMNACTIONPROTO']._serialized_end=95040
  _globals['_ASTALTERCOLUMNTYPEACTIONPROTO']._serialized_start=95043
  _globals['_ASTALTERCOLUMNTYPEACTIONPROTO']._serialized_end=95285
  _globals['_ASTALTERCOLUMNOPTIONSACTIONPROTO']._serialized_start=95288
  _globals['_ASTALTERCOLUMNOPTIONSACTIONPROTO']._serialized_end=95492
  _globals['_ASTALTERCOLUMNSETDEFAULTACTIONPROTO']._serialized_start=95495
  _globals['_ASTALTERCOLUMNSETDEFAULTACTIONPROTO']._serialized_end=95710
  _globals['_ASTALTERCOLUMNDROPDEFAULTACTIONPROTO']._serialized_start=95713
  _globals['_ASTALTERCOLUMNDROPDEFAULTACTIONPROTO']._serialized_end=95869
  _globals['_ASTALTERCOLUMNDROPNOTNULLACTIONPROTO']._serialized_start=95872
  _globals['_ASTALTERCOLUMNDROPNOTNULLACTIONPROTO']._serialized_end=96028
  _globals['_ASTALTERCOLUMNDROPGENERATEDACTIONPROTO']._serialized_start=96031
  _globals['_ASTALTERCOLUMNDROPGENERATEDACTIONPROTO']._serialized_end=96189
  _globals['_ASTALTERCOLUMNSETGENERATEDACTIONPROTO']._serialized_start=96192
  _globals['_ASTALTERCOLUMNSETGENERATEDACTIONPROTO']._serialized_end=96418
  _globals['_ASTGRANTTOCLAUSEPROTO']._serialized_start=96421
  _globals['_ASTGRANTTOCLAUSEPROTO']._serialized_end=96580
  _globals['_ASTRESTRICTTOCLAUSEPROTO']._serialized_start=96582
  _globals['_ASTRESTRICTTOCLAUSEPROTO']._serialized_end=96709
  _globals['_ASTADDTORESTRICTEELISTCLAUSEPROTO']._serialized_start=96712
  _globals['_ASTADDTORESTRICTEELISTCLAUSEPROTO']._serialized_end=96874
  _globals['_ASTREMOVEFROMRESTRICTEELISTCLAUSEPROTO']._serialized_start=96877
  _globals['_ASTREMOVEFROMRESTRICTEELISTCLAUSEPROTO']._serialized_end=97040
  _globals['_ASTFILTERUSINGCLAUSEPROTO']._serialized_start=97043
  _globals['_ASTFILTERUSINGCLAUSEPROTO']._serialized_end=97195
  _globals['_ASTREVOKEFROMCLAUSEPROTO']._serialized_start=97198
  _globals['_ASTREVOKEFROMCLAUSEPROTO']._serialized_end=97354
  _globals['_ASTRENAMETOCLAUSEPROTO']._serialized_start=97356
  _globals['_ASTRENAMETOCLAUSEPROTO']._serialized_end=97477
  _globals['_ASTSETCOLLATECLAUSEPROTO']._serialized_start=97479
  _globals['_ASTSETCOLLATECLAUSEPROTO']._serialized_end=97594
  _globals['_ASTALTERSUBENTITYACTIONPROTO']._serialized_start=97597
  _globals['_ASTALTERSUBENTITYACTIONPROTO']._serialized_end=97830
  _globals['_ASTADDSUBENTITYACTIONPROTO']._serialized_start=97833
  _globals['_ASTADDSUBENTITYACTIONPROTO']._serialized_end=98071
  _globals['_ASTDROPSUBENTITYACTIONPROTO']._serialized_start=98074
  _globals['_ASTDROPSUBENTITYACTIONPROTO']._serialized_end=98257
  _globals['_ASTADDTTLACTIONPROTO']._serialized_start=98260
  _globals['_ASTADDTTLACTIONPROTO']._serialized_end=98406
  _globals['_ASTREPLACETTLACTIONPROTO']._serialized_start=98409
  _globals['_ASTREPLACETTLACTIONPROTO']._serialized_end=98555
  _globals['_ASTDROPTTLACTIONPROTO']._serialized_start=98557
  _globals['_ASTDROPTTLACTIONPROTO']._serialized_end=98648
  _globals['_ASTALTERACTIONLISTPROTO']._serialized_start=98650
  _globals['_ASTALTERACTIONLISTPROTO']._serialized_end=98764
  _globals['_ASTALTERALLROWACCESSPOLICIESSTATEMENTPROTO']._serialized_start=98767
  _globals['_ASTALTERALLROWACCESSPOLICIESSTATEMENTPROTO']._serialized_end=98968
  _globals['_ASTFOREIGNKEYACTIONSPROTO']._serialized_start=98971
  _globals['_ASTFOREIGNKEYACTIONSPROTO']._serialized_end=99169
  _globals['_ASTFOREIGNKEYREFERENCEPROTO']._serialized_start=99172
  _globals['_ASTFOREIGNKEYREFERENCEPROTO']._serialized_end=99473
  _globals['_ASTSCRIPTPROTO']._serialized_start=99475
  _globals['_ASTSCRIPTPROTO']._serialized_end=99591
  _globals['_ASTELSEIFCLAUSEPROTO']._serialized_start=99594
  _globals['_ASTELSEIFCLAUSEPROTO']._serialized_end=99752
  _globals['_ASTELSEIFCLAUSELISTPROTO']._serialized_start=99754
  _globals['_ASTELSEIFCLAUSELISTPROTO']._serialized_end=99874
  _globals['_ASTIFSTATEMENTPROTO']._serialized_start=99877
  _globals['_ASTIFSTATEMENTPROTO']._serialized_end=100160
  _globals['_ASTWHENTHENCLAUSEPROTO']._serialized_start=100163
  _globals['_ASTWHENTHENCLAUSEPROTO']._serialized_end=100323
  _globals['_ASTWHENTHENCLAUSELISTPROTO']._serialized_start=100325
  _globals['_ASTWHENTHENCLAUSELISTPROTO']._serialized_end=100452
  _globals['_ASTCASESTATEMENTPROTO']._serialized_start=100455
  _globals['_ASTCASESTATEMENTPROTO']._serialized_end=100695
  _globals['_ASTHINTPROTO']._serialized_start=100698
  _globals['_ASTHINTPROTO']._serialized_end=100855
  _globals['_ASTHINTENTRYPROTO']._serialized_start=100858
  _globals['_ASTHINTENTRYPROTO']._serialized_end=101054
  _globals['_ASTUNPIVOTINITEMLABELPROTO']._serialized_start=101057
  _globals['_ASTUNPIVOTINITEMLABELPROTO']._serialized_end=101226
  _globals['_ASTDESCRIPTORPROTO']._serialized_start=101228
  _globals['_ASTDESCRIPTORPROTO']._serialized_end=101343
  _globals['_ANYASTCOLUMNSCHEMAPROTO']._serialized_start=101346
  _globals['_ANYASTCOLUMNSCHEMAPROTO']._serialized_end=101722
  _globals['_ASTCOLUMNSCHEMAPROTO']._serialized_start=101725
  _globals['_ASTCOLUMNSCHEMAPROTO']._serialized_end=102129
  _globals['_ASTSIMPLECOLUMNSCHEMAPROTO']._serialized_start=102131
  _globals['_ASTSIMPLECOLUMNSCHEMAPROTO']._serialized_end=102258
  _globals['_ANYASTELEMENTTYPECOLUMNSCHEMAPROTO']._serialized_start=102261
  _globals['_ANYASTELEMENTTYPECOLUMNSCHEMAPROTO']._serialized_end=102459
  _globals['_ASTELEMENTTYPECOLUMNSCHEMAPROTO']._serialized_start=102462
  _globals['_ASTELEMENTTYPECOLUMNSCHEMAPROTO']._serialized_end=102600
  _globals['_ASTARRAYCOLUMNSCHEMAPROTO']._serialized_start=102602
  _globals['_ASTARRAYCOLUMNSCHEMAPROTO']._serialized_end=102687
  _globals['_ASTRANGECOLUMNSCHEMAPROTO']._serialized_start=102689
  _globals['_ASTRANGECOLUMNSCHEMAPROTO']._serialized_end=102774
  _globals['_ASTPRIMARYKEYELEMENTPROTO']._serialized_start=102777
  _globals['_ASTPRIMARYKEYELEMENTPROTO']._serialized_end=103009
  _globals['_ASTPRIMARYKEYELEMENTLISTPROTO']._serialized_start=103011
  _globals['_ASTPRIMARYKEYELEMENTLISTPROTO']._serialized_end=103135
  _globals['_ANYASTTABLECONSTRAINTPROTO']._serialized_start=103138
  _globals['_ANYASTTABLECONSTRAINTPROTO']._serialized_end=103370
  _globals['_ASTTABLECONSTRAINTPROTO']._serialized_start=103372
  _globals['_ASTTABLECONSTRAINTPROTO']._serialized_end=103444
  _globals['_ASTPRIMARYKEYPROTO']._serialized_start=103447
  _globals['_ASTPRIMARYKEYPROTO']._serialized_end=103703
  _globals['_ASTFOREIGNKEYPROTO']._serialized_start=103706
  _globals['_ASTFOREIGNKEYPROTO']._serialized_end=103989
  _globals['_ASTCHECKCONSTRAINTPROTO']._serialized_start=103992
  _globals['_ASTCHECKCONSTRAINTPROTO']._serialized_end=104246
  _globals['_ASTDESCRIPTORCOLUMNPROTO']._serialized_start=104248
  _globals['_ASTDESCRIPTORCOLUMNPROTO']._serialized_end=104356
  _globals['_ASTDESCRIPTORCOLUMNLISTPROTO']._serialized_start=104359
  _globals['_ASTDESCRIPTORCOLUMNLISTPROTO']._serialized_end=104495
  _globals['_ASTCREATEENTITYSTATEMENTPROTO']._serialized_start=104498
  _globals['_ASTCREATEENTITYSTATEMENTPROTO']._serialized_end=104821
  _globals['_ASTRAISESTATEMENTPROTO']._serialized_start=104823
  _globals['_ASTRAISESTATEMENTPROTO']._serialized_end=104946
  _globals['_ASTEXCEPTIONHANDLERPROTO']._serialized_start=104948
  _globals['_ASTEXCEPTIONHANDLERPROTO']._serialized_end=105069
  _globals['_ASTEXCEPTIONHANDLERLISTPROTO']._serialized_start=105072
  _globals['_ASTEXCEPTIONHANDLERLISTPROTO']._serialized_end=105208
  _globals['_ASTBEGINENDBLOCKPROTO']._serialized_start=105211
  _globals['_ASTBEGINENDBLOCKPROTO']._serialized_end=105445
  _globals['_ASTIDENTIFIERLISTPROTO']._serialized_start=105447
  _globals['_ASTIDENTIFIERLISTPROTO']._serialized_end=105564
  _globals['_ASTVARIABLEDECLARATIONPROTO']._serialized_start=105567
  _globals['_ASTVARIABLEDECLARATIONPROTO']._serialized_end=105797
  _globals['_ASTUNTILCLAUSEPROTO']._serialized_start=105799
  _globals['_ASTUNTILCLAUSEPROTO']._serialized_end=105910
  _globals['_ANYASTBREAKCONTINUESTATEMENTPROTO']._serialized_start=105913
  _globals['_ANYASTBREAKCONTINUESTATEMENTPROTO']._serialized_end=106102
  _globals['_ASTBREAKCONTINUESTATEMENTPROTO']._serialized_start=106104
  _globals['_ASTBREAKCONTINUESTATEMENTPROTO']._serialized_end=106225
  _globals['_ASTBREAKSTATEMENTPROTO']._serialized_start=106228
  _globals['_ASTBREAKSTATEMENTPROTO']._serialized_end=106388
  _globals['_ASTCONTINUESTATEMENTPROTO']._serialized_start=106391
  _globals['_ASTCONTINUESTATEMENTPROTO']._serialized_end=106554
  _globals['_ASTDROPPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_start=106557
  _globals['_ASTDROPPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_end=106820
  _globals['_ASTDROPROWACCESSPOLICYSTATEMENTPROTO']._serialized_start=106823
  _globals['_ASTDROPROWACCESSPOLICYSTATEMENTPROTO']._serialized_end=107030
  _globals['_ASTCREATEPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_start=107033
  _globals['_ASTCREATEPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_end=107335
  _globals['_ASTCREATEROWACCESSPOLICYSTATEMENTPROTO']._serialized_start=107338
  _globals['_ASTCREATEROWACCESSPOLICYSTATEMENTPROTO']._serialized_end=107665
  _globals['_ASTDROPSTATEMENTPROTO']._serialized_start=107668
  _globals['_ASTDROPSTATEMENTPROTO']._serialized_end=107922
  _globals['_ASTRETURNSTATEMENTPROTO']._serialized_start=107924
  _globals['_ASTRETURNSTATEMENTPROTO']._serialized_end=107999
  _globals['_ASTSINGLEASSIGNMENTPROTO']._serialized_start=108002
  _globals['_ASTSINGLEASSIGNMENTPROTO']._serialized_end=108177
  _globals['_ASTPARAMETERASSIGNMENTPROTO']._serialized_start=108180
  _globals['_ASTPARAMETERASSIGNMENTPROTO']._serialized_end=108356
  _globals['_ASTSYSTEMVARIABLEASSIGNMENTPROTO']._serialized_start=108359
  _globals['_ASTSYSTEMVARIABLEASSIGNMENTPROTO']._serialized_end=108551
  _globals['_ASTASSIGNMENTFROMSTRUCTPROTO']._serialized_start=108554
  _globals['_ASTASSIGNMENTFROMSTRUCTPROTO']._serialized_end=108745
  _globals['_ANYASTCREATETABLESTMTBASEPROTO']._serialized_start=108748
  _globals['_ANYASTCREATETABLESTMTBASEPROTO']._serialized_end=109055
  _globals['_ASTCREATETABLESTMTBASEPROTO']._serialized_start=109058
  _globals['_ASTCREATETABLESTMTBASEPROTO']._serialized_end=109471
  _globals['_ASTCREATETABLESTATEMENTPROTO']._serialized_start=109474
  _globals['_ASTCREATETABLESTATEMENTPROTO']._serialized_end=109921
  _globals['_ASTCREATEEXTERNALTABLESTATEMENTPROTO']._serialized_start=109924
  _globals['_ASTCREATEEXTERNALTABLESTATEMENTPROTO']._serialized_end=110100
  _globals['_ANYASTCREATEVIEWSTATEMENTBASEPROTO']._serialized_start=110103
  _globals['_ANYASTCREATEVIEWSTATEMENTBASEPROTO']._serialized_end=110428
  _globals['_ASTCREATEVIEWSTATEMENTBASEPROTO']._serialized_start=110431
  _globals['_ASTCREATEVIEWSTATEMENTBASEPROTO']._serialized_end=110813
  _globals['_ASTCREATEVIEWSTATEMENTPROTO']._serialized_start=110815
  _globals['_ASTCREATEVIEWSTATEMENTPROTO']._serialized_end=110902
  _globals['_ASTCREATEMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_start=110905
  _globals['_ASTCREATEMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_end=111161
  _globals['_ASTCREATEAPPROXVIEWSTATEMENTPROTO']._serialized_start=111163
  _globals['_ASTCREATEAPPROXVIEWSTATEMENTPROTO']._serialized_end=111256
  _globals['_ANYASTLOOPSTATEMENTPROTO']._serialized_start=111259
  _globals['_ANYASTLOOPSTATEMENTPROTO']._serialized_end=111506
  _globals['_ASTLOOPSTATEMENTPROTO']._serialized_start=111509
  _globals['_ASTLOOPSTATEMENTPROTO']._serialized_end=111667
  _globals['_ASTWHILESTATEMENTPROTO']._serialized_start=111669
  _globals['_ASTWHILESTATEMENTPROTO']._serialized_end=111792
  _globals['_ASTREPEATSTATEMENTPROTO']._serialized_start=111794
  _globals['_ASTREPEATSTATEMENTPROTO']._serialized_end=111919
  _globals['_ASTFORINSTATEMENTPROTO']._serialized_start=111922
  _globals['_ASTFORINSTATEMENTPROTO']._serialized_end=112080
  _globals['_ANYASTALTERSTATEMENTBASEPROTO']._serialized_start=112083
  _globals['_ANYASTALTERSTATEMENTBASEPROTO']._serialized_end=113386
  _globals['_ASTALTERSTATEMENTBASEPROTO']._serialized_start=113389
  _globals['_ASTALTERSTATEMENTBASEPROTO']._serialized_end=113588
  _globals['_ASTALTERCONNECTIONSTATEMENTPROTO']._serialized_start=113590
  _globals['_ASTALTERCONNECTIONSTATEMENTPROTO']._serialized_end=113677
  _globals['_ASTALTERDATABASESTATEMENTPROTO']._serialized_start=113679
  _globals['_ASTALTERDATABASESTATEMENTPROTO']._serialized_end=113764
  _globals['_ASTALTERSCHEMASTATEMENTPROTO']._serialized_start=113766
  _globals['_ASTALTERSCHEMASTATEMENTPROTO']._serialized_end=113849
  _globals['_ASTALTEREXTERNALSCHEMASTATEMENTPROTO']._serialized_start=113851
  _globals['_ASTALTEREXTERNALSCHEMASTATEMENTPROTO']._serialized_end=113942
  _globals['_ASTALTERTABLESTATEMENTPROTO']._serialized_start=113944
  _globals['_ASTALTERTABLESTATEMENTPROTO']._serialized_end=114026
  _globals['_ASTALTERVIEWSTATEMENTPROTO']._serialized_start=114028
  _globals['_ASTALTERVIEWSTATEMENTPROTO']._serialized_end=114109
  _globals['_ASTALTERMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_start=114111
  _globals['_ASTALTERMATERIALIZEDVIEWSTATEMENTPROTO']._serialized_end=114204
  _globals['_ASTALTERAPPROXVIEWSTATEMENTPROTO']._serialized_start=114206
  _globals['_ASTALTERAPPROXVIEWSTATEMENTPROTO']._serialized_end=114293
  _globals['_ASTALTERMODELSTATEMENTPROTO']._serialized_start=114295
  _globals['_ASTALTERMODELSTATEMENTPROTO']._serialized_end=114377
  _globals['_ASTALTERPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_start=114380
  _globals['_ASTALTERPRIVILEGERESTRICTIONSTATEMENTPROTO']._serialized_end=114576
  _globals['_ASTALTERROWACCESSPOLICYSTATEMENTPROTO']._serialized_start=114579
  _globals['_ASTALTERROWACCESSPOLICYSTATEMENTPROTO']._serialized_end=114714
  _globals['_ASTALTERENTITYSTATEMENTPROTO']._serialized_start=114716
  _globals['_ASTALTERENTITYSTATEMENTPROTO']._serialized_end=114842
  _globals['_ASTREBUILDACTIONPROTO']._serialized_start=114844
  _globals['_ASTREBUILDACTIONPROTO']._serialized_end=114913
  _globals['_ASTALTERINDEXSTATEMENTPROTO']._serialized_start=114916
  _globals['_ASTALTERINDEXSTATEMENTPROTO']._serialized_end=115119
  _globals['_ANYASTCREATEFUNCTIONSTMTBASEPROTO']._serialized_start=115122
  _globals['_ANYASTCREATEFUNCTIONSTMTBASEPROTO']._serialized_end=115354
  _globals['_ASTCREATEFUNCTIONSTMTBASEPROTO']._serialized_start=115357
  _globals['_ASTCREATEFUNCTIONSTMTBASEPROTO']._serialized_end=115805
  _globals['_ASTCREATEFUNCTIONSTATEMENTPROTO']._serialized_start=115808
  _globals['_ASTCREATEFUNCTIONSTATEMENTPROTO']._serialized_end=116118
  _globals['_ASTCREATETABLEFUNCTIONSTATEMENTPROTO']._serialized_start=116121
  _globals['_ASTCREATETABLEFUNCTIONSTATEMENTPROTO']._serialized_end=116310
  _globals['_ASTSTRUCTCOLUMNSCHEMAPROTO']._serialized_start=116313
  _globals['_ASTSTRUCTCOLUMNSCHEMAPROTO']._serialized_end=116447
  _globals['_ASTINFERREDTYPECOLUMNSCHEMAPROTO']._serialized_start=116449
  _globals['_ASTINFERREDTYPECOLUMNSCHEMAPROTO']._serialized_end=116530
  _globals['_ASTEXECUTEINTOCLAUSEPROTO']._serialized_start=116532
  _globals['_ASTEXECUTEINTOCLAUSEPROTO']._serialized_end=116652
  _globals['_ASTEXECUTEUSINGARGUMENTPROTO']._serialized_start=116655
  _globals['_ASTEXECUTEUSINGARGUMENTPROTO']._serialized_end=116815
  _globals['_ASTEXECUTEUSINGCLAUSEPROTO']._serialized_start=116817
  _globals['_ASTEXECUTEUSINGCLAUSEPROTO']._serialized_end=116942
  _globals['_ASTEXECUTEIMMEDIATESTATEMENTPROTO']._serialized_start=116945
  _globals['_ASTEXECUTEIMMEDIATESTATEMENTPROTO']._serialized_end=117185
  _globals['_ASTAUXLOADDATAFROMFILESOPTIONSLISTPROTO']._serialized_start=117188
  _globals['_ASTAUXLOADDATAFROMFILESOPTIONSLISTPROTO']._serialized_end=117320
  _globals['_ASTAUXLOADDATAPARTITIONSCLAUSEPROTO']._serialized_start=117323
  _globals['_ASTAUXLOADDATAPARTITIONSCLAUSEPROTO']._serialized_end=117479
  _globals['_ASTAUXLOADDATASTATEMENTPROTO']._serialized_start=117482
  _globals['_ASTAUXLOADDATASTATEMENTPROTO']._serialized_end=118003
  _globals['_ASTLABELPROTO']._serialized_start=118005
  _globals['_ASTLABELPROTO']._serialized_end=118102
  _globals['_ASTWITHEXPRESSIONPROTO']._serialized_start=118105
  _globals['_ASTWITHEXPRESSIONPROTO']._serialized_end=118274
  _globals['_ASTTTLCLAUSEPROTO']._serialized_start=118276
  _globals['_ASTTTLCLAUSEPROTO']._serialized_end=118386
  _globals['_ASTLOCATIONPROTO']._serialized_start=118388
  _globals['_ASTLOCATIONPROTO']._serialized_end=118445
  _globals['_ASTINPUTOUTPUTCLAUSEPROTO']._serialized_start=118448
  _globals['_ASTINPUTOUTPUTCLAUSEPROTO']._serialized_end=118615
  _globals['_ASTSPANNERTABLEOPTIONSPROTO']._serialized_start=118618
  _globals['_ASTSPANNERTABLEOPTIONSPROTO']._serialized_end=118805
  _globals['_ASTSPANNERINTERLEAVECLAUSEPROTO']._serialized_start=118808
  _globals['_ASTSPANNERINTERLEAVECLAUSEPROTO']._serialized_end=119053
  _globals['_ASTSPANNERALTERCOLUMNACTIONPROTO']._serialized_start=119056
  _globals['_ASTSPANNERALTERCOLUMNACTIONPROTO']._serialized_end=119198
  _globals['_ASTSPANNERSETONDELETEACTIONPROTO']._serialized_start=119201
  _globals['_ASTSPANNERSETONDELETEACTIONPROTO']._serialized_end=119340
  _globals['_ASTRANGELITERALPROTO']._serialized_start=119343
  _globals['_ASTRANGELITERALPROTO']._serialized_end=119505
  _globals['_ASTRANGETYPEPROTO']._serialized_start=119508
  _globals['_ASTRANGETYPEPROTO']._serialized_end=119718
  _globals['_ASTCREATEPROPERTYGRAPHSTATEMENTPROTO']._serialized_start=119721
  _globals['_ASTCREATEPROPERTYGRAPHSTATEMENTPROTO']._serialized_end=120038
  _globals['_ASTGRAPHELEMENTTABLELISTPROTO']._serialized_start=120041
  _globals['_ASTGRAPHELEMENTTABLELISTPROTO']._serialized_end=120171
  _globals['_ASTGRAPHELEMENTTABLEPROTO']._serialized_start=120174
  _globals['_ASTGRAPHELEMENTTABLEPROTO']._serialized_end=120729
  _globals['_ASTGRAPHNODETABLEREFERENCEPROTO']._serialized_start=120732
  _globals['_ASTGRAPHNODETABLEREFERENCEPROTO']._serialized_end=121067
  _globals['_ASTGRAPHELEMENTLABELANDPROPERTIESLISTPROTO']._serialized_start=121070
  _globals['_ASTGRAPHELEMENTLABELANDPROPERTIESLISTPROTO']._serialized_end=121233
  _globals['_ASTGRAPHELEMENTLABELANDPROPERTIESPROTO']._serialized_start=121236
  _globals['_ASTGRAPHELEMENTLABELANDPROPERTIESPROTO']._serialized_end=121476
  _globals['_ASTGRAPHDERIVEDPROPERTYPROTO']._serialized_start=121479
  _globals['_ASTGRAPHDERIVEDPROPERTYPROTO']._serialized_end=121691
  _globals['_ASTGRAPHDERIVEDPROPERTYLISTPROTO']._serialized_start=121694
  _globals['_ASTGRAPHDERIVEDPROPERTYLISTPROTO']._serialized_end=121826
  _globals['_ASTGRAPHPROPERTIESPROTO']._serialized_start=121829
  _globals['_ASTGRAPHPROPERTIESPROTO']._serialized_end=122047
  _globals['_ASTGRAPHDYNAMICLABELPROTO']._serialized_start=122049
  _globals['_ASTGRAPHDYNAMICLABELPROTO']._serialized_end=122162
  _globals['_ASTGRAPHDYNAMICPROPERTIESPROTO']._serialized_start=122164
  _globals['_ASTGRAPHDYNAMICPROPERTIESPROTO']._serialized_end=122287
  _globals['_ASTGRAPHPATTERNPROTO']._serialized_start=122290
  _globals['_ASTGRAPHPATTERNPROTO']._serialized_end=122453
  _globals['_ASTGQLQUERYPROTO']._serialized_start=122455
  _globals['_ASTGQLQUERYPROTO']._serialized_end=122578
  _globals['_ASTGQLGRAPHPATTERNQUERYPROTO']._serialized_start=122581
  _globals['_ASTGQLGRAPHPATTERNQUERYPROTO']._serialized_end=122773
  _globals['_ASTGQLLINEAROPSQUERYPROTO']._serialized_start=122776
  _globals['_ASTGQLLINEAROPSQUERYPROTO']._serialized_end=122965
  _globals['_ASTGRAPHTABLEQUERYPROTO']._serialized_start=122968
  _globals['_ASTGRAPHTABLEQUERYPROTO']._serialized_end=123247
  _globals['_ANYASTGRAPHLABELEXPRESSIONPROTO']._serialized_start=123250
  _globals['_ANYASTGRAPHLABELEXPRESSIONPROTO']._serialized_end=123528
  _globals['_ASTGRAPHLABELEXPRESSIONPROTO']._serialized_start=123530
  _globals['_ASTGRAPHLABELEXPRESSIONPROTO']._serialized_end=123622
  _globals['_ASTGRAPHELEMENTLABELPROTO']._serialized_start=123624
  _globals['_ASTGRAPHELEMENTLABELPROTO']._serialized_end=123749
  _globals['_ASTGRAPHWILDCARDLABELPROTO']._serialized_start=123751
  _globals['_ASTGRAPHWILDCARDLABELPROTO']._serialized_end=123834
  _globals['_ASTGRAPHLABELOPERATIONPROTO']._serialized_start=123837
  _globals['_ASTGRAPHLABELOPERATIONPROTO']._serialized_end=124048
  _globals['_ASTGRAPHLABELFILTERPROTO']._serialized_start=124051
  _globals['_ASTGRAPHLABELFILTERPROTO']._serialized_end=124184
  _globals['_ASTGRAPHISLABELEDPREDICATEPROTO']._serialized_start=124187
  _globals['_ASTGRAPHISLABELEDPREDICATEPROTO']._serialized_end=124398
  _globals['_ASTGRAPHELEMENTPATTERNFILLERPROTO']._serialized_start=124401
  _globals['_ASTGRAPHELEMENTPATTERNFILLERPROTO']._serialized_end=124801
  _globals['_ASTGRAPHPROPERTYSPECIFICATIONPROTO']._serialized_start=124804
  _globals['_ASTGRAPHPROPERTYSPECIFICATIONPROTO']._serialized_end=124956
  _globals['_ASTGRAPHPROPERTYNAMEANDVALUEPROTO']._serialized_start=124959
  _globals['_ASTGRAPHPROPERTYNAMEANDVALUEPROTO']._serialized_end=125132
  _globals['_ANYASTGRAPHPATHBASEPROTO']._serialized_start=125135
  _globals['_ANYASTGRAPHPATHBASEPROTO']._serialized_end=125328
  _globals['_ASTGRAPHPATHBASEPROTO']._serialized_start=125330
  _globals['_ASTGRAPHPATHBASEPROTO']._serialized_end=125444
  _globals['_ANYASTGRAPHELEMENTPATTERNPROTO']._serialized_start=125447
  _globals['_ANYASTGRAPHELEMENTPATTERNPROTO']._serialized_end=125637
  _globals['_ASTGRAPHELEMENTPATTERNPROTO']._serialized_start=125640
  _globals['_ASTGRAPHELEMENTPATTERNPROTO']._serialized_end=125777
  _globals['_ASTGRAPHNODEPATTERNPROTO']._serialized_start=125779
  _globals['_ASTGRAPHNODEPATTERNPROTO']._serialized_end=125859
  _globals['_ASTGRAPHLHSHINTPROTO']._serialized_start=125861
  _globals['_ASTGRAPHLHSHINTPROTO']._serialized_end=125959
  _globals['_ASTGRAPHRHSHINTPROTO']._serialized_start=125961
  _globals['_ASTGRAPHRHSHINTPROTO']._serialized_end=126059
  _globals['_ASTGRAPHPATHSEARCHPREFIXPROTO']._serialized_start=126062
  _globals['_ASTGRAPHPATHSEARCHPREFIXPROTO']._serialized_end=126272
  _globals['_ASTGRAPHPATHSEARCHPREFIXCOUNTPROTO']._serialized_start=126274
  _globals['_ASTGRAPHPATHSEARCHPREFIXCOUNTPROTO']._serialized_end=126401
  _globals['_ASTGRAPHEDGEPATTERNPROTO']._serialized_start=126404
  _globals['_ASTGRAPHEDGEPATTERNPROTO']._serialized_end=126654
  _globals['_ASTGRAPHPATHMODEPROTO']._serialized_start=126656
  _globals['_ASTGRAPHPATHMODEPROTO']._serialized_end=126778
  _globals['_ASTGRAPHPATHPATTERNPROTO']._serialized_start=126781
  _globals['_ASTGRAPHPATHPATTERNPROTO']._serialized_end=127192
  _globals['_ANYASTGQLOPERATORPROTO']._serialized_start=127195
  _globals['_ANYASTGQLOPERATORPROTO']._serialized_end=127922
  _globals['_ASTGQLOPERATORPROTO']._serialized_start=127924
  _globals['_ASTGQLOPERATORPROTO']._serialized_end=127984
  _globals['_ASTGQLMATCHPROTO']._serialized_start=127987
  _globals['_ASTGQLMATCHPROTO']._serialized_end=128160
  _globals['_ASTGQLRETURNPROTO']._serialized_start=128163
  _globals['_ASTGQLRETURNPROTO']._serialized_end=128328
  _globals['_ASTGQLWITHPROTO']._serialized_start=128330
  _globals['_ASTGQLWITHPROTO']._serialized_end=128434
  _globals['_ASTGQLFORPROTO']._serialized_start=128437
  _globals['_ASTGQLFORPROTO']._serialized_end=128650
  _globals['_ANYASTGQLCALLBASEPROTO']._serialized_start=128653
  _globals['_ANYASTGQLCALLBASEPROTO']._serialized_end=128838
  _globals['_ASTGQLCALLBASEPROTO']._serialized_start=128841
  _globals['_ASTGQLCALLBASEPROTO']._serialized_end=129011
  _globals['_ASTGQLNAMEDCALLPROTO']._serialized_start=129014
  _globals['_ASTGQLNAMEDCALLPROTO']._serialized_end=129176
  _globals['_ASTYIELDITEMLISTPROTO']._serialized_start=129178
  _globals['_ASTYIELDITEMLISTPROTO']._serialized_end=129302
  _globals['_ASTGQLINLINESUBQUERYCALLPROTO']._serialized_start=129304
  _globals['_ASTGQLINLINESUBQUERYCALLPROTO']._serialized_end=129423
  _globals['_ASTGQLLETPROTO']._serialized_start=129426
  _globals['_ASTGQLLETPROTO']._serialized_end=129569
  _globals['_ASTGQLLETVARIABLEDEFINITIONLISTPROTO']._serialized_start=129572
  _globals['_ASTGQLLETVARIABLEDEFINITIONLISTPROTO']._serialized_end=129722
  _globals['_ASTGQLLETVARIABLEDEFINITIONPROTO']._serialized_start=129725
  _globals['_ASTGQLLETVARIABLEDEFINITIONPROTO']._serialized_end=129899
  _globals['_ASTGQLFILTERPROTO']._serialized_start=129901
  _globals['_ASTGQLFILTERPROTO']._serialized_end=130015
  _globals['_ASTGQLOPERATORLISTPROTO']._serialized_start=130017
  _globals['_ASTGQLOPERATORLISTPROTO']._serialized_end=130140
  _globals['_ASTGQLSETOPERATIONPROTO']._serialized_start=130143
  _globals['_ASTGQLSETOPERATIONPROTO']._serialized_end=130324
  _globals['_ASTGQLPAGELIMITPROTO']._serialized_start=130326
  _globals['_ASTGQLPAGELIMITPROTO']._serialized_end=130434
  _globals['_ASTGQLPAGEOFFSETPROTO']._serialized_start=130436
  _globals['_ASTGQLPAGEOFFSETPROTO']._serialized_end=130546
  _globals['_ASTGQLPAGEPROTO']._serialized_start=130549
  _globals['_ASTGQLPAGEPROTO']._serialized_end=130699
  _globals['_ASTGQLORDERBYANDPAGEPROTO']._serialized_start=130702
  _globals['_ASTGQLORDERBYANDPAGEPROTO']._serialized_end=130859
  _globals['_ASTGQLSAMPLEPROTO']._serialized_start=130861
  _globals['_ASTGQLSAMPLEPROTO']._serialized_end=130973
  _globals['_ASTSELECTWITHPROTO']._serialized_start=130976
  _globals['_ASTSELECTWITHPROTO']._serialized_end=131131
  _globals['_ASTCOLUMNWITHOPTIONSPROTO']._serialized_start=131134
  _globals['_ASTCOLUMNWITHOPTIONSPROTO']._serialized_end=131295
  _globals['_ASTCOLUMNWITHOPTIONSLISTPROTO']._serialized_start=131298
  _globals['_ASTCOLUMNWITHOPTIONSLISTPROTO']._serialized_end=131433
  _globals['_ASTMACROBODYPROTO']._serialized_start=131435
  _globals['_ASTMACROBODYPROTO']._serialized_end=131502
  _globals['_ASTDEFINEMACROSTATEMENTPROTO']._serialized_start=131505
  _globals['_ASTDEFINEMACROSTATEMENTPROTO']._serialized_end=131664
  _globals['_ASTUNDROPSTATEMENTPROTO']._serialized_start=131667
  _globals['_ASTUNDROPSTATEMENTPROTO']._serialized_end=131976
  _globals['_ASTIDENTITYCOLUMNINFOPROTO']._serialized_start=131979
  _globals['_ASTIDENTITYCOLUMNINFOPROTO']._serialized_end=132331
  _globals['_ASTIDENTITYCOLUMNSTARTWITHPROTO']._serialized_start=132333
  _globals['_ASTIDENTITYCOLUMNSTARTWITHPROTO']._serialized_end=132452
  _globals['_ASTIDENTITYCOLUMNINCREMENTBYPROTO']._serialized_start=132454
  _globals['_ASTIDENTITYCOLUMNINCREMENTBYPROTO']._serialized_end=132575
  _globals['_ASTIDENTITYCOLUMNMAXVALUEPROTO']._serialized_start=132577
  _globals['_ASTIDENTITYCOLUMNMAXVALUEPROTO']._serialized_end=132695
  _globals['_ASTIDENTITYCOLUMNMINVALUEPROTO']._serialized_start=132697
  _globals['_ASTIDENTITYCOLUMNMINVALUEPROTO']._serialized_end=132815
  _globals['_ASTALIASEDQUERYMODIFIERSPROTO']._serialized_start=132818
  _globals['_ASTALIASEDQUERYMODIFIERSPROTO']._serialized_end=132963
  _globals['_ASTINTORUNBOUNDEDPROTO']._serialized_start=132965
  _globals['_ASTINTORUNBOUNDEDPROTO']._serialized_end=133081
  _globals['_ASTRECURSIONDEPTHMODIFIERPROTO']._serialized_start=133084
  _globals['_ASTRECURSIONDEPTHMODIFIERPROTO']._serialized_end=133302
  _globals['_ASTMAPTYPEPROTO']._serialized_start=133305
  _globals['_ASTMAPTYPEPROTO']._serialized_end=133555
  _globals['_ASTLOCKMODEPROTO']._serialized_start=133557
  _globals['_ASTLOCKMODEPROTO']._serialized_end=133676
  _globals['_ASTPIPERECURSIVEUNIONPROTO']._serialized_start=133679
  _globals['_ASTPIPERECURSIVEUNIONPROTO']._serialized_end=134043
  _globals['_ASTRUNSTATEMENTPROTO']._serialized_start=134046
  _globals['_ASTRUNSTATEMENTPROTO']._serialized_end=134291
  _globals['_ASTCREATESEQUENCESTATEMENTPROTO']._serialized_start=134294
  _globals['_ASTCREATESEQUENCESTATEMENTPROTO']._serialized_end=134476
  _globals['_ASTALTERSEQUENCESTATEMENTPROTO']._serialized_start=134478
  _globals['_ASTALTERSEQUENCESTATEMENTPROTO']._serialized_end=134563
# @@protoc_insertion_point(module_scope)
